@@ -1,27 +1,24 @@
-/*-
-# MOTIF/X-BASED BARREL(tm)
-#
-#  xbarrel.c
-#
-###
-#
-#  Copyright (c) 2003 - 2007	David A. Bagley, bagleyd@tux.org
-#
-#                   All Rights Reserved
-#
-#  Permission to use, copy, modify, and distribute this software and
-#  its documentation for any purpose and without fee is hereby granted,
-#  provided that the above copyright notice appear in all copies and
-#  that both that copyright notice and this permission notice appear in
-#  supporting documentation, and that the name of the author not be
-#  used in advertising or publicity pertaining to distribution of the
-#  software without specific, written prior permission.
-#
-#  This program is distributed in the hope that it will be "playable",
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-#
-*/
+/*
+ * @(#)xbarrel.c
+ *
+ * Copyright 2003 - 2008  David A. Bagley, bagleyd@tux.org
+ *
+ * All rights reserved.
+ *
+ * Permission to use, copy, modify, and distribute this software and
+ * its documentation for any purpose and without fee is hereby granted,
+ * provided that the above copyright notice appear in all copies and
+ * that both that copyright notice and this permission notice appear in
+ * supporting documentation, and that the name of the author not be
+ * used in advertising or publicity pertaining to distribution of the
+ * software without specific, written prior permission.
+ *
+ * This program is distributed in the hope that it will be "useful",
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ */
+
+/* Driver file for Barrel */
 
 /*-
   Version 7: 03/11/15 X/Windows
@@ -61,7 +58,7 @@ static BarrelRec widget;
 #include "pixmaps/mouse-l.xbm"
 #include "pixmaps/mouse-r.xbm"
 #endif
-#define PRINT_MESSAGE(b) PrintState(message, b)
+#define PRINT_MESSAGE(b) printState(message, b)
 #else
 #define PRINT_MESSAGE(b) XtWarning(b)
 #endif
@@ -93,7 +90,7 @@ static BarrelRec widget;
 
 #ifndef WINVER
 static const char aboutHelp[] = {
-"Barrel Version 7.3.2\n"
+"Barrel Version 7.4\n"
 "Send bugs (reports or fixes) to the author: "
 "David Bagley <bagleyd@tux.org>\n"
 "The latest version is at: "
@@ -225,12 +222,12 @@ static char recordDsp[MESSAGE_LENGTH] = "NOT RECORDED";
 #ifdef HAVE_MOTIF
 #define MIN_SPEED 1
 #define MAX_SPEED 50
-static Widget moves, record, message;
+static Widget movesText, recordText, message;
 static Widget orientizeSwitch, pairsSwitch, practiceSwitch;
 #if 0
-static Widget tile, face;
+static Widget tileSlider, faceSlider;
 #endif
-static Widget speed;
+static Widget speedSlider;
 static char buff[21];
 static Widget descriptionDialog, featuresDialog;
 static Widget optionsDialog, referencesDialog, aboutDialog;
@@ -253,19 +250,19 @@ static char userNameDsp[USER_NAME_LENGTH] = "";
 
 #ifdef HAVE_MOTIF
 static void
-PrintState(Widget w, char *msg)
+printState(Widget w, char *msg)
 {
 	XmString xmstr;
 
 	if (!XtIsSubclass(w, xmLabelWidgetClass))
-		XtError("PrintState() requires a Label Widget");
+		XtError("printState() requires a Label Widget");
 	xmstr = XmStringCreateLtoR(msg, XmSTRING_DEFAULT_CHARSET);
 	XtVaSetValues(w, XmNlabelString, xmstr, NULL);
 }
 #endif
 
 static void
-PrintRecords(void)
+printRecords(void)
 {
 	int k, l;
 
@@ -283,7 +280,7 @@ PrintRecords(void)
 #endif
 
 static void
-InitRecords(void)
+initRecords(void)
 {
 	int k, l;
 
@@ -296,7 +293,7 @@ InitRecords(void)
 }
 
 static void
-ReadRecords(void)
+readRecords(void)
 {
 	FILE *fp;
 	int k, l, n;
@@ -355,7 +352,7 @@ ReadRecords(void)
 }
 
 static void
-WriteRecords(void)
+writeRecords(void)
 {
 	FILE *fp;
 	int k, l;
@@ -405,7 +402,7 @@ WriteRecords(void)
 }
 
 static void
-PrintRecord(Boolean orient, Boolean pairs, Boolean practice)
+printRecord(Boolean orient, Boolean pairs, Boolean practice)
 {
 	int k = (orient) ? 1 : 0, l = (pairs) ? 1 : 0;
 
@@ -423,21 +420,21 @@ PrintRecord(Boolean orient, Boolean pairs, Boolean practice)
 			puzzleRecord[l][k].name);
 	}
 #ifdef HAVE_MOTIF
-	PrintState(record, recordDsp);
+	printState(recordText, recordDsp);
 #endif
 }
 
 static void
-PrintStatus(char *msg, int nMoves
+printStatus(char *msg, int nMoves
 #ifndef HAVE_MOTIF
 		, Boolean pairs
 #endif
 		)
 {
 #ifdef HAVE_MOTIF
-	PrintState(message, msg);
+	printState(message, msg);
 	(void) sprintf(buff, "%d", nMoves);
-	PrintState(moves, buff);
+	printState(movesText, buff);
 #else
 	if (pairs)
 		(void) sprintf(titleDsp, "%s: norm@ (%d/%s) - %s",
@@ -454,25 +451,25 @@ PrintStatus(char *msg, int nMoves
 }
 
 static Boolean
-HandleSolved(int counter, Boolean orient, Boolean pairs)
+handleSolved(int counter, Boolean orient, Boolean pairs)
 {
 	int k = (orient) ? 1 : 0, l = (pairs) ? 1 : 0;
 
 	if ((counter < puzzleRecord[l][k].score ||
 			puzzleRecord[l][k].score <= NEVER)) {
-		ReadRecords();	/* Maybe its been updated by another */
+		readRecords();	/* Maybe its been updated by another */
 		puzzleRecord[l][k].score = counter;
 		(void) strncpy(puzzleRecord[l][k].name, userNameDsp,
 			USER_NAME_LENGTH);
-		WriteRecords();
-		PrintRecord(orient, pairs, False);
+		writeRecords();
+		printRecord(orient, pairs, False);
 		return True;
 	}
 	return False;
 }
 
 static void
-Initialize(
+initialize(
 #ifdef WINVER
 BarrelWidget w, HBRUSH brush
 #else
@@ -484,7 +481,7 @@ Widget w
 	char *userName, *scoreFile;
 
 #ifdef WINVER
-	InitializePuzzle(w, brush);
+	initializePuzzle(w, brush);
 
 	w->barrel.started = FALSE;
 	orient = w->barrel.orient;
@@ -512,17 +509,17 @@ Widget w
 	if (strcmp(scoreFile, ""))
 		(void) strncpy(scoreFileName, scoreFile, FILE_NAME_LENGTH);
 	if (scoreOnly) {
-		InitRecords();
-		ReadRecords();
-		PrintRecords();
+		initRecords();
+		readRecords();
+		printRecords();
 		exit(0);
 	}
 #ifdef HAVE_MOTIF
 #if 0
 	if (tiles > MAX_TILES)
-		XtVaSetValues(tile, XmNmaximum, tiles, NULL);
-	XmScaleSetValue(tile, tiles);
-	XmScaleSetValue(face, faces);
+		XtVaSetValues(tileSlider, XmNmaximum, tiles, NULL);
+	XmScaleSetValue(tileSlider, tiles);
+	XmScaleSetValue(faceSlider, faces);
 #endif
 	XmToggleButtonSetState(orientizeSwitch, orient, True);
 	XmToggleButtonSetState(pairsSwitch, pairs, True);
@@ -531,13 +528,14 @@ Widget w
 		int delay;
 
 		XtVaGetValues(w, XtNdelay, &delay, NULL);
-		XmScaleSetValue(speed, MAX_SPEED + MIN_SPEED - delay - 1);
+		XmScaleSetValue(speedSlider,
+			MAX_SPEED + MIN_SPEED - delay - 1);
 	}
 #endif
 #endif
 	SET_STARTED(w, False);
-	InitRecords();
-	ReadRecords();
+	initRecords();
+	readRecords();
 #ifndef WINVER
 	(void) strncpy(userNameDsp, userName, USER_NAME_LENGTH);
 #endif
@@ -562,8 +560,8 @@ Widget w
 			(void) sprintf(userNameDsp, "%s", "guest");
 #endif
 	}
-	PrintRecord(orient, pairs, practice);
-	PrintStatus(messageDsp, movesDsp
+	printRecord(orient, pairs, practice);
+	printStatus(messageDsp, movesDsp
 #ifndef HAVE_MOTIF
 		, pairs
 #endif
@@ -575,7 +573,7 @@ void
 setPuzzle(BarrelWidget w, int reason)
 #else
 static void
-CallbackPuzzle(Widget w, caddr_t clientData, barrelCallbackStruct *callData)
+puzzleListener(Widget w, caddr_t clientData, barrelCallbackStruct *callData)
 #endif
 {
 #ifndef WINVER
@@ -638,7 +636,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, barrelCallbackStruct *callData)
 		if (practice) {
 			(void) strncpy(recordDsp, "practice", MESSAGE_LENGTH);
 #ifdef HAVE_MOTIF
-			PrintState(record, recordDsp);
+			printState(recordText, recordDsp);
 #endif
 		}
 		movesDsp = 0;
@@ -672,7 +670,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, barrelCallbackStruct *callData)
 		else if (cheat)
 			(void) sprintf(messageDsp,
 				"No cheating %s!!", userNameDsp);
-		else if (HandleSolved(movesDsp, orient, pairs))
+		else if (handleSolved(movesDsp, orient, pairs))
 			(void) sprintf(messageDsp,
 				"Congratulations %s!!", userNameDsp);
 		else
@@ -689,7 +687,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, barrelCallbackStruct *callData)
 		if (!practice)
 			(void) strncpy(messageDsp, "Randomize to start",
 				MESSAGE_LENGTH);
-		PrintRecord(orient, pairs, practice);
+		printRecord(orient, pairs, practice);
 #ifdef WINVER
 		w->barrel.practice = practice;
 		w->barrel.started = False;
@@ -716,7 +714,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, barrelCallbackStruct *callData)
 	case ACTION_ORIENTIZE:
 		movesDsp = 0;
 		orient = !orient;
-		PrintRecord(orient, pairs, practice);
+		printRecord(orient, pairs, practice);
 #ifdef WINVER
 		w->barrel.orient = orient;
 #else
@@ -729,7 +727,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, barrelCallbackStruct *callData)
 	case ACTION_PAIRS:
 		movesDsp = 0;
 		pairs = !pairs;
-		PrintRecord(orient, pairs, practice);
+		printRecord(orient, pairs, practice);
 #ifdef WINVER
 		w->barrel.pairs = pairs;
 #else
@@ -743,22 +741,22 @@ CallbackPuzzle(Widget w, caddr_t clientData, barrelCallbackStruct *callData)
 	case ACTION_INCX:
 		movesDsp = 0;
 		tiles++;
-		PrintRecord(tiles, faces, orient, pairs, practice);
+		printRecord(tiles, faces, orient, pairs, practice);
 #ifdef WINVER
 		w->barrel.tiles = tiles;
 #else
 		XtVaSetValues(w, XtNtiles, tiles, NULL);
 #ifdef HAVE_MOTIF
 		if (tiles > MAX_TILES)
-			XtVaSetValues(tile, XmNmaximum, tiles, NULL);
-		XmScaleSetValue(tile, tiles);
+			XtVaSetValues(tileSlider, XmNmaximum, tiles, NULL);
+		XmScaleSetValue(tileSlider, tiles);
 #endif
 #endif
 		break;
 	case ACTION_DECX:
 		movesDsp = 0;
 		tiles--;
-		PrintRecord(tiles, faces, orient, pairs, practice);
+		printRecord(tiles, faces, orient, pairs, practice);
 #ifdef WINVER
 		w->barrel.tiles = tiles;
 #else
@@ -766,33 +764,33 @@ CallbackPuzzle(Widget w, caddr_t clientData, barrelCallbackStruct *callData)
 #ifdef HAVE_MOTIF
 		XmScaleSetValue(tile, tiles);
 		if (tiles > MAX_TILES)
-			XtVaSetValues(tile, XmNmaximum, tiles, NULL);
+			XtVaSetValues(tileSlider, XmNmaximum, tiles, NULL);
 #endif
 #endif
 		break;
 	case ACTION_INCY:
 		movesDsp = 0;
 		faces++;
-		PrintRecord(tiles, faces, orient, pairs, practice);
+		printRecord(tiles, faces, orient, pairs, practice);
 #ifdef WINVER
 		w->barrel.faces = faces;
 #else
 		XtVaSetValues(w, XtNfaces, faces, NULL);
 #ifdef HAVE_MOTIF
-		XmScaleSetValue(face, faces);
+		XmScaleSetValue(faceSlider, faces);
 #endif
 #endif
 		break;
 	case ACTION_DECY:
 		movesDsp = 0;
 		faces--;
-		PrintRecord(tiles, faces, orient, pairs, practice);
+		printRecord(tiles, faces, orient, pairs, practice);
 #ifdef WINVER
 		w->barrel.faces = faces;
 #else
 		XtVaSetValues(w, XtNfaces, faces, NULL);
 #ifdef HAVE_MOTIF
-		XmScaleSetValue(face, faces);
+		XmScaleSetValue(faceSlider, faces);
 #endif
 #endif
 		break;
@@ -821,13 +819,13 @@ CallbackPuzzle(Widget w, caddr_t clientData, barrelCallbackStruct *callData)
 				XtVaSetValues(w,
 					XtNdelay, delay, NULL);
 			}
-			XmScaleSetValue(speed,
+			XmScaleSetValue(speedSlider,
 				MAX_SPEED + MIN_SPEED - delay - 1);
 		}
 		return;
 #endif
 	}
-	PrintStatus(messageDsp, movesDsp
+	printStatus(messageDsp, movesDsp
 #ifndef HAVE_MOTIF
 		, pairs
 #endif
@@ -836,15 +834,11 @@ CallbackPuzzle(Widget w, caddr_t clientData, barrelCallbackStruct *callData)
 
 #ifdef WINVER
 static LRESULT CALLBACK
-About(HWND hDlg, UINT message, WPARAM wParam, LPARAM lParam)
+about(HWND hDlg, UINT message, WPARAM wParam, LPARAM lParam)
 {
-	switch (message) {
-	case WM_COMMAND:
-		if (LOWORD(wParam) == IDOK) {
-			(void) EndDialog(hDlg, TRUE);
-			return TRUE;
-		}
-		break;
+	if (message == WM_COMMAND && LOWORD(wParam) == IDOK) {
+		(void) EndDialog(hDlg, TRUE);
+		return TRUE;
 	}
 	return FALSE;
 }
@@ -862,7 +856,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_BRUSH));
-			EnterPuzzle(&widget);
+			enterPuzzle(&widget);
 			(void) EndPaint(hWnd, &paint);
 		}
 	} else {
@@ -870,33 +864,33 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_BRUSH));
-			LeavePuzzle(&widget);
+			leavePuzzle(&widget);
 			(void) EndPaint(hWnd, &paint);
 		}
 	}
 	switch (message) {
 	case WM_CREATE:
-		Initialize(&widget, brush);
+		initialize(&widget, brush);
 		break;
 	case WM_DESTROY:
-		DestroyPuzzle(&widget, brush);
+		destroyPuzzle(&widget, brush);
 		break;
 	case WM_SIZE:
-		ResizePuzzle(&widget);
+		resizePuzzle(&widget);
 		(void) InvalidateRect(hWnd, NULL, TRUE);
 		break;
 	case WM_PAINT:
 		widget.core.hDC = BeginPaint(hWnd, &paint);
 		(void) SelectObject(widget.core.hDC,
 			GetStockObject(NULL_PEN));
-		ExposePuzzle(&widget);
+		exposePuzzle(&widget);
 		(void) EndPaint(hWnd, &paint);
 		break;
 	case WM_RBUTTONDOWN:
 		widget.core.hDC = GetDC(hWnd);
 		(void) SelectObject(widget.core.hDC,
 			GetStockObject(NULL_PEN));
-		RandomizePuzzle(&widget);
+		randomizePuzzle(&widget);
 		(void) ReleaseDC(hWnd, widget.core.hDC);
 		break;
 	case WM_LBUTTONDOWN:
@@ -904,7 +898,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 		widget.core.hDC = GetDC(hWnd);
 		(void) SelectObject(widget.core.hDC,
 			GetStockObject(NULL_PEN));
-		SelectPuzzle(&widget, LOWORD(lParam), HIWORD(lParam),
+		selectPuzzle(&widget, LOWORD(lParam), HIWORD(lParam),
 			((GetKeyState(VK_SHIFT) >> 1) ||
 			(GetKeyState(VK_CAPITAL) & 1)));
 		(void) ReleaseDC(hWnd, widget.core.hDC);
@@ -916,7 +910,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 				widget.core.hDC = GetDC(hWnd);
 				(void) SelectObject(widget.core.hDC,
 					GetStockObject(NULL_PEN));
-				ReleasePuzzle(&widget,
+				releasePuzzle(&widget,
 					LOWORD(lParam), HIWORD(lParam),
 					((GetKeyState(VK_SHIFT) >> 1) ||
 					(GetKeyState(VK_CAPITAL) & 1)));
@@ -927,7 +921,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 		widget.core.hDC = GetDC(hWnd);
 		(void) SelectObject(widget.core.hDC,
 			GetStockObject(NULL_PEN));
-		MotionPuzzle(&widget, LOWORD(lParam), HIWORD(lParam),
+		motionPuzzle(&widget, LOWORD(lParam), HIWORD(lParam),
 			((GetKeyState(VK_SHIFT) >> 1) ||
 			(GetKeyState(VK_CAPITAL) & 1)));
 		(void) ReleaseDC(hWnd, widget.core.hDC);
@@ -937,7 +931,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 		widget.core.hDC = GetDC(hWnd);
 		(void) SelectObject(widget.core.hDC,
 			GetStockObject(NULL_PEN));
-		ReleasePuzzle(&widget, LOWORD(lParam), HIWORD(lParam),
+		releasePuzzle(&widget, LOWORD(lParam), HIWORD(lParam),
 			((GetKeyState(VK_SHIFT) >> 1) ||
 			(GetKeyState(VK_CAPITAL) & 1)));
 		(void) ReleaseDC(hWnd, widget.core.hDC);
@@ -955,12 +949,12 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			ClientToScreen(hWnd, &origin);
 			(void) GetCursorPos(&cursor);
 			if (zDelta > (WHEEL_DELTA >> 1)) {
-				MovePuzzleInput(&widget, cursor.x - origin.x,
+				movePuzzleInput(&widget, cursor.x - origin.x,
 					TOP,
 					((GetKeyState(VK_SHIFT) >> 1) ||
 					(GetKeyState(VK_CAPITAL) & 1)));
 			} else if (zDelta < -(WHEEL_DELTA >> 1)) {
-				MovePuzzleInput(&widget, cursor.x - origin.x,
+				movePuzzleInput(&widget, cursor.x - origin.x,
 					BOTTOM,
 					((GetKeyState(VK_SHIFT) >> 1) ||
 					(GetKeyState(VK_CAPITAL) & 1)));
@@ -972,67 +966,67 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 	case WM_COMMAND:
 		switch (LOWORD(wParam)) {
 		case ACTION_GET:
-			GetPuzzle(&widget);
-			ResizePuzzle(&widget);
+			getPuzzle(&widget);
+			resizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
 		case ACTION_WRITE:
-			WritePuzzle(&widget);
+			writePuzzle(&widget);
 			break;
 		case ACTION_EXIT:
-			DestroyPuzzle(&widget, brush);
+			destroyPuzzle(&widget, brush);
 			break;
 		case ACTION_HIDE:
-			HidePuzzle(&widget);
+			hidePuzzle(&widget);
 			break;
 		case ACTION_UNDO:
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_PEN));
-			UndoPuzzle(&widget);
+			undoPuzzle(&widget);
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
 		case ACTION_REDO:
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_PEN));
-			RedoPuzzle(&widget);
+			redoPuzzle(&widget);
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
 		case ACTION_CLEAR:
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_PEN));
-			ClearPuzzle(&widget);
+			clearPuzzle(&widget);
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
 		case ACTION_PRACTICE:
-			PracticePuzzle(&widget);
-			SizePuzzle(&widget);
+			practicePuzzle(&widget);
+			sizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
 		case ACTION_RANDOMIZE:
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_PEN));
-			RandomizePuzzle(&widget);
+			randomizePuzzle(&widget);
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
 		case ACTION_SOLVE:
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_PEN));
-			SolvePuzzle(&widget);
+			solvePuzzle(&widget);
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
 		case ACTION_ORIENTIZE:
-			OrientizePuzzle(&widget);
-			SizePuzzle(&widget);
+			orientizePuzzle(&widget);
+			sizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
 		case ACTION_PAIRS:
-			(void) PairsPuzzle(&widget);
-			SizePuzzle(&widget);
+			(void) pairsPuzzle(&widget);
+			sizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
 		case ACTION_LEFT:
@@ -1042,7 +1036,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_PEN));
-			(void) MovePuzzleInput(&widget, 0,
+			(void) movePuzzleInput(&widget, 0,
 				(int) LOWORD(wParam) - ACTION_SHIFT_UP,
 				!((int) wParam % 2));
 			(void) ReleaseDC(hWnd, widget.core.hDC);
@@ -1058,7 +1052,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 				origin.x = 0, origin.y = 0;
 				ClientToScreen(hWnd, &origin);
 				(void) GetCursorPos(&cursor);
-				(void) MovePuzzleInput(&widget,
+				(void) movePuzzleInput(&widget,
 					cursor.x - origin.x,
 					(int) LOWORD(wParam) - ACTION_UP,
 					FALSE);
@@ -1066,13 +1060,13 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			}
 			break;
 		case ACTION_SPEED:
-			SpeedPuzzle(&widget);
+			speedUpPuzzle(&widget);
 			break;
 		case ACTION_SLOW:
-			SlowPuzzle(&widget);
+			slowDownPuzzle(&widget);
 			break;
 		case ACTION_SOUND:
-			SoundPuzzle(&widget);
+			toggleSoundPuzzle(&widget);
 			break;
 		case ACTION_DESCRIPTION:
 			(void) MessageBox(hWnd, descriptionHelp,
@@ -1088,7 +1082,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			break;
 		case ACTION_ABOUT:
 			(void) DialogBox(widget.core.hInstance,
-				"About", hWnd, (DLGPROC) About);
+				"About", hWnd, (DLGPROC) about);
 			break;
 		}
 		break;
@@ -1153,7 +1147,7 @@ WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance, LPSTR lpCmdLine,
 #else
 
 static void
-Usage(char *programName)
+usage(char *programName)
 {
 	unsigned int i;
 
@@ -1216,7 +1210,7 @@ static XrmOptionDescRec options[] =
 
 #ifdef HAVE_MOTIF
 static void
-CallbackPuzzlePractice(Widget w, XtPointer clientData,
+puzzlePracticeListener(Widget w, XtPointer clientData,
 		XmAnyCallbackStruct *cbs)
 {
 	if (cbs->reason == XmCR_OK) {
@@ -1225,7 +1219,7 @@ CallbackPuzzlePractice(Widget w, XtPointer clientData,
 }
 
 static void
-CallbackPuzzleRandomize(Widget w, XtPointer clientData,
+puzzleRandomizeListener(Widget w, XtPointer clientData,
 		XmAnyCallbackStruct *cbs)
 {
 	if (cbs->reason == XmCR_OK) {
@@ -1235,7 +1229,7 @@ CallbackPuzzleRandomize(Widget w, XtPointer clientData,
 
 #if 0
 static void
-TileSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
+tileChangeListener(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 {
 	int tiles = cbs->value, faces, old;
 	Boolean orient, pairs, practice;
@@ -1252,14 +1246,14 @@ TileSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 		XtNtiles, tiles, NULL);
 	movesDsp = 0;
 	(void) sprintf(buff, "%d", movesDsp);
-	PrintState(moves, buff);
-	PrintRecord(tiles, faces, orient, pairs, practice);
+	printState(movesText, buff);
+	printRecord(tiles, faces, orient, pairs, practice);
 	(void) strcpy(messageDsp, "");
-	PrintState(message, messageDsp);
+	printState(message, messageDsp);
 }
 
 static void
-FaceSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
+faceChangeListener(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 {
 	int tiles, faces = cbs->value, old;
 	Boolean orient, pairs, practice;
@@ -1276,15 +1270,15 @@ FaceSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 		XtNfaces, faces, NULL);
 	movesDsp = 0;
 	(void) sprintf(buff, "%d", movesDsp);
-	PrintState(moves, buff);
-	PrintRecord(tiles, faces, orient, pairs, practice);
+	printState(movesText, buff);
+	printRecord(tiles, faces, orient, pairs, practice);
 	(void) strcpy(messageDsp, "");
-	PrintState(message, messageDsp);
+	printState(message, messageDsp);
 }
 #endif
 
 static void
-OrientToggle(Widget w, XtPointer clientData, XmToggleButtonCallbackStruct *cbs)
+orientToggle(Widget w, XtPointer clientData, XmToggleButtonCallbackStruct *cbs)
 {
 	Boolean orient = cbs->set, pairs, practice, oldOrient;
 	char *picture;
@@ -1304,14 +1298,14 @@ OrientToggle(Widget w, XtPointer clientData, XmToggleButtonCallbackStruct *cbs)
 		XtNorient, orient, NULL);
 	movesDsp = 0;
 	(void) sprintf(buff, "%d", movesDsp);
-	PrintState(moves, buff);
-	PrintRecord(orient, pairs, practice);
+	printState(movesText, buff);
+	printRecord(orient, pairs, practice);
 	(void) strcpy(messageDsp, "");
-	PrintState(message, messageDsp);
+	printState(message, messageDsp);
 }
 
 static void
-PairsToggle(Widget w, XtPointer clientData, XmToggleButtonCallbackStruct *cbs)
+pairsToggle(Widget w, XtPointer clientData, XmToggleButtonCallbackStruct *cbs)
 {
 	Boolean orient, pairs = cbs->set, practice, oldPairs;
 
@@ -1325,14 +1319,14 @@ PairsToggle(Widget w, XtPointer clientData, XmToggleButtonCallbackStruct *cbs)
 		XtNpairs, pairs, NULL);
 	movesDsp = 0;
 	(void) sprintf(buff, "%d", movesDsp);
-	PrintState(moves, buff);
-	PrintRecord(orient, pairs, practice);
+	printState(movesText, buff);
+	printRecord(orient, pairs, practice);
 	(void) strcpy(messageDsp, "");
-	PrintState(message, messageDsp);
+	printState(message, messageDsp);
 }
 
 static void
-PracticeToggle(Widget w, XtPointer clientData,
+practiceToggle(Widget w, XtPointer clientData,
 		XmToggleButtonCallbackStruct *cbs)
 {
 	Boolean orient, pairs, practice = cbs->set, oldPract;
@@ -1348,17 +1342,17 @@ PracticeToggle(Widget w, XtPointer clientData,
 		XtNstart, False, NULL);
 	movesDsp = 0;
 	(void) sprintf(buff, "%d", movesDsp);
-	PrintState(moves, buff);
-	PrintRecord(orient, pairs, practice);
+	printState(movesText, buff);
+	printRecord(orient, pairs, practice);
 	if (practice)
 		(void) strcpy(messageDsp, "");
 	else
 		(void) strncpy(messageDsp, "Randomize to start", MESSAGE_LENGTH);
-	PrintState(message, messageDsp);
+	printState(message, messageDsp);
 }
 
 static void
-SpeedSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
+speedChangeListener(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 {
 	int delay = MAX_SPEED + MIN_SPEED - cbs->value - 1, oldDelay;
 
@@ -1370,7 +1364,7 @@ SpeedSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 }
 
 static void
-fileCB(Widget w, void *value, void *clientData)
+fileMenuListener(Widget w, void *value, void *clientData)
 {
 	int val = (int) value + ACTION_GET;
 
@@ -1442,7 +1436,7 @@ createHelp(Widget w, char *text, char *title)
 }
 
 static void
-helpCB(Widget w, XtPointer value, XtPointer clientData)
+helpMenuListener(Widget w, XtPointer value, XtPointer clientData)
 {
 	int val = (int) value;
 
@@ -1466,7 +1460,7 @@ helpCB(Widget w, XtPointer value, XtPointer clientData)
 		{
 			char *buf;
 
-			intCat(&buf, "helpCB: %d", val);
+			intCat(&buf, "helpMenuListener: %d", val);
 			XtWarning(buf);
 			free(buf);
 		}
@@ -1495,7 +1489,7 @@ main(int argc, char **argv)
 	topLevel = XtInitialize(argv[0], "Barrel",
 		options, XtNumber(options), &argc, argv);
 	if (argc != 1)
-		Usage(argv[0]);
+		usage(argv[0]);
 
 #ifdef HAVE_MOTIF
 	menuBarPanel = XtVaCreateManagedWidget("menuBarPanel",
@@ -1515,7 +1509,7 @@ main(int argc, char **argv)
 	writeString = XmStringCreateSimple((char *) "Write");
 	quitString = XmStringCreateSimple((char *) "Quit");
 	(void) XmVaCreateSimplePulldownMenu(menuBar, (char *) "file_menu",
-		0, fileCB,
+		0, fileMenuListener,
 		XmVaPUSHBUTTON, getString, 'G', NULL, NULL,
 		XmVaPUSHBUTTON, writeString, 'W', NULL, NULL,
 		XmVaSEPARATOR,
@@ -1570,23 +1564,23 @@ main(int argc, char **argv)
 	widget = XtVaCreateManagedWidget("Description",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'D', NULL);
-		XtAddCallback(widget, XmNactivateCallback, helpCB, (char *) 0);
+		XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 0);
 	widget = XtVaCreateManagedWidget("Features",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'F', NULL);
-	XtAddCallback(widget, XmNactivateCallback, helpCB, (char *) 1);
+	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 1);
 	widget = XtVaCreateManagedWidget("Options",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'O', NULL);
-	XtAddCallback(widget, XmNactivateCallback, helpCB, (char *) 2);
+	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 2);
 	widget = XtVaCreateManagedWidget("References",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'R', NULL);
-	XtAddCallback(widget, XmNactivateCallback, helpCB, (char *) 3);
+	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 3);
 	widget = XtVaCreateManagedWidget("About",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'A', NULL);
-	XtAddCallback(widget, XmNactivateCallback, helpCB, (char *) 4);
+	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 4);
 	XtManageChild(menuBar);
 	descriptionDialog = createHelp(menuBar, (char *) descriptionHelp,
 		(char *) "Description");
@@ -1603,11 +1597,11 @@ main(int argc, char **argv)
 	practiceDialog = createQuery(topLevel,
 		(char *) "Are you sure you want to toggle the practice mode?",
 		(char *) "Practice Query",
-		(XtCallbackProc) CallbackPuzzlePractice);
+		(XtCallbackProc) puzzlePracticeListener);
 	randomizeDialog = createQuery(topLevel,
 		(char *) "Are you sure you want to randomize?",
 		(char *) "Randomize Query",
-		(XtCallbackProc) CallbackPuzzleRandomize);
+		(XtCallbackProc) puzzleRandomizeListener);
 	mainPanel = XtCreateManagedWidget("mainPanel",
 		xmPanedWindowWidgetClass, menuBarPanel,
 		NULL, 0);
@@ -1663,12 +1657,12 @@ main(int argc, char **argv)
 	(void) XtVaCreateManagedWidget("movesText",
 		xmLabelGadgetClass, movesRowCol,
 		XtVaTypedArg, XmNlabelString, XmRString, "Moves", 6, NULL);
-	moves = XtVaCreateManagedWidget("0",
+	movesText = XtVaCreateManagedWidget("0",
 		xmLabelWidgetClass, movesRowCol, NULL);
 	(void) XtVaCreateManagedWidget("recordText",
 		xmLabelGadgetClass, movesRowCol,
 		XtVaTypedArg, XmNlabelString, XmRString, "Record", 7, NULL);
-	record = XtVaCreateManagedWidget("0",
+	recordText = XtVaCreateManagedWidget("0",
 		xmLabelWidgetClass, movesRowCol, NULL);
 #if 0
 	tilesRowCol = XtVaCreateManagedWidget("tilesRowCol",
@@ -1676,7 +1670,7 @@ main(int argc, char **argv)
 		XmNnumColumns, 1,
 		XmNorientation, XmHORIZONTAL,
 		XmNpacking, XmPACK_COLUMN, NULL);
-	tile = XtVaCreateManagedWidget("tile",
+	tileSlider = XtVaCreateManagedWidget("tileSlider",
 		xmScaleWidgetClass, tilesRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Tiles", 6,
 		XmNminimum, MIN_TILES,
@@ -1684,9 +1678,9 @@ main(int argc, char **argv)
 		XmNvalue, DEFAULT_TILES,
 		XmNshowValue, True,
 		XmNorientation, XmHORIZONTAL, NULL);
-	XtAddCallback(tile, XmNvalueChangedCallback,
-		(XtCallbackProc) TileSlider, (XtPointer) NULL);
-	face = XtVaCreateManagedWidget("face",
+	XtAddCallback(tileSlider, XmNvalueChangedCallback,
+		(XtCallbackProc) tileChangeListener, (XtPointer) NULL);
+	faceSlider = XtVaCreateManagedWidget("faceSlider",
 		xmScaleWidgetClass, tilesRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Faces", 6,
 		XmNminimum, MIN_FACES,
@@ -1694,15 +1688,15 @@ main(int argc, char **argv)
 		XmNvalue, DEFAULT_FACES,
 		XmNshowValue, True,
 		XmNorientation, XmHORIZONTAL, NULL);
-	XtAddCallback(face, XmNvalueChangedCallback,
-		(XtCallbackProc) FaceSlider, (XtPointer) NULL);
+	XtAddCallback(faceSlider, XmNvalueChangedCallback,
+		(XtCallbackProc) faceChangeListener, (XtPointer) NULL);
 #endif
 	speedRowCol = XtVaCreateManagedWidget("speedRowCol",
 		xmRowColumnWidgetClass, controlPanel,
 		XmNnumColumns, 1,
 		XmNorientation, XmHORIZONTAL,
 		XmNpacking, XmPACK_COLUMN, NULL);
-	speed = XtVaCreateManagedWidget("Animation Speed",
+	speedSlider = XtVaCreateManagedWidget("speedSlider",
 		xmScaleWidgetClass, speedRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Animation Speed", 16,
 		XmNminimum, MIN_SPEED,
@@ -1710,8 +1704,8 @@ main(int argc, char **argv)
 		XmNvalue, MAX_SPEED - DEFAULT_DELAY,
 		XmNshowValue, True,
 		XmNorientation, XmHORIZONTAL, NULL);
-	XtAddCallback(speed, XmNvalueChangedCallback,
-		(XtCallbackProc) SpeedSlider, (XtPointer) NULL);
+	XtAddCallback(speedSlider, XmNvalueChangedCallback,
+		(XtCallbackProc) speedChangeListener, (XtPointer) NULL);
 	switchRowCol = XtVaCreateManagedWidget("switchRowCol",
 		xmRowColumnWidgetClass, controlPanel,
 		XmNnumColumns, 1,
@@ -1721,17 +1715,17 @@ main(int argc, char **argv)
 		xmToggleButtonWidgetClass, switchRowCol,
 		XmNset, DEFAULT_ORIENT, NULL);
 	XtAddCallback(orientizeSwitch, XmNvalueChangedCallback,
-		(XtCallbackProc) OrientToggle, (XtPointer) NULL);
+		(XtCallbackProc) orientToggle, (XtPointer) NULL);
 	pairsSwitch = XtVaCreateManagedWidget("Pairs rigid",
 		xmToggleButtonWidgetClass, switchRowCol,
 		XmNset, DEFAULT_PAIRS, NULL);
 	XtAddCallback(pairsSwitch, XmNvalueChangedCallback,
-		(XtCallbackProc) PairsToggle, (XtPointer) NULL);
+		(XtCallbackProc) pairsToggle, (XtPointer) NULL);
 	practiceSwitch = XtVaCreateManagedWidget("Practice",
 		xmToggleButtonWidgetClass, switchRowCol,
 		XmNset, DEFAULT_PRACTICE, NULL);
 	XtAddCallback(practiceSwitch, XmNvalueChangedCallback,
-		(XtCallbackProc) PracticeToggle, (XtPointer) NULL);
+		(XtCallbackProc) practiceToggle, (XtPointer) NULL);
 	messageRowCol = XtVaCreateManagedWidget("messageRowCol",
 		xmRowColumnWidgetClass, controlPanel, NULL);
 	message = XtVaCreateManagedWidget("Play Barrel! (use mouse and keypad)",
@@ -1775,14 +1769,14 @@ main(int argc, char **argv)
 #endif
 		XtNiconPixmap, pixmap, NULL);
 	XtAddCallback(puzzle, XtNselectCallback,
-		(XtCallbackProc) CallbackPuzzle, (XtPointer) NULL);
-	Initialize(puzzle);
+		(XtCallbackProc) puzzleListener, (XtPointer) NULL);
+	initialize(puzzle);
 	XtRealizeWidget(topLevel);
 	XGrabButton(XtDisplay(puzzle), (unsigned int) AnyButton, AnyModifier,
 		XtWindow(puzzle), TRUE, (unsigned int) (ButtonPressMask |
 		ButtonMotionMask | ButtonReleaseMask),
 		GrabModeAsync, GrabModeAsync, XtWindow(puzzle),
-		XCreateFontCursor(XtDisplay(puzzle), XC_crosshair));
+		XCreateFontCursor(XtDisplay(puzzle), XC_hand2));
 	XtMainLoop();
 
 #ifdef VMS
