@@ -1,27 +1,24 @@
-/*-
-# MOTIF/X-BASED CUBES
-#
-#  xcubes.c
-#
-###
-#
-#  Copyright (c) 1993 - 2008	David A. Bagley, bagleyd@tux.org
-#
-#                   All Rights Reserved
-#
-#  Permission to use, copy, modify, and distribute this software and
-#  its documentation for any purpose and without fee is hereby granted,
-#  provided that the above copyright notice appear in all copies and
-#  that both that copyright notice and this permission notice appear in
-#  supporting documentation, and that the name of the author not be
-#  used in advertising or publicity pertaining to distribution of the
-#  software without specific, written prior permission.
-#
-#  This program is distributed in the hope that it will be "playable",
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-#
-*/
+/*
+ * @(#)xcubes.c
+ *
+ * Copyright 1993 - 2008  David A. Bagley, bagleyd@tux.org
+ *
+ * All rights reserved.
+ *
+ * Permission to use, copy, modify, and distribute this software and
+ * its documentation for any purpose and without fee is hereby granted,
+ * provided that the above copyright notice appear in all copies and
+ * that both that copyright notice and this permission notice appear in
+ * supporting documentation, and that the name of the author not be
+ * used in advertising or publicity pertaining to distribution of the
+ * software without specific, written prior permission.
+ *
+ * This program is distributed in the hope that it will be "useful",
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ */
+
+/* Driver file for Cubes */
 
 #include "file.h"
 #ifdef WINVER
@@ -56,7 +53,7 @@ static CubesRec widget;
 #include "pixmaps/mouse-l.xbm"
 #include "pixmaps/mouse-r.xbm"
 #endif
-#define PRINT_MESSAGE(b) PrintState(message, b)
+#define PRINT_MESSAGE(b) printState(message, b)
 #else
 #define PRINT_MESSAGE(b) XtWarning(b)
 #endif
@@ -88,7 +85,7 @@ static CubesRec widget;
 
 #ifndef WINVER
 static const char aboutHelp[] = {
-"Cubes Version 7.3.3\n"
+"Cubes Version 7.4\n"
 "Send bugs (reports or fixes) to the author: "
 "David Bagley <bagleyd@tux.org>\n"
 "The latest version is at: "
@@ -220,7 +217,8 @@ static char recordDsp[MESSAGE_LENGTH] = "NOT RECORDED";
 #ifdef HAVE_MOTIF
 #define MIN_SPEED 1
 #define MAX_SPEED 50
-static Widget moves, record, message, blockX, blockY, blockZ, speed;
+static Widget movesText, recordText, message;
+static Widget blockXSlider, blockYSlider, blockZSlider, speedSlider;
 static char buff[21];
 static Widget descriptionDialog, featuresDialog;
 static Widget optionsDialog, referencesDialog, aboutDialog;
@@ -244,19 +242,19 @@ static char userNameDsp[USER_NAME_LENGTH] = "";
 
 #ifdef HAVE_MOTIF
 static void
-PrintState(Widget w, char *msg)
+printState(Widget w, char *msg)
 {
 	XmString xmstr;
 
 	if (!XtIsSubclass(w, xmLabelWidgetClass))
-		XtError("PrintState() requires a Label Widget");
+		XtError("printState() requires a Label Widget");
 	xmstr = XmStringCreateLtoR(msg, XmSTRING_DEFAULT_CHARSET);
 	XtVaSetValues(w, XmNlabelString, xmstr, NULL);
 }
 #endif
 
 static void
-PrintRecords(void)
+printRecords(void)
 {
 	int i, j, k;
 
@@ -275,7 +273,7 @@ PrintRecords(void)
 #endif
 
 static void
-InitRecords(void)
+initRecords(void)
 {
 	int i, j, k;
 
@@ -301,7 +299,7 @@ InitRecords(void)
 }
 
 static void
-ReadRecords(void)
+readRecords(void)
 {
 	FILE *fp;
 	int i, j, k, n;
@@ -373,7 +371,7 @@ ReadRecords(void)
 }
 
 static void
-WriteRecords(void)
+writeRecords(void)
 {
 	FILE *fp;
 	int i, j, k;
@@ -425,7 +423,7 @@ WriteRecords(void)
 }
 
 static void
-PrintRecord(int sizeX, int sizeY, int sizeZ)
+printRecord(int sizeX, int sizeY, int sizeZ)
 {
 	int i = sizeX - MIN_CUBES, j = sizeY - MIN_CUBES, k = sizeZ - MIN_CUBES;
 
@@ -438,21 +436,21 @@ PrintRecord(int sizeX, int sizeY, int sizeZ)
 			puzzleRecord[i][j][k].score, puzzleRecord[i][j][k].name);
 	}
 #ifdef HAVE_MOTIF
-	PrintState(record, recordDsp);
+	printState(recordText, recordDsp);
 #endif
 }
 
 static void
-PrintStatus(char *msg, int nMoves
+printStatus(char *msg, int nMoves
 #ifndef HAVE_MOTIF
 		, int sizeX, int sizeY, int sizeZ
 #endif
 		)
 {
 #ifdef HAVE_MOTIF
-	PrintState(message, msg);
+	printState(message, msg);
 	(void) sprintf(buff, "%d", nMoves);
-	PrintState(moves, buff);
+	printState(movesText, buff);
 #else
 	(void) sprintf(titleDsp, "%s: %dx%dx%d@ (%d/%s) - %s",
 		progDsp, sizeX, sizeY, sizeZ, nMoves, recordDsp, msg);
@@ -465,14 +463,14 @@ PrintStatus(char *msg, int nMoves
 }
 
 static Boolean
-HandleSolved(int counter, int sizeX, int sizeY, int sizeZ)
+handleSolved(int counter, int sizeX, int sizeY, int sizeZ)
 {
 	int i = sizeX - MIN_CUBES, j = sizeY - MIN_CUBES, k = sizeZ - MIN_CUBES;
 
 	if (sizeX <= MAX_CUBES && sizeY <= MAX_CUBES && sizeZ <= MAX_CUBES &&
 			(counter < puzzleRecord[i][j][k].score ||
 			puzzleRecord[i][j][k].score <= NEVER)) {
-		ReadRecords();	/* Maybe its been updated by another */
+		readRecords();	/* Maybe its been updated by another */
 
 		puzzleRecord[i][j][k].score = puzzleRecord[i][k][j].score =
 			puzzleRecord[j][i][k].score =
@@ -492,15 +490,15 @@ HandleSolved(int counter, int sizeX, int sizeY, int sizeZ)
 			USER_NAME_LENGTH);
 		(void) strncpy(puzzleRecord[k][j][i].name, userNameDsp,
 			USER_NAME_LENGTH);
-		WriteRecords();
-		PrintRecord(sizeX, sizeY, sizeZ);
+		writeRecords();
+		printRecord(sizeX, sizeY, sizeZ);
 		return True;
 	}
 	return False;
 }
 
 static void
-Initialize(
+initialize(
 #ifdef WINVER
 CubesWidget w, HBRUSH brush
 #else
@@ -512,7 +510,7 @@ Widget w
 	char *userName, *scoreFile;
 
 #ifdef WINVER
-	InitializePuzzle(w, brush);
+	initializePuzzle(w, brush);
 
 	sizeX = w->cubes.sizeX;
 	sizeY = w->cubes.sizeY;
@@ -539,32 +537,33 @@ Widget w
 	if (strcmp(scoreFile, ""))
 		(void) strncpy(scoreFileName, scoreFile, FILE_NAME_LENGTH);
 	if (scoreOnly) {
-		InitRecords();
-		ReadRecords();
-		PrintRecords();
+		initRecords();
+		readRecords();
+		printRecords();
 		exit(0);
 	}
 #ifdef HAVE_MOTIF
 	if (sizeX > MAX_CUBES)
-		XtVaSetValues(blockX, XmNmaximum, sizeX, NULL);
-	XmScaleSetValue(blockX, sizeX);
+		XtVaSetValues(blockXSlider, XmNmaximum, sizeX, NULL);
+	XmScaleSetValue(blockXSlider, sizeX);
 	if (sizeY > MAX_CUBES)
-		XtVaSetValues(blockY, XmNmaximum, sizeY, NULL);
-	XmScaleSetValue(blockY, sizeY);
+		XtVaSetValues(blockYSlider, XmNmaximum, sizeY, NULL);
+	XmScaleSetValue(blockYSlider, sizeY);
 	if (sizeZ > MAX_CUBES)
-		XtVaSetValues(blockZ, XmNmaximum, sizeZ, NULL);
-	XmScaleSetValue(blockZ, sizeZ);
+		XtVaSetValues(blockZSlider, XmNmaximum, sizeZ, NULL);
+	XmScaleSetValue(blockZSlider, sizeZ);
 	{
 		int delay;
 
 		XtVaGetValues(w, XtNdelay, &delay, NULL);
-		XmScaleSetValue(speed, MAX_SPEED + MIN_SPEED - delay - 1);
+		XmScaleSetValue(speedSlider,
+			MAX_SPEED + MIN_SPEED - delay - 1);
 	}
 #endif
 #endif
 	SET_STARTED(w, False);
-	InitRecords();
-	ReadRecords();
+	initRecords();
+	readRecords();
 #ifndef WINVER
 	(void) strncpy(userNameDsp, userName, USER_NAME_LENGTH);
 #endif
@@ -589,8 +588,8 @@ Widget w
 			(void) sprintf(userNameDsp, "%s", "guest");
 #endif
 	}
-	PrintRecord(sizeX, sizeY, sizeZ);
-	PrintStatus(messageDsp, movesDsp
+	printRecord(sizeX, sizeY, sizeZ);
+	printStatus(messageDsp, movesDsp
 #ifndef HAVE_MOTIF
 		, sizeX, sizeY, sizeZ
 #endif
@@ -602,7 +601,7 @@ void
 setPuzzle(CubesWidget w, int reason)
 #else
 static void
-CallbackPuzzle(Widget w, caddr_t clientData, cubesCallbackStruct *callData)
+puzzleListener(Widget w, caddr_t clientData, cubesCallbackStruct *callData)
 #endif
 {
 #ifndef WINVER
@@ -682,7 +681,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, cubesCallbackStruct *callData)
 		if (cheat)
 			(void) sprintf(messageDsp,
 				"No cheating %s!!", userNameDsp);
-		else if (!randomized && HandleSolved(movesDsp,
+		else if (!randomized && handleSolved(movesDsp,
 				sizeX, sizeY, sizeZ))
 			(void) sprintf(messageDsp,
 				"Congratulations %s!!", userNameDsp);
@@ -702,90 +701,90 @@ CallbackPuzzle(Widget w, caddr_t clientData, cubesCallbackStruct *callData)
 	case ACTION_INCX:
 		movesDsp = 0;
 		sizeX++;
-		PrintRecord(sizeX, sizeY, sizeZ);
+		printRecord(sizeX, sizeY, sizeZ);
 #ifdef WINVER
 		w->cubes.sizeX = sizeX;
 #else
 		XtVaSetValues(w, XtNsizeX, sizeX, NULL);
 #ifdef HAVE_MOTIF
 		if (sizeX > MAX_CUBES)
-			XtVaSetValues(blockX, XmNmaximum, sizeX, NULL);
-		XmScaleSetValue(blockX, sizeX);
+			XtVaSetValues(blockXSlider, XmNmaximum, sizeX, NULL);
+		XmScaleSetValue(blockXSlider, sizeX);
 #endif
 #endif
 		break;
 	case ACTION_DECX:
 		movesDsp = 0;
 		sizeX--;
-		PrintRecord(sizeX, sizeY, sizeZ);
+		printRecord(sizeX, sizeY, sizeZ);
 #ifdef WINVER
 		w->cubes.sizeX = sizeX;
 #else
 		XtVaSetValues(w, XtNsizeX, sizeX, NULL);
 #ifdef HAVE_MOTIF
-		XmScaleSetValue(blockX, sizeX);
+		XmScaleSetValue(blockXSlider, sizeX);
 		if (sizeX >= MAX_CUBES)
-			XtVaSetValues(blockX, XmNmaximum, sizeX, NULL);
+			XtVaSetValues(blockXSlider, XmNmaximum, sizeX, NULL);
 #endif
 #endif
 		break;
 	case ACTION_INCY:
 		movesDsp = 0;
 		sizeY++;
-		PrintRecord(sizeX, sizeY, sizeZ);
+		printRecord(sizeX, sizeY, sizeZ);
 #ifdef WINVER
 		w->cubes.sizeY = sizeY;
 #else
 		XtVaSetValues(w, XtNsizeY, sizeY, NULL);
 #ifdef HAVE_MOTIF
 		if (sizeY > MAX_CUBES)
-			XtVaSetValues(blockY, XmNmaximum, sizeY, NULL);
-		XmScaleSetValue(blockY, sizeY);
+			XtVaSetValues(blockYSlider, XmNmaximum, sizeY, NULL);
+		XmScaleSetValue(blockYSlider, sizeY);
 #endif
 #endif
 		break;
 	case ACTION_DECY:
 		movesDsp = 0;
 		sizeY--;
-		PrintRecord(sizeX, sizeY, sizeZ);
+		printRecord(sizeX, sizeY, sizeZ);
 #ifdef WINVER
 		w->cubes.sizeY = sizeY;
 #else
 		XtVaSetValues(w, XtNsizeY, sizeY, NULL);
 #ifdef HAVE_MOTIF
-		XmScaleSetValue(blockY, sizeY);
+		XmScaleSetValue(blockYSlider, sizeY);
 		if (sizeY >= MAX_CUBES)
-			XtVaSetValues(blockY, XmNmaximum, sizeY, NULL);
+			XtVaSetValues(blockYSlider, XmNmaximum, sizeY, NULL);
 #endif
 #endif
 		break;
 	case ACTION_INCZ:
 		movesDsp = 0;
 		sizeZ++;
-		PrintRecord(sizeX, sizeY, sizeZ);
+		printRecord(sizeX, sizeY, sizeZ);
 #ifdef WINVER
 		w->cubes.sizeZ = sizeZ;
 #else
 		XtVaSetValues(w, XtNsizeZ, sizeZ, NULL);
 #ifdef HAVE_MOTIF
 		if (sizeZ > MAX_CUBES)
-			XtVaSetValues(blockZ, XmNmaximum, sizeZ, NULL);
-		XmScaleSetValue(blockZ, sizeZ);
+			XtVaSetValues(blockZSlider, XmNmaximum, sizeZ, NULL);
+		XmScaleSetValue(blockZSlider, sizeZ);
 #endif
 #endif
 		break;
 	case ACTION_DECZ:
 		movesDsp = 0;
 		sizeZ--;
-		PrintRecord(sizeX, sizeY, sizeZ);
+		printRecord(sizeX, sizeY, sizeZ);
 #ifdef WINVER
 		w->cubes.sizeZ = sizeZ;
 #else
 		XtVaSetValues(w, XtNsizeZ, sizeZ, NULL);
 #ifdef HAVE_MOTIF
-		XmScaleSetValue(blockZ, sizeZ);
+		XmScaleSetValue(blockZSlider, sizeZ);
 		if (sizeZ >= MAX_CUBES)
-			XtVaSetValues(blockZ, XmNmaximum, sizeZ, NULL);
+			XtVaSetValues(blockZSlider, XmNmaximum, sizeZ, NULL);
 #endif
 #endif
 		break;
@@ -813,13 +812,13 @@ CallbackPuzzle(Widget w, caddr_t clientData, cubesCallbackStruct *callData)
 				XtVaSetValues(w,
 					XtNdelay, delay, NULL);
 			}
-			XmScaleSetValue(speed,
+			XmScaleSetValue(speedSlider,
 				MAX_SPEED + MIN_SPEED - delay - 1);
 		}
 		return;
 #endif
 	}
-	PrintStatus(messageDsp, movesDsp
+	printStatus(messageDsp, movesDsp
 #ifndef HAVE_MOTIF
 		, sizeX, sizeY, sizeZ
 #endif
@@ -828,15 +827,11 @@ CallbackPuzzle(Widget w, caddr_t clientData, cubesCallbackStruct *callData)
 
 #ifdef WINVER
 static LRESULT CALLBACK
-About(HWND hDlg, UINT message, WPARAM wParam, LPARAM lParam)
+about(HWND hDlg, UINT message, WPARAM wParam, LPARAM lParam)
 {
-	switch (message) {
-	case WM_COMMAND:
-		if (LOWORD(wParam) == IDOK) {
-			(void) EndDialog(hDlg, TRUE);
-			return TRUE;
-		}
-		break;
+	if (message == WM_COMMAND && LOWORD(wParam) == IDOK) {
+		(void) EndDialog(hDlg, TRUE);
+		return TRUE;
 	}
 	return FALSE;
 }
@@ -853,7 +848,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_BRUSH));
-			EnterPuzzle(&widget);
+			enterPuzzle(&widget);
 			(void) EndPaint(hWnd, &paint);
 		}
 	} else {
@@ -861,47 +856,47 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_BRUSH));
-			LeavePuzzle(&widget);
+			leavePuzzle(&widget);
 			(void) EndPaint(hWnd, &paint);
 		}
 	}
 	switch (message) {
 	case WM_CREATE:
-		Initialize(&widget, brush);
+		initialize(&widget, brush);
 		break;
 	case WM_DESTROY:
-		DestroyPuzzle(&widget, brush);
+		destroyPuzzle(&widget, brush);
 		break;
 	case WM_SIZE:
-		ResizePuzzle(&widget);
+		resizePuzzle(&widget);
 		(void) InvalidateRect(hWnd, NULL, TRUE);
 		break;
 	case WM_PAINT:
 		widget.core.hDC = BeginPaint(hWnd, &paint);
 		(void) SelectObject(widget.core.hDC,
 			GetStockObject(NULL_PEN));
-		ExposePuzzle(&widget);
+		exposePuzzle(&widget);
 		(void) EndPaint(hWnd, &paint);
 		break;
 	case WM_RBUTTONDOWN:
 		widget.core.hDC = GetDC(hWnd);
 		(void) SelectObject(widget.core.hDC,
 			GetStockObject(NULL_PEN));
-		ClearPuzzle(&widget);
+		clearPuzzle(&widget);
 		(void) ReleaseDC(hWnd, widget.core.hDC);
 		break;
 	case WM_LBUTTONDOWN:
 		widget.core.hDC = GetDC(hWnd);
 		(void) SelectObject(widget.core.hDC,
 			GetStockObject(NULL_PEN));
-		SelectPuzzle(&widget, LOWORD(lParam), HIWORD(lParam));
+		selectPuzzle(&widget, LOWORD(lParam), HIWORD(lParam));
 		(void) ReleaseDC(hWnd, widget.core.hDC);
 		break;
 	case WM_LBUTTONUP:
 		widget.core.hDC = GetDC(hWnd);
 		(void) SelectObject(widget.core.hDC,
 			GetStockObject(NULL_PEN));
-		ReleasePuzzle(&widget);
+		releasePuzzle(&widget);
 		(void) ReleaseDC(hWnd, widget.core.hDC);
 		break;
 #if (_WIN32_WINNT >= 0x0400) || (_WIN32_WINDOWS > 0x0400)
@@ -917,17 +912,17 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			ClientToScreen(hWnd, &origin);
 			(void) GetCursorPos(&cursor);
 			if (zDelta > (WHEEL_DELTA >> 1)) {
-				MovePuzzle(&widget, TOP,
+				movePuzzle(&widget, TOP,
 					(GetKeyState(VK_CONTROL) >> 1) ? 1 : 0);
 				if (GetKeyState(VK_CONTROL) >> 1) {
-					SizePuzzle(&widget);
+					sizePuzzle(&widget);
 					(void) InvalidateRect(hWnd, NULL, TRUE);
 				}
 			} else if (zDelta < -(WHEEL_DELTA >> 1)) {
-				MovePuzzle(&widget, BOTTOM,
+				movePuzzle(&widget, BOTTOM,
 					(GetKeyState(VK_CONTROL) >> 1) ? 1 : 0);
 				if (GetKeyState(VK_CONTROL) >> 1) {
-					SizePuzzle(&widget);
+					sizePuzzle(&widget);
 					(void) InvalidateRect(hWnd, NULL, TRUE);
 				}
 			}
@@ -938,52 +933,52 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 	case WM_COMMAND:
 		switch (LOWORD(wParam)) {
 		case ACTION_GET:
-			GetPuzzle(&widget);
-			ResizePuzzle(&widget);
+			getPuzzle(&widget);
+			resizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
 		case ACTION_WRITE:
-			WritePuzzle(&widget);
+			writePuzzle(&widget);
 			break;
 		case ACTION_EXIT:
-			DestroyPuzzle(&widget, brush);
+			destroyPuzzle(&widget, brush);
 			break;
 		case ACTION_HIDE:
-			HidePuzzle(&widget);
+			hidePuzzle(&widget);
 			break;
 		case ACTION_UNDO:
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_PEN));
-			UndoPuzzle(&widget);
+			undoPuzzle(&widget);
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
 		case ACTION_REDO:
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_PEN));
-			RedoPuzzle(&widget);
+			redoPuzzle(&widget);
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
 		case ACTION_CLEAR:
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_PEN));
-			ClearPuzzle(&widget);
+			clearPuzzle(&widget);
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
 		case ACTION_RANDOMIZE:
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_PEN));
-			RandomizePuzzle(&widget);
+			randomizePuzzle(&widget);
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
 		case ACTION_SOLVE:
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_PEN));
-			SolvePuzzle(&widget);
+			solvePuzzle(&widget);
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
 		case ACTION_UP:
@@ -995,7 +990,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_PEN));
-			(void) MovePuzzle(&widget,
+			(void) movePuzzle(&widget,
 				(int) LOWORD(wParam) - ACTION_UP, FALSE);
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
@@ -1005,21 +1000,21 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 		case ACTION_DECY:
 		case ACTION_INCZ:
 		case ACTION_DECZ:
-			if (MovePuzzle(&widget,
+			if (movePuzzle(&widget,
 					(int) LOWORD(wParam) - ACTION_DECY,
 					TRUE)) {
-				SizePuzzle(&widget);
+				sizePuzzle(&widget);
 				(void) InvalidateRect(hWnd, NULL, TRUE);
 			}
 			break;
 		case ACTION_SPEED:
-			SpeedPuzzle(&widget);
+			speedUpPuzzle(&widget);
 			break;
 		case ACTION_SLOW:
-			SlowPuzzle(&widget);
+			slowDownPuzzle(&widget);
 			break;
 		case ACTION_SOUND:
-			SoundPuzzle(&widget);
+			toggleSoundPuzzle(&widget);
 			break;
 		case ACTION_DESCRIPTION:
 			(void) MessageBox(hWnd, descriptionHelp,
@@ -1035,7 +1030,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			break;
 		case ACTION_ABOUT:
 			(void) DialogBox(widget.core.hInstance,
-				"About", hWnd, (DLGPROC) About);
+				"About", hWnd, (DLGPROC) about);
 			break;
 		}
 		break;
@@ -1100,7 +1095,7 @@ WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance, LPSTR lpCmdLine,
 #else
 
 static void
-Usage(char *programName)
+usage(char *programName)
 {
 	unsigned int i;
 
@@ -1149,7 +1144,7 @@ static XrmOptionDescRec options[] =
 
 #ifdef HAVE_MOTIF
 static void
-CallbackPuzzleClear(Widget w, XtPointer clientData, XmAnyCallbackStruct *cbs)
+puzzleListenerClear(Widget w, XtPointer clientData, XmAnyCallbackStruct *cbs)
 {
 	if (cbs->reason == XmCR_OK) {
 		XtVaSetValues(puzzle, XtNmenu, ACTION_CLEAR, NULL);
@@ -1157,7 +1152,7 @@ CallbackPuzzleClear(Widget w, XtPointer clientData, XmAnyCallbackStruct *cbs)
 }
 
 static void
-BlockXSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
+blockXChangeListener(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 {
 	int sizeX = cbs->value, sizeY, sizeZ, oldX;
 
@@ -1171,14 +1166,14 @@ BlockXSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 		XtNsizeX, sizeX, NULL);
 	movesDsp = 0;
 	(void) sprintf(buff, "%d", movesDsp);
-	PrintState(moves, buff);
-	PrintRecord(sizeX, sizeY, sizeZ);
+	printState(movesText, buff);
+	printRecord(sizeX, sizeY, sizeZ);
 	(void) strcpy(messageDsp, "");
-	PrintState(message, messageDsp);
+	printState(message, messageDsp);
 }
 
 static void
-BlockYSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
+blockYChangeListener(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 {
 	int sizeX, sizeY = cbs->value, sizeZ, oldY;
 
@@ -1192,14 +1187,14 @@ BlockYSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 		XtNsizeY, sizeY, NULL);
 	movesDsp = 0;
 	(void) sprintf(buff, "%d", movesDsp);
-	PrintState(moves, buff);
-	PrintRecord(sizeX, sizeY, sizeZ);
+	printState(movesText, buff);
+	printRecord(sizeX, sizeY, sizeZ);
 	(void) strcpy(messageDsp, "");
-	PrintState(message, messageDsp);
+	printState(message, messageDsp);
 }
 
 static void
-BlockZSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
+blockZChangeListener(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 {
 	int sizeX, sizeY, sizeZ = cbs->value, oldZ;
 
@@ -1213,14 +1208,14 @@ BlockZSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 		XtNsizeZ, sizeZ, NULL);
 	movesDsp = 0;
 	(void) sprintf(buff, "%d", movesDsp);
-	PrintState(moves, buff);
-	PrintRecord(sizeX, sizeY, sizeZ);
+	printState(movesText, buff);
+	printRecord(sizeX, sizeY, sizeZ);
 	(void) strcpy(messageDsp, "");
-	PrintState(message, messageDsp);
+	printState(message, messageDsp);
 }
 
 static void
-SpeedSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
+speedChangeListener(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 {
 	int delay = MAX_SPEED + MIN_SPEED - cbs->value - 1, oldDelay;
 
@@ -1232,7 +1227,7 @@ SpeedSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 }
 
 static void
-fileCB(Widget w, void *value, void *clientData)
+fileMenuListener(Widget w, void *value, void *clientData)
 {
 	int val = (int) value + ACTION_GET;
 
@@ -1304,7 +1299,7 @@ createHelp(Widget w, char *text, char *title)
 }
 
 static void
-helpCB(Widget w, XtPointer value, XtPointer clientData)
+helpMenuListener(Widget w, XtPointer value, XtPointer clientData)
 {
 	int val = (int) value;
 
@@ -1328,7 +1323,7 @@ helpCB(Widget w, XtPointer value, XtPointer clientData)
 		{
 			char *buf;
 
-			intCat(&buf, "helpCB: %d", val);
+			intCat(&buf, "helpMenuListener: %d", val);
 			XtWarning(buf);
 			free(buf);
 		}
@@ -1355,7 +1350,7 @@ main(int argc, char **argv)
 	topLevel = XtInitialize(argv[0], "Cubes",
 		options, XtNumber(options), &argc, argv);
 	if (argc != 1)
-		Usage(argv[0]);
+		usage(argv[0]);
 
 #ifdef HAVE_MOTIF
 	menuBarPanel = XtVaCreateManagedWidget("menuBarPanel",
@@ -1375,7 +1370,7 @@ main(int argc, char **argv)
 	writeString = XmStringCreateSimple((char *) "Write");
 	quitString = XmStringCreateSimple((char *) "Quit");
 	(void) XmVaCreateSimplePulldownMenu(menuBar, (char *) "file_menu",
-		0, fileCB,
+		0, fileMenuListener,
 		XmVaPUSHBUTTON, getString, 'G', NULL, NULL,
 		XmVaPUSHBUTTON, writeString, 'W', NULL, NULL,
 		XmVaSEPARATOR,
@@ -1421,23 +1416,23 @@ main(int argc, char **argv)
 	widget = XtVaCreateManagedWidget("Description",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'D', NULL);
-		XtAddCallback(widget, XmNactivateCallback, helpCB, (char *) 0);
+		XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 0);
 	widget = XtVaCreateManagedWidget("Features",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'F', NULL);
-	XtAddCallback(widget, XmNactivateCallback, helpCB, (char *) 1);
+	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 1);
 	widget = XtVaCreateManagedWidget("Options",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'O', NULL);
-	XtAddCallback(widget, XmNactivateCallback, helpCB, (char *) 2);
+	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 2);
 	widget = XtVaCreateManagedWidget("References",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'R', NULL);
-	XtAddCallback(widget, XmNactivateCallback, helpCB, (char *) 3);
+	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 3);
 	widget = XtVaCreateManagedWidget("About",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'A', NULL);
-	XtAddCallback(widget, XmNactivateCallback, helpCB, (char *) 4);
+	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 4);
 	XtManageChild(menuBar);
 	descriptionDialog = createHelp(menuBar, (char *) descriptionHelp,
 		(char *) "Description");
@@ -1454,7 +1449,7 @@ main(int argc, char **argv)
 	clearDialog = createQuery(topLevel,
 		(char *) "Are you sure you want to start over?",
 		(char *) "Clear Query",
-		(XtCallbackProc) CallbackPuzzleClear);
+		(XtCallbackProc) puzzleListenerClear);
 	mainPanel = XtCreateManagedWidget("mainPanel",
 		xmPanedWindowWidgetClass, menuBarPanel,
 		NULL, 0);
@@ -1510,19 +1505,19 @@ main(int argc, char **argv)
 	(void) XtVaCreateManagedWidget("movesText",
 		xmLabelGadgetClass, movesRowCol,
 		XtVaTypedArg, XmNlabelString, XmRString, "Moves", 6, NULL);
-	moves = XtVaCreateManagedWidget("0",
+	movesText = XtVaCreateManagedWidget("0",
 		xmLabelWidgetClass, movesRowCol, NULL);
 	(void) XtVaCreateManagedWidget("recordText",
 		xmLabelGadgetClass, movesRowCol,
 		XtVaTypedArg, XmNlabelString, XmRString, "Record", 7, NULL);
-	record = XtVaCreateManagedWidget("0",
+	recordText = XtVaCreateManagedWidget("0",
 		xmLabelWidgetClass, movesRowCol, NULL);
 	blocksRowCol = XtVaCreateManagedWidget("blocksRowCol",
 		xmRowColumnWidgetClass, controlPanel,
 		XmNnumColumns, 1,
 		XmNorientation, XmHORIZONTAL,
 		XmNpacking, XmPACK_COLUMN, NULL);
-	blockX = XtVaCreateManagedWidget("blockX",
+	blockXSlider = XtVaCreateManagedWidget("blockXSlider",
 		xmScaleWidgetClass, blocksRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Blocks X", 9,
 		XmNminimum, MIN_CUBES,
@@ -1530,9 +1525,9 @@ main(int argc, char **argv)
 		XmNvalue, DEFAULT_CUBESX,
 		XmNshowValue, True,
 		XmNorientation, XmHORIZONTAL, NULL);
-	XtAddCallback(blockX, XmNvalueChangedCallback,
-		(XtCallbackProc) BlockXSlider, (XtPointer) NULL);
-	blockY = XtVaCreateManagedWidget("blockY",
+	XtAddCallback(blockXSlider, XmNvalueChangedCallback,
+		(XtCallbackProc) blockXChangeListener, (XtPointer) NULL);
+	blockYSlider = XtVaCreateManagedWidget("blockYSlider",
 		xmScaleWidgetClass, blocksRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Blocks Y", 9,
 		XmNminimum, MIN_CUBES,
@@ -1540,9 +1535,9 @@ main(int argc, char **argv)
 		XmNvalue, DEFAULT_CUBESY,
 		XmNshowValue, True,
 		XmNorientation, XmHORIZONTAL, NULL);
-	XtAddCallback(blockY, XmNvalueChangedCallback,
-		(XtCallbackProc) BlockYSlider, (XtPointer) NULL);
-	blockZ = XtVaCreateManagedWidget("blockZ",
+	XtAddCallback(blockYSlider, XmNvalueChangedCallback,
+		(XtCallbackProc) blockYChangeListener, (XtPointer) NULL);
+	blockZSlider = XtVaCreateManagedWidget("blockZSlider",
 		xmScaleWidgetClass, blocksRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Blocks Z", 9,
 		XmNminimum, MIN_CUBES,
@@ -1550,14 +1545,14 @@ main(int argc, char **argv)
 		XmNvalue, DEFAULT_CUBESZ,
 		XmNshowValue, True,
 		XmNorientation, XmHORIZONTAL, NULL);
-	XtAddCallback(blockZ, XmNvalueChangedCallback,
-		(XtCallbackProc) BlockZSlider, (XtPointer) NULL);
+	XtAddCallback(blockZSlider, XmNvalueChangedCallback,
+		(XtCallbackProc) blockZChangeListener, (XtPointer) NULL);
 	speedRowCol = XtVaCreateManagedWidget("speedRowCol",
 		xmRowColumnWidgetClass, controlPanel,
 		XmNnumColumns, 1,
 		XmNorientation, XmHORIZONTAL,
 		XmNpacking, XmPACK_COLUMN, NULL);
-	speed = XtVaCreateManagedWidget("Animation Speed",
+	speedSlider = XtVaCreateManagedWidget("speedSlider",
 		xmScaleWidgetClass, speedRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Animation Speed", 16,
 		XmNminimum, MIN_SPEED,
@@ -1565,8 +1560,8 @@ main(int argc, char **argv)
 		XmNvalue, MAX_SPEED - DEFAULT_DELAY,
 		XmNshowValue, True,
 		XmNorientation, XmHORIZONTAL, NULL);
-	XtAddCallback(speed, XmNvalueChangedCallback,
-		(XtCallbackProc) SpeedSlider, (XtPointer) NULL);
+	XtAddCallback(speedSlider, XmNvalueChangedCallback,
+		(XtCallbackProc) speedChangeListener, (XtPointer) NULL);
 	messageRowCol = XtVaCreateManagedWidget("messageRowCol",
 		xmRowColumnWidgetClass, controlPanel, NULL);
 	message = XtVaCreateManagedWidget("Play Cubes! (use mouse or keypad)",
@@ -1610,14 +1605,14 @@ main(int argc, char **argv)
 #endif
 		XtNiconPixmap, pixmap, NULL);
 	XtAddCallback(puzzle, XtNselectCallback,
-		(XtCallbackProc) CallbackPuzzle, (XtPointer) NULL);
-	Initialize(puzzle);
+		(XtCallbackProc) puzzleListener, (XtPointer) NULL);
+	initialize(puzzle);
 	XtRealizeWidget(topLevel);
 	XGrabButton(XtDisplay(puzzle), (unsigned int) AnyButton, AnyModifier,
 		XtWindow(puzzle), TRUE, (unsigned int) (ButtonPressMask |
 		ButtonMotionMask | ButtonReleaseMask),
 		GrabModeAsync, GrabModeAsync, XtWindow(puzzle),
-		XCreateFontCursor(XtDisplay(puzzle), XC_crosshair));
+		XCreateFontCursor(XtDisplay(puzzle), XC_hand2));
 	XtMainLoop();
 
 #ifdef VMS
