@@ -1,31 +1,24 @@
 /*
-# MOTIF/X-BASED DIAL
-#
-#  xdial.c
-#
-###
-#
-#  Copyright (c) 1994 - 2008	David A. Bagley, bagleyd@tux.org
-#
-#                   All Rights Reserved
-#
-#  Permission to use, copy, modify, and distribute this software and
-#  its documentation for any purpose and without fee is hereby granted,
-#  provided that the above copyright notice appear in all copies and
-#  that both that copyright notice and this permission notice appear in
-#  supporting documentation, and that the name of the author not be
-#  used in advertising or publicity pertaining to distribution of the
-#  software without specific, written prior permission.
-#
-#  This program is distributed in the hope that it will be "useful",
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-#
-*/
+ * @(#)xdial.c
+ *
+ * Copyright 1994 - 2008  David A. Bagley, bagleyd@tux.org
+ *
+ * All rights reserved.
+ *
+ * Permission to use, copy, modify, and distribute this software and
+ * its documentation for any purpose and without fee is hereby granted,
+ * provided that the above copyright notice appear in all copies and
+ * that both that copyright notice and this permission notice appear in
+ * supporting documentation, and that the name of the author not be
+ * used in advertising or publicity pertaining to distribution of the
+ * software without specific, written prior permission.
+ *
+ * This program is distributed in the hope that it will be "useful",
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ */
 
-/*
-  xdial.c   Test for dial widget
-*/
+/* Driver file for Dial */
 
 #include <stdio.h>
 #include "xwin.h"
@@ -61,7 +54,7 @@
 #define DEFINE_XBM (char *) dial_bits, dial_width, dial_height
 
 static const char aboutHelp[] = {
-"Dial Version 7.3.2\n"
+"Dial Version 7.4\n"
 "Send bugs (reports or fixes) to the author: "
 "David Bagley <bagleyd@tux.org>\n"
 "The latest version is at: "
@@ -72,13 +65,13 @@ static const char aboutHelp[] = {
 static Widget tracker;
 static Widget aboutDialog;
 static Arg arg[3];
+static char *progDsp;
 #endif
 #define FILE_NAME_LENGTH 1024
 #define TITLE_LENGTH 2048
-static char *progDsp;
 
-static void Initialize(void);
-static void CallbackDial(Widget w, caddr_t clientData,
+static void initialize(void);
+static void callbackDial(Widget w, caddr_t clientData,
 	dialCallbackStruct *callData);
 static void PrintState(Widget w, int n);
 
@@ -93,7 +86,7 @@ static char titleDsp[TITLE_LENGTH] = "";
 
 #ifdef HAVE_MOTIF
 static void
-fileCB(Widget w, void *value, void *clientData)
+fileMenuListener(Widget w, void *value, void *clientData)
 {
 	int val = (int) value;
 
@@ -138,7 +131,7 @@ createHelp(Widget w, char *text, char *title)
 }
 
 static void
-helpCB(Widget w, XtPointer value, XtPointer clientData)
+helpMenuListener(Widget w, XtPointer value, XtPointer clientData)
 {
 	int val = (int) value;
 
@@ -150,7 +143,7 @@ helpCB(Widget w, XtPointer value, XtPointer clientData)
 		{
 			char *buf;
 
-			intCat(&buf, "helpCB: %d", val);
+			intCat(&buf, "helpMenuListener: %d", val);
 			XtWarning(buf);
 			free(buf);
 		}
@@ -169,8 +162,9 @@ main(int argc, char **argv)
 	XmString fileString, moveString;
 	XmString quitString;
 	XmString incrementString, decrementString;
-#endif
 
+	progDsp = argv[0];
+#endif
 	topLevel = XtInitialize(argv[0], "Dial",
 		NULL, 0, &argc, argv);
 #ifdef HAVE_MOTIF
@@ -190,7 +184,7 @@ main(int argc, char **argv)
 	XtManageChild(menuBar);
 	quitString = XmStringCreateSimple((char *) "Quit");
 	(void) XmVaCreateSimplePulldownMenu(menuBar, (char *) "file_menu",
-		0, fileCB,
+		0, fileMenuListener,
 		XmVaPUSHBUTTON, quitString, 'Q', NULL, NULL,
 		NULL);
 	XmStringFree(quitString);
@@ -213,7 +207,7 @@ main(int argc, char **argv)
 	widget = XtVaCreateManagedWidget("About",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'A', NULL);
-	XtAddCallback(widget, XmNactivateCallback, helpCB, (char *) 0);
+	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 0);
 	XtManageChild(menuBar);
 	aboutDialog = createHelp(menuBar, (char *) aboutHelp,
 		(char *) "About");
@@ -285,15 +279,15 @@ main(int argc, char **argv)
 #endif
 		XtNiconPixmap, pixmap, NULL);
 	XtAddCallback(dial, XtNselectCallback,
-		(XtCallbackProc) CallbackDial, (XtPointer) NULL);
+		(XtCallbackProc) callbackDial, (XtPointer) NULL);
 	XtAddCallback(dialsq, XtNselectCallback,
-		(XtCallbackProc) CallbackDial, (XtPointer) NULL);
+		(XtCallbackProc) callbackDial, (XtPointer) NULL);
 #ifndef HAVE_MOTIF
 	XtVaSetValues(shell,
 		XtNinput, True,
 		XtNiconPixmap, pixmap, NULL);
 #endif
-	Initialize();
+	initialize();
 	XtRealizeWidget(topLevel);
 #ifndef HAVE_MOTIF
 	XtRealizeWidget(shell);
@@ -303,13 +297,13 @@ main(int argc, char **argv)
 		(unsigned int) (ButtonPressMask | ButtonMotionMask |
 		ButtonReleaseMask),
 		GrabModeAsync, GrabModeAsync, XtWindow(dial),
-		XCreateFontCursor(XtDisplay(dial), XC_crosshair));
+		XCreateFontCursor(XtDisplay(dial), XC_hand2));
 	XGrabButton(XtDisplay(dialsq), (unsigned int) AnyButton, AnyModifier,
 		XtWindow(dialsq), TRUE,
 		(unsigned int) (ButtonPressMask | ButtonMotionMask |
 		ButtonReleaseMask),
 		GrabModeAsync, GrabModeAsync, XtWindow(dialsq),
-		XCreateFontCursor(XtDisplay(dialsq), XC_crosshair));
+		XCreateFontCursor(XtDisplay(dialsq), XC_hand2));
 	XtMainLoop();
 
 #ifdef VMS
@@ -319,7 +313,7 @@ main(int argc, char **argv)
 #endif
 }
 
-static void Initialize(void)
+static void initialize(void)
 {
 	int n;
 
@@ -333,7 +327,7 @@ static void Initialize(void)
 	PrintState(XtParent(dialsq), n);
 }
 
-static void CallbackDial(Widget w, caddr_t clientData,
+static void callbackDial(Widget w, caddr_t clientData,
 		dialCallbackStruct *callData)
 {
 	int reason = callData->reason;
