@@ -1,27 +1,22 @@
-/*-
-# X-BASED DINOSAUR CUBE
-#
-#  Dino.c
-#
-###
-#
-#  Copyright (c) 1995 - 2007	David A. Bagley, bagleyd@tux.org
-#
-#                   All Rights Reserved
-#
-#  Permission to use, copy, modify, and distribute this software and
-#  its documentation for any purpose and without fee is hereby granted,
-#  provided that the above copyright notice appear in all copies and
-#  that both that copyright notice and this permission notice appear in
-#  supporting documentation, and that the name of the author not be
-#  used in advertising or publicity pertaining to distribution of the
-#  software without specific, written prior permission.
-#
-#  This program is distributed in the hope that it will be "playable",
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-#
-*/
+/*
+ * @(#)Dino.c
+ *
+ * Copyright 1995 - 2008  David A. Bagley, bagleyd@tux.org
+ *
+ * All rights reserved.
+ *
+ * Permission to use, copy, modify, and distribute this software and
+ * its documentation for any purpose and without fee is hereby granted,
+ * provided that the above copyright notice appear in all copies and
+ * that both that copyright notice and this permission notice appear in
+ * supporting documentation, and that the name of the author not be
+ * used in advertising or publicity pertaining to distribution of the
+ * software without specific, written prior permission.
+ *
+ * This program is distributed in the hope that it will be "useful",
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ */
 
 /* Methods file for Dino */
 
@@ -67,9 +62,9 @@ static const char faceColorChar[MAX_FACES] =
 #endif
 #endif
 
-static Boolean SetValuesPuzzle(Widget current, Widget request, Widget renew);
-static void DestroyPuzzle(Widget old);
-static void InitializePuzzle(Widget request, Widget renew);
+static Boolean setValuesPuzzle(Widget current, Widget request, Widget renew);
+static void destroyPuzzle(Widget old);
+static void initializePuzzle(Widget request, Widget renew);
 
 DinoClassRec dinoClassRec =
 {
@@ -80,7 +75,7 @@ DinoClassRec dinoClassRec =
 		NULL,		/* class initialize */
 		NULL,		/* class part initialize */
 		FALSE,		/* class inited */
-		(XtInitProc) InitializePuzzle,	/* initialize */
+		(XtInitProc) initializePuzzle,	/* initialize */
 		NULL,		/* initialize hook */
 		XtInheritRealize,	/* realize */
 		NULL,		/* actions */
@@ -92,10 +87,10 @@ DinoClassRec dinoClassRec =
 		TRUE,		/* compress exposure */
 		TRUE,		/* compress enterleave */
 		TRUE,		/* visible interest */
-		(XtWidgetProc) DestroyPuzzle,	/* destroy */
+		(XtWidgetProc) destroyPuzzle,	/* destroy */
 		NULL,		/* resize */
 		NULL,		/* expose */
-		(XtSetValuesFunc) SetValuesPuzzle,	/* set values */
+		(XtSetValuesFunc) setValuesPuzzle,	/* set values */
 		NULL,		/* set values hook */
 		XtInheritSetValuesAlmost,	/* set values almost */
 		NULL,		/* get values hook */
@@ -483,7 +478,7 @@ static DinoStack undo = {NULL, NULL, NULL, 0};
 static DinoStack redo = {NULL, NULL, NULL, 0};
 
 static void
-CheckPieces(DinoWidget w)
+checkPieces(DinoWidget w)
 {
 	char *buf1 = NULL;
 
@@ -497,9 +492,18 @@ CheckPieces(DinoWidget w)
 }
 
 static int
-GetStyle(DinoWidget w, int shift, int control, int alt)
+getStyle(DinoWidget w, int shift, int control, int alt)
 {
-	if (w->dino.mode != BOTH) {
+	if (w->dino.mode == BOTH) {
+		if (shift)
+			return EDGE;
+		else {
+			if (alt)
+				return MIDDLE;
+			else
+				return CORNER;
+		}
+	} else {
 		if (control && shift) {
 			if (w->dino.mode == PERIOD3)
 				return EDGE;
@@ -513,20 +517,11 @@ GetStyle(DinoWidget w, int shift, int control, int alt)
 			return MIDDLE;
 		else
 			return CORNER;
-	} else {
-		if (shift)
-			return EDGE;
-		else {
-			if (alt)
-				return MIDDLE;
-			else
-				return CORNER;
-		}
 	}
 }
 
 Boolean
-CheckSolved(DinoWidget w)
+checkSolved(DinoWidget w)
 {
 	int face, position;
 	DinoCornerLoc test = {0, FALSE};
@@ -547,7 +542,7 @@ CheckSolved(DinoWidget w)
 
 #if DEBUG
 void
-PrintCube(DinoWidget w)
+printCube(DinoWidget w)
 {
 	int face, position;
 
@@ -563,50 +558,50 @@ PrintCube(DinoWidget w)
 #endif
 
 static void
-DrawTriangle(DinoWidget w, int face, int position, int offset)
+drawTriangle(DinoWidget w, int face, int position, int offset)
 {
 	if (w->dino.dim == 2)
-		DrawTriangle2D((Dino2DWidget) w, face, position, offset);
+		drawTriangle2D((Dino2DWidget) w, face, position, offset);
 	else if (w->dino.dim == 3)
-		DrawTriangle3D((Dino3DWidget) w, face, position, offset);
+		drawTriangle3D((Dino3DWidget) w, face, position, offset);
 }
 
 void
-DrawAllPieces(DinoWidget w)
+drawAllPieces(DinoWidget w)
 {
 	int face, position;
 
 #ifdef HAVE_OPENGL
 	if (w->dino.dim == 4) {
-		DrawAllPiecesGL((DinoGLWidget) w);
+		drawAllPiecesGL((DinoGLWidget) w);
 	}
 #endif
 	for (face = 0; face < MAX_FACES; face++)
 		for (position = 0; position < MAX_ORIENT; position++)
-			DrawTriangle(w, face, position, FALSE);
+			drawTriangle(w, face, position, FALSE);
 }
 
 static void
-DrawFrame(const DinoWidget w, const Boolean focus)
+drawFrame(const DinoWidget w, const Boolean focus)
 {
 	if (w->dino.dim == 2)
-		DrawFrame2D((Dino2DWidget) w, focus);
+		drawFrame2D((Dino2DWidget) w, focus);
 	else if (w->dino.dim == 3)
-		DrawFrame3D((Dino3DWidget) w, focus);
+		drawFrame3D((Dino3DWidget) w, focus);
 #ifdef HAVE_OPENGL
 	else if (w->dino.dim == 4)
-		DrawFrameGL((DinoGLWidget) w, focus);
+		drawFrameGL((DinoGLWidget) w, focus);
 #endif
 }
 
 static void
-MoveNoPieces(DinoWidget w)
+moveNoPieces(DinoWidget w)
 {
 	setPuzzle(w, ACTION_ILLEGAL);
 }
 
 static void
-RotateFace(DinoWidget w, int face, int direction)
+rotateFace(DinoWidget w, int face, int direction)
 {
 	int side;
 
@@ -619,43 +614,44 @@ RotateFace(DinoWidget w, int face, int direction)
 			w->dino.faceLoc[(side + MAX_ORIENT - 1) % MAX_ORIENT] :
 			w->dino.faceLoc[(side + 1) % MAX_ORIENT];
 		w->dino.cubeLoc[face][side].rotation =
-			(w->dino.cubeLoc[face][side].rotation + direction) % MAX_ORIENT;
-		DrawTriangle(w, face, side, FALSE);
+			(w->dino.cubeLoc[face][side].rotation + direction) %
+			MAX_ORIENT;
+		drawTriangle(w, face, side, FALSE);
 	}
 #ifdef HAVE_OPENGL
 	if (w->dino.dim == 4) {
-		DrawAllPiecesGL((DinoGLWidget) w);
+		drawAllPiecesGL((DinoGLWidget) w);
 	}
 #endif
 }
 
 static void
-ReadDiagonal(DinoWidget w, int face, int corner, int h)
+readDiagonal(DinoWidget w, int face, int corner, int h)
 {
 	w->dino.spindleLoc[h][0] = w->dino.cubeLoc[face][corner];
 	w->dino.spindleLoc[h][1] = w->dino.cubeLoc[face][(corner + 1) % MAX_ORIENT];
 }
 
 static void
-WriteDiagonal(DinoWidget w, int face, int corner, int rotate, int h)
+writeDiagonal(DinoWidget w, int face, int corner, int rotate, int h)
 {
 	w->dino.spindleLoc[h][0].rotation =
 		(w->dino.spindleLoc[h][0].rotation + rotate) % MAX_ORIENT;
 	w->dino.spindleLoc[h][1].rotation =
 		(w->dino.spindleLoc[h][1].rotation + rotate) % MAX_ORIENT;
 	w->dino.cubeLoc[face][corner] = w->dino.spindleLoc[h][0];
-	DrawTriangle(w, face, corner, FALSE);
+	drawTriangle(w, face, corner, FALSE);
 	w->dino.cubeLoc[face][(corner + 1) % MAX_ORIENT] = w->dino.spindleLoc[h][1];
-	DrawTriangle(w, face, (corner + 1) % MAX_ORIENT, FALSE);
+	drawTriangle(w, face, (corner + 1) % MAX_ORIENT, FALSE);
 #ifdef HAVE_OPENGL
 	if (w->dino.dim == 4) {
-		DrawAllPiecesGL((DinoGLWidget) w);
+		drawAllPiecesGL((DinoGLWidget) w);
 	}
 #endif
 }
 
 static void
-ReadFace(DinoWidget w, int face, int h)
+readFace(DinoWidget w, int face, int h)
 {
 	int side;
 
@@ -664,7 +660,7 @@ ReadFace(DinoWidget w, int face, int h)
 }
 
 static void
-WriteFace(DinoWidget w, int face, int rotate, int h)
+writeFace(DinoWidget w, int face, int rotate, int h)
 {
 	int side, newSide;
 
@@ -672,201 +668,213 @@ WriteFace(DinoWidget w, int face, int rotate, int h)
 		newSide = (side + rotate) % MAX_ORIENT;
 		w->dino.cubeLoc[face][newSide] = w->dino.rowLoc[h][side];
 		w->dino.cubeLoc[face][newSide].rotation =
-			(w->dino.cubeLoc[face][newSide].rotation + rotate) % MAX_ORIENT;
-		DrawTriangle(w, face, (side + rotate) % MAX_ORIENT, FALSE);
+			(w->dino.cubeLoc[face][newSide].rotation + rotate) %
+			MAX_ORIENT;
+		drawTriangle(w, face, (side + rotate) % MAX_ORIENT, FALSE);
 	}
 #ifdef HAVE_OPENGL
 	if (w->dino.dim == 4) {
-		DrawAllPiecesGL((DinoGLWidget) w);
+		drawAllPiecesGL((DinoGLWidget) w);
 	}
 #endif
 }
 
 static void
-MoveEdges(DinoWidget w, int face, int corner, int direction)
+moveEdges(DinoWidget w, int face, int corner, int direction)
 {
+	int oldFace = face, corn = corner, dir = direction;
 	int k, newFace, rotate, newCorner, newDirection;
 
-	ReadDiagonal((DinoWidget) w, face, corner, 0);
+	readDiagonal((DinoWidget) w, oldFace, corn, 0);
 	for (k = 1; k <= 2; k++) {
-		newFace = oppFace[face];
-		/*rotate = (((face == 1 || face == 3) ? 1 : 3) + 3 * direction) %
+		newFace = oppFace[oldFace];
+		/*rotate = (((oldFace == 1 || oldFace == 3) ? 1 : 3) + 3 * dir) %
 		  MAX_ORIENT; */
-		newCorner = ((((face == 1 || face == 3) + corner) % 2) ?
-			(corner + 3) : (corner + 1)) % MAX_ORIENT;
-		rotate = (newCorner - corner + MAX_ORIENT) % MAX_ORIENT;
-		newDirection = (rotate + direction) % MAX_ORIENT;
+		newCorner = ((((((oldFace == 1 || oldFace == 3) ? 1 : 0) +
+			corn) & 1) == 1) ? (corn + 3) :
+			(corn + 1)) % MAX_ORIENT;
+		rotate = (newCorner - corn + MAX_ORIENT) % MAX_ORIENT;
+		newDirection = (rotate + dir) % MAX_ORIENT;
 		if (k != 2)
-			ReadDiagonal((DinoWidget) w, newFace, newCorner, k);
-		WriteDiagonal(w, newFace, newCorner, rotate, k - 1);
-		face = newFace;
-		corner = newCorner;
-		direction = newDirection;
+			readDiagonal((DinoWidget) w, newFace, newCorner, k);
+		writeDiagonal(w, newFace, newCorner, rotate, k - 1);
+		oldFace = newFace;
+		corn = newCorner;
+		dir = newDirection;
 	}
 }
 
 static void
-MoveFaces(DinoWidget w, int f, int d, int rotate)
+moveFaces(DinoWidget w, int f, int d, int rotate)
 {
-	int k, face, newFace;
+	int k, face, newFace, rot = rotate;
 
 	face = faceToRotate2[f][d][0];
-	ReadFace((DinoWidget) w, face, 0);
+	readFace((DinoWidget) w, face, 0);
 	for (k = 1; k <= 2; k++) {
-		newFace = faceToRotate2[f][d][k % 2];
-		rotate = MAX_ORIENT - rotate;
+		newFace = faceToRotate2[f][d][k & 1];
+		rot = MAX_ORIENT - rot;
 		if (k != 2)
-			ReadFace((DinoWidget) w, newFace, k);
-		WriteFace(w, newFace, rotate, k - 1);
+			readFace((DinoWidget) w, newFace, k);
+		writeFace(w, newFace, rot, k - 1);
 		face = newFace;
 	}
 }
 
 static void
-MoveInsideCorners(DinoWidget w, int face, int corner, int direction)
+moveInsideCorners(DinoWidget w, int face, int corner, int direction)
 {
+	int oldFace = face, corn = corner, oldDir = direction;
 	int newFace, newCorner, newDirection, dir, k;
 
-	ReadDiagonal((DinoWidget) w, face, corner, 0);
+	readDiagonal((DinoWidget) w, oldFace, corn, 0);
 	for (k = 1; k <= MAX_ROTATE; k++) {
-		dir = direction / 2;
-		newFace = slideCorner[face][corner][dir].face;
-		newCorner = slideCorner[face][corner][dir].side;
-		newDirection = 2 * slideCorner[face][corner][dir].dir +
-			!(newCorner % 2);
+		dir = oldDir / 2;
+		newFace = slideCorner[oldFace][corn][dir].face;
+		newCorner = slideCorner[oldFace][corn][dir].side;
+		newDirection = 2 * slideCorner[oldFace][corn][dir].dir +
+			(((newCorner & 1) == 0) ? 1 : 0);
 		if (k != MAX_ROTATE)
-			ReadDiagonal((DinoWidget) w, newFace, newCorner, k);
-		WriteDiagonal(w, newFace, newCorner,
-		  (newDirection - direction + MAX_ORIENT) % MAX_ORIENT, k - 1);
-		face = newFace;
-		corner = newCorner;
-		direction = newDirection;
+			readDiagonal((DinoWidget) w, newFace, newCorner, k);
+		writeDiagonal(w, newFace, newCorner,
+			(newDirection - oldDir + MAX_ORIENT) %
+			MAX_ORIENT, k - 1);
+		oldFace = newFace;
+		corn = newCorner;
+		oldDir = newDirection;
 	}
 }
 
 static void
-MoveOutsideCorners(DinoWidget w, int face, int corner, int direction)
+moveOutsideCorners(DinoWidget w, int face, int corner, int direction)
 {
+	int oldFace = face, corn = corner, oldDir = direction;
 	int newFace, newCorner, newDirection, dir, k;
 
-	ReadDiagonal((DinoWidget) w, face, corner, 0);
+	readDiagonal((DinoWidget) w, oldFace, corn, 0);
 	for (k = 1; k <= MAX_ROTATE; k++) {
-		corner = (corner + 2) % MAX_ORIENT;
-		dir = direction / 2;
-		newFace = slideCorner[face][corner][dir].face;
-		newCorner = (slideCorner[face][corner][dir].side + 2) %
+		corn = (corn + 2) % MAX_ORIENT;
+		dir = oldDir / 2;
+		newFace = slideCorner[oldFace][corn][dir].face;
+		newCorner = (slideCorner[oldFace][corn][dir].side + 2) %
 			MAX_ORIENT;
-		newDirection = 2 * slideCorner[face][corner][dir].dir +
-			!(newCorner % 2);
+		newDirection = 2 * slideCorner[oldFace][corn][dir].dir +
+			(((newCorner & 1) == 0) ? 1 : 0);
 		if (k != MAX_ROTATE)
-			ReadDiagonal((DinoWidget) w, newFace, newCorner, k);
-		WriteDiagonal(w, newFace, newCorner,
-		  (newDirection - direction + MAX_ORIENT) % MAX_ORIENT, k - 1);
-		face = newFace;
-		corner = newCorner;
-		direction = newDirection;
+			readDiagonal((DinoWidget) w, newFace, newCorner, k);
+		writeDiagonal(w, newFace, newCorner,
+			(newDirection - oldDir + MAX_ORIENT) %
+			MAX_ORIENT, k - 1);
+		oldFace = newFace;
+		corn = newCorner;
+		oldDir = newDirection;
 	}
 }
 
 static void
-MovePieces(DinoWidget w, int face, int position, int direction, int style)
+movePieces(DinoWidget w, int face, int position, int direction, int style)
 {
+	int oldFace = face, dir = direction;
 	int corner, newCorner;
 
-	corner = (position - !((position + direction) % 2) + MAX_ORIENT) %
-		MAX_ORIENT;
+	corner = (position - ((((position + dir) & 1) == 0) ?
+		1 : 0) + MAX_ORIENT) % MAX_ORIENT;
 	if (style == CORNER) {
-		MoveInsideCorners(w, face, corner, direction);
+		moveInsideCorners(w, oldFace, corner, dir);
 	} else if (style == MIDDLE) {
-		MoveOutsideCorners(w, face, corner, direction);
-		newCorner = oppCorner[face][corner].rotation;
-		face = oppCorner[face][corner].face;
-		if (((face != 1 && face != 3) + corner) % 2)
-			direction = (direction + 1) % MAX_ORIENT;
+		moveOutsideCorners(w, oldFace, corner, dir);
+		newCorner = oppCorner[oldFace][corner].rotation;
+		oldFace = oppCorner[oldFace][corner].face;
+		if (((((oldFace == 1 || oldFace == 3) ? 0 : 1) + corner) &
+				1) == 1)
+			dir = (dir + 1) % MAX_ORIENT;
 		else
-			direction = (direction + 3) % MAX_ORIENT;
+			dir = (dir + 3) % MAX_ORIENT;
 		corner = newCorner;
-		MoveOutsideCorners(w, face, corner, direction);
+		moveOutsideCorners(w, oldFace, corner, dir);
 	} else if (style == EDGE) {
-		MoveEdges(w, face, corner, direction);
-		MoveFaces(w, face, corner,
-			((face == 2 || face == 5) ? CCW : HALF) % MAX_ORIENT);
+		moveEdges(w, oldFace, corner, dir);
+		moveFaces(w, oldFace, corner,
+			((oldFace == 2 || oldFace == 5) ? CCW : HALF) %
+			MAX_ORIENT);
 	} else {
 		int k, newFace, rotate, newDirection;
 
-		RotateFace(w, faceToRotate[face][direction % MAX_ORIENT], CW);
-		RotateFace(w, faceToRotate[face][(direction + 2) % MAX_ORIENT],
+		rotateFace(w, faceToRotate[oldFace][dir % MAX_ORIENT], CW);
+		rotateFace(w, faceToRotate[oldFace][(dir + 2) % MAX_ORIENT],
 			CCW);
-		ReadFace((DinoWidget) w, face, 0);
+		readFace((DinoWidget) w, oldFace, 0);
 		for (k = 1; k <= MAX_ORIENT; k++) {
-			newFace = slideNextFace[face][direction % MAX_ORIENT].face;
-			rotate = slideNextFace[face][direction % MAX_ORIENT].rotation;
-			newDirection = (rotate + direction) % MAX_ORIENT;
+			newFace = slideNextFace[oldFace][dir % MAX_ORIENT].face;
+			rotate = slideNextFace[oldFace][dir % MAX_ORIENT].rotation;
+			newDirection = (rotate + dir) % MAX_ORIENT;
 			if (k != MAX_ORIENT)
-				ReadFace((DinoWidget) w, newFace, k);
-			WriteFace(w, newFace, rotate, k - 1);
-			face = newFace;
-			direction = newDirection;
+				readFace((DinoWidget) w, newFace, k);
+			writeFace(w, newFace, rotate, k - 1);
+			oldFace = newFace;
+			dir = newDirection;
 		}
 	}
 }
 
 static void
-MoveControlCb(DinoWidget w, int face, int position, int direction, int style)
+moveControlCb(DinoWidget w, int face, int position, int direction, int style)
 {
 	int newFace, newSide, newDirection, corner, newCorner;
 
-	MovePieces(w, face, position, direction, style);
+	movePieces(w, face, position, direction, style);
 	setPuzzleMove(w, ACTION_CONTROL, face, position, direction, style);
 	if (style == CORNER) {
 		newSide = (position + 2) % MAX_ORIENT;
-		MovePieces(w, face, newSide, direction, MIDDLE);
+		movePieces(w, face, newSide, direction, MIDDLE);
 		setPuzzleMove(w, ACTION_CONTROL, face, newSide, direction,
 			MIDDLE);
-		corner = (position - !((position + direction) % 2) +
-			MAX_ORIENT) % MAX_ORIENT;
+		corner = (position - ((((position + direction) & 1) ==
+			0) ? 1 : 0) + MAX_ORIENT) % MAX_ORIENT;
 		newFace = oppCorner[face][corner].face;
 		newCorner = oppCorner[face][corner].rotation;
 		newDirection = 2 * ((direction / 2 +
-			(face != 1 && face != 3)) % 2) + !(newCorner % 2);
+			((face == 1 || face == 3) ? 0 : 1)) & 1) +
+			(((newCorner & 1) == 0) ? 1 : 0);
 		newSide = newCorner;
-		MovePieces(w, newFace, newSide, newDirection, CORNER);
+		movePieces(w, newFace, newSide, newDirection, CORNER);
 		setPuzzleMove(w, ACTION_CONTROL, newFace, newSide,
 			newDirection, CORNER);
 	} else if (style == MIDDLE) {
 		newSide = (position + 2) % MAX_ORIENT;
-		MovePieces(w, face, newSide, direction, CORNER);
+		movePieces(w, face, newSide, direction, CORNER);
 		setPuzzleMove(w, ACTION_CONTROL, face, newSide, direction,
 			CORNER);
-		corner = (position - !((position + direction) % 2) +
-			MAX_ORIENT) % MAX_ORIENT;
+		corner = (position - ((((position + direction) & 1) ==
+			0) ? 1 : 0) + MAX_ORIENT) % MAX_ORIENT;
 		newCorner = oppCorner[face][corner].rotation;
 		newFace = oppCorner[face][corner].face;
-		if (newFace != 1 && newFace != 3)
-			newDirection = (direction + 2) % MAX_ORIENT;
-		else
+		if (newFace == 1 || newFace == 3)
 			newDirection = direction;
-		newDirection = 2 * (newDirection / 2) + !(newDirection % 2);
+		else
+			newDirection = (direction + 2) % MAX_ORIENT;
+		newDirection = 2 * (newDirection / 2) +
+			(((newDirection & 1) == 0) ? 1 : 0);
 		newSide = (newCorner + 2) % MAX_ORIENT;
-		MovePieces(w, newFace, newSide, newDirection, CORNER);
+		movePieces(w, newFace, newSide, newDirection, CORNER);
 		setPuzzleMove(w, ACTION_CONTROL, newFace, newSide,
 			newDirection, CORNER);
 	} else if (style == EDGE) {
 		newSide = (position + 2) % MAX_ORIENT;
-		MovePieces(w, face, newSide, direction, EDGE);
+		movePieces(w, face, newSide, direction, EDGE);
 		setPuzzleMove(w, ACTION_CONTROL, face, newSide, direction,
 			EDGE);
 	}
 }
 
 void
-MovePuzzle(DinoWidget w, int face, int position, int direction, int style,
+movePuzzle(DinoWidget w, int face, int position, int direction, int style,
 		int control)
 {
 	if (control)
-		MoveControlCb(w, face, position, direction, style);
+		moveControlCb(w, face, position, direction, style);
 	else {
-		MovePieces(w, face, position, direction, style);
+		movePieces(w, face, position, direction, style);
 		setPuzzleMove(w, ACTION_MOVED, face, position, direction,
 			style);
 	}
@@ -880,23 +888,23 @@ MovePuzzle(DinoWidget w, int face, int position, int direction, int style,
 }
 
 static Boolean
-SelectPieces(DinoWidget w, int x, int y, int *face, int *position)
+selectPieces(DinoWidget w, int x, int y, int *face, int *position)
 {
 	if (w->dino.dim == 2)
-		return SelectPieces2D((Dino2DWidget) w, x, y,
+		return selectPieces2D((Dino2DWidget) w, x, y,
 			face, position);
 	else if (w->dino.dim == 3)
-		return SelectPieces3D((Dino3DWidget) w, x, y,
+		return selectPieces3D((Dino3DWidget) w, x, y,
 			face, position);
 	return False;
 }
 
 static int
-CheckMoveDir(int position1, int position2, int *direction)
+checkMoveDir(int position1, int position2, int *direction)
 {
 	if (position1 == position2)
 		return 2;
-	if (!((position1 - position2 + MAX_ORIENT) % 2))
+	if (((position1 - position2 + MAX_ORIENT) & 1) == 0)
 		return 0;
 	switch (position1) {
 	case 0:
@@ -918,34 +926,34 @@ CheckMoveDir(int position1, int position2, int *direction)
 }
 
 static Boolean
-NarrowSelection(DinoWidget w, int *face, int *direction)
+narrowSelection(DinoWidget w, int *face, int *direction)
 {
 	if (w->dino.dim == 2)
-		return NarrowSelection2D((Dino2DWidget) w, face, direction);
+		return narrowSelection2D((Dino2DWidget) w, face, direction);
 	else if (w->dino.dim == 3)
-		return NarrowSelection3D((Dino3DWidget) w, face, direction);
+		return narrowSelection3D((Dino3DWidget) w, face, direction);
 	return False;
 }
 
 static Boolean
-PositionPieces(DinoWidget w, int x, int y, int *face, int *position, int *direction)
+positionPieces(DinoWidget w, int x, int y, int *face, int *position, int *direction)
 {
-	if (!SelectPieces(w, x, y, face, position))
+	if (!selectPieces(w, x, y, face, position))
 		return False;
-	return NarrowSelection(w, face, direction);
+	return narrowSelection(w, face, direction);
 }
 
 void
-MovePuzzleInput(DinoWidget w, int x, int y, int direction, int shift,
+movePuzzleInput(DinoWidget w, int x, int y, int direction, int shift,
 		int control, int alt)
 {
 	int face, position, style;
 
-	if (!w->dino.practice && !control && CheckSolved(w)) {
-		MoveNoPieces(w);
+	if (!w->dino.practice && !control && checkSolved(w)) {
+		moveNoPieces(w);
 		return;
 	}
-	if (!PositionPieces(w, x, y, &face, &position, &direction))
+	if (!positionPieces(w, x, y, &face, &position, &direction))
 		return;
 	if (direction >= 2 * MAX_ORIENT) {
 		if (control)
@@ -953,16 +961,16 @@ MovePuzzleInput(DinoWidget w, int x, int y, int direction, int shift,
 		else
 			return;
 	} else
-		style = GetStyle(w, shift, control, alt);
+		style = getStyle(w, shift, control, alt);
 	control = (control) ? 1 : 0;
-	MovePuzzle(w, face, position, direction, style, control);
-	if (!control && CheckSolved(w)) {
+	movePuzzle(w, face, position, direction, style, control);
+	if (!control && checkSolved(w)) {
 		setPuzzle(w, ACTION_SOLVED);
 	}
 }
 
 static void
-ResetPieces(DinoWidget w)
+resetPieces(DinoWidget w)
 {
 	int face, position;
 
@@ -980,7 +988,7 @@ ResetPieces(DinoWidget w)
 }
 
 static void
-GetPieces(DinoWidget w)
+getPieces(DinoWidget w)
 {
 	FILE *fp;
 	int c, mode, orient, practice, moves;
@@ -1062,7 +1070,7 @@ GetPieces(DinoWidget w)
 		setPuzzle(w, ACTION_PRACTICE);
 	}
 #ifdef WINVER
-	ResetPieces(w);
+	resetPieces(w);
 #endif
 	while ((c = getc(fp)) != EOF && c != SYMBOL);
 	(void) fscanf(fp, "%d", &moves);
@@ -1081,7 +1089,7 @@ GetPieces(DinoWidget w)
 }
 
 static void
-WritePieces(DinoWidget w)
+writePieces(DinoWidget w)
 {
 	FILE *fp;
 	char *buf1 = NULL, *buf2 = NULL;
@@ -1137,7 +1145,7 @@ WritePieces(DinoWidget w)
 }
 
 static void
-UndoPieces(DinoWidget w)
+undoPieces(DinoWidget w)
 {
 	if (madeMoves(&undo)) {
 		int face, position, direction, style, control;
@@ -1150,12 +1158,12 @@ UndoPieces(DinoWidget w)
 			(direction + MAX_ORIENT / 2) % MAX_ORIENT :
 			5 * MAX_ORIENT - direction;
 		if (control)
-			MoveControlCb(w, face, position, direction, style);
+			moveControlCb(w, face, position, direction, style);
 		else {
-			MovePieces(w, face, position, direction, style);
+			movePieces(w, face, position, direction, style);
 			setPuzzleMove(w, ACTION_UNDO, face, position, direction,
 				style);
-			if (CheckSolved(w)) {
+			if (checkSolved(w)) {
 				setPuzzle(w, ACTION_SOLVED);
 			}
 		}
@@ -1163,7 +1171,7 @@ UndoPieces(DinoWidget w)
 }
 
 static void
-RedoPieces(DinoWidget w)
+redoPieces(DinoWidget w)
 {
 	if (madeMoves(&redo)) {
 		int face, position, direction, style, control;
@@ -1173,12 +1181,12 @@ RedoPieces(DinoWidget w)
 		setMove(&undo,
 			face, position, direction, style, control);
 		if (control)
-			MoveControlCb(w, face, position, direction, style);
+			moveControlCb(w, face, position, direction, style);
 		else {
-			MovePieces(w, face, position, direction, style);
+			movePieces(w, face, position, direction, style);
 			setPuzzleMove(w, ACTION_REDO, face, position, direction,
 				style);
-			if (CheckSolved(w)) {
+			if (checkSolved(w)) {
 				setPuzzle(w, ACTION_SOLVED);
 			}
 		}
@@ -1186,26 +1194,26 @@ RedoPieces(DinoWidget w)
 }
 
 static void
-ClearPieces(DinoWidget w)
+clearPieces(DinoWidget w)
 {
 	setPuzzle(w, ACTION_CLEAR);
 }
 
 static void
-PracticePieces(DinoWidget w)
+practicePieces(DinoWidget w)
 {
 	setPuzzle(w, ACTION_PRACTICE);
 }
 
 static void
-RandomizePieces(DinoWidget w)
+randomizePieces(DinoWidget w)
 {
 	int face, position, direction, style;
 	int big = MAX_ORIENT * 3 + NRAND(2);
 
 	w->dino.cheat = False;
 	if (w->dino.practice)
-		PracticePieces(w);
+		practicePieces(w);
 	setPuzzle(w, ACTION_RESET);
 
 #ifdef DEBUG
@@ -1223,20 +1231,20 @@ RandomizePieces(DinoWidget w)
 			style = NRAND(3);
 		else
 			style = NRAND(2);
-		MovePuzzle(w, face, position, direction, style, FALSE);
+		movePuzzle(w, face, position, direction, style, FALSE);
 	}
 	flushMoves(w, &undo, TRUE);
 	flushMoves(w, &redo, FALSE);
 	setPuzzle(w, ACTION_RANDOMIZE);
-	if (CheckSolved(w)) {
+	if (checkSolved(w)) {
 		setPuzzle(w, ACTION_SOLVED);
 	}
 }
 
 static void
-SolvePieces(DinoWidget w)
+solvePieces(DinoWidget w)
 {
-	if (CheckSolved(w))
+	if (checkSolved(w))
 		return;
 	{
 		setPuzzle(w, ACTION_SOLVE_MESSAGE);
@@ -1244,19 +1252,19 @@ SolvePieces(DinoWidget w)
 }
 
 static void
-OrientizePieces(DinoWidget w)
+orientizePieces(DinoWidget w)
 {
 	setPuzzle(w, ACTION_ORIENTIZE);
 }
 
 static void
-ViewPieces(DinoWidget w)
+viewPieces(DinoWidget w)
 {
 	setPuzzle(w, ACTION_VIEW);
 }
 
 static void
-SpeedPieces(DinoWidget w)
+speedPieces(DinoWidget w)
 {
 	w->dino.delay -= 5;
 	if (w->dino.delay < 0)
@@ -1267,7 +1275,7 @@ SpeedPieces(DinoWidget w)
 }
 
 static void
-SlowPieces(DinoWidget w)
+slowPieces(DinoWidget w)
 {
 	w->dino.delay += 5;
 #ifdef HAVE_MOTIF
@@ -1276,14 +1284,14 @@ SlowPieces(DinoWidget w)
 }
 
 static void
-SoundPieces(DinoWidget w)
+soundPieces(DinoWidget w)
 {
 	w->dino.sound = !w->dino.sound;
 }
 
 #ifdef WINVER
 static void
-SetValuesPuzzle(DinoWidget w)
+setValuesPuzzle(DinoWidget w)
 {
 	struct tagColor {
 		int red, green, blue;
@@ -1347,7 +1355,7 @@ SetValuesPuzzle(DinoWidget w)
 }
 
 void
-DestroyPuzzle(HBRUSH brush)
+destroyPuzzle(HBRUSH brush)
 {
 	deleteMoves(&undo);
 	deleteMoves(&redo);
@@ -1356,41 +1364,41 @@ DestroyPuzzle(HBRUSH brush)
 }
 
 void
-ResizePuzzle(DinoWidget w)
+resizePuzzle(DinoWidget w)
 {
 	if (w->dino.dim == 2)
-		ResizePuzzle2D((Dino2DWidget) w);
+		resizePuzzle2D((Dino2DWidget) w);
 	else if (w->dino.dim == 3)
-		ResizePuzzle3D((Dino3DWidget) w);
+		resizePuzzle3D((Dino3DWidget) w);
 #ifdef HAVE_OPENGL
 	else if (w->dino.dim == 4)
-		ResizePuzzleGL((DinoGLWidget) w);
+		resizePuzzleGL((DinoGLWidget) w);
 #endif
 }
 
 void
-SizePuzzle(DinoWidget w)
+sizePuzzle(DinoWidget w)
 {
-	ResetPieces(w);
-	ResizePuzzle(w);
+	resetPieces(w);
+	resizePuzzle(w);
 }
 
 void
-ExposePuzzle(DinoWidget w)
+exposePuzzle(DinoWidget w)
 {
 	if (w->dino.dim == 2)
-		ExposePuzzle2D((Dino2DWidget) w);
+		exposePuzzle2D((Dino2DWidget) w);
 	else if (w->dino.dim == 3)
-		ExposePuzzle3D((Dino3DWidget) w);
+		exposePuzzle3D((Dino3DWidget) w);
 #ifdef HAVE_OPENGL
 	else if (w->dino.dim == 4)
-		ExposePuzzleGL((DinoGLWidget) w);
+		exposePuzzleGL((DinoGLWidget) w);
 #endif
 }
 
 #else
 static void
-GetColor(DinoWidget w, int face)
+getColor(DinoWidget w, int face)
 {
 	XGCValues values;
 	XtGCMask valueMask;
@@ -1445,7 +1453,7 @@ GetColor(DinoWidget w, int face)
 }
 
 void
-SetAllColors(DinoWidget w)
+setAllColors(DinoWidget w)
 {
 	XGCValues values;
 	XtGCMask valueMask;
@@ -1494,14 +1502,14 @@ SetAllColors(DinoWidget w)
 		XtReleaseGC((Widget) w, w->dino.borderGC);
 	w->dino.borderGC = XtGetGC((Widget) w, valueMask, &values);
 	for (face = 0; face < MAX_FACES; face++)
-		GetColor(w, face);
+		getColor(w, face);
 	if (w->dino.fontInfo)
 		XSetFont(XtDisplay(w), w->dino.borderGC,
 			w->dino.fontInfo->fid);
 }
 
 static Boolean
-SetValuesPuzzle(Widget current, Widget request, Widget renew)
+setValuesPuzzle(Widget current, Widget request, Widget renew)
 {
 	DinoWidget c = (DinoWidget) current, w = (DinoWidget) renew;
 	Boolean redraw = False, setColors = False;
@@ -1518,23 +1526,23 @@ SetValuesPuzzle(Widget current, Widget request, Widget renew)
 			w->dino.reverse != c->dino.reverse ||
 			w->dino.mono != c->dino.mono) {
 		loadFont(w);
-		SetAllColors(w);
+		setAllColors(w);
 		redraw = True;
 	} else if (w->dino.background != c->dino.background ||
 			w->dino.foreground != c->dino.foreground ||
 			setColors) {
-		SetAllColors(w);
+		setAllColors(w);
 		redraw = True;
 	}
 	if (w->dino.orient != c->dino.orient) {
-		ResetPieces(w);
+		resetPieces(w);
 		redraw = TRUE;
 	} else if (w->dino.practice != c->dino.practice) {
-		ResetPieces(w);
+		resetPieces(w);
 		redraw = TRUE;
 	}
 	if (w->dino.mode != c->dino.mode) {
-		ResetPieces(w);
+		resetPieces(w);
 		redraw = TRUE;
 	}
 
@@ -1544,43 +1552,43 @@ SetValuesPuzzle(Widget current, Widget request, Widget renew)
 		w->dino.menu = ACTION_IGNORE;
 		switch (menu) {
 		case ACTION_GET:
-			GetPieces(w);
+			getPieces(w);
 			break;
 		case ACTION_WRITE:
-			WritePieces(w);
+			writePieces(w);
 			break;
 		case ACTION_UNDO:
-			UndoPieces(w);
+			undoPieces(w);
 			break;
 		case ACTION_REDO:
-			RedoPieces(w);
+			redoPieces(w);
 			break;
 		case ACTION_CLEAR:
-			ClearPieces(w);
+			clearPieces(w);
 			break;
 		case ACTION_PRACTICE:
-			PracticePieces(w);
+			practicePieces(w);
 			break;
 		case ACTION_RANDOMIZE:
-			RandomizePieces(w);
+			randomizePieces(w);
 			break;
 		case ACTION_SOLVE:
-			SolvePieces(w);
+			solvePieces(w);
 			break;
 		case ACTION_ORIENTIZE:
-			OrientizePieces(w);
+			orientizePieces(w);
 			break;
 		case ACTION_SPEED:
-			SpeedPieces(w);
+			speedPieces(w);
 			break;
 		case ACTION_SLOW:
-			SlowPieces(w);
+			slowPieces(w);
 			break;
 		case ACTION_SOUND:
-			SoundPieces(w);
+			soundPieces(w);
 			break;
 		case ACTION_VIEW:
-			ViewPieces(w);
+			viewPieces(w);
 			break;
 		default:
 			break;
@@ -1590,11 +1598,11 @@ SetValuesPuzzle(Widget current, Widget request, Widget renew)
 		setStartPosition(w);
 		w->dino.currentDirection = IGNORE_DIR;
 	} else if (w->dino.currentDirection == CLEAR_DIR) {
-		ResetPieces(w);
+		resetPieces(w);
 		redraw = TRUE;
 		w->dino.currentDirection = IGNORE_DIR;
 	} else if (w->dino.currentDirection > IGNORE_DIR) {
-		MovePieces(w, w->dino.currentFace, w->dino.currentPosition,
+		movePieces(w, w->dino.currentFace, w->dino.currentPosition,
 			w->dino.currentDirection, w->dino.style);
 		w->dino.currentDirection = IGNORE_DIR;
 	}
@@ -1602,7 +1610,7 @@ SetValuesPuzzle(Widget current, Widget request, Widget renew)
 }
 
 static void
-DestroyPuzzle(Widget old)
+destroyPuzzle(Widget old)
 {
 	DinoWidget w = (DinoWidget) old;
 	Display *display = XtDisplay(w);
@@ -1623,7 +1631,7 @@ DestroyPuzzle(Widget old)
 }
 
 void
-QuitPuzzle(DinoWidget w, XEvent *event, char **args, int nArgs)
+quitPuzzle(DinoWidget w, XEvent *event, char **args, int nArgs)
 {
 	XtCloseDisplay(XtDisplay(w));
 	exit(0);
@@ -1634,7 +1642,7 @@ QuitPuzzle(DinoWidget w, XEvent *event, char **args, int nArgs)
 static
 #endif
 void
-InitializePuzzle(
+initializePuzzle(
 #ifdef WINVER
 DinoWidget w, HBRUSH brush
 #else
@@ -1643,7 +1651,7 @@ Widget request, Widget renew
 )
 {
 #ifdef WINVER
-	SetValuesPuzzle(w);
+	setValuesPuzzle(w);
 #else
 	DinoWidget w = (DinoWidget) renew;
 	int face;
@@ -1659,11 +1667,11 @@ Widget request, Widget renew
 #endif
 	w->dino.focus = False;
 	loadFont(w);
-	CheckPieces(w);
+	checkPieces(w);
 	newMoves(&undo);
 	newMoves(&redo);
 	w->dino.cheat = False;
-	ResetPieces(w);
+	resetPieces(w);
 #ifdef WINVER
 	brush = CreateSolidBrush(w->dino.inverseGC);
 	SETBACK(w->core.hWnd, brush);
@@ -1674,7 +1682,7 @@ Widget request, Widget renew
 }
 
 void
-HidePuzzle(DinoWidget w
+hidePuzzle(DinoWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
@@ -1684,7 +1692,7 @@ HidePuzzle(DinoWidget w
 }
 
 void
-SelectPuzzle(DinoWidget w
+selectPuzzle(DinoWidget w
 #ifdef WINVER
 , const int x, const int y, const int control
 #else
@@ -1697,10 +1705,10 @@ SelectPuzzle(DinoWidget w
 	int control = (int) (event->xkey.state & ControlMask);
 #endif
 
-	if (SelectPieces(w, x, y, &(w->dino.currentFace),
+	if (selectPieces(w, x, y, &(w->dino.currentFace),
 			&(w->dino.currentPosition))) {
-		if (control || w->dino.practice || !CheckSolved(w))
-			DrawTriangle(w, w->dino.currentFace,
+		if (control || w->dino.practice || !checkSolved(w))
+			drawTriangle(w, w->dino.currentFace,
 				w->dino.currentPosition, TRUE);
 	} else {
 		w->dino.currentFace = IGNORE_DIR;
@@ -1709,7 +1717,7 @@ SelectPuzzle(DinoWidget w
 }
 
 void
-ReleasePuzzle(DinoWidget w
+releasePuzzle(DinoWidget w
 #ifdef WINVER
 , const int x, const int y, const int shift, const int control, const int alt
 #else
@@ -1728,13 +1736,13 @@ ReleasePuzzle(DinoWidget w
 
 	if (w->dino.currentFace <= IGNORE_DIR)
 		return;
-	DrawTriangle(w, w->dino.currentFace, w->dino.currentPosition, FALSE);
-	style = GetStyle(w, shift, control, alt);
-	if (!control && !w->dino.practice && CheckSolved(w))
-		MoveNoPieces(w);
-	else if (SelectPieces(w, x, y, &face, &position)) {
+	drawTriangle(w, w->dino.currentFace, w->dino.currentPosition, FALSE);
+	style = getStyle(w, shift, control, alt);
+	if (!control && !w->dino.practice && checkSolved(w))
+		moveNoPieces(w);
+	else if (selectPieces(w, x, y, &face, &position)) {
 		if (face == w->dino.currentFace) {
-			count = CheckMoveDir(w->dino.currentPosition,
+			count = checkMoveDir(w->dino.currentPosition,
 				position, &direction);
 			/* count == 2 too annoying */
 			if (count == 2)
@@ -1757,16 +1765,16 @@ ReleasePuzzle(DinoWidget w
 				count = 0;
 		}
 		if (count == 1) {
-			MovePuzzle(w, w->dino.currentFace,
+			movePuzzle(w, w->dino.currentFace,
 				w->dino.currentPosition, direction,
 				style, (control) ? 1 : 0);
-			if (!control && CheckSolved(w)) {
+			if (!control && checkSolved(w)) {
 				setPuzzle(w, ACTION_SOLVED);
 			}
 		} else if (count == 2) {
 			setPuzzle(w, ACTION_AMBIGUOUS);
 		} else if (count == 0)
-			MoveNoPieces(w);
+			moveNoPieces(w);
 	}
 	w->dino.currentFace = IGNORE_DIR;
 	w->dino.currentDirection = IGNORE_DIR;
@@ -1774,12 +1782,12 @@ ReleasePuzzle(DinoWidget w
 
 #ifndef WINVER
 void
-PracticePuzzleMaybe(DinoWidget w
+practicePuzzleWithQuery(DinoWidget w
 , XEvent *event, char **args, int nArgs
 )
 {
 	if (!w->dino.started)
-		PracticePieces(w);
+		practicePieces(w);
 #ifdef HAVE_MOTIF
 	else {
 		setPuzzle(w, ACTION_PRACTICE_QUERY);
@@ -1788,23 +1796,23 @@ PracticePuzzleMaybe(DinoWidget w
 }
 
 void
-PracticePuzzle2(DinoWidget w
+practicePuzzleWithDoubleClick(DinoWidget w
 , XEvent *event, char **args, int nArgs
 )
 {
 #ifdef HAVE_MOTIF
 	if (!w->dino.started)
 #endif
-		PracticePieces(w);
+		practicePieces(w);
 }
 
 void
-RandomizePuzzleMaybe(DinoWidget w
+randomizePuzzleWithQuery(DinoWidget w
 , XEvent *event, char **args, int nArgs
 )
 {
 	if (!w->dino.started)
-		RandomizePieces(w);
+		randomizePieces(w);
 #ifdef HAVE_MOTIF
 	else {
 		setPuzzle(w, ACTION_RANDOMIZE_QUERY);
@@ -1813,110 +1821,110 @@ RandomizePuzzleMaybe(DinoWidget w
 }
 
 void
-RandomizePuzzle2(DinoWidget w
+randomizePuzzleWithDoubleClick(DinoWidget w
 , XEvent *event, char **args, int nArgs
 )
 {
 #ifdef HAVE_MOTIF
 	if (!w->dino.started)
 #endif
-		RandomizePieces(w);
+		randomizePieces(w);
 }
 #endif
 
 void
-GetPuzzle(DinoWidget w
+getPuzzle(DinoWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 )
 {
-	GetPieces(w);
+	getPieces(w);
 }
 
 void
-WritePuzzle(DinoWidget w
+writePuzzle(DinoWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 )
 {
-	WritePieces(w);
+	writePieces(w);
 }
 
 void
-UndoPuzzle(DinoWidget w
+undoPuzzle(DinoWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 )
 {
-	UndoPieces(w);
+	undoPieces(w);
 }
 
 void
-RedoPuzzle(DinoWidget w
+redoPuzzle(DinoWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 )
 {
-	RedoPieces(w);
+	redoPieces(w);
 }
 
 void
-ClearPuzzle(DinoWidget w
+clearPuzzle(DinoWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 )
 {
-	ClearPieces(w);
+	clearPieces(w);
 }
 
 void
-RandomizePuzzle(DinoWidget w
+randomizePuzzle(DinoWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 )
 {
-	RandomizePieces(w);
+	randomizePieces(w);
 }
 
 void
-SolvePuzzle(DinoWidget w
+solvePuzzle(DinoWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 )
 {
-	SolvePieces(w);
+	solvePieces(w);
 }
 
 void
-PracticePuzzle(DinoWidget w
+practicePuzzle(DinoWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 )
 {
-	PracticePieces(w);
+	practicePieces(w);
 }
 
 void
-OrientizePuzzle(DinoWidget w
+orientizePuzzle(DinoWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 )
 {
-	OrientizePieces(w);
+	orientizePieces(w);
 }
 
 #ifndef WINVER
 void
-Period2ModePuzzle(DinoWidget w
+period2modePuzzle(DinoWidget w
 , XEvent *event, char **args, int nArgs
 )
 {
@@ -1924,7 +1932,7 @@ Period2ModePuzzle(DinoWidget w
 }
 
 void
-Period3ModePuzzle(DinoWidget w
+period3modePuzzle(DinoWidget w
 , XEvent *event, char **args, int nArgs
 )
 {
@@ -1932,7 +1940,7 @@ Period3ModePuzzle(DinoWidget w
 }
 
 void
-BothModePuzzle(DinoWidget w
+bothmodePuzzle(DinoWidget w
 , XEvent *event, char **args, int nArgs
 )
 {
@@ -1941,76 +1949,76 @@ BothModePuzzle(DinoWidget w
 #endif
 
 void
-ViewPuzzle(DinoWidget w
+viewPuzzle(DinoWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 )
 {
-	ViewPieces(w);
+	viewPieces(w);
 }
 
 void
-SpeedPuzzle(DinoWidget w
+speedUpPuzzle(DinoWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 )
 {
-	SpeedPieces(w);
+	speedPieces(w);
 }
 
 void
-SlowPuzzle(DinoWidget w
+slowDownPuzzle(DinoWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 )
 {
-	SlowPieces(w);
+	slowPieces(w);
 }
 
 void
-SoundPuzzle(DinoWidget w
+toggleSoundPuzzle(DinoWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 )
 {
-	SoundPieces(w);
+	soundPieces(w);
 }
 
 void
-EnterPuzzle(DinoWidget w
+enterPuzzle(DinoWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 )
 {
 	w->dino.focus = True;
-	DrawFrame(w, w->dino.focus);
+	drawFrame(w, w->dino.focus);
 }
 
 void
-LeavePuzzle(DinoWidget w
+leavePuzzle(DinoWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 )
 {
 	w->dino.focus = False;
-	DrawFrame(w, w->dino.focus);
+	drawFrame(w, w->dino.focus);
 }
 
 #ifdef WINVER
 void
-PeriodModePuzzle(DinoWidget w, const int mode)
+periodmodePuzzle(DinoWidget w, const int mode)
 {
 	setPuzzle(w, mode + ACTION_PERIOD2);
 }
 
 void
-DimPuzzle(DinoWidget w)
+dimPuzzle(DinoWidget w)
 {
 	setPuzzle(w, ACTION_DIM);
 }
