@@ -1,27 +1,22 @@
-/*-
-# X-BASED DINOSAUR CUBE
-#
-#  DinoGLP.h
-#
-###
-#
-#  Copyright (c) 2006 - 2008	David A. Bagley, bagleyd@tux.org
-#
-#                   All Rights Reserved
-#
-#  Permission to use, copy, modify, and distribute this software and
-#  its documentation for any purpose and without fee is hereby granted,
-#  provided that the above copyright notice appear in all copies and
-#  that both that copyright notice and this permission notice appear in
-#  supporting documentation, and that the name of the author not be
-#  used in advertising or publicity pertaining to distribution of the
-#  software without specific, written prior permission.
-#
-#  This program is distributed in the hope that it will be "playable",
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-#
-*/
+/*
+ * @(#)DinoGLP.h
+ *
+ * Copyright 2007 - 2008  David A. Bagley, bagleyd@tux.org
+ *
+ * All rights reserved.
+ *
+ * Permission to use, copy, modify, and distribute this software and
+ * its documentation for any purpose and without fee is hereby granted,
+ * provided that the above copyright notice appear in all copies and
+ * that both that copyright notice and this permission notice appear in
+ * supporting documentation, and that the name of the author not be
+ * used in advertising or publicity pertaining to distribution of the
+ * software without specific, written prior permission.
+ *
+ * This program is distributed in the hope that it will be "useful",
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ */
 
 /* Private header file for DinoGL */
 
@@ -110,13 +105,13 @@ typedef struct _DinoGLRec {
 	DinoGLPart  dinoGL;
 } DinoGLRec;
 
-extern Boolean SelectPiecesGL(DinoGLWidget w, int x, int y,
+extern Boolean selectPiecesGL(DinoGLWidget w, int x, int y,
 	int *face, int *position);
-extern void DrawFrameGL(DinoGLWidget w, Boolean focus);
-extern void DrawAllPiecesGL(DinoGLWidget w);
+extern void drawFrameGL(DinoGLWidget w, Boolean focus);
+extern void drawAllPiecesGL(DinoGLWidget w);
 #ifdef WINVER
-extern void ResizePuzzleGL(DinoGLWidget w);
-extern void ExposePuzzleGL(DinoGLWidget w);
+extern void resizePuzzleGL(DinoGLWidget w);
+extern void exposePuzzleGL(DinoGLWidget w);
 #endif
 
 #endif /* _DinoGLP_h */
