@@ -1,27 +1,24 @@
-/*-
-# MOTIF/X-BASED DINOSAUR CUBE
-#
-#  xdino.c
-#
-###
-#
-#  Copyright (c) 1995 - 2007	David A. Bagley, bagleyd@tux.org
-#
-#                   All Rights Reserved
-#
-#  Permission to use, copy, modify, and distribute this software and
-#  its documentation for any purpose and without fee is hereby granted,
-#  provided that the above copyright notice appear in all copies and
-#  that both that copyright notice and this permission notice appear in
-#  supporting documentation, and that the name of the author not be
-#  used in advertising or publicity pertaining to distribution of the
-#  software without specific, written prior permission.
-#
-#  This program is distributed in the hope that it will be "playable",
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-#
-*/
+/*
+ * @(#)xdino.c
+ *
+ * Copyright 1995 - 2008  David A. Bagley, bagleyd@tux.org
+ *
+ * All rights reserved.
+ *
+ * Permission to use, copy, modify, and distribute this software and
+ * its documentation for any purpose and without fee is hereby granted,
+ * provided that the above copyright notice appear in all copies and
+ * that both that copyright notice and this permission notice appear in
+ * supporting documentation, and that the name of the author not be
+ * used in advertising or publicity pertaining to distribution of the
+ * software without specific, written prior permission.
+ *
+ * This program is distributed in the hope that it will be "useful",
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ */
+
+/* Driver file for Dino */
 
 #include "file.h"
 #ifdef WINVER
@@ -57,7 +54,7 @@ static DinoRec widget;
 #include "pixmaps/mouse-l.xbm"
 #include "pixmaps/mouse-r.xbm"
 #endif
-#define PRINT_MESSAGE(b) PrintState(message, b)
+#define PRINT_MESSAGE(b) printState(message, b)
 #else
 #define PRINT_MESSAGE(b) XtWarning(b)
 #endif
@@ -94,7 +91,7 @@ static DinoRec widget;
 
 #ifndef WINVER
 static const char aboutHelp[] = {
-"Dino Version 7.3.2\n"
+"Dino Version 7.4\n"
 "Send bugs (reports or fixes) to the author: "
 "David Bagley <bagleyd@tux.org>\n"
 "The latest version is at: "
@@ -253,7 +250,7 @@ static char progDsp[PROGRAM_NAME_LENGTH] = TITLE;
 static char userNameDsp[USER_NAME_LENGTH] = "Guest";
 #else
 #ifdef HAVE_MOTIF
-static Widget moves, record, message, modes[MAX_MODES];
+static Widget movesText, recordText, message, modes[MAX_MODES];
 static Widget orientizeSwitch, practiceSwitch;
 static char buff[21];
 static const char *modeString[] =
@@ -280,19 +277,19 @@ static char userNameDsp[USER_NAME_LENGTH] = "";
 
 #ifdef HAVE_MOTIF
 static void
-PrintState(Widget w, char *msg)
+printState(Widget w, char *msg)
 {
 	XmString xmstr;
 
 	if (!XtIsSubclass(w, xmLabelWidgetClass))
-		XtError("PrintState() requires a Label Widget");
+		XtError("printState() requires a Label Widget");
 	xmstr = XmStringCreateLtoR(msg, XmSTRING_DEFAULT_CHARSET);
 	XtVaSetValues(w, XmNlabelString, xmstr, NULL);
 }
 #endif
 
 static void
-PrintRecords(void)
+printRecords(void)
 {
 	int mode, orient;
 
@@ -310,7 +307,7 @@ PrintRecords(void)
 #endif
 
 static void
-InitRecords(void)
+initRecords(void)
 {
 	int mode, orient;
 
@@ -323,7 +320,7 @@ InitRecords(void)
 }
 
 static void
-ReadRecords(void)
+readRecords(void)
 {
 	FILE *fp;
 	int n, mode, orient;
@@ -382,7 +379,7 @@ ReadRecords(void)
 }
 
 static void
-WriteRecords(void)
+writeRecords(void)
 {
 	FILE *fp;
 	int mode, orient;
@@ -431,7 +428,7 @@ WriteRecords(void)
 }
 
 static void
-PrintRecord(int mode, Boolean orient, Boolean practice)
+printRecord(int mode, Boolean orient, Boolean practice)
 {
 	int i = mode - PERIOD2;
 	int j = (orient) ? 1 : 0;
@@ -445,7 +442,7 @@ PrintRecord(int mode, Boolean orient, Boolean practice)
 			puzzleRecord[i][j].score, puzzleRecord[i][j].name);
 	}
 #ifdef HAVE_MOTIF
-	PrintState(record, recordDsp);
+	printState(recordText, recordDsp);
 #endif
 }
 
@@ -453,7 +450,7 @@ PrintRecord(int mode, Boolean orient, Boolean practice)
 /* There is probably a better way to assure that they are the same
  * but I do not know it off hand. */
 static void
-MakeEquivalent(String *userName, String *scoreFile, int *mode,
+makeEquivalent(String *userName, String *scoreFile, int *mode,
 		Boolean *orient, Boolean *practice)
 {
 	Boolean mono, reverse;
@@ -487,9 +484,9 @@ MakeEquivalent(String *userName, String *scoreFile, int *mode,
 	if (strcmp(*scoreFile, ""))
 		(void) strncpy(scoreFileName, *scoreFile, FILE_NAME_LENGTH);
 	if (scoreOnly) {
-		InitRecords();
-		ReadRecords();
-		PrintRecords();
+		initRecords();
+		readRecords();
+		printRecords();
 		exit(0);
 	}
 	XtVaSetValues(puzzle2d,
@@ -536,16 +533,16 @@ MakeEquivalent(String *userName, String *scoreFile, int *mode,
 #endif
 
 static void
-PrintStatus(char *msg, int nMoves
+printStatus(char *msg, int nMoves
 #ifndef HAVE_MOTIF
 		, int dim, int mode
 #endif
 		)
 {
 #ifdef HAVE_MOTIF
-	PrintState(message, msg);
+	printState(message, msg);
 	(void) sprintf(buff, "%d", nMoves);
-	PrintState(moves, buff);
+	printState(movesText, buff);
 #else
 	char mb[10];
 
@@ -576,14 +573,14 @@ PrintStatus(char *msg, int nMoves
 }
 
 static Boolean
-HandleSolved(int counter, int mode, Boolean orient)
+handleSolved(int counter, int mode, Boolean orient)
 {
 	int i = mode - PERIOD2;
 	int j = (orient) ? 1 : 0;
 
 	if (counter < puzzleRecord[i][j].score ||
 			puzzleRecord[i][j].score <= NEVER) {
-		ReadRecords();	/* Maybe its been updated by another */
+		readRecords();	/* Maybe its been updated by another */
 		puzzleRecord[i][j].score = counter;
 		(void) strncpy(puzzleRecord[i][j].name, userNameDsp,
 			USER_NAME_LENGTH);
@@ -593,15 +590,15 @@ HandleSolved(int counter, int mode, Boolean orient)
 			(void) strncpy(puzzleRecord[!i][j].name, userNameDsp,
 				USER_NAME_LENGTH);
 		}
-		WriteRecords();
-		PrintRecord(mode, orient, False);
+		writeRecords();
+		printRecord(mode, orient, False);
 		return True;
 	}
 	return False;
 }
 
 static void
-Initialize(
+initialize(
 #ifdef WINVER
 DinoWidget w, HBRUSH brush
 #else
@@ -615,7 +612,7 @@ void
 #ifdef WINVER
 	int dim;
 
-	InitializePuzzle(w, brush);
+	initializePuzzle(w, brush);
 
 	mode = w->dino.mode;
 	orient = w->dino.orient;
@@ -627,15 +624,15 @@ void
 	if (strcmp(scoreFile, ""))
 		(void) strncpy(scoreFileName, scoreFile, FILE_NAME_LENGTH);
 #else
-	MakeEquivalent(&userName, &scoreFile, &mode, &orient, &practice);
+	makeEquivalent(&userName, &scoreFile, &mode, &orient, &practice);
 #ifdef HAVE_MOTIF
 	XmToggleButtonSetState(modes[mode - PERIOD2], True, False);
 	XmToggleButtonSetState(orientizeSwitch, orient, True);
 	XmToggleButtonSetState(practiceSwitch, practice, True);
 #endif
 #endif
-	InitRecords();
-	ReadRecords();
+	initRecords();
+	readRecords();
 #ifndef WINVER
 	(void) strncpy(userNameDsp, userName, USER_NAME_LENGTH);
 #endif
@@ -660,17 +657,17 @@ void
 			(void) sprintf(userNameDsp, "%s", "guest");
 #endif
 	}
-	PrintRecord(mode, orient, practice);
+	printRecord(mode, orient, practice);
 #ifdef WINVER
-	PrintStatus(messageDsp, movesDsp, dim, mode);
+	printStatus(messageDsp, movesDsp, dim, mode);
 #else
 #ifdef HAVE_MOTIF
-	PrintStatus(messageDsp, movesDsp);
+	printStatus(messageDsp, movesDsp);
 #else
-	PrintStatus(messageDsp, movesDsp, 2, mode);
-	PrintStatus(messageDsp, movesDsp, 3, mode);
+	printStatus(messageDsp, movesDsp, 2, mode);
+	printStatus(messageDsp, movesDsp, 3, mode);
 #ifdef HAVE_OPENGL
-	PrintStatus(messageDsp, movesDsp, 4, mode);
+	printStatus(messageDsp, movesDsp, 4, mode);
 #endif
 #endif
 #endif
@@ -681,7 +678,7 @@ void
 setPuzzle(DinoWidget w, int reason)
 #else
 static void
-CallbackPuzzle(Widget w, caddr_t clientData, dinoCallbackStruct *callData)
+puzzleListener(Widget w, caddr_t clientData, dinoCallbackStruct *callData)
 #endif
 {
 	int mode;
@@ -807,7 +804,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, dinoCallbackStruct *callData)
 			(void) strncpy(recordDsp, "practice",
 				MESSAGE_LENGTH);
 #ifdef HAVE_MOTIF
-			PrintState(record, recordDsp);
+			printState(recordText, recordDsp);
 #endif
 		}
 		movesDsp = 0;
@@ -893,7 +890,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, dinoCallbackStruct *callData)
 		else if (cheat)
 			(void) sprintf(messageDsp,
 				"No cheating %s!!", userNameDsp);
-		else if (HandleSolved(movesDsp, mode, orient))
+		else if (handleSolved(movesDsp, mode, orient))
 			(void) sprintf(messageDsp,
 				"Congratulations %s!!", userNameDsp);
 		else
@@ -924,7 +921,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, dinoCallbackStruct *callData)
 		if (!practice)
 			(void) strncpy(messageDsp, "Randomize to start",
 				MESSAGE_LENGTH);
-		PrintRecord(mode, orient, practice);
+		printRecord(mode, orient, practice);
 #ifdef WINVER
 		w->dino.practice = practice;
 		w->dino.started = False;
@@ -989,7 +986,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, dinoCallbackStruct *callData)
 	case ACTION_ORIENTIZE:
 		movesDsp = 0;
 		orient = !orient;
-		PrintRecord(mode, orient, practice);
+		printRecord(mode, orient, practice);
 #ifdef WINVER
 		w->dino.orient = orient;
 #else
@@ -1011,7 +1008,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, dinoCallbackStruct *callData)
 	case ACTION_BOTH:
 		movesDsp = 0;
 		mode = reason - ACTION_PERIOD2 + PERIOD2;
-		PrintRecord(mode, orient, practice);
+		printRecord(mode, orient, practice);
 #ifdef WINVER
 		w->dino.mode = mode;
 #else
@@ -1082,15 +1079,15 @@ CallbackPuzzle(Widget w, caddr_t clientData, dinoCallbackStruct *callData)
 #endif
 	}
 #ifdef WINVER
-	PrintStatus(messageDsp, movesDsp, dim, mode);
+	printStatus(messageDsp, movesDsp, dim, mode);
 #else
 #ifdef HAVE_MOTIF
-	PrintStatus(messageDsp, movesDsp);
+	printStatus(messageDsp, movesDsp);
 #else
-	PrintStatus(messageDsp, movesDsp, dim, mode);
-	PrintStatus(messageDsp, movesDsp, otherdim1, mode);
+	printStatus(messageDsp, movesDsp, dim, mode);
+	printStatus(messageDsp, movesDsp, otherdim1, mode);
 #ifdef HAVE_OPENGL
-	PrintStatus(messageDsp, movesDsp, otherdim2, mode);
+	printStatus(messageDsp, movesDsp, otherdim2, mode);
 #endif
 #endif
 #endif
@@ -1129,19 +1126,15 @@ setPuzzleMove(DinoWidget w, int reason, int face, int position, int direction,
 		SET_STARTED(w, True);
 		break;
 	}
-	PrintStatus(messageDsp, movesDsp, dim, mode);
+	printStatus(messageDsp, movesDsp, dim, mode);
 }
 
 static LRESULT CALLBACK
-About(HWND hDlg, UINT message, WPARAM wParam, LPARAM lParam)
+about(HWND hDlg, UINT message, WPARAM wParam, LPARAM lParam)
 {
-	switch (message) {
-	case WM_COMMAND:
-		if (LOWORD(wParam) == IDOK) {
-			(void) EndDialog(hDlg, TRUE);
-			return TRUE;
-		}
-		break;
+	if (message == WM_COMMAND && LOWORD(wParam) == IDOK) {
+		(void) EndDialog(hDlg, TRUE);
+		return TRUE;
 	}
 	return FALSE;
 }
@@ -1159,7 +1152,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_BRUSH));
-			EnterPuzzle(&widget);
+			enterPuzzle(&widget);
 			(void) EndPaint(hWnd, &paint);
 		}
 	} else {
@@ -1167,40 +1160,40 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_BRUSH));
-			LeavePuzzle(&widget);
+			leavePuzzle(&widget);
 			(void) EndPaint(hWnd, &paint);
 		}
 	}
 	switch (message) {
 	case WM_CREATE:
-		Initialize(&widget, brush);
+		initialize(&widget, brush);
 		break;
 	case WM_DESTROY:
-		DestroyPuzzle(brush);
+		destroyPuzzle(brush);
 		break;
 	case WM_SIZE:
-		ResizePuzzle(&widget);
+		resizePuzzle(&widget);
 		(void) InvalidateRect(hWnd, NULL, TRUE);
 		break;
 	case WM_PAINT:
 		widget.core.hDC = BeginPaint(hWnd, &paint);
 		(void) SelectObject(widget.core.hDC,
 			GetStockObject(NULL_PEN));
-		ExposePuzzle(&widget);
+		exposePuzzle(&widget);
 		(void) EndPaint(hWnd, &paint);
 		break;
 	case WM_RBUTTONDOWN:
 		widget.core.hDC = GetDC(hWnd);
 		(void) SelectObject(widget.core.hDC,
 			GetStockObject(NULL_PEN));
-		RandomizePuzzle(&widget);
+		randomizePuzzle(&widget);
 		(void) ReleaseDC(hWnd, widget.core.hDC);
 		break;
 	case WM_LBUTTONDOWN:
 		widget.core.hDC = GetDC(hWnd);
 		(void) SelectObject(widget.core.hDC,
 			GetStockObject(NULL_PEN));
-		SelectPuzzle(&widget, LOWORD(lParam), HIWORD(lParam),
+		selectPuzzle(&widget, LOWORD(lParam), HIWORD(lParam),
 			(GetKeyState(VK_CONTROL) >> 1) ? 1 : 0);
 		(void) ReleaseDC(hWnd, widget.core.hDC);
 		break;
@@ -1208,7 +1201,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 		widget.core.hDC = GetDC(hWnd);
 		(void) SelectObject(widget.core.hDC,
 			GetStockObject(NULL_PEN));
-		ReleasePuzzle(&widget, LOWORD(lParam), HIWORD(lParam),
+		releasePuzzle(&widget, LOWORD(lParam), HIWORD(lParam),
 			((GetKeyState(VK_SHIFT) >> 1) ||
 			(GetKeyState(VK_CAPITAL) & 1)),
 			(GetKeyState(VK_CONTROL) >> 1) ? 1 : 0,
@@ -1228,7 +1221,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			ClientToScreen(hWnd, &origin);
 			(void) GetCursorPos(&cursor);
 			if (zDelta > (WHEEL_DELTA >> 1)) {
-				MovePuzzleInput(&widget,
+				movePuzzleInput(&widget,
 					cursor.x - origin.x,
 					cursor.y - origin.y,
 					TOP,
@@ -1237,7 +1230,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 					(GetKeyState(VK_CONTROL) >> 1) ? 1 : 0,
 					(GetKeyState(VK_TAB) >> 1) ? 1 : 0);
 			} else if (zDelta < -(WHEEL_DELTA >> 1)) {
-				MovePuzzleInput(&widget,
+				movePuzzleInput(&widget,
 					cursor.x - origin.x,
 					cursor.y - origin.y,
 					BOTTOM,
@@ -1253,70 +1246,70 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 	case WM_COMMAND:
 		switch (LOWORD(wParam)) {
 		case ACTION_GET:
-			GetPuzzle(&widget);
-			ResizePuzzle(&widget);
+			getPuzzle(&widget);
+			resizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
 		case ACTION_WRITE:
-			WritePuzzle(&widget);
+			writePuzzle(&widget);
 			break;
 		case ACTION_EXIT:
-			DestroyPuzzle(brush);
+			destroyPuzzle(brush);
 			break;
 		case ACTION_HIDE:
-			HidePuzzle(&widget);
+			hidePuzzle(&widget);
 			break;
 		case ACTION_UNDO:
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_PEN));
-			UndoPuzzle(&widget);
+			undoPuzzle(&widget);
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
 		case ACTION_REDO:
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_PEN));
-			RedoPuzzle(&widget);
+			redoPuzzle(&widget);
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
 		case ACTION_CLEAR:
-			ClearPuzzle(&widget);
-			SizePuzzle(&widget);
+			clearPuzzle(&widget);
+			sizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
 		case ACTION_RANDOMIZE:
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_PEN));
-			RandomizePuzzle(&widget);
+			randomizePuzzle(&widget);
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
 		case ACTION_PRACTICE:
-			PracticePuzzle(&widget);
-			SizePuzzle(&widget);
+			practicePuzzle(&widget);
+			sizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
 		case ACTION_SOLVE:
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_PEN));
-			SolvePuzzle(&widget);
+			solvePuzzle(&widget);
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
 		case ACTION_ORIENTIZE:
-			OrientizePuzzle(&widget);
-			SizePuzzle(&widget);
+			orientizePuzzle(&widget);
+			sizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
 		case ACTION_DIM:
-			(void) DimPuzzle(&widget);
-			ResizePuzzle(&widget);
+			(void) dimPuzzle(&widget);
+			resizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
 		case ACTION_VIEW:
-			(void) ViewPuzzle(&widget);
-			SizePuzzle(&widget);
+			(void) viewPuzzle(&widget);
+			sizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
 		case ACTION_SHIFT_TR:
@@ -1350,7 +1343,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 				ClientToScreen(hWnd, &origin);
 				(void) GetCursorPos(&cursor);
 				shift = shift || (GetKeyState(VK_CAPITAL) & 1);
-				(void) MovePuzzleInput(&widget,
+				(void) movePuzzleInput(&widget,
 					cursor.x - origin.x,
 					cursor.y - origin.y,
 					(int) LOWORD(wParam) -
@@ -1389,7 +1382,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 				origin.x = 0, origin.y = 0;
 						ClientToScreen(hWnd, &origin);
 						(void) GetCursorPos(&cursor);
-				(void) MovePuzzleInput(&widget,
+				(void) movePuzzleInput(&widget,
 					cursor.x - origin.x,
 					cursor.y - origin.y,
 					(int) LOWORD(wParam) -
@@ -1429,7 +1422,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 				origin.x = 0, origin.y = 0;
 				ClientToScreen(hWnd, &origin);
 				(void) GetCursorPos(&cursor);
-				(void) MovePuzzleInput(&widget,
+				(void) movePuzzleInput(&widget,
 					cursor.x - origin.x,
 					cursor.y - origin.y,
 					(int) LOWORD(wParam) -
@@ -1442,19 +1435,19 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 		case ACTION_PERIOD2:
 		case ACTION_PERIOD3:
 		case ACTION_BOTH:
-			PeriodModePuzzle(&widget,
+			periodmodePuzzle(&widget,
 				(int) LOWORD(wParam) - ACTION_PERIOD2);
-			SizePuzzle(&widget);
+			sizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
 		case ACTION_SPEED:
-			SpeedPuzzle(&widget);
+			speedUpPuzzle(&widget);
 			break;
 		case ACTION_SLOW:
-			SlowPuzzle(&widget);
+			slowDownPuzzle(&widget);
 			break;
 		case ACTION_SOUND:
-			SoundPuzzle(&widget);
+			toggleSoundPuzzle(&widget);
 			break;
 		case ACTION_DESCRIPTION:
 			(void) MessageBox(hWnd, descriptionHelp,
@@ -1470,7 +1463,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			break;
 		case ACTION_ABOUT:
 			(void) DialogBox(widget.core.hInstance,
-				"About", hWnd, (DLGPROC) About);
+				"About", hWnd, (DLGPROC) about);
 			break;
 		}
 		break;
@@ -1530,7 +1523,7 @@ WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance, LPSTR lpCmdLine,
 
 #else
 static void
-Usage(char *programName)
+usage(char *programName)
 {
 	unsigned int i;
 
@@ -1583,7 +1576,7 @@ static XrmOptionDescRec options[] =
 
 #ifdef HAVE_MOTIF
 static void
-CallbackPuzzlePractice(Widget w, XtPointer clientData, XmAnyCallbackStruct *cbs)
+puzzlePracticeListener(Widget w, XtPointer clientData, XmAnyCallbackStruct *cbs)
 {
 	if (cbs->reason == XmCR_OK) {
 		XtVaSetValues(puzzle2d, XtNmenu, ACTION_PRACTICE, NULL);
@@ -1591,14 +1584,14 @@ CallbackPuzzlePractice(Widget w, XtPointer clientData, XmAnyCallbackStruct *cbs)
 }
 
 static void
-CallbackPuzzleRandomize(Widget w, XtPointer clientData, XmAnyCallbackStruct *cbs)
+puzzleRandomizeListener(Widget w, XtPointer clientData, XmAnyCallbackStruct *cbs)
 {
 	if (cbs->reason == XmCR_OK) {
 		XtVaSetValues(puzzle2d, XtNmenu, ACTION_RANDOMIZE, NULL);
 	}
 }
 static void
-ModeToggle(Widget w, int mode, XmToggleButtonCallbackStruct *cbs)
+modeToggle(Widget w, int mode, XmToggleButtonCallbackStruct *cbs)
 {
 	Boolean orient, practice;
 
@@ -1616,15 +1609,15 @@ ModeToggle(Widget w, int mode, XmToggleButtonCallbackStruct *cbs)
 #endif
 		movesDsp = 0;
 		(void) sprintf(buff, "%d", movesDsp);
-		PrintState(moves, buff);
-		PrintRecord(mode + PERIOD2, orient, practice);
+		printState(movesText, buff);
+		printRecord(mode + PERIOD2, orient, practice);
 		(void) strcpy(messageDsp, "");
-		PrintState(message, messageDsp);
+		printState(message, messageDsp);
 	}
 }
 
 static void
-OrientToggle(Widget w, XtPointer clientData, XmToggleButtonCallbackStruct *cbs)
+orientToggle(Widget w, XtPointer clientData, XmToggleButtonCallbackStruct *cbs)
 {
 	int mode;
 	Boolean orient = cbs->set, practice;
@@ -1642,14 +1635,14 @@ OrientToggle(Widget w, XtPointer clientData, XmToggleButtonCallbackStruct *cbs)
 #endif
 	movesDsp = 0;
 	(void) sprintf(buff, "%d", movesDsp);
-	PrintState(moves, buff);
-	PrintRecord(mode, orient, practice);
+	printState(movesText, buff);
+	printRecord(mode, orient, practice);
 	(void) strcpy(messageDsp, "");
-	PrintState(message, messageDsp);
+	printState(message, messageDsp);
 }
 
 static void
-PracticeToggle(Widget w, XtPointer clientData,
+practiceToggle(Widget w, XtPointer clientData,
 		XmToggleButtonCallbackStruct *cbs)
 {
 	int mode;
@@ -1671,17 +1664,17 @@ PracticeToggle(Widget w, XtPointer clientData,
 		XtNpractice, &orient, NULL);
 	movesDsp = 0;
 	(void) sprintf(buff, "%d", movesDsp);
-	PrintState(moves, buff);
-	PrintRecord(mode, orient, practice);
+	printState(movesText, buff);
+	printRecord(mode, orient, practice);
 	if (practice)
 		(void) strcpy(messageDsp, "");
 	else
 		(void) strncpy(messageDsp, "Randomize to start", MESSAGE_LENGTH);
-	PrintState(message, messageDsp);
+	printState(message, messageDsp);
 }
 
 static void
-fileCB(Widget w, void *value, void *clientData)
+fileMenuListener(Widget w, void *value, void *clientData)
 {
 	int val = (int) value + ACTION_GET;
 
@@ -1753,7 +1746,7 @@ createHelp(Widget w, char *text, char *title)
 }
 
 static void
-helpCB(Widget w, XtPointer value, XtPointer clientData)
+helpMenuListener(Widget w, XtPointer value, XtPointer clientData)
 {
 	int val = (int) value;
 
@@ -1777,7 +1770,7 @@ helpCB(Widget w, XtPointer value, XtPointer clientData)
 		{
 			char *buf;
 
-			intCat(&buf, "helpCB: %d", val);
+			intCat(&buf, "helpMenuListener: %d", val);
 			XtWarning(buf);
 			free(buf);
 		}
@@ -1807,7 +1800,7 @@ main(int argc, char **argv)
 	topLevel = XtInitialize(argv[0], "Dino",
 		options, XtNumber(options), &argc, argv);
 	if (argc != 1)
-		Usage(argv[0]);
+		usage(argv[0]);
 
 #ifdef HAVE_MOTIF
 	menuBarPanel = XtVaCreateManagedWidget("menuBarPanel",
@@ -1827,7 +1820,7 @@ main(int argc, char **argv)
 	writeString = XmStringCreateSimple((char *) "Write");
 	quitString = XmStringCreateSimple((char *) "Quit");
 	(void) XmVaCreateSimplePulldownMenu(menuBar, (char *) "file_menu",
-		0, fileCB,
+		0, fileMenuListener,
 		XmVaPUSHBUTTON, getString, 'G', NULL, NULL,
 		XmVaPUSHBUTTON, writeString, 'W', NULL, NULL,
 		XmVaSEPARATOR,
@@ -1882,23 +1875,23 @@ main(int argc, char **argv)
 	widget = XtVaCreateManagedWidget("Description",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'D', NULL);
-	XtAddCallback(widget, XmNactivateCallback, helpCB, (char *) 0);
+	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 0);
 	widget = XtVaCreateManagedWidget("Features",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'F', NULL);
-	XtAddCallback(widget, XmNactivateCallback, helpCB, (char *) 1);
+	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 1);
 	widget = XtVaCreateManagedWidget("Options",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'O', NULL);
-	XtAddCallback(widget, XmNactivateCallback, helpCB, (char *) 2);
+	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 2);
 	widget = XtVaCreateManagedWidget("References",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'R', NULL);
-	XtAddCallback(widget, XmNactivateCallback, helpCB, (char *) 3);
+	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 3);
 	widget = XtVaCreateManagedWidget("About",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'A', NULL);
-	XtAddCallback(widget, XmNactivateCallback, helpCB, (char *) 4);
+	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 4);
 	XtManageChild(menuBar);
 	descriptionDialog = createHelp(menuBar, (char *) descriptionHelp,
 		(char *) "Description");
@@ -1915,11 +1908,11 @@ main(int argc, char **argv)
 	practiceDialog = createQuery(topLevel,
 		(char *) "Are you sure you want to toggle the practice mode?",
 		(char *) "Practice Query",
-		(XtCallbackProc) CallbackPuzzlePractice);
+		(XtCallbackProc) puzzlePracticeListener);
 	randomizeDialog = createQuery(topLevel,
 		(char *) "Are you sure you want to randomize?",
 		(char *) "Randomize Query",
-		(XtCallbackProc) CallbackPuzzleRandomize);
+		(XtCallbackProc) puzzleRandomizeListener);
 	mainPanel = XtCreateManagedWidget("mainPanel",
 		xmPanedWindowWidgetClass, menuBarPanel,
 		NULL, 0);
@@ -1975,12 +1968,12 @@ main(int argc, char **argv)
 	(void) XtVaCreateManagedWidget("movesText",
 		xmLabelGadgetClass, movesRowCol,
 		XtVaTypedArg, XmNlabelString, XmRString, "Moves", 6, NULL);
-	moves = XtVaCreateManagedWidget("0",
+	movesText = XtVaCreateManagedWidget("0",
 		xmLabelWidgetClass, movesRowCol, NULL);
 	(void) XtVaCreateManagedWidget("recordText",
 		xmLabelGadgetClass, movesRowCol,
 		XtVaTypedArg, XmNlabelString, XmRString, "Record", 7, NULL);
-	record = XtVaCreateManagedWidget("0",
+	recordText = XtVaCreateManagedWidget("0",
 		xmLabelWidgetClass, movesRowCol, NULL);
 
 	labelRowCol = XtVaCreateManagedWidget("labelRowCol",
@@ -1999,7 +1992,7 @@ main(int argc, char **argv)
 			xmToggleButtonGadgetClass, radioRowCol,
 			XmNradioBehavior, True, NULL);
 		XtAddCallback(modes[i], XmNvalueChangedCallback,
-			(XtCallbackProc) ModeToggle, (XtPointer) i);
+			(XtCallbackProc) modeToggle, (XtPointer) i);
 	}
 	switchRowCol = XtVaCreateManagedWidget("switchRowCol",
 		xmRowColumnWidgetClass, controlPanel,
@@ -2010,12 +2003,12 @@ main(int argc, char **argv)
 		xmToggleButtonWidgetClass, switchRowCol,
 		XmNset, DEFAULT_ORIENT, NULL);
 	XtAddCallback(orientizeSwitch, XmNvalueChangedCallback,
-		(XtCallbackProc) OrientToggle, (XtPointer) NULL);
+		(XtCallbackProc) orientToggle, (XtPointer) NULL);
 	practiceSwitch = XtVaCreateManagedWidget("Practice",
 		xmToggleButtonWidgetClass, switchRowCol,
 		XmNset, DEFAULT_PRACTICE, NULL);
 	XtAddCallback(practiceSwitch, XmNvalueChangedCallback,
-		(XtCallbackProc) PracticeToggle, (XtPointer) NULL);
+		(XtCallbackProc) practiceToggle, (XtPointer) NULL);
 	messageRowCol = XtVaCreateManagedWidget("messageRowCol",
 		xmRowColumnWidgetClass, controlPanel,
 		XmNnumColumns, 1,
@@ -2028,7 +2021,7 @@ main(int argc, char **argv)
 	XtVaSetValues(puzzle2d,
 		XtNheight, 200, NULL);
 	XtAddCallback(puzzle2d, XtNselectCallback,
-		(XtCallbackProc) CallbackPuzzle, (XtPointer) NULL);
+		(XtCallbackProc) puzzleListener, (XtPointer) NULL);
 	puzzle3d = XtCreateManagedWidget("dino",
 		dino3dWidgetClass, mainPanel, NULL, 0);
 	XtVaSetValues(puzzle3d,
@@ -2092,10 +2085,8 @@ main(int argc, char **argv)
 		XtNinput, True,
 		XtNiconPixmap, pixmap, NULL);
 #endif
-	XtAddCallback(puzzle2d, XtNselectCallback,
-		(XtCallbackProc) CallbackPuzzle, (XtPointer) NULL);
 	XtAddCallback(puzzle3d, XtNselectCallback,
-		(XtCallbackProc) CallbackPuzzle, (XtPointer) NULL);
+		(XtCallbackProc) puzzleListener, (XtPointer) NULL);
 #ifdef HAVE_OPENGL
 #ifndef HAVE_MOTIF
 	XtVaSetValues(shellGL,
@@ -2103,9 +2094,9 @@ main(int argc, char **argv)
 		XtNiconPixmap, pixmap, NULL);
 #endif
 	XtAddCallback(puzzleGL, XtNselectCallback,
-		(XtCallbackProc) CallbackPuzzle, (XtPointer) NULL);
+		(XtCallbackProc) puzzleListener, (XtPointer) NULL);
 #endif
-	Initialize();
+	initialize();
 	XtRealizeWidget(topLevel);
 #ifndef HAVE_MOTIF
 	XtRealizeWidget(shell);
@@ -2117,12 +2108,12 @@ main(int argc, char **argv)
 		XtWindow(puzzle2d), TRUE, (unsigned int) (ButtonPressMask |
 		ButtonMotionMask | ButtonReleaseMask),
 		GrabModeAsync, GrabModeAsync, XtWindow(puzzle2d),
-		XCreateFontCursor(XtDisplay(puzzle2d), XC_crosshair));
+		XCreateFontCursor(XtDisplay(puzzle2d), XC_hand2));
 	XGrabButton(XtDisplay(puzzle3d), (unsigned int) AnyButton, AnyModifier,
 		XtWindow(puzzle3d), TRUE, (unsigned int) (ButtonPressMask |
 		ButtonMotionMask | ButtonReleaseMask),
 		GrabModeAsync, GrabModeAsync, XtWindow(puzzle3d),
-		XCreateFontCursor(XtDisplay(puzzle3d), XC_crosshair));
+		XCreateFontCursor(XtDisplay(puzzle3d), XC_hand2));
 #ifdef HAVE_OPENGL
 	XGrabButton(XtDisplay(puzzleGL), (unsigned int) AnyButton, AnyModifier,
 		XtWindow(puzzleGL), TRUE, (unsigned int) (ButtonPressMask |
