@@ -1,27 +1,22 @@
-/*-
-# X-BASED HEXAGONS
-#
-#  HexagonsP.h
-#
-###
-#
-#  Copyright (c) 1994 - 2008	David A. Bagley, bagleyd@tux.org
-#
-#                   All Rights Reserved
-#
-#  Permission to use, copy, modify, and distribute this software and
-#  its documentation for any purpose and without fee is hereby granted,
-#  provided that the above copyright notice appear in all copies and
-#  that both that copyright notice and this permission notice appear in
-#  supporting documentation, and that the name of the author not be
-#  used in advertising or publicity pertaining to distribution of the
-#  software without specific, written prior permission.
-#
-#  This program is distributed in the hope that it will be "playable",
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-#
-*/
+/*
+ * @(#)HexagonsP.h
+ *
+ * Copyright 1994 - 2008  David A. Bagley, bagleyd@tux.org
+ *
+ * All rights reserved.
+ *
+ * Permission to use, copy, modify, and distribute this software and
+ * its documentation for any purpose and without fee is hereby granted,
+ * provided that the above copyright notice appear in all copies and
+ * that both that copyright notice and this permission notice appear in
+ * supporting documentation, and that the name of the author not be
+ * used in advertising or publicity pertaining to distribution of the
+ * software without specific, written prior permission.
+ *
+ * This program is distributed in the hope that it will be "useful",
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ */
 
 /* Private header file for Hexagons */
 
@@ -33,28 +28,28 @@
 #include "Hexagons.h"
 
 #ifdef WINVER
-extern void DestroyPuzzle(HexagonsWidget w, HBRUSH brush);
-extern void ResizePuzzle(HexagonsWidget w);
-extern void SizePuzzle(HexagonsWidget w);
-extern void InitializePuzzle(HexagonsWidget w, HBRUSH brush);
-extern void ExposePuzzle(HexagonsWidget w);
-extern void HidePuzzle(HexagonsWidget w);
-extern void SelectPuzzle(HexagonsWidget w, const int x, const int y);
-extern void ReleasePuzzle(HexagonsWidget w, const int x, const int y);
-extern void GetPuzzle(HexagonsWidget w);
-extern void WritePuzzle(HexagonsWidget w);
-extern void UndoPuzzle(HexagonsWidget w);
-extern void RedoPuzzle(HexagonsWidget w);
-extern void ClearPuzzle(HexagonsWidget w);
-extern void RandomizePuzzle(HexagonsWidget w);
-extern void SolvePuzzle(HexagonsWidget w);
-extern void CornersPuzzle(HexagonsWidget w);
-extern void SpeedPuzzle(HexagonsWidget w);
-extern void SlowPuzzle(HexagonsWidget w);
-extern void SoundPuzzle(HexagonsWidget w);
-extern void EnterPuzzle(HexagonsWidget w);
-extern void LeavePuzzle(HexagonsWidget w);
-extern int MovePuzzle(HexagonsWidget w, const int direction,
+extern void destroyPuzzle(HexagonsWidget w, HBRUSH brush);
+extern void resizePuzzle(HexagonsWidget w);
+extern void sizePuzzle(HexagonsWidget w);
+extern void initializePuzzle(HexagonsWidget w, HBRUSH brush);
+extern void exposePuzzle(HexagonsWidget w);
+extern void hidePuzzle(HexagonsWidget w);
+extern void selectPuzzle(HexagonsWidget w, const int x, const int y);
+extern void releasePuzzle(HexagonsWidget w, const int x, const int y);
+extern void getPuzzle(HexagonsWidget w);
+extern void writePuzzle(HexagonsWidget w);
+extern void undoPuzzle(HexagonsWidget w);
+extern void redoPuzzle(HexagonsWidget w);
+extern void clearPuzzle(HexagonsWidget w);
+extern void randomizePuzzle(HexagonsWidget w);
+extern void solvePuzzle(HexagonsWidget w);
+extern void cornersPuzzle(HexagonsWidget w);
+extern void speedUpPuzzle(HexagonsWidget w);
+extern void slowDownPuzzle(HexagonsWidget w);
+extern void toggleSoundPuzzle(HexagonsWidget w);
+extern void enterPuzzle(HexagonsWidget w);
+extern void leavePuzzle(HexagonsWidget w);
+extern int movePuzzle(HexagonsWidget w, const int direction,
 	const int control);
 
 #else
@@ -161,15 +156,15 @@ typedef struct _HexagonsRec {
 
 extern int *startPosition;
 extern void setPuzzle(HexagonsWidget w, int reason);
-extern int MovePuzzleDir(HexagonsWidget w, const int direction,
+extern int movePuzzleDir(HexagonsWidget w, const int direction,
 	const int fast);
 
 #if 0
 /* For future auto-solver */
-extern void SolveSomeTiles(HexagonsWidget w);
+extern void solveSomeTiles(HexagonsWidget w);
 #endif
-extern void DrawAllTiles(const HexagonsWidget w);
-extern Boolean CheckSolved(const HexagonsWidget w);
+extern void drawAllTiles(const HexagonsWidget w);
+extern Boolean checkSolved(const HexagonsWidget w);
 extern void newMoves(HexagonsStack *s);
 extern void deleteMoves(HexagonsStack *s);
 extern void setMove(HexagonsStack *s, int direction);
@@ -182,8 +177,8 @@ extern void printMoves(FILE *fp, HexagonsStack *s);
 extern void scanStartPosition(FILE *fp, HexagonsWidget w);
 extern void printStartPosition(FILE *fp, HexagonsWidget w);
 extern void setStartPosition(HexagonsWidget w);
-extern int Row(HexagonsWidget w, const int pos);
-extern int TrBl(HexagonsWidget w, const int pos, const int posRow);
-extern int TlBr(HexagonsWidget w, const int pos, const int posRow);
+extern int toRow(HexagonsWidget w, const int pos);
+extern int toTrBl(HexagonsWidget w, const int pos, const int posRow);
+extern int toTlBr(HexagonsWidget w, const int pos, const int posRow);
 
 #endif /* _HexagonsP_h */
