@@ -1,27 +1,24 @@
-/*-
-# MOTIF/X-BASED HEXAGONS
-#
-#  xhexagons.c
-#
-###
-#
-#  Copyright (c) 1993 - 2008	David A. Bagley, bagleyd@tux.org
-#
-#                   All Rights Reserved
-#
-#  Permission to use, copy, modify, and distribute this software and
-#  its documentation for any purpose and without fee is hereby granted,
-#  provided that the above copyright notice appear in all copies and
-#  that both that copyright notice and this permission notice appear in
-#  supporting documentation, and that the name of the author not be
-#  used in advertising or publicity pertaining to distribution of the
-#  software without specific, written prior permission.
-#
-#  This program is distributed in the hope that it will be "playable",
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-#
-*/
+/*
+ * @(#)xhexagons.c
+ *
+ * Copyright 1993 - 2008  David A. Bagley, bagleyd@tux.org
+ *
+ * All rights reserved.
+ *
+ * Permission to use, copy, modify, and distribute this software and
+ * its documentation for any purpose and without fee is hereby granted,
+ * provided that the above copyright notice appear in all copies and
+ * that both that copyright notice and this permission notice appear in
+ * supporting documentation, and that the name of the author not be
+ * used in advertising or publicity pertaining to distribution of the
+ * software without specific, written prior permission.
+ *
+ * This program is distributed in the hope that it will be "useful",
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ */
+
+/* Driver file for Hexagons */
 
 #include "file.h"
 #ifdef WINVER
@@ -57,7 +54,7 @@ static HexagonsRec widget;
 #include "pixmaps/mouse-l.xbm"
 #include "pixmaps/mouse-r.xbm"
 #endif
-#define PRINT_MESSAGE(b) PrintState(message, b)
+#define PRINT_MESSAGE(b) printState(message, b)
 #else
 #define PRINT_MESSAGE(b) XtWarning(b)
 #endif
@@ -89,7 +86,7 @@ static HexagonsRec widget;
 
 #ifndef WINVER
 static const char aboutHelp[] = {
-"Hexagons Version 7.3.3\n"
+"Hexagons Version 7.4\n"
 "Send bugs (reports or fixes) to the author: "
 "David Bagley <bagleyd@tux.org>\n"
 "The latest version is at: "
@@ -220,9 +217,10 @@ static char recordDsp[MESSAGE_LENGTH] = "NOT RECORDED";
 #define MIN_SPEED 1
 #define MAX_SPEED 50
 #ifdef ANIMATE
-static Widget speed;
+static Widget speedSlider;
 #endif
-static Widget moves, record, message, cornersSwitch, tileX, tileY;
+static Widget movesText, recordText, message, cornersSwitch;
+static Widget tileXSlider, tileYSlider;
 static char buff[21];
 static Widget descriptionDialog, featuresDialog;
 static Widget optionsDialog, referencesDialog, aboutDialog;
@@ -246,19 +244,19 @@ static char userNameDsp[USER_NAME_LENGTH] = "";
 
 #ifdef HAVE_MOTIF
 static void
-PrintState(Widget w, char *msg)
+printState(Widget w, char *msg)
 {
 	XmString xmstr;
 
 	if (!XtIsSubclass(w, xmLabelWidgetClass))
-		XtError("PrintState() requires a Label Widget");
+		XtError("printState() requires a Label Widget");
 	xmstr = XmStringCreateLtoR(msg, XmSTRING_DEFAULT_CHARSET);
 	XtVaSetValues(w, XmNlabelString, xmstr, NULL);
 }
 #endif
 
 static void
-PrintRecords(void)
+printRecords(void)
 {
 	int i, j, k;
 
@@ -277,7 +275,7 @@ PrintRecords(void)
 #endif
 
 static void
-InitRecords(void)
+initRecords(void)
 {
 	int i, j, k;
 
@@ -291,7 +289,7 @@ InitRecords(void)
 }
 
 static void
-ReadRecords(void)
+readRecords(void)
 {
 	FILE *fp;
 	int i, j, k, n;
@@ -351,7 +349,7 @@ ReadRecords(void)
 }
 
 static void
-WriteRecords(void)
+writeRecords(void)
 {
 	FILE *fp;
 	int i, j, k;
@@ -401,7 +399,7 @@ WriteRecords(void)
 }
 
 static void
-PrintRecord(int sizeX, int sizeY, Boolean corners)
+printRecord(int sizeX, int sizeY, Boolean corners)
 {
 	int i = (corners) ? 1 : 0;
 	int j = sizeX - MIN_TILES, k = sizeY - MIN_TILES;
@@ -416,21 +414,21 @@ PrintRecord(int sizeX, int sizeY, Boolean corners)
 			puzzleRecord[i][j][k].name);
 	}
 #ifdef HAVE_MOTIF
-	PrintState(record, recordDsp);
+	printState(recordText, recordDsp);
 #endif
 }
 
 static void
-PrintStatus(char *msg, int nMoves
+printStatus(char *msg, int nMoves
 #ifndef HAVE_MOTIF
 		, int sizeX, int sizeY
 #endif
 		)
 {
 #ifdef HAVE_MOTIF
-	PrintState(message, msg);
+	printState(message, msg);
 	(void) sprintf(buff, "%d", nMoves);
-	PrintState(moves, buff);
+	printState(movesText, buff);
 #else
 	(void) sprintf(titleDsp, "%s: %dx%d@ (%d/%s) - %s",
 		progDsp, sizeX, sizeY, nMoves, recordDsp, msg);
@@ -443,7 +441,7 @@ PrintStatus(char *msg, int nMoves
 }
 
 static Boolean
-HandleSolved(int counter, int sizeX, int sizeY, int corners)
+handleSolved(int counter, int sizeX, int sizeY, int corners)
 {
 	int i = (corners) ? 1 : 0;
 	int j = sizeX - MIN_TILES, k = sizeY - MIN_TILES;
@@ -451,19 +449,19 @@ HandleSolved(int counter, int sizeX, int sizeY, int corners)
 	if (sizeX <= MAX_TILES && sizeY <= MAX_TILES &&
 			(counter < puzzleRecord[i][j][k].score ||
 			puzzleRecord[i][j][k].score <= NEVER)) {
-		ReadRecords();	/* Maybe its been updated by another */
+		readRecords();	/* Maybe its been updated by another */
 		puzzleRecord[i][j][k].score = counter;
 		(void) strncpy(puzzleRecord[i][j][k].name, userNameDsp,
 			USER_NAME_LENGTH);
-		WriteRecords();
-		PrintRecord(sizeX, sizeY, corners);
+		writeRecords();
+		printRecord(sizeX, sizeY, corners);
 		return True;
 	}
 	return False;
 }
 
 static void
-Initialize(
+initialize(
 #ifdef WINVER
 HexagonsWidget w, HBRUSH brush
 #else
@@ -476,7 +474,7 @@ Widget w
 	char *userName, *scoreFile;
 
 #ifdef WINVER
-	InitializePuzzle(w, brush);
+	initializePuzzle(w, brush);
 
 	sizeX = w->hexagons.sizeX;
 	sizeY = w->hexagons.sizeY;
@@ -503,32 +501,33 @@ Widget w
 	if (strcmp(scoreFile, ""))
 		(void) strncpy(scoreFileName, scoreFile, FILE_NAME_LENGTH);
 	if (scoreOnly) {
-		InitRecords();
-		ReadRecords();
-		PrintRecords();
+		initRecords();
+		readRecords();
+		printRecords();
 		exit(0);
 	}
 #ifdef HAVE_MOTIF
 	if (sizeX > MAX_TILES)
-		XtVaSetValues(tileX, XmNmaximum, sizeX, NULL);
-	XmScaleSetValue(tileX, sizeX);
+		XtVaSetValues(tileXSlider, XmNmaximum, sizeX, NULL);
+	XmScaleSetValue(tileXSlider, sizeX);
 	if (sizeY > MAX_TILES)
-		XtVaSetValues(tileY, XmNmaximum, sizeY, NULL);
-	XmScaleSetValue(tileY, sizeY);
+		XtVaSetValues(tileYSlider, XmNmaximum, sizeY, NULL);
+	XmScaleSetValue(tileYSlider, sizeY);
 	XmToggleButtonSetState(cornersSwitch, corners, True);
 #ifdef ANIMATE
 	{
 		int delay;
 
 		XtVaGetValues(w, XtNdelay, &delay, NULL);
-		XmScaleSetValue(speed, MAX_SPEED + MIN_SPEED - delay - 1);
+		XmScaleSetValue(speedSlider,
+			MAX_SPEED + MIN_SPEED - delay - 1);
 	}
 #endif
 #endif
 #endif
 	SET_STARTED(w, False);
-	InitRecords();
-	ReadRecords();
+	initRecords();
+	readRecords();
 #ifndef WINVER
 	(void) strncpy(userNameDsp, userName, USER_NAME_LENGTH);
 #endif
@@ -553,8 +552,8 @@ Widget w
 			(void) sprintf(userNameDsp, "%s", "guest");
 #endif
 	}
-	PrintRecord(sizeX, sizeY, corners);
-	PrintStatus(messageDsp, movesDsp
+	printRecord(sizeX, sizeY, corners);
+	printStatus(messageDsp, movesDsp
 #ifndef HAVE_MOTIF
 		, sizeX, sizeY
 #endif
@@ -566,7 +565,7 @@ void
 setPuzzle(HexagonsWidget w, int reason)
 #else
 static void
-CallbackPuzzle(Widget w, caddr_t clientData,
+puzzleListener(Widget w, caddr_t clientData,
 		hexagonsCallbackStruct *callData)
 #endif
 {
@@ -650,7 +649,7 @@ CallbackPuzzle(Widget w, caddr_t clientData,
 		if (cheat)
 			(void) sprintf(messageDsp,
 				"No cheating %s!!", userNameDsp);
-		else if (!randomized && HandleSolved(movesDsp,
+		else if (!randomized && handleSolved(movesDsp,
 				sizeX, sizeY, corners))
 			(void) sprintf(messageDsp,
 				"Congratulations %s!!", userNameDsp);
@@ -670,67 +669,67 @@ CallbackPuzzle(Widget w, caddr_t clientData,
 	case ACTION_INCX:
 		movesDsp = 0;
 		sizeX++;
-		PrintRecord(sizeX, sizeY, corners);
+		printRecord(sizeX, sizeY, corners);
 #ifdef WINVER
 		w->hexagons.sizeX = sizeX;
 #else
 		XtVaSetValues(w, XtNsizeX, sizeX, NULL);
 #ifdef HAVE_MOTIF
 		if (sizeX > MAX_TILES)
-			XtVaSetValues(tileX, XmNmaximum, sizeX, NULL);
-		XmScaleSetValue(tileX, sizeX);
+			XtVaSetValues(tileXSlider, XmNmaximum, sizeX, NULL);
+		XmScaleSetValue(tileXSlider, sizeX);
 #endif
 #endif
 		break;
 	case ACTION_DECX:
 		movesDsp = 0;
 		sizeX--;
-		PrintRecord(sizeX, sizeY, corners);
+		printRecord(sizeX, sizeY, corners);
 #ifdef WINVER
 		w->hexagons.sizeX = sizeX;
 #else
 		XtVaSetValues(w, XtNsizeX, sizeX, NULL);
 #ifdef HAVE_MOTIF
-		XmScaleSetValue(tileX, sizeX);
+		XmScaleSetValue(tileXSlider, sizeX);
 		if (sizeX >= MAX_TILES)
-			XtVaSetValues(tileX, XmNmaximum, sizeX, NULL);
+			XtVaSetValues(tileXSlider, XmNmaximum, sizeX, NULL);
 #endif
 #endif
 		break;
 	case ACTION_INCY:
 		movesDsp = 0;
 		sizeY++;
-		PrintRecord(sizeX, sizeY, corners);
+		printRecord(sizeX, sizeY, corners);
 #ifdef WINVER
 		w->hexagons.sizeY = sizeY;
 #else
 		XtVaSetValues(w, XtNsizeY, sizeY, NULL);
 #ifdef HAVE_MOTIF
 		if (sizeY > MAX_TILES)
-			XtVaSetValues(tileY, XmNmaximum, sizeY, NULL);
-		XmScaleSetValue(tileY, sizeY);
+			XtVaSetValues(tileYSlider, XmNmaximum, sizeY, NULL);
+		XmScaleSetValue(tileYSlider, sizeY);
 #endif
 #endif
 		break;
 	case ACTION_DECY:
 		movesDsp = 0;
 		sizeY--;
-		PrintRecord(sizeX, sizeY, corners);
+		printRecord(sizeX, sizeY, corners);
 #ifdef WINVER
 		w->hexagons.sizeY = sizeY;
 #else
 		XtVaSetValues(w, XtNsizeY, sizeY, NULL);
 #ifdef HAVE_MOTIF
-		XmScaleSetValue(tileY, sizeY);
+		XmScaleSetValue(tileYSlider, sizeY);
 		if (sizeY >= MAX_TILES)
-			XtVaSetValues(tileY, XmNmaximum, sizeY, NULL);
+			XtVaSetValues(tileYSlider, XmNmaximum, sizeY, NULL);
 #endif
 #endif
 		break;
 	case ACTION_CORNERS:
 		movesDsp = 0;
 		corners = !corners;
-		PrintRecord(sizeX, sizeY, corners);
+		printRecord(sizeX, sizeY, corners);
 #ifdef WINVER
 		w->hexagons.corners = corners;
 #else
@@ -764,13 +763,13 @@ CallbackPuzzle(Widget w, caddr_t clientData,
 				XtVaSetValues(w,
 					XtNdelay, delay, NULL);
 			}
-			XmScaleSetValue(speed,
+			XmScaleSetValue(speedSlider,
 				MAX_SPEED + MIN_SPEED - delay - 1);
 		}
 		return;
 #endif
 	}
-	PrintStatus(messageDsp, movesDsp
+	printStatus(messageDsp, movesDsp
 #ifndef HAVE_MOTIF
 		, sizeX, sizeY
 #endif
@@ -779,15 +778,11 @@ CallbackPuzzle(Widget w, caddr_t clientData,
 
 #ifdef WINVER
 static LRESULT CALLBACK
-About(HWND hDlg, UINT message, WPARAM wParam, LPARAM lParam)
+about(HWND hDlg, UINT message, WPARAM wParam, LPARAM lParam)
 {
-	switch (message) {
-	case WM_COMMAND:
-		if (LOWORD(wParam) == IDOK) {
-			(void) EndDialog(hDlg, TRUE);
-			return TRUE;
-		}
-		break;
+	if (message == WM_COMMAND && LOWORD(wParam) == IDOK) {
+		(void) EndDialog(hDlg, TRUE);
+		return TRUE;
 	}
 	return FALSE;
 }
@@ -804,7 +799,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_BRUSH));
-			EnterPuzzle(&widget);
+			enterPuzzle(&widget);
 			(void) EndPaint(hWnd, &paint);
 		}
 	} else {
@@ -812,47 +807,47 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_BRUSH));
-			LeavePuzzle(&widget);
+			leavePuzzle(&widget);
 			(void) EndPaint(hWnd, &paint);
 		}
 	}
 	switch (message) {
 	case WM_CREATE:
-		Initialize(&widget, brush);
+		initialize(&widget, brush);
 		break;
 	case WM_DESTROY:
-		DestroyPuzzle(&widget, brush);
+		destroyPuzzle(&widget, brush);
 		break;
 	case WM_SIZE:
-		ResizePuzzle(&widget);
+		resizePuzzle(&widget);
 		(void) InvalidateRect(hWnd, NULL, TRUE);
 		break;
 	case WM_PAINT:
 		widget.core.hDC = BeginPaint(hWnd, &paint);
 		(void) SelectObject(widget.core.hDC,
 			GetStockObject(NULL_PEN));
-		ExposePuzzle(&widget);
+		exposePuzzle(&widget);
 		(void) EndPaint(hWnd, &paint);
 		break;
 	case WM_RBUTTONDOWN:
 		widget.core.hDC = GetDC(hWnd);
 		(void) SelectObject(widget.core.hDC,
 			GetStockObject(NULL_PEN));
-		ClearPuzzle(&widget);
+		clearPuzzle(&widget);
 		(void) ReleaseDC(hWnd, widget.core.hDC);
 		break;
 	case WM_LBUTTONDOWN:
 		widget.core.hDC = GetDC(hWnd);
 		(void) SelectObject(widget.core.hDC,
 			GetStockObject(NULL_PEN));
-		SelectPuzzle(&widget, LOWORD(lParam), HIWORD(lParam));
+		selectPuzzle(&widget, LOWORD(lParam), HIWORD(lParam));
 		(void) ReleaseDC(hWnd, widget.core.hDC);
 		break;
 	case WM_LBUTTONUP:
 		widget.core.hDC = GetDC(hWnd);
 		(void) SelectObject(widget.core.hDC,
 			GetStockObject(NULL_PEN));
-		ReleasePuzzle(&widget, LOWORD(lParam), HIWORD(lParam));
+		releasePuzzle(&widget, LOWORD(lParam), HIWORD(lParam));
 		(void) ReleaseDC(hWnd, widget.core.hDC);
 		break;
 #if (_WIN32_WINNT >= 0x0400) || (_WIN32_WINDOWS > 0x0400)
@@ -868,17 +863,17 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			ClientToScreen(hWnd, &origin);
 			(void) GetCursorPos(&cursor);
 			if (zDelta > (WHEEL_DELTA >> 1)) {
-				MovePuzzle(&widget, TOP,
+				movePuzzle(&widget, TOP,
 			(GetKeyState(VK_CONTROL) >> 1) ? 1 : 0);
 				if (GetKeyState(VK_CONTROL) >> 1) {
-					SizePuzzle(&widget);
+					sizePuzzle(&widget);
 					(void) InvalidateRect(hWnd, NULL, TRUE);
 				}
 			} else if (zDelta < -(WHEEL_DELTA >> 1)) {
-				MovePuzzle(&widget, BOTTOM,
+				movePuzzle(&widget, BOTTOM,
 			(GetKeyState(VK_CONTROL) >> 1) ? 1 : 0);
 				if (GetKeyState(VK_CONTROL) >> 1) {
-					SizePuzzle(&widget);
+					sizePuzzle(&widget);
 					(void) InvalidateRect(hWnd, NULL, TRUE);
 				}
 			}
@@ -889,57 +884,57 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 	case WM_COMMAND:
 		switch (LOWORD(wParam)) {
 		case ACTION_GET:
-			GetPuzzle(&widget);
-			ResizePuzzle(&widget);
+			getPuzzle(&widget);
+			resizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
 		case ACTION_WRITE:
-			WritePuzzle(&widget);
+			writePuzzle(&widget);
 			break;
 		case ACTION_EXIT:
-			DestroyPuzzle(&widget, brush);
+			destroyPuzzle(&widget, brush);
 			break;
 		case ACTION_HIDE:
-			HidePuzzle(&widget);
+			hidePuzzle(&widget);
 			break;
 		case ACTION_UNDO:
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_PEN));
-			UndoPuzzle(&widget);
+			undoPuzzle(&widget);
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
 		case ACTION_REDO:
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_PEN));
-			RedoPuzzle(&widget);
+			redoPuzzle(&widget);
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
 		case ACTION_CLEAR:
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_PEN));
-			ClearPuzzle(&widget);
+			clearPuzzle(&widget);
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
 		case ACTION_RANDOMIZE:
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_PEN));
-			RandomizePuzzle(&widget);
+			randomizePuzzle(&widget);
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
 		case ACTION_SOLVE:
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_PEN));
-			SolvePuzzle(&widget);
+			solvePuzzle(&widget);
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
 		case ACTION_CORNERS:
-			CornersPuzzle(&widget);
-			SizePuzzle(&widget);
+			cornersPuzzle(&widget);
+			sizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
 		case ACTION_TR:
@@ -951,7 +946,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_PEN));
-			(void) MovePuzzle(&widget,
+			(void) movePuzzle(&widget,
 				(int) LOWORD(wParam) - ACTION_TR, FALSE);
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
@@ -959,21 +954,21 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 		case ACTION_INCX:
 		case ACTION_INCY:
 		case ACTION_DECX:
-			if (MovePuzzle(&widget,
+			if (movePuzzle(&widget,
 					(int) LOWORD(wParam) - ACTION_DECY,
 					TRUE)) {
-				SizePuzzle(&widget);
+				sizePuzzle(&widget);
 				(void) InvalidateRect(hWnd, NULL, TRUE);
 			}
 			break;
 		case ACTION_SPEED:
-			SpeedPuzzle(&widget);
+			speedUpPuzzle(&widget);
 			break;
 		case ACTION_SLOW:
-			SlowPuzzle(&widget);
+			slowDownPuzzle(&widget);
 			break;
 		case ACTION_SOUND:
-			SoundPuzzle(&widget);
+			toggleSoundPuzzle(&widget);
 			break;
 		case ACTION_DESCRIPTION:
 			(void) MessageBox(hWnd, descriptionHelp,
@@ -989,7 +984,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			break;
 		case ACTION_ABOUT:
 			(void) DialogBox(widget.core.hInstance,
-				"About", hWnd, (DLGPROC) About);
+				"About", hWnd, (DLGPROC) about);
 			break;
 		}
 		break;
@@ -1050,7 +1045,7 @@ WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance, LPSTR lpCmdLine,
 #else
 
 static void
-Usage(char *programName)
+usage(char *programName)
 {
 	unsigned int i;
 
@@ -1099,7 +1094,7 @@ static XrmOptionDescRec options[] =
 
 #ifdef HAVE_MOTIF
 static void
-CallbackPuzzleClear(Widget w, XtPointer clientData,
+puzzleListenerClear(Widget w, XtPointer clientData,
 		XmAnyCallbackStruct *cbs)
 {
 	if (cbs->reason == XmCR_OK) {
@@ -1108,7 +1103,7 @@ CallbackPuzzleClear(Widget w, XtPointer clientData,
 }
 
 static void
-TileXSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
+tileXChangeListener(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 {
 	int sizeX = cbs->value, sizeY, oldX;
 	Boolean corners;
@@ -1123,14 +1118,14 @@ TileXSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 		XtNsizeX, sizeX, NULL);
 	movesDsp = 0;
 	(void) sprintf(buff, "%d", movesDsp);
-	PrintState(moves, buff);
-	PrintRecord(sizeX, sizeY, corners);
+	printState(movesText, buff);
+	printRecord(sizeX, sizeY, corners);
 	(void) strcpy(messageDsp, "");
-	PrintState(message, messageDsp);
+	printState(message, messageDsp);
 }
 
 static void
-TileYSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
+tileYChangeListener(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 {
 	int sizeX, sizeY = cbs->value, oldY;
 	Boolean corners;
@@ -1142,21 +1137,21 @@ TileYSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 	if (oldY == sizeY)
 		return;
 	if (corners && sizeY == 1) {
-		XmScaleSetValue(tileY, oldY);
+		XmScaleSetValue(tileYSlider, oldY);
 		return;
 	}
 	XtVaSetValues(puzzle,
 		XtNsizeY, sizeY, NULL);
 	movesDsp = 0;
 	(void) sprintf(buff, "%d", movesDsp);
-	PrintState(moves, buff);
-	PrintRecord(sizeX, sizeY, corners);
+	printState(movesText, buff);
+	printRecord(sizeX, sizeY, corners);
 	(void) strcpy(messageDsp, "");
-	PrintState(message, messageDsp);
+	printState(message, messageDsp);
 }
 
 static void
-CornersToggle(Widget w, XtPointer clientData,
+cornersToggle(Widget w, XtPointer clientData,
 		XmToggleButtonCallbackStruct *cbs)
 {
 	int sizeX, sizeY;
@@ -1176,15 +1171,15 @@ CornersToggle(Widget w, XtPointer clientData,
 		XtNcorners, corners, NULL);
 	movesDsp = 0;
 	(void) sprintf(buff, "%d", movesDsp);
-	PrintState(moves, buff);
-	PrintRecord(sizeX, sizeY, corners);
+	printState(movesText, buff);
+	printRecord(sizeX, sizeY, corners);
 	(void) strcpy(messageDsp, "");
-	PrintState(message, messageDsp);
+	printState(message, messageDsp);
 }
 
 #ifdef ANIMATE
 static void
-SpeedSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
+speedChangeListener(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 {
 	int delay = MAX_SPEED + MIN_SPEED - cbs->value - 1, oldDelay;
 
@@ -1197,7 +1192,7 @@ SpeedSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 #endif
 
 static void
-fileCB(Widget w, void *value, void *clientData)
+fileMenuListener(Widget w, void *value, void *clientData)
 {
 	int val = (int) value + ACTION_GET;
 
@@ -1269,7 +1264,7 @@ createHelp(Widget w, char *text, char *title)
 }
 
 static void
-helpCB(Widget w, XtPointer value, XtPointer clientData)
+helpMenuListener(Widget w, XtPointer value, XtPointer clientData)
 {
 	int val = (int) value;
 
@@ -1293,7 +1288,7 @@ helpCB(Widget w, XtPointer value, XtPointer clientData)
 		{
 			char *buf;
 
-			intCat(&buf, "helpCB: %d", val);
+			intCat(&buf, "helpMenuListener: %d", val);
 			XtWarning(buf);
 			free(buf);
 		}
@@ -1321,7 +1316,7 @@ main(int argc, char **argv)
 	topLevel = XtInitialize(argv[0], "Hexagons",
 		options, XtNumber(options), &argc, argv);
 	if (argc != 1)
-		Usage(argv[0]);
+		usage(argv[0]);
 
 #ifdef HAVE_MOTIF
 	menuBarPanel = XtVaCreateManagedWidget("menuBarPanel",
@@ -1341,7 +1336,7 @@ main(int argc, char **argv)
 	writeString = XmStringCreateSimple((char *) "Write");
 	quitString = XmStringCreateSimple((char *) "Quit");
 	(void) XmVaCreateSimplePulldownMenu(menuBar, (char *) "file_menu",
-		0, fileCB,
+		0, fileMenuListener,
 		XmVaPUSHBUTTON, getString, 'G', NULL, NULL,
 		XmVaPUSHBUTTON, writeString, 'W', NULL, NULL,
 		XmVaSEPARATOR,
@@ -1390,23 +1385,23 @@ main(int argc, char **argv)
 	widget = XtVaCreateManagedWidget("Description",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'D', NULL);
-		XtAddCallback(widget, XmNactivateCallback, helpCB, (char *) 0);
+		XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 0);
 	widget = XtVaCreateManagedWidget("Features",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'F', NULL);
-	XtAddCallback(widget, XmNactivateCallback, helpCB, (char *) 1);
+	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 1);
 	widget = XtVaCreateManagedWidget("Options",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'O', NULL);
-	XtAddCallback(widget, XmNactivateCallback, helpCB, (char *) 2);
+	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 2);
 	widget = XtVaCreateManagedWidget("References",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'R', NULL);
-	XtAddCallback(widget, XmNactivateCallback, helpCB, (char *) 3);
+	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 3);
 	widget = XtVaCreateManagedWidget("About",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'A', NULL);
-	XtAddCallback(widget, XmNactivateCallback, helpCB, (char *) 4);
+	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 4);
 	XtManageChild(menuBar);
 	descriptionDialog = createHelp(menuBar, (char *) descriptionHelp,
 		(char *) "Description");
@@ -1423,7 +1418,7 @@ main(int argc, char **argv)
 	clearDialog = createQuery(topLevel,
 		(char *) "Are you sure you want to start over?",
 		(char *) "Clear Query",
-		(XtCallbackProc) CallbackPuzzleClear);
+		(XtCallbackProc) puzzleListenerClear);
 	mainPanel = XtCreateManagedWidget("mainPanel",
 		xmPanedWindowWidgetClass, menuBarPanel,
 		NULL, 0);
@@ -1479,19 +1474,19 @@ main(int argc, char **argv)
 	(void) XtVaCreateManagedWidget("movesText",
 		xmLabelGadgetClass, movesRowCol,
 		XtVaTypedArg, XmNlabelString, XmRString, "Moves", 6, NULL);
-	moves = XtVaCreateManagedWidget("0",
+	movesText = XtVaCreateManagedWidget("0",
 		xmLabelWidgetClass, movesRowCol, NULL);
 	(void) XtVaCreateManagedWidget("recordText",
 		xmLabelGadgetClass, movesRowCol,
 		XtVaTypedArg, XmNlabelString, XmRString, "Record", 7, NULL);
-	record = XtVaCreateManagedWidget("0",
+	recordText = XtVaCreateManagedWidget("0",
 		xmLabelWidgetClass, movesRowCol, NULL);
 	tilesRowCol = XtVaCreateManagedWidget("tilesRowCol",
 		xmRowColumnWidgetClass, controlPanel,
 		XmNnumColumns, 1,
 		XmNorientation, XmHORIZONTAL,
 		XmNpacking, XmPACK_COLUMN, NULL);
-	tileX = XtVaCreateManagedWidget("tileX",
+	tileXSlider = XtVaCreateManagedWidget("tileX",
 		xmScaleWidgetClass, tilesRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Size X", 7,
 		XmNminimum, MIN_TILES,
@@ -1499,9 +1494,9 @@ main(int argc, char **argv)
 		XmNvalue, DEFAULT_TILESX,
 		XmNshowValue, True,
 		XmNorientation, XmHORIZONTAL, NULL);
-	XtAddCallback(tileX, XmNvalueChangedCallback,
-		(XtCallbackProc) TileXSlider, (XtPointer) NULL);
-	tileY = XtVaCreateManagedWidget("tileY",
+	XtAddCallback(tileXSlider, XmNvalueChangedCallback,
+		(XtCallbackProc) tileXChangeListener, (XtPointer) NULL);
+	tileYSlider = XtVaCreateManagedWidget("tileY",
 		xmScaleWidgetClass, tilesRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Size Y", 7,
 		XmNminimum, MIN_TILES,
@@ -1509,20 +1504,20 @@ main(int argc, char **argv)
 		XmNvalue, DEFAULT_TILESY,
 		XmNshowValue, True,
 		XmNorientation, XmHORIZONTAL, NULL);
-	XtAddCallback(tileY, XmNvalueChangedCallback,
-		(XtCallbackProc) TileYSlider, (XtPointer) NULL);
+	XtAddCallback(tileYSlider, XmNvalueChangedCallback,
+		(XtCallbackProc) tileYChangeListener, (XtPointer) NULL);
 	cornersSwitch = XtVaCreateManagedWidget("Corners",
 		xmToggleButtonWidgetClass, tilesRowCol,
 		XmNset, DEFAULT_CORNERS, NULL);
 	XtAddCallback(cornersSwitch, XmNvalueChangedCallback,
-		(XtCallbackProc) CornersToggle, (XtPointer) NULL);
+		(XtCallbackProc) cornersToggle, (XtPointer) NULL);
 #ifdef ANIMATE
 	speedRowCol = XtVaCreateManagedWidget("speedRowCol",
 		xmRowColumnWidgetClass, controlPanel,
 		XmNnumColumns, 1,
 		XmNorientation, XmHORIZONTAL,
 		XmNpacking, XmPACK_COLUMN, NULL);
-	speed = XtVaCreateManagedWidget("Animation Speed",
+	speedSlider = XtVaCreateManagedWidget("speedSlider",
 		xmScaleWidgetClass, speedRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Animation Speed", 16,
 		XmNminimum, MIN_SPEED,
@@ -1530,8 +1525,8 @@ main(int argc, char **argv)
 		XmNvalue, MAX_SPEED - DEFAULT_DELAY,
 		XmNshowValue, True,
 		XmNorientation, XmHORIZONTAL, NULL);
-	XtAddCallback(speed, XmNvalueChangedCallback,
-		(XtCallbackProc) SpeedSlider, (XtPointer) NULL);
+	XtAddCallback(speedSlider, XmNvalueChangedCallback,
+		(XtCallbackProc) speedChangeListener, (XtPointer) NULL);
 #endif
 	messageRowCol = XtVaCreateManagedWidget("messageRowCol",
 		xmRowColumnWidgetClass, controlPanel, NULL);
@@ -1576,14 +1571,14 @@ main(int argc, char **argv)
 #endif
 		XtNiconPixmap, pixmap, NULL);
 	XtAddCallback(puzzle, XtNselectCallback,
-		(XtCallbackProc) CallbackPuzzle, (XtPointer) NULL);
-	Initialize(puzzle);
+		(XtCallbackProc) puzzleListener, (XtPointer) NULL);
+	initialize(puzzle);
 	XtRealizeWidget(topLevel);
 	XGrabButton(XtDisplay(puzzle), (unsigned int) AnyButton, AnyModifier,
 		XtWindow(puzzle), TRUE, (unsigned int) (ButtonPressMask |
 		ButtonMotionMask | ButtonReleaseMask),
 		GrabModeAsync, GrabModeAsync, XtWindow(puzzle),
-		XCreateFontCursor(XtDisplay(puzzle), XC_crosshair));
+		XCreateFontCursor(XtDisplay(puzzle), XC_hand2));
 	XtMainLoop();
 
 #ifdef VMS
