@@ -1,27 +1,24 @@
-/*-
-# MOTIF/X-BASED MASTERBALL(tm)
-#
-#  xmball.c
-#
-###
-#
-#  Copyright (c) 1994 - 2007	David A. Bagley, bagleyd@tux.org
-#
-#                   All Rights Reserved
-#
-#  Permission to use, copy, modify, and distribute this software and
-#  its documentation for any purpose and without fee is hereby granted,
-#  provided that the above copyright notice appear in all copies and
-#  that both that copyright notice and this permission notice appear in
-#  supporting documentation, and that the name of the author not be
-#  used in advertising or publicity pertaining to distribution of the
-#  software without specific, written prior permission.
-#
-#  This program is distributed in the hope that it will be "playable",
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-#
-*/
+/*
+ * @(#)xmball.c
+ *
+ * Copyright 1994 - 2008  David A. Bagley, bagleyd@tux.org
+ *
+ * All rights reserved.
+ *
+ * Permission to use, copy, modify, and distribute this software and
+ * its documentation for any purpose and without fee is hereby granted,
+ * provided that the above copyright notice appear in all copies and
+ * that both that copyright notice and this permission notice appear in
+ * supporting documentation, and that the name of the author not be
+ * used in advertising or publicity pertaining to distribution of the
+ * software without specific, written prior permission.
+ *
+ * This program is distributed in the hope that it will be "useful",
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ */
+
+/* Driver file for Mball */
 
 #include "file.h"
 #ifdef WINVER
@@ -58,7 +55,7 @@ static MballRec widget;
 #include "pixmaps/mouse-l.xbm"
 #include "pixmaps/mouse-r.xbm"
 #endif
-#define PRINT_MESSAGE(b) PrintState(message, b)
+#define PRINT_MESSAGE(b) printState(message, b)
 #else
 #define PRINT_MESSAGE(b) XtWarning(b)
 #endif
@@ -90,7 +87,7 @@ static MballRec widget;
 
 #ifndef WINVER
 static const char aboutHelp[] = {
-"Mball Version 7.3.2\n"
+"Mball Version 7.4\n"
 "Send bugs (reports or fixes) to the author: "
 "David Bagley <bagleyd@tux.org>\n"
 "The latest version is at: "
@@ -235,8 +232,8 @@ static char messageDsp[MESSAGE_LENGTH] = "Welcome";
 static char recordDsp[MESSAGE_LENGTH] = "NOT RECORDED";
 
 #ifdef HAVE_MOTIF
-static Widget moves, record, message, orientizeSwitch, practiceSwitch;
-static Widget wedge[(MAX_WEDGES - MIN_WEDGES) / 2 + 1], ring;
+static Widget movesText, recordText, message, orientizeSwitch, practiceSwitch;
+static Widget wedge[(MAX_WEDGES - MIN_WEDGES) / 2 + 1], ringSlider;
 static char buff[21];
 static const char *wedgeString[] =
 {
@@ -264,19 +261,19 @@ static char userNameDsp[USER_NAME_LENGTH] = "";
 
 #ifdef HAVE_MOTIF
 static void
-PrintState(Widget w, char *msg)
+printState(Widget w, char *msg)
 {
 	XmString xmstr;
 
 	if (!XtIsSubclass(w, xmLabelWidgetClass))
-		XtError("PrintState() requires a Label Widget");
+		XtError("printState() requires a Label Widget");
 	xmstr = XmStringCreateLtoR(msg, XmSTRING_DEFAULT_CHARSET);
 	XtVaSetValues(w, XmNlabelString, xmstr, NULL);
 }
 #endif
 
 static void
-PrintRecords(void)
+printRecords(void)
 {
 	int i, j, orient;
 
@@ -295,7 +292,7 @@ PrintRecords(void)
 #endif
 
 static void
-InitRecords(void)
+initRecords(void)
 {
 	int i, j, orient;
 
@@ -309,7 +306,7 @@ InitRecords(void)
 }
 
 static void
-ReadRecords(void)
+readRecords(void)
 {
 	FILE *fp;
 	int i, j, n, orient;
@@ -369,7 +366,7 @@ ReadRecords(void)
 }
 
 static void
-WriteRecords(void)
+writeRecords(void)
 {
 	FILE *fp;
 	int i, j, orient;
@@ -421,7 +418,7 @@ WriteRecords(void)
 }
 
 static void
-PrintRecord(int wedges, int rings, Boolean orient, Boolean practice)
+printRecord(int wedges, int rings, Boolean orient, Boolean practice)
 {
 	int i = (orient) ? 1 : 0;
 	int w = (wedges - MIN_WEDGES) / 2;
@@ -438,21 +435,21 @@ PrintRecord(int wedges, int rings, Boolean orient, Boolean practice)
 			puzzleRecord[i][w][r].score, puzzleRecord[i][w][r].name);
 	}
 #ifdef HAVE_MOTIF
-	PrintState(record, recordDsp);
+	printState(recordText, recordDsp);
 #endif
 }
 
 static void
-PrintStatus(char *msg, int nMoves
+printStatus(char *msg, int nMoves
 #ifndef HAVE_MOTIF
 		, int wedges, int rings
 #endif
 		)
 {
 #ifdef HAVE_MOTIF
-	PrintState(message, msg);
+	printState(message, msg);
 	(void) sprintf(buff, "%d", nMoves);
-	PrintState(moves, buff);
+	printState(movesText, buff);
 #else
 	(void) sprintf(titleDsp, "%s.%d: %d@ (%d/%s) - %s",
 		progDsp, wedges, rings, nMoves, recordDsp, msg);
@@ -465,7 +462,7 @@ PrintStatus(char *msg, int nMoves
 }
 
 static Boolean
-HandleSolved(int counter, int wedges, int rings, Boolean orient)
+handleSolved(int counter, int wedges, int rings, Boolean orient)
 {
 	int i = (orient) ? 1 : 0;
 	int w = (wedges - MIN_WEDGES) / 2;
@@ -473,7 +470,7 @@ HandleSolved(int counter, int wedges, int rings, Boolean orient)
 
 	if (rings <= MAX_RINGS && (counter < puzzleRecord[i][w][r].score ||
 			puzzleRecord[i][w][r].score <= NEVER)) {
-		ReadRecords();	/* Maybe its been updated by another */
+		readRecords();	/* Maybe its been updated by another */
 		puzzleRecord[i][w][r].score = counter;
 		(void) strncpy(puzzleRecord[i][w][r].name, userNameDsp,
 			USER_NAME_LENGTH);
@@ -483,15 +480,15 @@ HandleSolved(int counter, int wedges, int rings, Boolean orient)
 			(void) strncpy(puzzleRecord[!i][w][r].name, userNameDsp,
 				USER_NAME_LENGTH);
 		}
-		WriteRecords();
-		PrintRecord(wedges, rings, orient, False);
+		writeRecords();
+		printRecord(wedges, rings, orient, False);
 		return True;
 	}
 	return False;
 }
 
 static void
-Initialize(
+initialize(
 #ifdef WINVER
 MballWidget w, HBRUSH brush
 #else
@@ -504,7 +501,7 @@ Widget w
 	char *userName, *scoreFile;
 
 #ifdef WINVER
-	InitializePuzzle(w, brush);
+	initializePuzzle(w, brush);
 
 	wedges = w->mball.wedges;
 	rings = w->mball.rings;
@@ -533,23 +530,23 @@ Widget w
 	if (strcmp(scoreFile, ""))
 		(void) strncpy(scoreFileName, scoreFile, FILE_NAME_LENGTH);
 	if (scoreOnly) {
-		InitRecords();
-		ReadRecords();
-		PrintRecords();
+		initRecords();
+		readRecords();
+		printRecords();
 		exit(0);
 	}
 #ifdef HAVE_MOTIF
 	XmToggleButtonSetState(wedge[(wedges - MIN_WEDGES) / 2], True, False);
 	if (rings > MAX_RINGS)
-		XtVaSetValues(ring, XmNmaximum, rings, NULL);
-	XmScaleSetValue(ring, rings);
+		XtVaSetValues(ringSlider, XmNmaximum, rings, NULL);
+	XmScaleSetValue(ringSlider, rings);
 	XmToggleButtonSetState(orientizeSwitch, orient, True);
 	XmToggleButtonSetState(practiceSwitch, practice, True);
 #endif
 #endif
 	SET_STARTED(w, False);
-	InitRecords();
-	ReadRecords();
+	initRecords();
+	readRecords();
 #ifndef WINVER
 	(void) strncpy(userNameDsp, userName, USER_NAME_LENGTH);
 #endif
@@ -574,8 +571,8 @@ Widget w
 			(void) sprintf(userNameDsp, "%s", "guest");
 #endif
 	}
-	PrintRecord(wedges, rings, orient, practice);
-	PrintStatus(messageDsp, movesDsp
+	printRecord(wedges, rings, orient, practice);
+	printStatus(messageDsp, movesDsp
 #ifndef HAVE_MOTIF
 		, wedges, rings
 #endif
@@ -587,7 +584,7 @@ void
 setPuzzle(MballWidget w, int reason)
 #else
 static void
-CallbackPuzzle(Widget w, caddr_t clientData, mballCallbackStruct *callData)
+puzzleListener(Widget w, caddr_t clientData, mballCallbackStruct *callData)
 #endif
 {
 #ifndef WINVER
@@ -656,7 +653,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, mballCallbackStruct *callData)
 			(void) strncpy(recordDsp, "practice",
 				MESSAGE_LENGTH);
 #ifdef HAVE_MOTIF
-			PrintState(record, recordDsp);
+			printState(recordText, recordDsp);
 #endif
 		}
 		movesDsp = 0;
@@ -690,7 +687,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, mballCallbackStruct *callData)
 		else if (cheat)
 			(void) sprintf(messageDsp,
 				"No cheating %s!!", userNameDsp);
-		else if (HandleSolved(movesDsp, wedges, rings, orient))
+		else if (handleSolved(movesDsp, wedges, rings, orient))
 			(void) sprintf(messageDsp,
 				"Congratulations %s!!", userNameDsp);
 		else
@@ -709,7 +706,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, mballCallbackStruct *callData)
 		if (!practice)
 			(void) strncpy(messageDsp, "Randomize to start",
 				MESSAGE_LENGTH);
-		PrintRecord(wedges, rings, orient, practice);
+		printRecord(wedges, rings, orient, practice);
 #ifdef WINVER
 		w->mball.practice = practice;
 		w->mball.started = False;
@@ -737,37 +734,37 @@ CallbackPuzzle(Widget w, caddr_t clientData, mballCallbackStruct *callData)
 	case ACTION_INCREMENT:
 		movesDsp = 0;
 		rings++;
-		PrintRecord(wedges, rings, orient, practice);
+		printRecord(wedges, rings, orient, practice);
 #ifdef WINVER
 		w->mball.rings = rings;
 #else
 		XtVaSetValues(w, XtNrings, rings, NULL);
 #ifdef HAVE_MOTIF
 		if (rings > MAX_RINGS)
-			XtVaSetValues(ring, XmNmaximum, rings, NULL);
-		XmScaleSetValue(ring, rings);
+			XtVaSetValues(ringSlider, XmNmaximum, rings, NULL);
+		XmScaleSetValue(ringSlider, rings);
 #endif
 #endif
 		break;
 	case ACTION_DECREMENT:
 		movesDsp = 0;
 		rings--;
-		PrintRecord(wedges, rings, orient, practice);
+		printRecord(wedges, rings, orient, practice);
 #ifdef WINVER
 		w->mball.rings = rings;
 #else
 		XtVaSetValues(w, XtNrings, rings, NULL);
 #ifdef HAVE_MOTIF
-		XmScaleSetValue(ring, rings);
+		XmScaleSetValue(ringSlider, rings);
 		if (rings >= MAX_RINGS)
-			XtVaSetValues(ring, XmNmaximum, rings, NULL);
+			XtVaSetValues(ringSlider, XmNmaximum, rings, NULL);
 #endif
 #endif
 		break;
 	case ACTION_ORIENTIZE:
 		movesDsp = 0;
 		orient = !orient;
-		PrintRecord(wedges, rings, orient, practice);
+		printRecord(wedges, rings, orient, practice);
 #ifdef WINVER
 		w->mball.orient = orient;
 #else
@@ -785,7 +782,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, mballCallbackStruct *callData)
 	case ACTION_WEDGE12:
 		movesDsp = 0;
 		wedges = 2 * (reason - ACTION_WEDGE2) + MIN_WEDGES;
-		PrintRecord(wedges, rings, orient, practice);
+		printRecord(wedges, rings, orient, practice);
 #ifdef WINVER
 		w->mball.wedges = wedges;
 #else
@@ -805,7 +802,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, mballCallbackStruct *callData)
 		SET_STARTED(w, True);
 		break;
 	}
-	PrintStatus(messageDsp, movesDsp
+	printStatus(messageDsp, movesDsp
 #ifndef HAVE_MOTIF
 		, wedges, rings
 #endif
@@ -814,15 +811,11 @@ CallbackPuzzle(Widget w, caddr_t clientData, mballCallbackStruct *callData)
 
 #ifdef WINVER
 static LRESULT CALLBACK
-About(HWND hDlg, UINT message, WPARAM wParam, LPARAM lParam)
+about(HWND hDlg, UINT message, WPARAM wParam, LPARAM lParam)
 {
-	switch (message) {
-	case WM_COMMAND:
-		if (LOWORD(wParam) == IDOK) {
-			(void) EndDialog(hDlg, TRUE);
-			return TRUE;
-		}
-		break;
+	if (message == WM_COMMAND && LOWORD(wParam) == IDOK) {
+		(void) EndDialog(hDlg, TRUE);
+		return TRUE;
 	}
 	return FALSE;
 }
@@ -839,7 +832,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_BRUSH));
-			EnterPuzzle(&widget);
+			enterPuzzle(&widget);
 			(void) EndPaint(hWnd, &paint);
 		}
 	} else {
@@ -847,40 +840,40 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_BRUSH));
-			LeavePuzzle(&widget);
+			leavePuzzle(&widget);
 			(void) EndPaint(hWnd, &paint);
 		}
 	}
 	switch (message) {
 	case WM_CREATE:
-		Initialize(&widget, brush);
+		initialize(&widget, brush);
 		break;
 	case WM_DESTROY:
-		DestroyPuzzle(brush);
+		destroyPuzzle(brush);
 		break;
 	case WM_SIZE:
-		ResizePuzzle(&widget);
+		resizePuzzle(&widget);
 		(void) InvalidateRect(hWnd, NULL, TRUE);
 		break;
 	case WM_PAINT:
 		widget.core.hDC = BeginPaint(hWnd, &paint);
 		(void) SelectObject(widget.core.hDC,
 			GetStockObject(NULL_PEN));
-		ExposePuzzle(&widget);
+		exposePuzzle(&widget);
 		(void) EndPaint(hWnd, &paint);
 		break;
 	case WM_RBUTTONDOWN:
 		widget.core.hDC = GetDC(hWnd);
 		(void) SelectObject(widget.core.hDC,
 			GetStockObject(NULL_PEN));
-		RandomizePuzzle(&widget);
+		randomizePuzzle(&widget);
 		(void) ReleaseDC(hWnd, widget.core.hDC);
 		break;
 	case WM_LBUTTONDOWN:
 		widget.core.hDC = GetDC(hWnd);
 		(void) SelectObject(widget.core.hDC,
 			GetStockObject(NULL_PEN));
-		SelectPuzzle(&widget, LOWORD(lParam), HIWORD(lParam),
+		selectPuzzle(&widget, LOWORD(lParam), HIWORD(lParam),
 			(GetKeyState(VK_CONTROL) >> 1) ? 1 : 0);
 		(void) ReleaseDC(hWnd, widget.core.hDC);
 		break;
@@ -888,7 +881,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 		widget.core.hDC = GetDC(hWnd);
 		(void) SelectObject(widget.core.hDC,
 			GetStockObject(NULL_PEN));
-		ReleasePuzzle(&widget, LOWORD(lParam), HIWORD(lParam),
+		releasePuzzle(&widget, LOWORD(lParam), HIWORD(lParam),
 			(GetKeyState(VK_CONTROL) >> 1) ? 1 : 0);
 		(void) ReleaseDC(hWnd, widget.core.hDC);
 		break;
@@ -905,13 +898,13 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			ClientToScreen(hWnd, &origin);
 			(void) GetCursorPos(&cursor);
 			if (zDelta > (WHEEL_DELTA >> 1)) {
-				MovePuzzleInput(&widget,
+				movePuzzleInput(&widget,
 					cursor.x - origin.x,
 					cursor.y - origin.y,
 					TOP,
 					(GetKeyState(VK_CONTROL) >> 1) ? 1 : 0);
 			} else if (zDelta < -(WHEEL_DELTA >> 1)) {
-				MovePuzzleInput(&widget,
+				movePuzzleInput(&widget,
 					cursor.x - origin.x,
 					cursor.y - origin.y,
 					BOTTOM,
@@ -924,62 +917,62 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 	case WM_COMMAND:
 		switch (LOWORD(wParam)) {
 		case ACTION_GET:
-			GetPuzzle(&widget);
-			ResizePuzzle(&widget);
+			getPuzzle(&widget);
+			resizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
 		case ACTION_WRITE:
-			WritePuzzle(&widget);
+			writePuzzle(&widget);
 			break;
 		case ACTION_EXIT:
-			DestroyPuzzle(brush);
+			destroyPuzzle(brush);
 			break;
 		case ACTION_HIDE:
-			HidePuzzle(&widget);
+			hidePuzzle(&widget);
 			break;
 		case ACTION_UNDO:
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_PEN));
-			UndoPuzzle(&widget);
+			undoPuzzle(&widget);
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
 		case ACTION_REDO:
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_PEN));
-			RedoPuzzle(&widget);
+			redoPuzzle(&widget);
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
 		case ACTION_CLEAR:
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_PEN));
-			ClearPuzzle(&widget);
+			clearPuzzle(&widget);
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
 		case ACTION_PRACTICE:
-			PracticePuzzle(&widget);
-			SizePuzzle(&widget);
+			practicePuzzle(&widget);
+			sizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
 		case ACTION_RANDOMIZE:
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_PEN));
-			RandomizePuzzle(&widget);
+			randomizePuzzle(&widget);
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
 		case ACTION_SOLVE:
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 			GetStockObject(NULL_PEN));
-			SolvePuzzle(&widget);
+			solvePuzzle(&widget);
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
 		case ACTION_ORIENTIZE:
-			OrientizePuzzle(&widget);
-			SizePuzzle(&widget);
+			orientizePuzzle(&widget);
+			sizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
 		case ACTION_TOP:
@@ -1005,7 +998,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 				origin.x = 0, origin.y = 0;
 				ClientToScreen(hWnd, &origin);
 				(void) GetCursorPos(&cursor);
-				(void) MovePuzzleInput(&widget,
+				(void) movePuzzleInput(&widget,
 					cursor.x - origin.x,
 					cursor.y - origin.y,
 					(int) LOWORD(wParam) - ACTION_TOP, FALSE);
@@ -1035,7 +1028,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 				origin.x = 0, origin.y = 0;
 				ClientToScreen(hWnd, &origin);
 				(void) GetCursorPos(&cursor);
-				(void) MovePuzzleInput(&widget,
+				(void) movePuzzleInput(&widget,
 					cursor.x - origin.x,
 					cursor.y - origin.y,
 					(int) LOWORD(wParam) - ACTION_CONTROL_TOP,
@@ -1044,13 +1037,13 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			}
 			break;
 		case ACTION_INCREMENT:
-			IncrementPuzzle(&widget);
-			SizePuzzle(&widget);
+			incrementPuzzle(&widget);
+			sizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
 		case ACTION_DECREMENT:
-			if (DecrementPuzzle(&widget)) {
-				SizePuzzle(&widget);
+			if (decrementPuzzle(&widget)) {
+				sizePuzzle(&widget);
 				(void) InvalidateRect(hWnd, NULL, TRUE);
 			}
 			break;
@@ -1060,19 +1053,19 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 		case ACTION_WEDGE8:
 		case ACTION_WEDGE10:
 		case ACTION_WEDGE12:
-			WedgePuzzle(&widget,
+			wedgePuzzle(&widget,
 				(int) LOWORD(wParam) - ACTION_WEDGE2);
-			SizePuzzle(&widget);
+			sizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
 		case ACTION_SPEED:
-			SpeedPuzzle(&widget);
+			speedUpPuzzle(&widget);
 			break;
 		case ACTION_SLOW:
-			SlowPuzzle(&widget);
+			slowDownPuzzle(&widget);
 			break;
 		case ACTION_SOUND:
-			SoundPuzzle(&widget);
+			toggleSoundPuzzle(&widget);
 			break;
 		case ACTION_DESCRIPTION:
 			(void) MessageBox(hWnd, descriptionHelp,
@@ -1088,7 +1081,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			break;
 		case ACTION_ABOUT:
 			(void) DialogBox(widget.core.hInstance,
-				"About", hWnd, (DLGPROC) About);
+				"About", hWnd, (DLGPROC) about);
 			break;
 		}
 		break;
@@ -1149,7 +1142,7 @@ WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance, LPSTR lpCmdLine,
 #else
 
 static void
-Usage(char *programName)
+usage(char *programName)
 {
 	unsigned int i;
 
@@ -1208,7 +1201,7 @@ static XrmOptionDescRec options[] =
 
 #ifdef HAVE_MOTIF
 static void
-CallbackPuzzlePractice(Widget w, XtPointer clientData,
+puzzlePracticeListener(Widget w, XtPointer clientData,
 		XmAnyCallbackStruct *cbs)
 {
 	if (cbs->reason == XmCR_OK) {
@@ -1217,7 +1210,7 @@ CallbackPuzzlePractice(Widget w, XtPointer clientData,
 }
 
 static void
-CallbackPuzzleRandomize(Widget w, XtPointer clientData,
+puzzleRandomizeListener(Widget w, XtPointer clientData,
 		XmAnyCallbackStruct *cbs)
 {
 	if (cbs->reason == XmCR_OK) {
@@ -1226,7 +1219,7 @@ CallbackPuzzleRandomize(Widget w, XtPointer clientData,
 }
 
 static void
-WedgeToggle(Widget w, int bit, XmToggleButtonCallbackStruct *cbs)
+wedgeToggle(Widget w, int bit, XmToggleButtonCallbackStruct *cbs)
 {
 	int wedges, rings;
 	Boolean orient, practice;
@@ -1241,15 +1234,15 @@ WedgeToggle(Widget w, int bit, XmToggleButtonCallbackStruct *cbs)
 			XtNwedges, wedges, NULL);
 		movesDsp = 0;
 		(void) sprintf(buff, "%d", movesDsp);
-		PrintState(moves, buff);
-		PrintRecord(wedges, rings, orient, practice);
+		printState(movesText, buff);
+		printRecord(wedges, rings, orient, practice);
 		(void) strcpy(messageDsp, "");
-		PrintState(message, messageDsp);
+		printState(message, messageDsp);
 	}
 }
 
 static void
-RingSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
+ringChangeListener(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 {
 	int wedges, rings = cbs->value, old;
 	Boolean orient, practice;
@@ -1265,14 +1258,14 @@ RingSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 		XtNrings, rings, NULL);
 	movesDsp = 0;
 	(void) sprintf(buff, "%d", movesDsp);
-	PrintState(moves, buff);
-	PrintRecord(wedges, rings, orient, practice);
+	printState(movesText, buff);
+	printRecord(wedges, rings, orient, practice);
 	(void) strcpy(messageDsp, "");
-	PrintState(message, messageDsp);
+	printState(message, messageDsp);
 }
 
 static void
-OrientToggle(Widget w, XtPointer clientData, XmToggleButtonCallbackStruct *cbs)
+orientToggle(Widget w, XtPointer clientData, XmToggleButtonCallbackStruct *cbs)
 {
 	int wedges, rings;
 	Boolean orient = cbs->set, practice, oldOrient;
@@ -1288,14 +1281,14 @@ OrientToggle(Widget w, XtPointer clientData, XmToggleButtonCallbackStruct *cbs)
 		XtNorient, orient, NULL);
 	movesDsp = 0;
 	(void) sprintf(buff, "%d", movesDsp);
-	PrintState(moves, buff);
-	PrintRecord(wedges, rings, orient, practice);
+	printState(movesText, buff);
+	printRecord(wedges, rings, orient, practice);
 	(void) strcpy(messageDsp, "");
-	PrintState(message, messageDsp);
+	printState(message, messageDsp);
 }
 
 static void
-PracticeToggle(Widget w, XtPointer clientData,
+practiceToggle(Widget w, XtPointer clientData,
 		XmToggleButtonCallbackStruct *cbs)
 {
 	int wedges, rings;
@@ -1313,17 +1306,17 @@ PracticeToggle(Widget w, XtPointer clientData,
 		XtNstart, False, NULL);
 	movesDsp = 0;
 	(void) sprintf(buff, "%d", movesDsp);
-	PrintState(moves, buff);
-	PrintRecord(wedges, rings, orient, practice);
+	printState(movesText, buff);
+	printRecord(wedges, rings, orient, practice);
 	if (practice)
 		(void) strcpy(messageDsp, "");
 	else
 		(void) strncpy(messageDsp, "Randomize to start", MESSAGE_LENGTH);
-	PrintState(message, messageDsp);
+	printState(message, messageDsp);
 }
 
 static void
-fileCB(Widget w, void *value, void *clientData)
+fileMenuListener(Widget w, void *value, void *clientData)
 {
 	int val = (int) value + ACTION_GET;
 
@@ -1395,7 +1388,7 @@ createHelp(Widget w, char *text, char *title)
 }
 
 static void
-helpCB(Widget w, XtPointer value, XtPointer clientData)
+helpMenuListener(Widget w, XtPointer value, XtPointer clientData)
 {
 	int val = (int) value;
 
@@ -1419,7 +1412,7 @@ helpCB(Widget w, XtPointer value, XtPointer clientData)
 		{
 			char *buf;
 
-			intCat(&buf, "helpCB: %d", val);
+			intCat(&buf, "helpMenuListener: %d", val);
 			XtWarning(buf);
 			free(buf);
 		}
@@ -1449,7 +1442,7 @@ main(int argc, char **argv)
 	topLevel = XtInitialize(argv[0], "Mball",
 		options, XtNumber(options), &argc, argv);
 	if (argc != 1)
-		Usage(argv[0]);
+		usage(argv[0]);
 
 #ifdef HAVE_MOTIF
 	menuBarPanel = XtVaCreateManagedWidget("menuBarPanel",
@@ -1469,7 +1462,7 @@ main(int argc, char **argv)
 	writeString = XmStringCreateSimple((char *) "Write");
 	quitString = XmStringCreateSimple((char *) "Quit");
 	(void) XmVaCreateSimplePulldownMenu(menuBar, (char *) "file_menu",
-		0, fileCB,
+		0, fileMenuListener,
 		XmVaPUSHBUTTON, getString, 'G', NULL, NULL,
 		XmVaPUSHBUTTON, writeString, 'W', NULL, NULL,
 		XmVaSEPARATOR,
@@ -1527,23 +1520,23 @@ main(int argc, char **argv)
 	widget = XtVaCreateManagedWidget("Description",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'D', NULL);
-		XtAddCallback(widget, XmNactivateCallback, helpCB, (char *) 0);
+		XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 0);
 	widget = XtVaCreateManagedWidget("Features",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'F', NULL);
-	XtAddCallback(widget, XmNactivateCallback, helpCB, (char *) 1);
+	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 1);
 	widget = XtVaCreateManagedWidget("Options",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'O', NULL);
-	XtAddCallback(widget, XmNactivateCallback, helpCB, (char *) 2);
+	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 2);
 	widget = XtVaCreateManagedWidget("References",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'R', NULL);
-	XtAddCallback(widget, XmNactivateCallback, helpCB, (char *) 3);
+	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 3);
 	widget = XtVaCreateManagedWidget("About",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'A', NULL);
-	XtAddCallback(widget, XmNactivateCallback, helpCB, (char *) 4);
+	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 4);
 	XtManageChild(menuBar);
 	descriptionDialog = createHelp(menuBar, (char *) descriptionHelp,
 		(char *) "Description");
@@ -1560,11 +1553,11 @@ main(int argc, char **argv)
 	practiceDialog = createQuery(topLevel,
 		(char *) "Are you sure you want to toggle the practice mode?",
 		(char *) "Practice Query",
-		(XtCallbackProc) CallbackPuzzlePractice);
+		(XtCallbackProc) puzzlePracticeListener);
 	randomizeDialog = createQuery(topLevel,
 		(char *) "Are you sure you want to randomize?",
 		(char *) "Randomize Query",
-		(XtCallbackProc) CallbackPuzzleRandomize);
+		(XtCallbackProc) puzzleRandomizeListener);
 	mainPanel = XtCreateManagedWidget("mainPanel",
 		xmPanedWindowWidgetClass, menuBarPanel,
 		NULL, 0);
@@ -1620,12 +1613,12 @@ main(int argc, char **argv)
 	(void) XtVaCreateManagedWidget("movesText",
 		xmLabelGadgetClass, movesRowCol,
 		XtVaTypedArg, XmNlabelString, XmRString, "Moves", 6, NULL);
-	moves = XtVaCreateManagedWidget("0",
+	movesText = XtVaCreateManagedWidget("0",
 		xmLabelWidgetClass, movesRowCol, NULL);
 	(void) XtVaCreateManagedWidget("recordText",
 		xmLabelGadgetClass, movesRowCol,
 		XtVaTypedArg, XmNlabelString, XmRString, "Record", 7, NULL);
-	record = XtVaCreateManagedWidget("0",
+	recordText = XtVaCreateManagedWidget("0",
 		xmLabelWidgetClass, movesRowCol, NULL);
 	labelRowCol = XtVaCreateManagedWidget("labelRowCol",
 		xmRowColumnWidgetClass, controlPanel, NULL);
@@ -1643,14 +1636,14 @@ main(int argc, char **argv)
 			xmToggleButtonGadgetClass, wedgesRowCol,
 			XmNradioBehavior, True, NULL);
 		XtAddCallback(wedge[i], XmNvalueChangedCallback,
-			(XtCallbackProc) WedgeToggle, (XtPointer) i);
+			(XtCallbackProc) wedgeToggle, (XtPointer) i);
 	}
 	ringsRowCol = XtVaCreateManagedWidget("ringsRowCol",
 		xmRowColumnWidgetClass, controlPanel,
 		XmNnumColumns, 1,
 		XmNorientation, XmHORIZONTAL,
 		XmNpacking, XmPACK_COLUMN, NULL);
-	ring = XtVaCreateManagedWidget("ring",
+	ringSlider = XtVaCreateManagedWidget("ringSlider",
 		xmScaleWidgetClass, ringsRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Rings", 6,
 		XmNminimum, MIN_RINGS,
@@ -1658,18 +1651,18 @@ main(int argc, char **argv)
 		XmNvalue, DEFAULT_RINGS,
 		XmNshowValue, True,
 		XmNorientation, XmHORIZONTAL, NULL);
-	XtAddCallback(ring, XmNvalueChangedCallback,
-		(XtCallbackProc) RingSlider, (XtPointer) NULL);
+	XtAddCallback(ringSlider, XmNvalueChangedCallback,
+		(XtCallbackProc) ringChangeListener, (XtPointer) NULL);
 	orientizeSwitch = XtVaCreateManagedWidget("Oriented",
 		xmToggleButtonWidgetClass, ringsRowCol,
 		XmNset, DEFAULT_ORIENT, NULL);
 	XtAddCallback(orientizeSwitch, XmNvalueChangedCallback,
-		(XtCallbackProc) OrientToggle, (XtPointer) NULL);
+		(XtCallbackProc) orientToggle, (XtPointer) NULL);
 	practiceSwitch = XtVaCreateManagedWidget("Practice",
 		xmToggleButtonWidgetClass, ringsRowCol,
 		XmNset, DEFAULT_PRACTICE, NULL);
 	XtAddCallback(practiceSwitch, XmNvalueChangedCallback,
-		(XtCallbackProc) PracticeToggle, (XtPointer) NULL);
+		(XtCallbackProc) practiceToggle, (XtPointer) NULL);
 	messageRowCol = XtVaCreateManagedWidget("messageRowCol",
 		xmRowColumnWidgetClass, controlPanel, NULL);
 	message = XtVaCreateManagedWidget("Play Masterball! (use mouse and keypad)",
@@ -1713,14 +1706,14 @@ main(int argc, char **argv)
 #endif
 		XtNiconPixmap, pixmap, NULL);
 	XtAddCallback(puzzle, XtNselectCallback,
-		(XtCallbackProc) CallbackPuzzle, (XtPointer) NULL);
-	Initialize(puzzle);
+		(XtCallbackProc) puzzleListener, (XtPointer) NULL);
+	initialize(puzzle);
 	XtRealizeWidget(topLevel);
 	XGrabButton(XtDisplay(puzzle), (unsigned int) AnyButton, AnyModifier,
 		XtWindow(puzzle), TRUE, (unsigned int) (ButtonPressMask |
 		ButtonMotionMask | ButtonReleaseMask),
 		GrabModeAsync, GrabModeAsync, XtWindow(puzzle),
-		XCreateFontCursor(XtDisplay(puzzle), XC_crosshair));
+		XCreateFontCursor(XtDisplay(puzzle), XC_hand2));
 	XtMainLoop();
 
 #ifdef VMS
