@@ -1,27 +1,22 @@
-/*-
-# X-BASED MISSING LINK(tm)
-#
-#  MlinkP.h
-#
-###
-#
-#  Copyright (c) 1994 - 2008	David A. Bagley, bagleyd@tux.org
-#
-#                   All Rights Reserved
-#
-#  Permission to use, copy, modify, and distribute this software and
-#  its documentation for any purpose and without fee is hereby granted,
-#  provided that the above copyright notice appear in all copies and
-#  that both that copyright notice and this permission notice appear in
-#  supporting documentation, and that the name of the author not be
-#  used in advertising or publicity pertaining to distribution of the
-#  software without specific, written prior permission.
-#
-#  This program is distributed in the hope that it will be "playable",
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-#
-*/
+/*
+ * @(#)MlinkP.h
+ *
+ * Copyright 1994 - 2008  David A. Bagley, bagleyd@tux.org
+ *
+ * All rights reserved.
+ *
+ * Permission to use, copy, modify, and distribute this software and
+ * its documentation for any purpose and without fee is hereby granted,
+ * provided that the above copyright notice appear in all copies and
+ * that both that copyright notice and this permission notice appear in
+ * supporting documentation, and that the name of the author not be
+ * used in advertising or publicity pertaining to distribution of the
+ * software without specific, written prior permission.
+ *
+ * This program is distributed in the hope that it will be "useful",
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ */
 
 /* Private header file for Mlink */
 
@@ -33,36 +28,36 @@
 #include "Mlink.h"
 
 #ifdef WINVER
-extern void DestroyPuzzle(MlinkWidget w, HBRUSH brush);
-extern void ResizePuzzle(MlinkWidget w);
-extern void SizePuzzle(MlinkWidget w);
-extern void InitializePuzzle(MlinkWidget w, HBRUSH brush);
-extern void ExposePuzzle(MlinkWidget w);
-extern void HidePuzzle(MlinkWidget w);
-extern void SelectPuzzle(MlinkWidget w,
+extern void destroyPuzzle(MlinkWidget w, HBRUSH brush);
+extern void resizePuzzle(MlinkWidget w);
+extern void sizePuzzle(MlinkWidget w);
+extern void initializePuzzle(MlinkWidget w, HBRUSH brush);
+extern void exposePuzzle(MlinkWidget w);
+extern void hidePuzzle(MlinkWidget w);
+extern void selectPuzzle(MlinkWidget w,
 	const int x, const int y, const int shift);
-extern void MotionPuzzle(MlinkWidget w,
+extern void motionPuzzle(MlinkWidget w,
 	const int x, const int y, const int shift);
-extern void ReleasePuzzle(MlinkWidget w,
+extern void releasePuzzle(MlinkWidget w,
 	const int x, const int y, const int shift);
-extern void PracticePuzzle(MlinkWidget w);
-extern void RandomizePuzzle(MlinkWidget w);
-extern void GetPuzzle(MlinkWidget w);
-extern void WritePuzzle(MlinkWidget w);
-extern void UndoPuzzle(MlinkWidget w);
-extern void RedoPuzzle(MlinkWidget w);
-extern void ClearPuzzle(MlinkWidget w);
-extern void SolvePuzzle(MlinkWidget w);
-extern void OrientizePuzzle(MlinkWidget w);
-extern void MiddlePuzzle(MlinkWidget w);
-extern void SpeedPuzzle(MlinkWidget w);
-extern void SlowPuzzle(MlinkWidget w);
-extern void SoundPuzzle(MlinkWidget w);
-extern void EnterPuzzle(MlinkWidget w);
-extern void LeavePuzzle(MlinkWidget w);
-extern void MovePuzzleInput(MlinkWidget w,
+extern void practicePuzzle(MlinkWidget w);
+extern void randomizePuzzle(MlinkWidget w);
+extern void getPuzzle(MlinkWidget w);
+extern void writePuzzle(MlinkWidget w);
+extern void undoPuzzle(MlinkWidget w);
+extern void redoPuzzle(MlinkWidget w);
+extern void clearPuzzle(MlinkWidget w);
+extern void solvePuzzle(MlinkWidget w);
+extern void orientizePuzzle(MlinkWidget w);
+extern void middlePuzzle(MlinkWidget w);
+extern void speedUpPuzzle(MlinkWidget w);
+extern void slowDownPuzzle(MlinkWidget w);
+extern void toggleSoundPuzzle(MlinkWidget w);
+extern void enterPuzzle(MlinkWidget w);
+extern void leavePuzzle(MlinkWidget w);
+extern void movePuzzleInput(MlinkWidget w,
 	int x, int direction, int shift, int control);
-extern int  MovePuzzleDir(MlinkWidget w, const int direction);
+extern int  movePuzzleDir(MlinkWidget w, const int direction);
 
 #else
 
@@ -161,15 +156,15 @@ typedef struct _MlinkRec {
 
 extern int *startPosition;
 extern void setPuzzle(MlinkWidget w, int reason);
-extern Boolean MovePuzzle(MlinkWidget w,
+extern Boolean movePuzzle(MlinkWidget w,
 	const int direction, const int tile, const int shift,
 	const Boolean motion, const int fast);
-extern void MovePuzzleDelay(MlinkWidget w,
+extern void movePuzzleDelay(MlinkWidget w,
 	const int direction, const int tile, const Boolean all);
 
-extern void SolveSomeTiles(MlinkWidget w);
-extern void DrawAllTiles(const MlinkWidget w);
-extern Boolean CheckSolved(const MlinkWidget w);
+extern void solveSomeTiles(MlinkWidget w);
+extern void drawAllTiles(const MlinkWidget w);
+extern Boolean checkSolved(const MlinkWidget w);
 extern void newMoves(MlinkStack *s);
 extern void deleteMoves(MlinkStack *s);
 extern void setMove(MlinkStack *s, int direction, int tile, int control);
