@@ -1,27 +1,24 @@
-/*-
-# MOTIF/X-BASED MISSING LINK(tm)
-#
-#  xmlink.c
-#
-###
-#
-#  Copyright (c) 1994 - 2007	David A. Bagley, bagleyd@tux.org
-#
-#                   All Rights Reserved
-#
-#  Permission to use, copy, modify, and distribute this software and
-#  its documentation for any purpose and without fee is hereby granted,
-#  provided that the above copyright notice appear in all copies and
-#  that both that copyright notice and this permission notice appear in
-#  supporting documentation, and that the name of the author not be
-#  used in advertising or publicity pertaining to distribution of the
-#  software without specific, written prior permission.
-#
-#  This program is distributed in the hope that it will be "playable",
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-#
-*/
+/*
+ * @(#)xmlink.c
+ *
+ * Copyright 1994 - 2008  David A. Bagley, bagleyd@tux.org
+ *
+ * All rights reserved.
+ *
+ * Permission to use, copy, modify, and distribute this software and
+ * its documentation for any purpose and without fee is hereby granted,
+ * provided that the above copyright notice appear in all copies and
+ * that both that copyright notice and this permission notice appear in
+ * supporting documentation, and that the name of the author not be
+ * used in advertising or publicity pertaining to distribution of the
+ * software without specific, written prior permission.
+ *
+ * This program is distributed in the hope that it will be "useful",
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ */
+
+/* Driver file for Mlink */
 
 /*-
   Version 7: 03/11/15 X/Windows
@@ -63,7 +60,7 @@ static MlinkRec widget;
 #include "pixmaps/mouse-l.xbm"
 #include "pixmaps/mouse-r.xbm"
 #endif
-#define PRINT_MESSAGE(b) PrintState(message, b)
+#define PRINT_MESSAGE(b) printState(message, b)
 #else
 #define PRINT_MESSAGE(b) XtWarning(b)
 #endif
@@ -95,7 +92,7 @@ static MlinkRec widget;
 
 #ifndef WINVER
 static const char aboutHelp[] = {
-"Mlink Version 7.3.2\n"
+"Mlink Version 7.4\n"
 "Send bugs (reports or fixes) to the author: "
 "David Bagley <bagleyd@tux.org>\n"
 "The latest version is at: "
@@ -227,8 +224,9 @@ static char recordDsp[MESSAGE_LENGTH] = "NOT RECORDED";
 #ifdef HAVE_MOTIF
 #define MIN_SPEED 1
 #define MAX_SPEED 50
-static Widget moves, record, message;
-static Widget orientizeSwitch, middleSwitch, practiceSwitch, tile, face, speed;
+static Widget movesText, recordText, message;
+static Widget orientizeSwitch, middleSwitch, practiceSwitch;
+static Widget tileSlider, faceSlider, speedSlider;
 static char buff[21];
 static Widget descriptionDialog, featuresDialog;
 static Widget optionsDialog, referencesDialog, aboutDialog;
@@ -251,19 +249,19 @@ static char userNameDsp[USER_NAME_LENGTH] = "";
 
 #ifdef HAVE_MOTIF
 static void
-PrintState(Widget w, char *msg)
+printState(Widget w, char *msg)
 {
 	XmString xmstr;
 
 	if (!XtIsSubclass(w, xmLabelWidgetClass))
-		XtError("PrintState() requires a Label Widget");
+		XtError("printState() requires a Label Widget");
 	xmstr = XmStringCreateLtoR(msg, XmSTRING_DEFAULT_CHARSET);
 	XtVaSetValues(w, XmNlabelString, xmstr, NULL);
 }
 #endif
 
 static void
-PrintRecords(void)
+printRecords(void)
 {
 	int i, j, k, l;
 
@@ -283,7 +281,7 @@ PrintRecords(void)
 #endif
 
 static void
-InitRecords(void)
+initRecords(void)
 {
 	int i, j, k, l;
 
@@ -298,7 +296,7 @@ InitRecords(void)
 }
 
 static void
-ReadRecords(void)
+readRecords(void)
 {
 	FILE *fp;
 	int i, j, k, l, n;
@@ -359,7 +357,7 @@ ReadRecords(void)
 }
 
 static void
-WriteRecords(void)
+writeRecords(void)
 {
 	FILE *fp;
 	int i, j, k, l;
@@ -413,7 +411,7 @@ WriteRecords(void)
 }
 
 static void
-PrintRecord(int tiles, int faces, Boolean orient, Boolean middle,
+printRecord(int tiles, int faces, Boolean orient, Boolean middle,
 		Boolean practice)
 {
 	int i = tiles - MIN_TILES, j = faces - MIN_FACES;
@@ -431,21 +429,21 @@ PrintRecord(int tiles, int faces, Boolean orient, Boolean middle,
 			puzzleRecord[l][k][j][i].name);
 	}
 #ifdef HAVE_MOTIF
-	PrintState(record, recordDsp);
+	printState(recordText, recordDsp);
 #endif
 }
 
 static void
-PrintStatus(char *msg, int nMoves
+printStatus(char *msg, int nMoves
 #ifndef HAVE_MOTIF
 		, int tiles, int faces, Boolean middle
 #endif
 		)
 {
 #ifdef HAVE_MOTIF
-	PrintState(message, msg);
+	printState(message, msg);
 	(void) sprintf(buff, "%d", nMoves);
-	PrintState(moves, buff);
+	printState(movesText, buff);
 #else
 	if (middle)
 		(void) sprintf(titleDsp, "%s: %dx%d norm@ (%d/%s) - %s",
@@ -462,14 +460,14 @@ PrintStatus(char *msg, int nMoves
 }
 
 static Boolean
-HandleSolved(int counter, int tiles, int faces, Boolean orient, Boolean middle)
+handleSolved(int counter, int tiles, int faces, Boolean orient, Boolean middle)
 {
 	int i = tiles - MIN_TILES, j = faces - MIN_FACES;
 	int k = (orient) ? 1 : 0, l = (middle) ? 1 : 0;
 
 	if (tiles <= MAX_TILES && (counter < puzzleRecord[l][k][j][i].score ||
 			puzzleRecord[l][k][j][i].score <= NEVER)) {
-		ReadRecords();	/* Maybe its been updated by another */
+		readRecords();	/* Maybe its been updated by another */
 		puzzleRecord[l][k][j][i].score = counter;
 		(void) strncpy(puzzleRecord[l][k][j][i].name, userNameDsp,
 			USER_NAME_LENGTH);
@@ -478,15 +476,15 @@ HandleSolved(int counter, int tiles, int faces, Boolean orient, Boolean middle)
 			(void) strncpy(puzzleRecord[!l][k][j][i].name,
 				userNameDsp, USER_NAME_LENGTH);
 		}
-		WriteRecords();
-		PrintRecord(tiles, faces, orient, middle, False);
+		writeRecords();
+		printRecord(tiles, faces, orient, middle, False);
 		return True;
 	}
 	return False;
 }
 
 static void
-Initialize(
+initialize(
 #ifdef WINVER
 MlinkWidget w, HBRUSH brush
 #else
@@ -499,7 +497,7 @@ Widget w
 	char *userName, *scoreFile;
 
 #ifdef WINVER
-	InitializePuzzle(w, brush);
+	initializePuzzle(w, brush);
 
 	tiles = w->mlink.tiles;
 	faces = w->mlink.faces;
@@ -530,16 +528,16 @@ Widget w
 	if (strcmp(scoreFile, ""))
 		(void) strncpy(scoreFileName, scoreFile, FILE_NAME_LENGTH);
 	if (scoreOnly) {
-		InitRecords();
-		ReadRecords();
-		PrintRecords();
+		initRecords();
+		readRecords();
+		printRecords();
 		exit(0);
 	}
 #ifdef HAVE_MOTIF
 	if (tiles > MAX_TILES)
-		XtVaSetValues(tile, XmNmaximum, tiles, NULL);
-	XmScaleSetValue(tile, tiles);
-	XmScaleSetValue(face, faces);
+		XtVaSetValues(tileSlider, XmNmaximum, tiles, NULL);
+	XmScaleSetValue(tileSlider, tiles);
+	XmScaleSetValue(faceSlider, faces);
 	XmToggleButtonSetState(orientizeSwitch, orient, True);
 	XmToggleButtonSetState(middleSwitch, middle, True);
 	XmToggleButtonSetState(practiceSwitch, practice, True);
@@ -547,13 +545,14 @@ Widget w
 		int delay;
 
 		XtVaGetValues(w, XtNdelay, &delay, NULL);
-		XmScaleSetValue(speed, MAX_SPEED + MIN_SPEED - delay - 1);
+		XmScaleSetValue(speedSlider,
+			MAX_SPEED + MIN_SPEED - delay - 1);
 	}
 #endif
 #endif
 	SET_STARTED(w, False);
-	InitRecords();
-	ReadRecords();
+	initRecords();
+	readRecords();
 #ifndef WINVER
 	(void) strncpy(userNameDsp, userName, USER_NAME_LENGTH);
 #endif
@@ -578,8 +577,8 @@ Widget w
 			(void) sprintf(userNameDsp, "%s", "guest");
 #endif
 	}
-	PrintRecord(tiles, faces, orient, middle, practice);
-	PrintStatus(messageDsp, movesDsp
+	printRecord(tiles, faces, orient, middle, practice);
+	printStatus(messageDsp, movesDsp
 #ifndef HAVE_MOTIF
 		, tiles, faces, middle
 #endif
@@ -591,7 +590,7 @@ void
 setPuzzle(MlinkWidget w, int reason)
 #else
 static void
-CallbackPuzzle(Widget w, caddr_t clientData, mlinkCallbackStruct *callData)
+puzzleListener(Widget w, caddr_t clientData, mlinkCallbackStruct *callData)
 #endif
 {
 #ifndef WINVER
@@ -659,7 +658,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, mlinkCallbackStruct *callData)
 		if (practice) {
 			(void) strncpy(recordDsp, "practice", MESSAGE_LENGTH);
 #ifdef HAVE_MOTIF
-			PrintState(record, recordDsp);
+			printState(recordText, recordDsp);
 #endif
 		}
 		movesDsp = 0;
@@ -693,7 +692,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, mlinkCallbackStruct *callData)
 		else if (cheat)
 			(void) sprintf(messageDsp,
 				"No cheating %s!!", userNameDsp);
-		else if (HandleSolved(movesDsp, tiles, faces,
+		else if (handleSolved(movesDsp, tiles, faces,
 				orient, middle))
 			(void) sprintf(messageDsp,
 				"Congratulations %s!!", userNameDsp);
@@ -711,7 +710,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, mlinkCallbackStruct *callData)
 		if (!practice)
 			(void) strncpy(messageDsp, "Randomize to start",
 				MESSAGE_LENGTH);
-		PrintRecord(tiles, faces, orient, middle, practice);
+		printRecord(tiles, faces, orient, middle, practice);
 #ifdef WINVER
 		w->mlink.practice = practice;
 		w->mlink.started = False;
@@ -738,7 +737,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, mlinkCallbackStruct *callData)
 	case ACTION_ORIENTIZE:
 		movesDsp = 0;
 		orient = !orient;
-		PrintRecord(tiles, faces, orient, middle, practice);
+		printRecord(tiles, faces, orient, middle, practice);
 #ifdef WINVER
 		w->mlink.orient = orient;
 #else
@@ -751,7 +750,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, mlinkCallbackStruct *callData)
 	case ACTION_MIDDLE:
 		movesDsp = 0;
 		middle = !middle;
-		PrintRecord(tiles, faces, orient, middle, practice);
+		printRecord(tiles, faces, orient, middle, practice);
 #ifdef WINVER
 		w->mlink.middle = middle;
 #else
@@ -764,56 +763,56 @@ CallbackPuzzle(Widget w, caddr_t clientData, mlinkCallbackStruct *callData)
 	case ACTION_INCX:
 		movesDsp = 0;
 		tiles++;
-		PrintRecord(tiles, faces, orient, middle, practice);
+		printRecord(tiles, faces, orient, middle, practice);
 #ifdef WINVER
 		w->mlink.tiles = tiles;
 #else
 		XtVaSetValues(w, XtNtiles, tiles, NULL);
 #ifdef HAVE_MOTIF
 		if (tiles > MAX_TILES)
-			XtVaSetValues(tile, XmNmaximum, tiles, NULL);
-		XmScaleSetValue(tile, tiles);
+			XtVaSetValues(tileSlider, XmNmaximum, tiles, NULL);
+		XmScaleSetValue(tileSlider, tiles);
 #endif
 #endif
 		break;
 	case ACTION_DECX:
 		movesDsp = 0;
 		tiles--;
-		PrintRecord(tiles, faces, orient, middle, practice);
+		printRecord(tiles, faces, orient, middle, practice);
 #ifdef WINVER
 		w->mlink.tiles = tiles;
 #else
 		XtVaSetValues(w, XtNtiles, tiles, NULL);
 #ifdef HAVE_MOTIF
-		XmScaleSetValue(tile, tiles);
+		XmScaleSetValue(tileSlider, tiles);
 		if (tiles >= MAX_TILES)
-			XtVaSetValues(tile, XmNmaximum, tiles, NULL);
+			XtVaSetValues(tileSlider, XmNmaximum, tiles, NULL);
 #endif
 #endif
 		break;
 	case ACTION_INCY:
 		movesDsp = 0;
 		faces++;
-		PrintRecord(tiles, faces, orient, middle, practice);
+		printRecord(tiles, faces, orient, middle, practice);
 #ifdef WINVER
 		w->mlink.faces = faces;
 #else
 		XtVaSetValues(w, XtNfaces, faces, NULL);
 #ifdef HAVE_MOTIF
-		XmScaleSetValue(face, faces);
+		XmScaleSetValue(faceSlider, faces);
 #endif
 #endif
 		break;
 	case ACTION_DECY:
 		movesDsp = 0;
 		faces--;
-		PrintRecord(tiles, faces, orient, middle, practice);
+		printRecord(tiles, faces, orient, middle, practice);
 #ifdef WINVER
 		w->mlink.faces = faces;
 #else
 		XtVaSetValues(w, XtNfaces, faces, NULL);
 #ifdef HAVE_MOTIF
-		XmScaleSetValue(face, faces);
+		XmScaleSetValue(faceSlider, faces);
 #endif
 #endif
 		break;
@@ -841,13 +840,13 @@ CallbackPuzzle(Widget w, caddr_t clientData, mlinkCallbackStruct *callData)
 				XtVaSetValues(w,
 					XtNdelay, delay, NULL);
 			}
-			XmScaleSetValue(speed,
+			XmScaleSetValue(speedSlider,
 				MAX_SPEED + MIN_SPEED - delay - 1);
 		}
 		return;
 #endif
 	}
-	PrintStatus(messageDsp, movesDsp
+	printStatus(messageDsp, movesDsp
 #ifndef HAVE_MOTIF
 		, tiles, faces, middle
 #endif
@@ -856,15 +855,11 @@ CallbackPuzzle(Widget w, caddr_t clientData, mlinkCallbackStruct *callData)
 
 #ifdef WINVER
 static LRESULT CALLBACK
-About(HWND hDlg, UINT message, WPARAM wParam, LPARAM lParam)
+about(HWND hDlg, UINT message, WPARAM wParam, LPARAM lParam)
 {
-	switch (message) {
-	case WM_COMMAND:
-		if (LOWORD(wParam) == IDOK) {
-			(void) EndDialog(hDlg, TRUE);
-			return TRUE;
-		}
-		break;
+	if (message == WM_COMMAND && LOWORD(wParam) == IDOK) {
+		(void) EndDialog(hDlg, TRUE);
+		return TRUE;
 	}
 	return FALSE;
 }
@@ -882,7 +877,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_BRUSH));
-			EnterPuzzle(&widget);
+			enterPuzzle(&widget);
 			(void) EndPaint(hWnd, &paint);
 		}
 	} else {
@@ -890,33 +885,33 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_BRUSH));
-			LeavePuzzle(&widget);
+			leavePuzzle(&widget);
 			(void) EndPaint(hWnd, &paint);
 		}
 	}
 	switch (message) {
 	case WM_CREATE:
-		Initialize(&widget, brush);
+		initialize(&widget, brush);
 		break;
 	case WM_DESTROY:
-		DestroyPuzzle(&widget, brush);
+		destroyPuzzle(&widget, brush);
 		break;
 	case WM_SIZE:
-		ResizePuzzle(&widget);
+		resizePuzzle(&widget);
 		(void) InvalidateRect(hWnd, NULL, TRUE);
 		break;
 	case WM_PAINT:
 		widget.core.hDC = BeginPaint(hWnd, &paint);
 		(void) SelectObject(widget.core.hDC,
 			GetStockObject(NULL_PEN));
-		ExposePuzzle(&widget);
+		exposePuzzle(&widget);
 		(void) EndPaint(hWnd, &paint);
 		break;
 	case WM_RBUTTONDOWN:
 		widget.core.hDC = GetDC(hWnd);
 		(void) SelectObject(widget.core.hDC,
 			GetStockObject(NULL_PEN));
-		RandomizePuzzle(&widget);
+		randomizePuzzle(&widget);
 		(void) ReleaseDC(hWnd, widget.core.hDC);
 		break;
 	case WM_LBUTTONDOWN:
@@ -924,7 +919,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 		widget.core.hDC = GetDC(hWnd);
 		(void) SelectObject(widget.core.hDC,
 			GetStockObject(NULL_PEN));
-		SelectPuzzle(&widget, LOWORD(lParam), HIWORD(lParam),
+		selectPuzzle(&widget, LOWORD(lParam), HIWORD(lParam),
 			((GetKeyState(VK_SHIFT) >> 1) ||
 			(GetKeyState(VK_CAPITAL) & 1)));
 		(void) ReleaseDC(hWnd, widget.core.hDC);
@@ -935,7 +930,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_PEN));
-			ReleasePuzzle(&widget, LOWORD(lParam), HIWORD(lParam),
+			releasePuzzle(&widget, LOWORD(lParam), HIWORD(lParam),
 				((GetKeyState(VK_SHIFT) >> 1) ||
 				(GetKeyState(VK_CAPITAL) & 1)));
 			(void) ReleaseDC(hWnd, widget.core.hDC);
@@ -944,7 +939,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 		widget.core.hDC = GetDC(hWnd);
 		(void) SelectObject(widget.core.hDC,
 			GetStockObject(NULL_PEN));
-		MotionPuzzle(&widget, LOWORD(lParam), HIWORD(lParam),
+		motionPuzzle(&widget, LOWORD(lParam), HIWORD(lParam),
 			((GetKeyState(VK_SHIFT) >> 1) ||
 			(GetKeyState(VK_CAPITAL) & 1)));
 		(void) ReleaseDC(hWnd, widget.core.hDC);
@@ -954,7 +949,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 		widget.core.hDC = GetDC(hWnd);
 		(void) SelectObject(widget.core.hDC,
 			GetStockObject(NULL_PEN));
-		ReleasePuzzle(&widget, LOWORD(lParam), HIWORD(lParam),
+		releasePuzzle(&widget, LOWORD(lParam), HIWORD(lParam),
 			((GetKeyState(VK_SHIFT) >> 1) ||
 			(GetKeyState(VK_CAPITAL) & 1)));
 		(void) ReleaseDC(hWnd, widget.core.hDC);
@@ -972,23 +967,23 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			ClientToScreen(hWnd, &origin);
 			(void) GetCursorPos(&cursor);
 			if (zDelta > (WHEEL_DELTA >> 1)) {
-				MovePuzzleInput(&widget, cursor.x - origin.x,
+				movePuzzleInput(&widget, cursor.x - origin.x,
 					TOP,
 					((GetKeyState(VK_SHIFT) >> 1) ||
 					(GetKeyState(VK_CAPITAL) & 1)),
 					(GetKeyState(VK_CONTROL) >> 1) ? 1 : 0);
 				if (GetKeyState(VK_CONTROL) >> 1) {
-					SizePuzzle(&widget);
+					sizePuzzle(&widget);
 					(void) InvalidateRect(hWnd, NULL, TRUE);
 				}
 			} else if (zDelta < -(WHEEL_DELTA >> 1)) {
-				MovePuzzleInput(&widget, cursor.x - origin.x,
+				movePuzzleInput(&widget, cursor.x - origin.x,
 					BOTTOM,
 					((GetKeyState(VK_SHIFT) >> 1) ||
 					(GetKeyState(VK_CAPITAL) & 1)),
 					(GetKeyState(VK_CONTROL) >> 1) ? 1 : 0);
 				if (GetKeyState(VK_CONTROL) >> 1) {
-					SizePuzzle(&widget);
+					sizePuzzle(&widget);
 					(void) InvalidateRect(hWnd, NULL, TRUE);
 				}
 			}
@@ -999,67 +994,67 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 	case WM_COMMAND:
 		switch (LOWORD(wParam)) {
 		case ACTION_GET:
-			GetPuzzle(&widget);
-			ResizePuzzle(&widget);
+			getPuzzle(&widget);
+			resizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
 		case ACTION_WRITE:
-			WritePuzzle(&widget);
+			writePuzzle(&widget);
 			break;
 		case ACTION_EXIT:
-			DestroyPuzzle(&widget, brush);
+			destroyPuzzle(&widget, brush);
 			break;
 		case ACTION_HIDE:
-			HidePuzzle(&widget);
+			hidePuzzle(&widget);
 			break;
 		case ACTION_UNDO:
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_PEN));
-			UndoPuzzle(&widget);
+			undoPuzzle(&widget);
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
 		case ACTION_REDO:
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_PEN));
-			RedoPuzzle(&widget);
+			redoPuzzle(&widget);
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
 		case ACTION_CLEAR:
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_PEN));
-			ClearPuzzle(&widget);
+			clearPuzzle(&widget);
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
 		case ACTION_PRACTICE:
-			PracticePuzzle(&widget);
-			SizePuzzle(&widget);
+			practicePuzzle(&widget);
+			sizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
 		case ACTION_RANDOMIZE:
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_PEN));
-			RandomizePuzzle(&widget);
+			randomizePuzzle(&widget);
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
 		case ACTION_SOLVE:
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_PEN));
-			SolvePuzzle(&widget);
+			solvePuzzle(&widget);
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
 		case ACTION_ORIENTIZE:
-			OrientizePuzzle(&widget);
-			SizePuzzle(&widget);
+			orientizePuzzle(&widget);
+			sizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
 		case ACTION_MIDDLE:
-			(void) MiddlePuzzle(&widget);
-			SizePuzzle(&widget);
+			(void) middlePuzzle(&widget);
+			sizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
 		case ACTION_LEFT:
@@ -1069,7 +1064,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_PEN));
-			(void) MovePuzzleInput(&widget, 0,
+			(void) movePuzzleInput(&widget, 0,
 				(int) LOWORD(wParam) - ACTION_SHIFT_UP,
 				!((int) wParam % 2), FALSE);
 			(void) ReleaseDC(hWnd, widget.core.hDC);
@@ -1085,7 +1080,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 				origin.x = 0, origin.y = 0;
 				ClientToScreen(hWnd, &origin);
 				(void) GetCursorPos(&cursor);
-				(void) MovePuzzleInput(&widget,
+				(void) movePuzzleInput(&widget,
 					cursor.x - origin.x,
 					(int) LOWORD(wParam) - ACTION_UP,
 					FALSE, FALSE);
@@ -1096,20 +1091,20 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 		case ACTION_INCX:
 		case ACTION_INCY:
 		case ACTION_DECX:
-			MovePuzzleInput(&widget, 0,
+			movePuzzleInput(&widget, 0,
 				(int) LOWORD(wParam) - ACTION_DECY,
 				FALSE, TRUE);
-			SizePuzzle(&widget);
+			sizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
 		case ACTION_SPEED:
-			SpeedPuzzle(&widget);
+			speedUpPuzzle(&widget);
 			break;
 		case ACTION_SLOW:
-			SlowPuzzle(&widget);
+			slowDownPuzzle(&widget);
 			break;
 		case ACTION_SOUND:
-			SoundPuzzle(&widget);
+			toggleSoundPuzzle(&widget);
 			break;
 		case ACTION_DESCRIPTION:
 			(void) MessageBox(hWnd, descriptionHelp,
@@ -1125,7 +1120,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			break;
 		case ACTION_ABOUT:
 			(void) DialogBox(widget.core.hInstance,
-				"About", hWnd, (DLGPROC) About);
+				"About", hWnd, (DLGPROC) about);
 			break;
 		}
 		break;
@@ -1190,7 +1185,7 @@ WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance, LPSTR lpCmdLine,
 #else
 
 static void
-Usage(char *programName)
+usage(char *programName)
 {
 	unsigned int i;
 
@@ -1253,7 +1248,7 @@ static XrmOptionDescRec options[] =
 
 #ifdef HAVE_MOTIF
 static void
-CallbackPuzzlePractice(Widget w, XtPointer clientData,
+puzzlePracticeListener(Widget w, XtPointer clientData,
 		XmAnyCallbackStruct *cbs)
 {
 	if (cbs->reason == XmCR_OK) {
@@ -1262,7 +1257,7 @@ CallbackPuzzlePractice(Widget w, XtPointer clientData,
 }
 
 static void
-CallbackPuzzleRandomize(Widget w, XtPointer clientData,
+puzzleRandomizeListener(Widget w, XtPointer clientData,
 		XmAnyCallbackStruct *cbs)
 {
 	if (cbs->reason == XmCR_OK) {
@@ -1271,7 +1266,7 @@ CallbackPuzzleRandomize(Widget w, XtPointer clientData,
 }
 
 static void
-TileSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
+tileChangeListener(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 {
 	int tiles = cbs->value, faces, old;
 	Boolean orient, middle, practice;
@@ -1288,14 +1283,14 @@ TileSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 		XtNtiles, tiles, NULL);
 	movesDsp = 0;
 	(void) sprintf(buff, "%d", movesDsp);
-	PrintState(moves, buff);
-	PrintRecord(tiles, faces, orient, middle, practice);
+	printState(movesText, buff);
+	printRecord(tiles, faces, orient, middle, practice);
 	(void) strcpy(messageDsp, "");
-	PrintState(message, messageDsp);
+	printState(message, messageDsp);
 }
 
 static void
-FaceSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
+faceChangeListener(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 {
 	int tiles, faces = cbs->value, old;
 	Boolean orient, middle, practice;
@@ -1312,14 +1307,14 @@ FaceSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 		XtNfaces, faces, NULL);
 	movesDsp = 0;
 	(void) sprintf(buff, "%d", movesDsp);
-	PrintState(moves, buff);
-	PrintRecord(tiles, faces, orient, middle, practice);
+	printState(movesText, buff);
+	printRecord(tiles, faces, orient, middle, practice);
 	(void) strcpy(messageDsp, "");
-	PrintState(message, messageDsp);
+	printState(message, messageDsp);
 }
 
 static void
-OrientToggle(Widget w, XtPointer clientData, XmToggleButtonCallbackStruct *cbs)
+orientToggle(Widget w, XtPointer clientData, XmToggleButtonCallbackStruct *cbs)
 {
 	int tiles, faces;
 	Boolean orient = cbs->set, middle, practice, oldOrient;
@@ -1342,14 +1337,14 @@ OrientToggle(Widget w, XtPointer clientData, XmToggleButtonCallbackStruct *cbs)
 		XtNorient, orient, NULL);
 	movesDsp = 0;
 	(void) sprintf(buff, "%d", movesDsp);
-	PrintState(moves, buff);
-	PrintRecord(tiles, faces, orient, middle, practice);
+	printState(movesText, buff);
+	printRecord(tiles, faces, orient, middle, practice);
 	(void) strcpy(messageDsp, "");
-	PrintState(message, messageDsp);
+	printState(message, messageDsp);
 }
 
 static void
-MiddleToggle(Widget w, XtPointer clientData, XmToggleButtonCallbackStruct *cbs)
+middleToggle(Widget w, XtPointer clientData, XmToggleButtonCallbackStruct *cbs)
 {
 	int tiles, faces;
 	Boolean orient, middle = cbs->set, practice, oldMid;
@@ -1366,14 +1361,14 @@ MiddleToggle(Widget w, XtPointer clientData, XmToggleButtonCallbackStruct *cbs)
 		XtNmiddle, middle, NULL);
 	movesDsp = 0;
 	(void) sprintf(buff, "%d", movesDsp);
-	PrintState(moves, buff);
-	PrintRecord(tiles, faces, orient, middle, practice);
+	printState(movesText, buff);
+	printRecord(tiles, faces, orient, middle, practice);
 	(void) strcpy(messageDsp, "");
-	PrintState(message, messageDsp);
+	printState(message, messageDsp);
 }
 
 static void
-PracticeToggle(Widget w, XtPointer clientData,
+practiceToggle(Widget w, XtPointer clientData,
 		XmToggleButtonCallbackStruct *cbs)
 {
 	int tiles, faces;
@@ -1392,17 +1387,17 @@ PracticeToggle(Widget w, XtPointer clientData,
 		XtNstart, False, NULL);
 	movesDsp = 0;
 	(void) sprintf(buff, "%d", movesDsp);
-	PrintState(moves, buff);
-	PrintRecord(tiles, faces, orient, middle, practice);
+	printState(movesText, buff);
+	printRecord(tiles, faces, orient, middle, practice);
 	if (practice)
 		(void) strcpy(messageDsp, "");
 	else
 		(void) strncpy(messageDsp, "Randomize to start", MESSAGE_LENGTH);
-	PrintState(message, messageDsp);
+	printState(message, messageDsp);
 }
 
 static void
-SpeedSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
+speedChangeListener(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 {
 	int delay = MAX_SPEED + MIN_SPEED - cbs->value - 1, oldDelay;
 
@@ -1414,7 +1409,7 @@ SpeedSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 }
 
 static void
-fileCB(Widget w, void *value, void *clientData)
+fileMenuListener(Widget w, void *value, void *clientData)
 {
 	int val = (int) value + ACTION_GET;
 
@@ -1486,7 +1481,7 @@ createHelp(Widget w, char *text, char *title)
 }
 
 static void
-helpCB(Widget w, XtPointer value, XtPointer clientData)
+helpMenuListener(Widget w, XtPointer value, XtPointer clientData)
 {
 	int val = (int) value;
 
@@ -1510,7 +1505,7 @@ helpCB(Widget w, XtPointer value, XtPointer clientData)
 		{
 			char *buf;
 
-			intCat(&buf, "helpCB: %d", val);
+			intCat(&buf, "helpMenuListener: %d", val);
 			XtWarning(buf);
 			free(buf);
 		}
@@ -1539,7 +1534,7 @@ main(int argc, char **argv)
 	topLevel = XtInitialize(argv[0], "Mlink",
 		options, XtNumber(options), &argc, argv);
 	if (argc != 1)
-		Usage(argv[0]);
+		usage(argv[0]);
 
 #ifdef HAVE_MOTIF
 	menuBarPanel = XtVaCreateManagedWidget("menuBarPanel",
@@ -1559,7 +1554,7 @@ main(int argc, char **argv)
 	writeString = XmStringCreateSimple((char *) "Write");
 	quitString = XmStringCreateSimple((char *) "Quit");
 	(void) XmVaCreateSimplePulldownMenu(menuBar, (char *) "file_menu",
-		0, fileCB,
+		0, fileMenuListener,
 		XmVaPUSHBUTTON, getString, 'G', NULL, NULL,
 		XmVaPUSHBUTTON, writeString, 'W', NULL, NULL,
 		XmVaSEPARATOR,
@@ -1614,23 +1609,23 @@ main(int argc, char **argv)
 	widget = XtVaCreateManagedWidget("Description",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'D', NULL);
-		XtAddCallback(widget, XmNactivateCallback, helpCB, (char *) 0);
+		XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 0);
 	widget = XtVaCreateManagedWidget("Features",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'F', NULL);
-	XtAddCallback(widget, XmNactivateCallback, helpCB, (char *) 1);
+	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 1);
 	widget = XtVaCreateManagedWidget("Options",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'O', NULL);
-	XtAddCallback(widget, XmNactivateCallback, helpCB, (char *) 2);
+	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 2);
 	widget = XtVaCreateManagedWidget("References",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'R', NULL);
-	XtAddCallback(widget, XmNactivateCallback, helpCB, (char *) 3);
+	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 3);
 	widget = XtVaCreateManagedWidget("About",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'A', NULL);
-	XtAddCallback(widget, XmNactivateCallback, helpCB, (char *) 4);
+	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 4);
 	XtManageChild(menuBar);
 	descriptionDialog = createHelp(menuBar, (char *) descriptionHelp,
 		(char *) "Description");
@@ -1647,11 +1642,11 @@ main(int argc, char **argv)
 	practiceDialog = createQuery(topLevel,
 		(char *) "Are you sure you want to toggle the practice mode?",
 		(char *) "Practice Query",
-		(XtCallbackProc) CallbackPuzzlePractice);
+		(XtCallbackProc) puzzlePracticeListener);
 	randomizeDialog = createQuery(topLevel,
 		(char *) "Are you sure you want to randomize?",
 		(char *) "Randomize Query",
-		(XtCallbackProc) CallbackPuzzleRandomize);
+		(XtCallbackProc) puzzleRandomizeListener);
 	mainPanel = XtCreateManagedWidget("mainPanel",
 		xmPanedWindowWidgetClass, menuBarPanel,
 		NULL, 0);
@@ -1707,19 +1702,19 @@ main(int argc, char **argv)
 	(void) XtVaCreateManagedWidget("movesText",
 		xmLabelGadgetClass, movesRowCol,
 		XtVaTypedArg, XmNlabelString, XmRString, "Moves", 6, NULL);
-	moves = XtVaCreateManagedWidget("0",
+	movesText = XtVaCreateManagedWidget("0",
 		xmLabelWidgetClass, movesRowCol, NULL);
 	(void) XtVaCreateManagedWidget("recordText",
 		xmLabelGadgetClass, movesRowCol,
 		XtVaTypedArg, XmNlabelString, XmRString, "Record", 7, NULL);
-	record = XtVaCreateManagedWidget("0",
+	recordText = XtVaCreateManagedWidget("0",
 		xmLabelWidgetClass, movesRowCol, NULL);
 	tilesRowCol = XtVaCreateManagedWidget("tilesRowCol",
 		xmRowColumnWidgetClass, controlPanel,
 		XmNnumColumns, 1,
 		XmNorientation, XmHORIZONTAL,
 		XmNpacking, XmPACK_COLUMN, NULL);
-	tile = XtVaCreateManagedWidget("tile",
+	tileSlider = XtVaCreateManagedWidget("tileSlider",
 		xmScaleWidgetClass, tilesRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Tiles", 6,
 		XmNminimum, MIN_TILES,
@@ -1727,9 +1722,9 @@ main(int argc, char **argv)
 		XmNvalue, DEFAULT_TILES,
 		XmNshowValue, True,
 		XmNorientation, XmHORIZONTAL, NULL);
-	XtAddCallback(tile, XmNvalueChangedCallback,
-		(XtCallbackProc) TileSlider, (XtPointer) NULL);
-	face = XtVaCreateManagedWidget("face",
+	XtAddCallback(tileSlider, XmNvalueChangedCallback,
+		(XtCallbackProc) tileChangeListener, (XtPointer) NULL);
+	faceSlider = XtVaCreateManagedWidget("faceSlider",
 		xmScaleWidgetClass, tilesRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Faces", 6,
 		XmNminimum, MIN_FACES,
@@ -1737,14 +1732,14 @@ main(int argc, char **argv)
 		XmNvalue, DEFAULT_FACES,
 		XmNshowValue, True,
 		XmNorientation, XmHORIZONTAL, NULL);
-	XtAddCallback(face, XmNvalueChangedCallback,
-		(XtCallbackProc) FaceSlider, (XtPointer) NULL);
+	XtAddCallback(faceSlider, XmNvalueChangedCallback,
+		(XtCallbackProc) faceChangeListener, (XtPointer) NULL);
 	speedRowCol = XtVaCreateManagedWidget("speedRowCol",
 		xmRowColumnWidgetClass, controlPanel,
 		XmNnumColumns, 1,
 		XmNorientation, XmHORIZONTAL,
 		XmNpacking, XmPACK_COLUMN, NULL);
-	speed = XtVaCreateManagedWidget("Animation Speed",
+	speedSlider = XtVaCreateManagedWidget("speedSlider",
 		xmScaleWidgetClass, speedRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Animation Speed", 16,
 		XmNminimum, MIN_SPEED,
@@ -1752,8 +1747,8 @@ main(int argc, char **argv)
 		XmNvalue, MAX_SPEED - DEFAULT_DELAY,
 		XmNshowValue, True,
 		XmNorientation, XmHORIZONTAL, NULL);
-	XtAddCallback(speed, XmNvalueChangedCallback,
-		(XtCallbackProc) SpeedSlider, (XtPointer) NULL);
+	XtAddCallback(speedSlider, XmNvalueChangedCallback,
+		(XtCallbackProc) speedChangeListener, (XtPointer) NULL);
 	switchRowCol = XtVaCreateManagedWidget("switchRowCol",
 		xmRowColumnWidgetClass, controlPanel,
 		XmNnumColumns, 1,
@@ -1763,17 +1758,17 @@ main(int argc, char **argv)
 		xmToggleButtonWidgetClass, switchRowCol,
 		XmNset, DEFAULT_ORIENT, NULL);
 	XtAddCallback(orientizeSwitch, XmNvalueChangedCallback,
-		(XtCallbackProc) OrientToggle, (XtPointer) NULL);
+		(XtCallbackProc) orientToggle, (XtPointer) NULL);
 	middleSwitch = XtVaCreateManagedWidget("Middle rigid",
 		xmToggleButtonWidgetClass, switchRowCol,
 		XmNset, DEFAULT_MIDDLE, NULL);
 	XtAddCallback(middleSwitch, XmNvalueChangedCallback,
-		(XtCallbackProc) MiddleToggle, (XtPointer) NULL);
+		(XtCallbackProc) middleToggle, (XtPointer) NULL);
 	practiceSwitch = XtVaCreateManagedWidget("Practice",
 		xmToggleButtonWidgetClass, switchRowCol,
 		XmNset, DEFAULT_PRACTICE, NULL);
 	XtAddCallback(practiceSwitch, XmNvalueChangedCallback,
-		(XtCallbackProc) PracticeToggle, (XtPointer) NULL);
+		(XtCallbackProc) practiceToggle, (XtPointer) NULL);
 	messageRowCol = XtVaCreateManagedWidget("messageRowCol",
 		xmRowColumnWidgetClass, controlPanel, NULL);
 	message = XtVaCreateManagedWidget("Play Missing Link! (use mouse and keypad)",
@@ -1817,14 +1812,14 @@ main(int argc, char **argv)
 #endif
 		XtNiconPixmap, pixmap, NULL);
 	XtAddCallback(puzzle, XtNselectCallback,
-		(XtCallbackProc) CallbackPuzzle, (XtPointer) NULL);
-	Initialize(puzzle);
+		(XtCallbackProc) puzzleListener, (XtPointer) NULL);
+	initialize(puzzle);
 	XtRealizeWidget(topLevel);
 	XGrabButton(XtDisplay(puzzle), (unsigned int) AnyButton, AnyModifier,
 		XtWindow(puzzle), TRUE, (unsigned int) (ButtonPressMask |
 		ButtonMotionMask | ButtonReleaseMask),
 		GrabModeAsync, GrabModeAsync, XtWindow(puzzle),
-		XCreateFontCursor(XtDisplay(puzzle), XC_crosshair));
+		XCreateFontCursor(XtDisplay(puzzle), XC_hand2));
 	XtMainLoop();
 
 #ifdef VMS
