@@ -1,27 +1,22 @@
-/*-
-# X-BASED OCTAHEDRON
-#
-#  OctP.h
-#
-###
-#
-#  Copyright (c) 1994 - 2007	David A. Bagley, bagleyd@tux.org
-#
-#                   All Rights Reserved
-#
-#  Permission to use, copy, modify, and distribute this software and
-#  its documentation for any purpose and without fee is hereby granted,
-#  provided that the above copyright notice appear in all copies and
-#  that both that copyright notice and this permission notice appear in
-#  supporting documentation, and that the name of the author not be
-#  used in advertising or publicity pertaining to distribution of the
-#  software without specific, written prior permission.
-#
-#  This program is distributed in the hope that it will be "playable",
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-#
-*/
+/*
+ * @(#)OctP.h
+ *
+ * Copyright 1994 - 2008  David A. Bagley, bagleyd@tux.org
+ *
+ * All rights reserved.
+ *
+ * Permission to use, copy, modify, and distribute this software and
+ * its documentation for any purpose and without fee is hereby granted,
+ * provided that the above copyright notice appear in all copies and
+ * that both that copyright notice and this permission notice appear in
+ * supporting documentation, and that the name of the author not be
+ * used in advertising or publicity pertaining to distribution of the
+ * software without specific, written prior permission.
+ *
+ * This program is distributed in the hope that it will be "useful",
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ */
 
 /* Private header file for Oct */
 
@@ -33,40 +28,40 @@
 #include "Oct.h"
 
 #ifdef WINVER
-extern void DestroyPuzzle(HBRUSH brush);
-extern void ResizePuzzle(OctWidget w);
-extern void SizePuzzle(OctWidget w);
-extern void InitializePuzzle(OctWidget w, HBRUSH brush);
-extern void ExposePuzzle(OctWidget w);
-extern void HidePuzzle(OctWidget w);
-extern void SelectPuzzle(OctWidget w,
+extern void destroyPuzzle(HBRUSH brush);
+extern void resizePuzzle(OctWidget w);
+extern void sizePuzzle(OctWidget w);
+extern void initializePuzzle(OctWidget w, HBRUSH brush);
+extern void exposePuzzle(OctWidget w);
+extern void hidePuzzle(OctWidget w);
+extern void selectPuzzle(OctWidget w,
 	const int x, const int y, const int control);
-extern void ReleasePuzzle(OctWidget w,
+extern void releasePuzzle(OctWidget w,
 	const int x, const int y, const int shift, const int control);
-extern void PracticePuzzle(OctWidget w);
-extern void RandomizePuzzle(OctWidget w);
-extern void GetPuzzle(OctWidget w);
-extern void WritePuzzle(OctWidget w);
-extern void UndoPuzzle(OctWidget w);
-extern void RedoPuzzle(OctWidget w);
-extern void ClearPuzzle(OctWidget w);
-extern void SolvePuzzle(OctWidget w);
-extern void IncrementPuzzle(OctWidget w);
-extern Boolean DecrementPuzzle(OctWidget w);
-extern void OrientizePuzzle(OctWidget w);
-extern void StickyModePuzzle(OctWidget w);
-extern void PeriodModePuzzle(OctWidget w, const int mode);
-extern void Period3ModePuzzle(OctWidget w);
-extern void Period4ModePuzzle(OctWidget w);
-extern void BothModePuzzle(OctWidget w);
-extern void SpeedPuzzle(OctWidget w);
-extern void SlowPuzzle(OctWidget w);
-extern void SoundPuzzle(OctWidget w);
-extern void EnterPuzzle(OctWidget w);
-extern void LeavePuzzle(OctWidget w);
-extern void MovePuzzleInput(OctWidget w,
+extern void practicePuzzle(OctWidget w);
+extern void randomizePuzzle(OctWidget w);
+extern void getPuzzle(OctWidget w);
+extern void writePuzzle(OctWidget w);
+extern void undoPuzzle(OctWidget w);
+extern void redoPuzzle(OctWidget w);
+extern void clearPuzzle(OctWidget w);
+extern void solvePuzzle(OctWidget w);
+extern void incrementPuzzle(OctWidget w);
+extern Boolean decrementPuzzle(OctWidget w);
+extern void orientizePuzzle(OctWidget w);
+extern void stickyModePuzzle(OctWidget w);
+extern void periodModePuzzle(OctWidget w, const int mode);
+extern void period3ModePuzzle(OctWidget w);
+extern void period4ModePuzzle(OctWidget w);
+extern void bothModePuzzle(OctWidget w);
+extern void speedUpPuzzle(OctWidget w);
+extern void slowDownPuzzle(OctWidget w);
+extern void toggleSoundPuzzle(OctWidget w);
+extern void enterPuzzle(OctWidget w);
+extern void leavePuzzle(OctWidget w);
+extern void movePuzzleInput(OctWidget w,
 	int x, int y, int direction, int shift, int control);
-extern int  MovePuzzleDir(OctWidget w, const int direction);
+extern int  movePuzzleDir(OctWidget w, const int direction);
 
 #else
 
@@ -111,16 +106,16 @@ extern OctClassRec octClassRec;
 #define MAX_SIDES (MAX_FACES/MAX_VIEWS)
 #define MAX_ORIENT (3*MAX_SIDES)
 
-typedef struct _MoveRecord {
+typedef struct _moveRecord {
 #if 0
 	int face, direction, style, control;
 #endif
 	unsigned short int packed;  /* This makes assumptions on the data. */
 	int position;		    /* Do not make assumptions on this one. */
-} MoveRecord;
+} moveRecord;
 
 typedef struct _MoveStack {
-	MoveRecord move;
+	moveRecord move;
 	struct _MoveStack *previous, *next;
 } MoveStack;
 
@@ -174,7 +169,7 @@ typedef struct _OctRec {
 
 extern OctLoc *startLoc[MAX_FACES];
 extern void setPuzzle(OctWidget w, int reason);
-extern void MovePuzzle(OctWidget w,
+extern void movePuzzle(OctWidget w,
 	int face, int position, int direction, int style, int control);
 
 #if 0
@@ -182,8 +177,8 @@ extern void MovePuzzle(OctWidget w,
 extern void SolvePolyhedrons(OctWidget w);
 
 #endif
-extern void DrawAllPieces(OctWidget w);
-extern Boolean CheckSolved(OctWidget w);
+extern void drawAllPieces(OctWidget w);
+extern Boolean checkSolved(OctWidget w);
 extern void newMoves(OctStack *s);
 extern void deleteMoves(OctStack *s);
 extern void setMove(OctStack *s,
