@@ -1,27 +1,24 @@
-/*-
-# MOTIF/X-BASED OCTAHEDRON
-#
-#  xoct.c
-#
-###
-#
-#  Copyright (c) 1993 - 2007	David A. Bagley, bagleyd@tux.org
-#
-#                   All Rights Reserved
-#
-#  Permission to use, copy, modify, and distribute this software and
-#  its documentation for any purpose and without fee is hereby granted,
-#  provided that the above copyright notice appear in all copies and
-#  that both that copyright notice and this permission notice appear in
-#  supporting documentation, and that the name of the author not be
-#  used in advertising or publicity pertaining to distribution of the
-#  software without specific, written prior permission.
-#
-#  This program is distributed in the hope that it will be "playable",
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-#
-*/
+/*
+ * @(#)xoct.c
+ *
+ * Copyright 1993 - 2008  David A. Bagley, bagleyd@tux.org
+ *
+ * All rights reserved.
+ *
+ * Permission to use, copy, modify, and distribute this software and
+ * its documentation for any purpose and without fee is hereby granted,
+ * provided that the above copyright notice appear in all copies and
+ * that both that copyright notice and this permission notice appear in
+ * supporting documentation, and that the name of the author not be
+ * used in advertising or publicity pertaining to distribution of the
+ * software without specific, written prior permission.
+ *
+ * This program is distributed in the hope that it will be "useful",
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ */
+
+/* Driver file for Oct */
 
 #include "file.h"
 #ifdef WINVER
@@ -58,7 +55,7 @@ static OctRec widget;
 #include "pixmaps/mouse-l.xbm"
 #include "pixmaps/mouse-r.xbm"
 #endif
-#define PRINT_MESSAGE(b) PrintState(message, b)
+#define PRINT_MESSAGE(b) printState(message, b)
 #else
 #define PRINT_MESSAGE(b) XtWarning(b)
 #endif
@@ -90,7 +87,7 @@ static OctRec widget;
 
 #ifndef WINVER
 static const char aboutHelp[] = {
-"Oct Version 7.3.2\n"
+"Oct Version 7.4\n"
 "Send bugs (reports or fixes) to the author: "
 "David Bagley <bagleyd@tux.org>\n"
 "The latest version is at: "
@@ -255,8 +252,9 @@ static char recordDsp[MESSAGE_LENGTH] = "NOT RECORDED";
 static int oldSize;
 
 #ifdef HAVE_MOTIF
-static Widget moves, record, message, modes[MAX_MODES], orientizeSwitch;
-static Widget stickySwitch, practiceSwitch, facets;
+static Widget movesText, recordText, message;
+static Widget modes[MAX_MODES], orientizeSwitch;
+static Widget stickySwitch, practiceSwitch, facetSlider;
 static char buff[21];
 static const char *modeString[] =
 {
@@ -284,19 +282,19 @@ static char userNameDsp[USER_NAME_LENGTH] = "";
 
 #ifdef HAVE_MOTIF
 static void
-PrintState(Widget w, char *msg)
+printState(Widget w, char *msg)
 {
 	XmString xmstr;
 
 	if (!XtIsSubclass(w, xmLabelWidgetClass))
-		XtError("PrintState() requires a Label Widget");
+		XtError("printState() requires a Label Widget");
 	xmstr = XmStringCreateLtoR(msg, XmSTRING_DEFAULT_CHARSET);
 	XtVaSetValues(w, XmNlabelString, xmstr, NULL);
 }
 #endif
 
 static void
-PrintRecords(void)
+printRecords(void)
 {
 	int i, mode, orient;
 
@@ -315,7 +313,7 @@ PrintRecords(void)
 #endif
 
 static void
-InitRecords(void)
+initRecords(void)
 {
 	int i, mode, orient;
 
@@ -329,7 +327,7 @@ InitRecords(void)
 }
 
 static void
-ReadRecords(void)
+readRecords(void)
 {
 	FILE *fp;
 	int i, n, mode, orient;
@@ -389,7 +387,7 @@ ReadRecords(void)
 }
 
 static void
-WriteRecords(void)
+writeRecords(void)
 {
 	FILE *fp;
 	int i, mode, orient;
@@ -440,7 +438,7 @@ WriteRecords(void)
 }
 
 static void
-PrintRecord(int size, int mode,
+printRecord(int size, int mode,
 		Boolean orient, Boolean sticky, Boolean practice)
 {
 	int i = mode - PERIOD3;
@@ -458,21 +456,21 @@ PrintRecord(int size, int mode,
 			puzzleRecord[i][j][k].score, puzzleRecord[i][j][k].name);
 	}
 #ifdef HAVE_MOTIF
-	PrintState(record, recordDsp);
+	printState(recordText, recordDsp);
 #endif
 }
 
 static void
-PrintStatus(char *msg, int nMoves
+printStatus(char *msg, int nMoves
 #ifndef HAVE_MOTIF
 		, int mode, int size, Boolean sticky
 #endif
 		)
 {
 #ifdef HAVE_MOTIF
-	PrintState(message, msg);
+	printState(message, msg);
 	(void) sprintf(buff, "%d", nMoves);
-	PrintState(moves, buff);
+	printState(movesText, buff);
 #else
 	char ss[10], mb[10];
 
@@ -495,7 +493,7 @@ PrintStatus(char *msg, int nMoves
 }
 
 static Boolean
-HandleSolved(int counter, int size, int mode, Boolean orient, Boolean sticky)
+handleSolved(int counter, int size, int mode, Boolean orient, Boolean sticky)
 {
 	int i = mode - PERIOD3;
 	int j = (orient) ? 1 : 0;
@@ -504,7 +502,7 @@ HandleSolved(int counter, int size, int mode, Boolean orient, Boolean sticky)
 	if ((sticky || size <= MAX_FACETS) &&
 			(counter < puzzleRecord[i][j][k].score ||
 			puzzleRecord[i][j][k].score <= NEVER)) {
-		ReadRecords();	/* Maybe its been updated by another */
+		readRecords();	/* Maybe its been updated by another */
 		puzzleRecord[i][j][k].score = counter;
 		(void) strncpy(puzzleRecord[i][j][k].name, userNameDsp, USER_NAME_LENGTH);
 		if ((size < 2 && mode != PERIOD4) ||
@@ -515,15 +513,15 @@ HandleSolved(int counter, int size, int mode, Boolean orient, Boolean sticky)
 			(void) strncpy(puzzleRecord[i][!j][k].name, userNameDsp,
 				USER_NAME_LENGTH);
 		}
-		WriteRecords();
-		PrintRecord(size, mode, orient, sticky, False);
+		writeRecords();
+		printRecord(size, mode, orient, sticky, False);
 		return True;
 	}
 	return False;
 }
 
 static void
-Initialize(
+initialize(
 #ifdef WINVER
 OctWidget w, HBRUSH brush
 #else
@@ -536,7 +534,7 @@ Widget w
 	char *userName, *scoreFile;
 
 #ifdef WINVER
-	InitializePuzzle(w, brush);
+	initializePuzzle(w, brush);
 
 	size = w->oct.size;
 	mode = w->oct.mode;
@@ -567,15 +565,15 @@ Widget w
 	if (strcmp(scoreFile, ""))
 		(void) strncpy(scoreFileName, scoreFile, FILE_NAME_LENGTH);
 	if (scoreOnly) {
-		InitRecords();
-		ReadRecords();
-		PrintRecords();
+		initRecords();
+		readRecords();
+		printRecords();
 		exit(0);
 	}
 #ifdef HAVE_MOTIF
 	if (size > MAX_FACETS)
-		XtVaSetValues(facets, XmNmaximum, size, NULL);
-	XmScaleSetValue(facets, size);
+		XtVaSetValues(facetSlider, XmNmaximum, size, NULL);
+	XmScaleSetValue(facetSlider, size);
 	XmToggleButtonSetState(modes[mode - PERIOD3], True, False);
 	XmToggleButtonSetState(orientizeSwitch, orient, True);
 	XmToggleButtonSetState(stickySwitch, sticky, True);
@@ -583,8 +581,8 @@ Widget w
 #endif
 #endif
 	SET_STARTED(w, False);
-	InitRecords();
-	ReadRecords();
+	initRecords();
+	readRecords();
 #ifndef WINVER
 	(void) strncpy(userNameDsp, userName, USER_NAME_LENGTH);
 #endif
@@ -609,9 +607,9 @@ Widget w
 			(void) sprintf(userNameDsp, "%s", "guest");
 #endif
 	}
-	PrintRecord(size, mode, orient, sticky, practice);
+	printRecord(size, mode, orient, sticky, practice);
 	oldSize = size;
-	PrintStatus(messageDsp, movesDsp
+	printStatus(messageDsp, movesDsp
 #ifndef HAVE_MOTIF
 		, mode, size, sticky
 #endif
@@ -623,7 +621,7 @@ void
 setPuzzle(OctWidget w, int reason)
 #else
 static void
-CallbackPuzzle(Widget w, caddr_t clientData, octCallbackStruct *callData)
+puzzleListener(Widget w, caddr_t clientData, octCallbackStruct *callData)
 #endif
 {
 #ifndef WINVER
@@ -694,7 +692,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, octCallbackStruct *callData)
 			(void) strncpy(recordDsp, "practice",
 				MESSAGE_LENGTH);
 #ifdef HAVE_MOTIF
-			PrintState(record, recordDsp);
+			printState(recordText, recordDsp);
 #endif
 		}
 		movesDsp = 0;
@@ -728,7 +726,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, octCallbackStruct *callData)
 		else if (cheat)
 			(void) sprintf(messageDsp,
 				"No cheating %s!!", userNameDsp);
-		else if (HandleSolved(movesDsp, size, mode, orient, sticky))
+		else if (handleSolved(movesDsp, size, mode, orient, sticky))
 			(void) sprintf(messageDsp,
 				"Congratulations %s!!", userNameDsp);
 		else
@@ -747,7 +745,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, octCallbackStruct *callData)
 		if (!practice)
 			(void) strncpy(messageDsp, "Randomize to start",
 				MESSAGE_LENGTH);
-		PrintRecord(size, mode, orient, sticky, practice);
+		printRecord(size, mode, orient, sticky, practice);
 #ifdef WINVER
 		w->oct.practice = practice;
 		w->oct.started = False;
@@ -777,15 +775,15 @@ CallbackPuzzle(Widget w, caddr_t clientData, octCallbackStruct *callData)
 			movesDsp = 0;
 			size++;
 			oldSize = size;
-			PrintRecord(size, mode, orient, sticky, practice);
+			printRecord(size, mode, orient, sticky, practice);
 #ifdef WINVER
 			w->oct.size = size;
 #else
 			XtVaSetValues(w, XtNsize, size, NULL);
 #ifdef HAVE_MOTIF
 			if (size > MAX_FACETS)
-				XtVaSetValues(facets, XmNmaximum, size, NULL);
-			XmScaleSetValue(facets, size);
+				XtVaSetValues(facetSlider, XmNmaximum, size, NULL);
+			XmScaleSetValue(facetSlider, size);
 #endif
 #endif
 		}
@@ -795,15 +793,15 @@ CallbackPuzzle(Widget w, caddr_t clientData, octCallbackStruct *callData)
 			movesDsp = 0;
 			size--;
 			oldSize = size;
-			PrintRecord(size, mode, orient, sticky, practice);
+			printRecord(size, mode, orient, sticky, practice);
 #ifdef WINVER
 			w->oct.size = size;
 #else
 			XtVaSetValues(w, XtNsize, size, NULL);
 #ifdef HAVE_MOTIF
-			XmScaleSetValue(facets, size);
+			XmScaleSetValue(facetSlider, size);
 			if (size >= MAX_FACETS)
-				XtVaSetValues(facets, XmNmaximum, size, NULL);
+				XtVaSetValues(facetSlider, XmNmaximum, size, NULL);
 #endif
 #endif
 		}
@@ -811,7 +809,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, octCallbackStruct *callData)
 	case ACTION_ORIENTIZE:
 		movesDsp = 0;
 		orient = !orient;
-		PrintRecord(size, mode, orient, sticky, practice);
+		printRecord(size, mode, orient, sticky, practice);
 #ifdef WINVER
 		w->oct.orient = orient;
 #else
@@ -826,7 +824,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, octCallbackStruct *callData)
 	case ACTION_BOTH:
 		movesDsp = 0;
 		mode = reason - ACTION_PERIOD3 + PERIOD3;
-		PrintRecord(size, mode, orient, sticky, practice);
+		printRecord(size, mode, orient, sticky, practice);
 #ifdef WINVER
 		w->oct.mode = mode;
 #else
@@ -843,7 +841,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, octCallbackStruct *callData)
 			size = 4;
 		else
 			size = oldSize;
-		PrintRecord(size, mode, orient, sticky, practice);
+		printRecord(size, mode, orient, sticky, practice);
 #ifdef WINVER
 		w->oct.sticky = sticky;
 		w->oct.size = size;
@@ -853,7 +851,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, octCallbackStruct *callData)
 			XtNsize, size, NULL);
 #ifdef HAVE_MOTIF
 		XmToggleButtonSetState(stickySwitch, sticky, True);
-		XmScaleSetValue(facets, size);
+		XmScaleSetValue(facetSlider, size);
 #endif
 #endif
 		break;
@@ -866,7 +864,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, octCallbackStruct *callData)
 		SET_STARTED(w, True);
 		break;
 	}
-	PrintStatus(messageDsp, movesDsp
+	printStatus(messageDsp, movesDsp
 #ifndef HAVE_MOTIF
 		, mode, size, sticky
 #endif
@@ -875,15 +873,11 @@ CallbackPuzzle(Widget w, caddr_t clientData, octCallbackStruct *callData)
 
 #ifdef WINVER
 static LRESULT CALLBACK
-About(HWND hDlg, UINT message, WPARAM wParam, LPARAM lParam)
+about(HWND hDlg, UINT message, WPARAM wParam, LPARAM lParam)
 {
-	switch (message) {
-	case WM_COMMAND:
-		if (LOWORD(wParam) == IDOK) {
-			(void) EndDialog(hDlg, TRUE);
-			return TRUE;
-		}
-		break;
+	if (message == WM_COMMAND && LOWORD(wParam) == IDOK) {
+		(void) EndDialog(hDlg, TRUE);
+		return TRUE;
 	}
 	return FALSE;
 }
@@ -901,7 +895,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_BRUSH));
-			EnterPuzzle(&widget);
+			enterPuzzle(&widget);
 			(void) EndPaint(hWnd, &paint);
 		}
 	} else {
@@ -909,40 +903,40 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_BRUSH));
-			LeavePuzzle(&widget);
+			leavePuzzle(&widget);
 			(void) EndPaint(hWnd, &paint);
 		}
 	}
 	switch (message) {
 	case WM_CREATE:
-		Initialize(&widget, brush);
+		initialize(&widget, brush);
 		break;
 	case WM_DESTROY:
-		DestroyPuzzle(brush);
+		destroyPuzzle(brush);
 		break;
 	case WM_SIZE:
-		ResizePuzzle(&widget);
+		resizePuzzle(&widget);
 		(void) InvalidateRect(hWnd, NULL, TRUE);
 		break;
 	case WM_PAINT:
 		widget.core.hDC = BeginPaint(hWnd, &paint);
 		(void) SelectObject(widget.core.hDC,
 			GetStockObject(NULL_PEN));
-		ExposePuzzle(&widget);
+		exposePuzzle(&widget);
 		(void) EndPaint(hWnd, &paint);
 		break;
 	case WM_RBUTTONDOWN:
 		widget.core.hDC = GetDC(hWnd);
 		(void) SelectObject(widget.core.hDC,
 			GetStockObject(NULL_PEN));
-		RandomizePuzzle(&widget);
+		randomizePuzzle(&widget);
 		(void) ReleaseDC(hWnd, widget.core.hDC);
 		break;
 	case WM_LBUTTONDOWN:
 		widget.core.hDC = GetDC(hWnd);
 		(void) SelectObject(widget.core.hDC,
 			GetStockObject(NULL_PEN));
-		SelectPuzzle(&widget, LOWORD(lParam), HIWORD(lParam),
+		selectPuzzle(&widget, LOWORD(lParam), HIWORD(lParam),
 			(GetKeyState(VK_CONTROL) >> 1) ? 1 : 0);
 		(void) ReleaseDC(hWnd, widget.core.hDC);
 		break;
@@ -950,7 +944,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 		widget.core.hDC = GetDC(hWnd);
 		(void) SelectObject(widget.core.hDC,
 			GetStockObject(NULL_PEN));
-		ReleasePuzzle(&widget, LOWORD(lParam), HIWORD(lParam),
+		releasePuzzle(&widget, LOWORD(lParam), HIWORD(lParam),
 			((GetKeyState(VK_SHIFT) >> 1) ||
 			(GetKeyState(VK_CAPITAL) & 1)),
 			(GetKeyState(VK_CONTROL) >> 1) ? 1 : 0);
@@ -969,7 +963,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			ClientToScreen(hWnd, &origin);
 			(void) GetCursorPos(&cursor);
 			if (zDelta > (WHEEL_DELTA >> 1)) {
-				MovePuzzleInput(&widget,
+				movePuzzleInput(&widget,
 					cursor.x - origin.x,
 					cursor.y - origin.y,
 					TOP,
@@ -977,7 +971,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 					(GetKeyState(VK_CAPITAL) & 1)),
 					(GetKeyState(VK_CONTROL) >> 1) ? 1 : 0);
 			} else if (zDelta < -(WHEEL_DELTA >> 1)) {
-				MovePuzzleInput(&widget,
+				movePuzzleInput(&widget,
 					cursor.x - origin.x,
 					cursor.y - origin.y,
 					BOTTOM,
@@ -992,67 +986,67 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 	case WM_COMMAND:
 		switch (LOWORD(wParam)) {
 		case ACTION_GET:
-			GetPuzzle(&widget);
-			ResizePuzzle(&widget);
+			getPuzzle(&widget);
+			resizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
 		case ACTION_WRITE:
-			WritePuzzle(&widget);
+			writePuzzle(&widget);
 			break;
 		case ACTION_EXIT:
-			DestroyPuzzle(brush);
+			destroyPuzzle(brush);
 			break;
 		case ACTION_HIDE:
-			HidePuzzle(&widget);
+			hidePuzzle(&widget);
 			break;
 		case ACTION_UNDO:
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_PEN));
-			UndoPuzzle(&widget);
+			undoPuzzle(&widget);
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
 		case ACTION_REDO:
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_PEN));
-			RedoPuzzle(&widget);
+			redoPuzzle(&widget);
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
 		case ACTION_CLEAR:
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_PEN));
-			ClearPuzzle(&widget);
+			clearPuzzle(&widget);
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
 		case ACTION_RANDOMIZE:
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_PEN));
-			RandomizePuzzle(&widget);
+			randomizePuzzle(&widget);
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
 		case ACTION_PRACTICE:
-			PracticePuzzle(&widget);
-			SizePuzzle(&widget);
+			practicePuzzle(&widget);
+			sizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
 		case ACTION_SOLVE:
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_PEN));
-			SolvePuzzle(&widget);
+			solvePuzzle(&widget);
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
 		case ACTION_ORIENTIZE:
-			OrientizePuzzle(&widget);
-			SizePuzzle(&widget);
+			orientizePuzzle(&widget);
+			sizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
 		case ACTION_STICKY:
-			(void) StickyModePuzzle(&widget);
-			SizePuzzle(&widget);
+			(void) stickyModePuzzle(&widget);
+			sizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
 		case ACTION_SHIFT_TOP:
@@ -1085,7 +1079,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 				origin.x = 0, origin.y = 0;
 				ClientToScreen(hWnd, &origin);
 				(void) GetCursorPos(&cursor);
-				(void) MovePuzzleInput(&widget,
+				(void) movePuzzleInput(&widget,
 					cursor.x - origin.x,
 					cursor.y - origin.y,
 					(int) LOWORD(wParam) -
@@ -1124,7 +1118,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 				origin.x = 0, origin.y = 0;
 				ClientToScreen(hWnd, &origin);
 				(void) GetCursorPos(&cursor);
-				(void) MovePuzzleInput(&widget,
+				(void) movePuzzleInput(&widget,
 					cursor.x - origin.x,
 					cursor.y - origin.y,
 					(int) LOWORD(wParam) -
@@ -1135,32 +1129,32 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			}
 			break;
 		case ACTION_INCREMENT:
-			IncrementPuzzle(&widget);
-			SizePuzzle(&widget);
+			incrementPuzzle(&widget);
+			sizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
 		case ACTION_DECREMENT:
-			if (DecrementPuzzle(&widget)) {
-				SizePuzzle(&widget);
+			if (decrementPuzzle(&widget)) {
+				sizePuzzle(&widget);
 				(void) InvalidateRect(hWnd, NULL, TRUE);
 			}
 			break;
 		case ACTION_PERIOD3:
 		case ACTION_PERIOD4:
 		case ACTION_BOTH:
-			PeriodModePuzzle(&widget,
+			periodModePuzzle(&widget,
 				(int) LOWORD(wParam) - ACTION_PERIOD3);
-			SizePuzzle(&widget);
+			sizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
 		case ACTION_SPEED:
-			SpeedPuzzle(&widget);
+			speedUpPuzzle(&widget);
 			break;
 		case ACTION_SLOW:
-			SlowPuzzle(&widget);
+			slowDownPuzzle(&widget);
 			break;
 		case ACTION_SOUND:
-			SoundPuzzle(&widget);
+			toggleSoundPuzzle(&widget);
 			break;
 		case ACTION_DESCRIPTION:
 			(void) MessageBox(hWnd, descriptionHelp,
@@ -1176,7 +1170,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			break;
 		case ACTION_ABOUT:
 			(void) DialogBox(widget.core.hInstance,
-				"About", hWnd, (DLGPROC) About);
+				"About", hWnd, (DLGPROC) about);
 			break;
 		}
 		break;
@@ -1237,7 +1231,7 @@ WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance, LPSTR lpCmdLine,
 #else
 
 static void
-Usage(char *programName)
+usage(char *programName)
 {
 	unsigned int i;
 
@@ -1293,7 +1287,7 @@ static XrmOptionDescRec options[] =
 
 #ifdef HAVE_MOTIF
 static void
-CallbackPuzzlePractice(Widget w, XtPointer clientData,
+puzzlePracticeListener(Widget w, XtPointer clientData,
 		XmAnyCallbackStruct *cbs)
 {
 	if (cbs->reason == XmCR_OK) {
@@ -1302,7 +1296,7 @@ CallbackPuzzlePractice(Widget w, XtPointer clientData,
 }
 
 static void
-CallbackPuzzleRandomize(Widget w, XtPointer clientData,
+puzzleRandomizeListener(Widget w, XtPointer clientData,
 		XmAnyCallbackStruct *cbs)
 {
 	if (cbs->reason == XmCR_OK) {
@@ -1310,7 +1304,7 @@ CallbackPuzzleRandomize(Widget w, XtPointer clientData,
 	}
 }
 static void
-PieceSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
+pieceChangeListener(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 {
 	int size = cbs->value, mode;
 	Boolean orient, sticky, practice;
@@ -1329,15 +1323,15 @@ PieceSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 		oldSize = size;
 		movesDsp = 0;
 		(void) sprintf(buff, "%d", movesDsp);
-		PrintState(moves, buff);
-		PrintRecord(size, mode, orient, sticky, practice);
+		printState(movesText, buff);
+		printRecord(size, mode, orient, sticky, practice);
 		(void) strcpy(messageDsp, "");
-		PrintState(message, messageDsp);
+		printState(message, messageDsp);
 	}
 }
 
 static void
-ModeToggle(Widget w, int mode, XmToggleButtonCallbackStruct *cbs)
+modeToggle(Widget w, int mode, XmToggleButtonCallbackStruct *cbs)
 {
 	int size;
 	Boolean orient, sticky, practice;
@@ -1352,15 +1346,15 @@ ModeToggle(Widget w, int mode, XmToggleButtonCallbackStruct *cbs)
 			XtNmode, mode + PERIOD3, NULL);
 		movesDsp = 0;
 		(void) sprintf(buff, "%d", movesDsp);
-		PrintState(moves, buff);
-		PrintRecord(size, mode + PERIOD3, orient, sticky, practice);
+		printState(movesText, buff);
+		printRecord(size, mode + PERIOD3, orient, sticky, practice);
 		(void) strcpy(messageDsp, "");
-		PrintState(message, messageDsp);
+		printState(message, messageDsp);
 	}
 }
 
 static void
-OrientToggle(Widget w, XtPointer clientData, XmToggleButtonCallbackStruct *cbs)
+orientToggle(Widget w, XtPointer clientData, XmToggleButtonCallbackStruct *cbs)
 {
 	int size, mode;
 	Boolean orient = cbs->set, sticky, practice;
@@ -1374,14 +1368,14 @@ OrientToggle(Widget w, XtPointer clientData, XmToggleButtonCallbackStruct *cbs)
 		XtNorient, orient, NULL);
 	movesDsp = 0;
 	(void) sprintf(buff, "%d", movesDsp);
-	PrintState(moves, buff);
-	PrintRecord(size, mode, orient, sticky, practice);
+	printState(movesText, buff);
+	printRecord(size, mode, orient, sticky, practice);
 	(void) strcpy(messageDsp, "");
-	PrintState(message, messageDsp);
+	printState(message, messageDsp);
 }
 
 static void
-StickyToggle(Widget w, XtPointer clientData, XmToggleButtonCallbackStruct *cbs)
+stickyToggle(Widget w, XtPointer clientData, XmToggleButtonCallbackStruct *cbs)
 {
 	int size, mode;
 	Boolean orient, sticky = cbs->set, practice;
@@ -1399,20 +1393,20 @@ StickyToggle(Widget w, XtPointer clientData, XmToggleButtonCallbackStruct *cbs)
 		else
 			size = oldSize;
 		if (size <= MAX_FACETS)
-			XmScaleSetValue(facets, size);
+			XmScaleSetValue(facetSlider, size);
 		XtVaSetValues(puzzle,
 			XtNsize, size, NULL);
 	}
 	movesDsp = 0;
 	(void) sprintf(buff, "%d", movesDsp);
-	PrintState(moves, buff);
-	PrintRecord(size, mode, orient, sticky, practice);
+	printState(movesText, buff);
+	printRecord(size, mode, orient, sticky, practice);
 	(void) strcpy(messageDsp, "");
-	PrintState(message, messageDsp);
+	printState(message, messageDsp);
 }
 
 static void
-PracticeToggle(Widget w, XtPointer clientData,
+practiceToggle(Widget w, XtPointer clientData,
 		XmToggleButtonCallbackStruct *cbs)
 {
 	int size, mode;
@@ -1428,17 +1422,17 @@ PracticeToggle(Widget w, XtPointer clientData,
 		XtNsticky, &sticky, NULL);
 	movesDsp = 0;
 	(void) sprintf(buff, "%d", movesDsp);
-	PrintState(moves, buff);
-	PrintRecord(size, mode, orient, sticky, practice);
+	printState(movesText, buff);
+	printRecord(size, mode, orient, sticky, practice);
 	if (practice)
 		(void) strcpy(messageDsp, "");
 	else
 		(void) strncpy(messageDsp, "Randomize to start", MESSAGE_LENGTH);
-	PrintState(message, messageDsp);
+	printState(message, messageDsp);
 }
 
 static void
-fileCB(Widget w, void *value, void *clientData)
+fileMenuListener(Widget w, void *value, void *clientData)
 {
 	int val = (int) value + ACTION_GET;
 
@@ -1509,7 +1503,7 @@ createHelp(Widget w, char *text, char *title)
 	return messageBox;
 }
 static void
-helpCB(Widget w, XtPointer value, XtPointer clientData)
+helpMenuListener(Widget w, XtPointer value, XtPointer clientData)
 {
 	int val = (int) value;
 
@@ -1533,7 +1527,7 @@ helpCB(Widget w, XtPointer value, XtPointer clientData)
 		{
 			char *buf;
 
-			intCat(&buf, "helpCB: %d", val);
+			intCat(&buf, "helpMenuListener: %d", val);
 			XtWarning(buf);
 			free(buf);
 		}
@@ -1548,7 +1542,7 @@ main(int argc, char **argv)
 #ifdef HAVE_MOTIF
 	Widget menuBar, pullDownMenu, widget;
 	Widget menuBarPanel, mainPanel, controlPanel;
-	Widget movesRowCol, facetsRowCol, labelRowCol, radioRowCol;
+	Widget movesRowCol, facetRowCol, labelRowCol, radioRowCol;
 	Widget switchRowCol, messageRowCol;
 	XmString fileString, playString;
 	XmString getString, writeString, quitString;
@@ -1564,7 +1558,7 @@ main(int argc, char **argv)
 	topLevel = XtInitialize(argv[0], "Oct",
 		options, XtNumber(options), &argc, argv);
 	if (argc != 1)
-		Usage(argv[0]);
+		usage(argv[0]);
 
 #ifdef HAVE_MOTIF
 	menuBarPanel = XtVaCreateManagedWidget("menuBarPanel",
@@ -1584,7 +1578,7 @@ main(int argc, char **argv)
 	writeString = XmStringCreateSimple((char *) "Write");
 	quitString = XmStringCreateSimple((char *) "Quit");
 	(void) XmVaCreateSimplePulldownMenu(menuBar, (char *) "file_menu",
-		0, fileCB,
+		0, fileMenuListener,
 		XmVaPUSHBUTTON, getString, 'G', NULL, NULL,
 		XmVaPUSHBUTTON, writeString, 'W', NULL, NULL,
 		XmVaSEPARATOR,
@@ -1645,23 +1639,23 @@ main(int argc, char **argv)
 	widget = XtVaCreateManagedWidget("Description",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'D', NULL);
-		XtAddCallback(widget, XmNactivateCallback, helpCB, (char *) 0);
+		XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 0);
 	widget = XtVaCreateManagedWidget("Features",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'F', NULL);
-	XtAddCallback(widget, XmNactivateCallback, helpCB, (char *) 1);
+	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 1);
 	widget = XtVaCreateManagedWidget("Options",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'O', NULL);
-	XtAddCallback(widget, XmNactivateCallback, helpCB, (char *) 2);
+	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 2);
 	widget = XtVaCreateManagedWidget("References",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'R', NULL);
-	XtAddCallback(widget, XmNactivateCallback, helpCB, (char *) 3);
+	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 3);
 	widget = XtVaCreateManagedWidget("About",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'A', NULL);
-	XtAddCallback(widget, XmNactivateCallback, helpCB, (char *) 4);
+	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 4);
 	XtManageChild(menuBar);
 	descriptionDialog = createHelp(menuBar, (char *) descriptionHelp,
 		(char *) "Description");
@@ -1678,11 +1672,11 @@ main(int argc, char **argv)
 	practiceDialog = createQuery(topLevel,
 		(char *) "Are you sure you want to toggle the practice mode?",
 		(char *) "Practice Query",
-		(XtCallbackProc) CallbackPuzzlePractice);
+		(XtCallbackProc) puzzlePracticeListener);
 	randomizeDialog = createQuery(topLevel,
 		(char *) "Are you sure you want to randomize?",
 		(char *) "Randomize Query",
-		(XtCallbackProc) CallbackPuzzleRandomize);
+		(XtCallbackProc) puzzleRandomizeListener);
 	mainPanel = XtCreateManagedWidget("mainPanel",
 		xmPanedWindowWidgetClass, menuBarPanel,
 		NULL, 0);
@@ -1738,28 +1732,28 @@ main(int argc, char **argv)
 	(void) XtVaCreateManagedWidget("movesText",
 		xmLabelGadgetClass, movesRowCol,
 		XtVaTypedArg, XmNlabelString, XmRString, "Moves", 6, NULL);
-	moves = XtVaCreateManagedWidget("0",
+	movesText = XtVaCreateManagedWidget("0",
 		xmLabelWidgetClass, movesRowCol, NULL);
 	(void) XtVaCreateManagedWidget("recordText",
 		xmLabelGadgetClass, movesRowCol,
 		XtVaTypedArg, XmNlabelString, XmRString, "Record", 7, NULL);
-	record = XtVaCreateManagedWidget("0",
+	recordText = XtVaCreateManagedWidget("0",
 		xmLabelWidgetClass, movesRowCol, NULL);
-	facetsRowCol = XtVaCreateManagedWidget("facetsRowCol",
+	facetRowCol = XtVaCreateManagedWidget("facetRowCol",
 		xmRowColumnWidgetClass, controlPanel,
 		XmNnumColumns, 1,
 		XmNorientation, XmHORIZONTAL,
 		XmNpacking, XmPACK_COLUMN, NULL);
-	facets = XtVaCreateManagedWidget("facets",
-		xmScaleWidgetClass, facetsRowCol,
+	facetSlider = XtVaCreateManagedWidget("facetSlider",
+		xmScaleWidgetClass, facetRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Size", 5,
 		XmNminimum, MIN_FACETS,
 		XmNmaximum, MAX_FACETS,
 		XmNvalue, MIN_FACETS,
 		XmNshowValue, True,
 		XmNorientation, XmHORIZONTAL, NULL);
-	XtAddCallback(facets, XmNvalueChangedCallback,
-		(XtCallbackProc) PieceSlider, (XtPointer) NULL);
+	XtAddCallback(facetSlider, XmNvalueChangedCallback,
+		(XtCallbackProc) pieceChangeListener, (XtPointer) NULL);
 	labelRowCol = XtVaCreateManagedWidget("labelRowCol",
 		xmRowColumnWidgetClass, controlPanel, NULL);
 	(void) XtVaCreateManagedWidget("PeriodText",
@@ -1776,7 +1770,7 @@ main(int argc, char **argv)
 			xmToggleButtonGadgetClass, radioRowCol,
 			XmNradioBehavior, True, NULL);
 		XtAddCallback(modes[i], XmNvalueChangedCallback,
-			(XtCallbackProc) ModeToggle, (XtPointer) i);
+			(XtCallbackProc) modeToggle, (XtPointer) i);
 	}
 	switchRowCol = XtVaCreateManagedWidget("switchRowCol",
 		xmRowColumnWidgetClass, controlPanel,
@@ -1787,17 +1781,17 @@ main(int argc, char **argv)
 		xmToggleButtonWidgetClass, switchRowCol,
 		XmNset, DEFAULT_ORIENT, NULL);
 	XtAddCallback(orientizeSwitch, XmNvalueChangedCallback,
-		(XtCallbackProc) OrientToggle, (XtPointer) NULL);
+		(XtCallbackProc) orientToggle, (XtPointer) NULL);
 	stickySwitch = XtVaCreateManagedWidget("Sticky",
 		xmToggleButtonWidgetClass, switchRowCol,
 		XmNset, DEFAULTSTICKY, NULL);
 	XtAddCallback(stickySwitch, XmNvalueChangedCallback,
-		(XtCallbackProc) StickyToggle, (XtPointer) NULL);
+		(XtCallbackProc) stickyToggle, (XtPointer) NULL);
 	practiceSwitch = XtVaCreateManagedWidget("Practice",
 		xmToggleButtonWidgetClass, switchRowCol,
 		XmNset, DEFAULT_PRACTICE, NULL);
 	XtAddCallback(practiceSwitch, XmNvalueChangedCallback,
-		(XtCallbackProc) PracticeToggle, (XtPointer) NULL);
+		(XtCallbackProc) practiceToggle, (XtPointer) NULL);
 	messageRowCol = XtVaCreateManagedWidget("messageRowCol",
 		xmRowColumnWidgetClass, controlPanel, NULL);
 	message = XtVaCreateManagedWidget("Play Oct! (use mouse and keypad)",
@@ -1841,14 +1835,14 @@ main(int argc, char **argv)
 #endif
 		XtNiconPixmap, pixmap, NULL);
 	XtAddCallback(puzzle, XtNselectCallback,
-		(XtCallbackProc) CallbackPuzzle, (XtPointer) NULL);
-	Initialize(puzzle);
+		(XtCallbackProc) puzzleListener, (XtPointer) NULL);
+	initialize(puzzle);
 	XtRealizeWidget(topLevel);
 	XGrabButton(XtDisplay(puzzle), (unsigned int) AnyButton, AnyModifier,
 		XtWindow(puzzle), TRUE, (unsigned int) (ButtonPressMask |
 		ButtonMotionMask | ButtonReleaseMask),
 		GrabModeAsync, GrabModeAsync, XtWindow(puzzle),
-		XCreateFontCursor(XtDisplay(puzzle), XC_crosshair));
+		XCreateFontCursor(XtDisplay(puzzle), XC_hand2));
 	XtMainLoop();
 
 #ifdef VMS
