@@ -1,27 +1,22 @@
-/*-
-# X-BASED PANEX(tm)
-#
-#  PanexP.h
-#
-###
-#
-#  Copyright (c) 1996 - 2007	David A. Bagley, bagleyd@tux.org
-#
-#                   All Rights Reserved
-#
-#  Permission to use, copy, modify, and distribute this software and
-#  its documentation for any purpose and without fee is hereby granted,
-#  provided that the above copyright notice appear in all copies and
-#  that both that copyright notice and this permission notice appear in
-#  supporting documentation, and that the name of the author not be
-#  used in advertising or publicity pertaining to distribution of the
-#  software without specific, written prior permission.
-#
-#  This program is distributed in the hope that it will be "playable",
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-#
-*/
+/*
+ * @(#)PanexP.h
+ *
+ * Copyright 1996 - 2008  David A. Bagley, bagleyd@tux.org
+ *
+ * All rights reserved.
+ *
+ * Permission to use, copy, modify, and distribute this software and
+ * its documentation for any purpose and without fee is hereby granted,
+ * provided that the above copyright notice appear in all copies and
+ * that both that copyright notice and this permission notice appear in
+ * supporting documentation, and that the name of the author not be
+ * used in advertising or publicity pertaining to distribution of the
+ * software without specific, written prior permission.
+ *
+ * This program is distributed in the hope that it will be "useful",
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ */
 
 /* Private header file for Panex */
 
@@ -33,29 +28,29 @@
 #include "Panex.h"
 
 #ifdef WINVER
-extern void DestroyPuzzle(HBRUSH brush);
-extern void ResizePuzzle(PanexWidget w);
-extern void SizePuzzle(PanexWidget w);
-extern void InitializePuzzle(PanexWidget w, HBRUSH brush);
-extern void ExposePuzzle(PanexWidget w);
-extern void HidePuzzle(PanexWidget w);
-extern void SelectPuzzle(PanexWidget w, const int x);
-extern void MotionPuzzle(PanexWidget w, const int x);
-extern void ReleasePuzzle(PanexWidget w, const int x);
-extern void GetPuzzle(PanexWidget w);
-extern void WritePuzzle(PanexWidget w);
-extern void UndoPuzzle(PanexWidget w);
-extern void RedoPuzzle(PanexWidget w);
-extern void ClearPuzzle(PanexWidget w);
-extern void SolvePuzzle(PanexWidget w);
-extern void ModePuzzle(PanexWidget w);
-extern void DecrementPuzzle(PanexWidget w);
-extern void IncrementPuzzle(PanexWidget w);
-extern void SpeedPuzzle(PanexWidget w);
-extern void SlowPuzzle(PanexWidget w);
-extern void SoundPuzzle(PanexWidget w);
-extern void EnterPuzzle(PanexWidget w);
-extern void LeavePuzzle(PanexWidget w);
+extern void destroyPuzzle(HBRUSH brush);
+extern void resizePuzzle(PanexWidget w);
+extern void sizePuzzle(PanexWidget w);
+extern void initializePuzzle(PanexWidget w, HBRUSH brush);
+extern void exposePuzzle(PanexWidget w);
+extern void hidePuzzle(PanexWidget w);
+extern void selectPuzzle(PanexWidget w, const int x);
+extern void motionPuzzle(PanexWidget w, const int x);
+extern void releasePuzzle(PanexWidget w, const int x);
+extern void getPuzzle(PanexWidget w);
+extern void writePuzzle(PanexWidget w);
+extern void undoPuzzle(PanexWidget w);
+extern void redoPuzzle(PanexWidget w);
+extern void clearPuzzle(PanexWidget w);
+extern void solvePuzzle(PanexWidget w);
+extern void modePuzzle(PanexWidget w);
+extern void decrementPuzzle(PanexWidget w);
+extern void incrementPuzzle(PanexWidget w);
+extern void speedUpPuzzle(PanexWidget w);
+extern void slowDownPuzzle(PanexWidget w);
+extern void toggleSoundPuzzle(PanexWidget w);
+extern void enterPuzzle(PanexWidget w);
+extern void leavePuzzle(PanexWidget w);
 
 #else
 
@@ -157,14 +152,14 @@ typedef struct _PanexRec {
 
 extern PanexLoc *startLoc[MAX_STACKS - 1];
 extern void setPuzzle(PanexWidget w, int reason);
-extern int MovePuzzle(PanexWidget w, int fromStack, int fromPosition,
+extern int movePuzzle(PanexWidget w, int fromStack, int fromPosition,
 	int toStack, int fast);
 
-extern void SolveTilesFromStart(PanexWidget w);
-extern void DrawAllTiles(PanexWidget w);
-extern int TopOfStack(PanexWidget w, int stack, int start);
-extern Boolean CheckMiddle(PanexWidget w);
-extern Boolean CheckSolved(PanexWidget w);
+extern void solveTilesFromStart(PanexWidget w);
+extern void drawAllTiles(PanexWidget w);
+extern int topOfStack(PanexWidget w, int stack, int start);
+extern Boolean checkMiddle(PanexWidget w);
+extern Boolean checkSolved(PanexWidget w);
 extern void InitMoves(void);
 extern void PutMove(int from, int to);
 extern void GetMove(int *from, int *to);
