@@ -1,38 +1,33 @@
-/*-
-# X-BASED PANEX(tm)
-#
-#  PanexS.c
-#
-###
-#
-#  Taken from Some Results on the Panex Puzzle by Mark Manasse &
-#  Danny Sleator of AT&T Bell Laboratories, and Victor K. Wei
-#  of Bell Communications Research.
-#  Thanks to Nick Baxter <nickb@baxterweb.com> for debugging level n > 4
-#  and vTrick.
-#  Though most code by Rene Jansen <rene.j.jansen@bigfoot.com> is now
-#  removed much inspiration was gained by his efforts implementing
-#  an algorithm from Quantum January/February 1996 by Vladimir
-#  Dubrovsky.
-#  Break ability taken from the X puzzle by Don Bennett, HP Labs
-#
-#  Copyright (c) 1996 - 2007	David A. Bagley, bagleyd@tux.org
-#
-#                   All Rights Reserved
-#
-#  Permission to use, copy, modify, and distribute this software and
-#  its documentation for any purpose and without fee is hereby granted,
-#  provided that the above copyright notice appear in all copies and
-#  that both that copyright notice and this permission notice appear in
-#  supporting documentation, and that the name of the author not be
-#  used in advertising or publicity pertaining to distribution of the
-#  software without specific, written prior permission.
-#
-#  This program is distributed in the hope that it will be "playable",
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-#
-*/
+/*
+ * @(#)PanexS.c
+ *
+ * Taken from Some Results on the Panex Puzzle by Mark Manasse &
+ * Danny Sleator of AT&T Bell Laboratories, and Victor K. Wei
+ * of Bell Communications Research.
+ * Thanks to Nick Baxter <nickb@baxterweb.com> for debugging level n > 4
+ * and vTrick.
+ * Though most code by Rene Jansen <rene.j.jansen@bigfoot.com> is now
+ * removed much inspiration was gained by his efforts implementing
+ * an algorithm from Quantum January/February 1996 by Vladimir
+ * Dubrovsky.
+ * Break ability taken from the X puzzle by Don Bennett, HP Labs
+ *
+ * Copyright 1996 - 2008  David A. Bagley, bagleyd@tux.org
+ *
+ * All rights reserved.
+ *
+ * Permission to use, copy, modify, and distribute this software and
+ * its documentation for any purpose and without fee is hereby granted,
+ * provided that the above copyright notice appear in all copies and
+ * that both that copyright notice and this permission notice appear in
+ * supporting documentation, and that the name of the author not be
+ * used in advertising or publicity pertaining to distribution of the
+ * software without specific, written prior permission.
+ *
+ * This program is distributed in the hope that it will be "useful",
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ */
 
 /* Solver file for Panex */
 
@@ -43,28 +38,28 @@
 #endif
 #include "PanexP.h"
 
-static Boolean SolvingFlag = False;
+static Boolean solvingFlag = False;
 #ifdef JMP
-static Boolean AbortSolvingFlag = False;
+static Boolean abortSolvingFlag = False;
 static jmp_buf solve_env;
 
 static void
-AbortSolving(void)
+abortSolving(void)
 {
-	if (SolvingFlag)
-		AbortSolvingFlag = True;
+	if (solvingFlag)
+		abortSolvingFlag = True;
 }
 
 #ifdef WINVER
 static Boolean
-ProcessMessage(UINT msg)
+processMessage(UINT msg)
 {
 	switch (msg) {
 	case WM_KEYDOWN:
 	case WM_CLOSE:
 	case WM_LBUTTONDOWN:
 	case WM_RBUTTONDOWN:
-		AbortSolving();
+		abortSolving();
 		return True;
 	default:
 		return False;
@@ -72,35 +67,35 @@ ProcessMessage(UINT msg)
 }
 #else
 static void
-ProcessButton(void /*XButtonEvent *event*/)
+processButton(void /*XButtonEvent *event*/)
 {
-	AbortSolving();
+	abortSolving();
 }
 
 static void
-ProcessVisibility(XVisibilityEvent *event)
+processVisibility(XVisibilityEvent *event)
 {
 	if (event->state != VisibilityUnobscured)
-		AbortSolving();
+		abortSolving();
 }
 
 static void
-GetNextEvent(PanexWidget w, XEvent *event)
+getNextEvent(PanexWidget w, XEvent *event)
 {
 	if (!XCheckMaskEvent(XtDisplay(w), VisibilityChangeMask, event))
 		(void) XNextEvent(XtDisplay(w), event);
 }
 
 static void
-ProcessEvent(XEvent *event)
+processEvent(XEvent *event)
 {
 	switch(event->type) {
 	case KeyPress:
 	case ButtonPress:
-		ProcessButton(/*&event->xbutton*/);
+		processButton(/*&event->xbutton*/);
 		break;
 	case VisibilityNotify:
-		ProcessVisibility(&event->xvisibility);
+		processVisibility(&event->xvisibility);
 		break;
 	default:
 		break;
@@ -108,13 +103,13 @@ ProcessEvent(XEvent *event)
 }
 
 static void
-ProcessEvents(PanexWidget w)
+processEvents(PanexWidget w)
 {
 	XEvent event;
 
 	while (XPending(XtDisplay(w))) {
-		GetNextEvent(w, &event);
-		ProcessEvent(&event);
+		getNextEvent(w, &event);
+		processEvent(&event);
 	}
 }
 #endif
@@ -135,7 +130,7 @@ static int counter; /* debugging */
 #endif
 
 static Boolean
-MoveATile(PanexWidget w, int fromStack, int toStack)
+moveATile(PanexWidget w, int fromStack, int toStack)
 {
 	int fromPosition;
 
@@ -144,19 +139,19 @@ MoveATile(PanexWidget w, int fromStack, int toStack)
 	MSG msg;
 
 	if (PeekMessage(&msg, NULL, 0, 0, 0)) {
-		if (!ProcessMessage(msg.message)) {
+		if (!processMessage(msg.message)) {
 			if (GetMessage(&msg, NULL, 0, 0))
 				DispatchMessage(&msg);
 		}
 	}
 #else
-	ProcessEvents(w);
+	processEvents(w);
 #endif
-	if (SolvingFlag && AbortSolvingFlag)
+	if (solvingFlag && abortSolvingFlag)
 		longjmp(solve_env, 1);
 #endif
-	if ((fromPosition = TopOfStack(w, fromStack, 0)) < 0 ||
-			MovePuzzle(w, fromStack, fromPosition, toStack, NORMAL) < 0) {
+	if ((fromPosition = topOfStack(w, fromStack, 0)) < 0 ||
+			movePuzzle(w, fromStack, fromPosition, toStack, NORMAL) < 0) {
 		(void) printf("move from %d to %d can not be made.",
 			fromStack, toStack);
 		return False;
@@ -165,7 +160,7 @@ MoveATile(PanexWidget w, int fromStack, int toStack)
 }
 
 static void
-SolveHanoiMode(PanexWidget w)
+solveHanoiMode(PanexWidget w)
 {
 	int triangleTurn;
 	int triangleDirection;
@@ -173,7 +168,7 @@ SolveHanoiMode(PanexWidget w)
 	int fromStack, toStack, temp1Stack, temp2Stack;
 	int temp1Loc, temp2Loc;
 
-	if (SolvingFlag)
+	if (solvingFlag)
 		return;
 #ifdef JMP
 	if (!setjmp(solve_env))
@@ -182,8 +177,8 @@ SolveHanoiMode(PanexWidget w)
 		triangleTurn = TRUE;
 		triangleDirection = (w->panex.tiles & 1) ? 2 : 1;
 		triangleStack = 0;
-		while (!CheckSolved(w)) {
-			SolvingFlag = True;
+		while (!checkSolved(w)) {
+			solvingFlag = True;
 
 			if (triangleTurn) {
 				fromStack = triangleStack;
@@ -194,8 +189,8 @@ SolveHanoiMode(PanexWidget w)
 			} else {
 				temp1Stack = (triangleStack + 1) % MAX_STACKS;
 				temp2Stack = (triangleStack + 2) % MAX_STACKS;
-				temp1Loc = TopOfStack(w, temp1Stack, 0);
-				temp2Loc = TopOfStack(w, temp2Stack, 0);
+				temp1Loc = topOfStack(w, temp1Stack, 0);
+				temp2Loc = topOfStack(w, temp2Stack, 0);
 				if (temp1Loc < 0 && temp2Loc < 0)
 					return;
 				else if (temp1Loc < 0) {
@@ -214,23 +209,24 @@ SolveHanoiMode(PanexWidget w)
 				}
 				triangleTurn = TRUE;
 			}
-			if (!MoveATile(w, fromStack, toStack))
+			if (!moveATile(w, fromStack, toStack))
 				return;
 		}
 	}
 #ifdef JMP
 	else {
-		DrawAllTiles(w);
+		drawAllTiles(w);
 	}
-	AbortSolvingFlag = False;
+	abortSolvingFlag = False;
 #endif
-	SolvingFlag = False;
+	solvingFlag = False;
 	w->panex.cheat = True; /* Assume the worst. */
 	setPuzzle(w, ACTION_COMPUTED);
 }
 
 #ifdef DEBUG
-static void PrintStacks(PanexWidget w)
+static void
+printStacks(PanexWidget w)
 {
 	int position, stack;
 
@@ -257,7 +253,7 @@ static void PrintStacks(PanexWidget w)
 /*
 	Recursive algorithm starts at level 5, shown by computer checking
 	to be the shortest algorithm, i.e. the upper bound U(n), to at
-	least to level 8.
+	least to level 9.
 	Lower bounds discussed by Manasse, Sleator, & Wei is given as L(n).
 	T(n) = move a tower of hight n
 	X(n) = transfer or swap towers
@@ -275,7 +271,7 @@ static void PrintStacks(PanexWidget w)
 	6	143	881	881	796
 	7	345	2189	2189	1944
 	8	836	5359	5359	4716
-	9	2018	?	13023	11408
+	9	2018	13023	13023	11408
 	10	4875	?	31537	27564
 */
 
@@ -287,22 +283,24 @@ static Boolean INVERSE = True;
 #endif
 
 /* Randomize to make it interesting */
-static void centerSwap(PanexWidget w)
+static void
+centerSwap(PanexWidget w)
 {
 	if (NRAND(2) == 1) {
-		(void) MoveATile(w, 1, 0);
-		(void) MoveATile(w, 1, 2);
-		(void) MoveATile(w, 0, 1);
-		(void) MoveATile(w, 2, 1);
+		(void) moveATile(w, 1, 0);
+		(void) moveATile(w, 1, 2);
+		(void) moveATile(w, 0, 1);
+		(void) moveATile(w, 2, 1);
 	} else {
-		(void) MoveATile(w, 1, 2);
-		(void) MoveATile(w, 1, 0);
-		(void) MoveATile(w, 2, 1);
-		(void) MoveATile(w, 0, 1);
+		(void) moveATile(w, 1, 2);
+		(void) moveATile(w, 1, 0);
+		(void) moveATile(w, 2, 1);
+		(void) moveATile(w, 0, 1);
 	}
 }
 
-static void sideSwap(PanexWidget w, Boolean side)
+static void
+sideSwap(PanexWidget w, Boolean side)
 {
 	int first, last;
 
@@ -314,15 +312,15 @@ static void sideSwap(PanexWidget w, Boolean side)
 		last = 2;
 	}
 	if (NRAND(2) == 1) {
-		(void) MoveATile(w, first, last);
-		(void) MoveATile(w, first, 1);
-		(void) MoveATile(w, last, first);
-		(void) MoveATile(w, 1, first);
+		(void) moveATile(w, first, last);
+		(void) moveATile(w, first, 1);
+		(void) moveATile(w, last, first);
+		(void) moveATile(w, 1, first);
 	} else {
-		(void) MoveATile(w, first, 1);
-		(void) MoveATile(w, first, last);
-		(void) MoveATile(w, 1, first);
-		(void) MoveATile(w, last, first);
+		(void) moveATile(w, first, 1);
+		(void) moveATile(w, first, last);
+		(void) moveATile(w, 1, first);
+		(void) moveATile(w, last, first);
 	}
 }
 
@@ -359,7 +357,8 @@ static void S(PanexWidget w, int n, Boolean side, Boolean inv);
 static void SBar(PanexWidget w, int n,
 	Boolean side, Boolean inv, Boolean vTrick);
 
-static void T(PanexWidget w, int n, Boolean side, Boolean inv)
+static void
+T(PanexWidget w, int n, Boolean side, Boolean inv)
 {
 	int first, last;
 
@@ -372,17 +371,17 @@ static void T(PanexWidget w, int n, Boolean side, Boolean inv)
 		}
 	if (inv) {
 		if (n == 1) {
-			(void) MoveATile(w, 1, first);
+			(void) moveATile(w, 1, first);
 		} else if (n == 2) {
-			(void) MoveATile(w, 1, last);
+			(void) moveATile(w, 1, last);
 			TBar(w, n, side, inv, False, False);
 		} else if (n == 3) {
-			(void) MoveATile(w, 1, first);
-			(void) MoveATile(w, 1, first);
-			(void) MoveATile(w, 1, last);
-			(void) MoveATile(w, first, 1);
-			(void) MoveATile(w, first, 1);
-			(void) MoveATile(w, last, first);
+			(void) moveATile(w, 1, first);
+			(void) moveATile(w, 1, first);
+			(void) moveATile(w, 1, last);
+			(void) moveATile(w, first, 1);
+			(void) moveATile(w, first, 1);
+			(void) moveATile(w, last, first);
 			T(w, 2, side, inv);
 		} else if (n >= 4) {
 			T(w, n - 2, side, inv); /* Paper says invert but... */
@@ -397,18 +396,18 @@ static void T(PanexWidget w, int n, Boolean side, Boolean inv)
 		}
 	} else {
 		if (n == 1) {
-			(void) MoveATile(w, first, 1);
+			(void) moveATile(w, first, 1);
 		} else if (n == 2) {
 			TBar(w, n, side, inv, False, False);
-			(void) MoveATile(w, last, 1);
+			(void) moveATile(w, last, 1);
 		} else if (n == 3) {
 			T(w, 2, side, inv);
-			(void) MoveATile(w, first, last);
-			(void) MoveATile(w, 1, first);
-			(void) MoveATile(w, 1, first);
-			(void) MoveATile(w, last, 1);
-			(void) MoveATile(w, first, 1);
-			(void) MoveATile(w, first, 1);
+			(void) moveATile(w, first, last);
+			(void) moveATile(w, 1, first);
+			(void) moveATile(w, 1, first);
+			(void) moveATile(w, last, 1);
+			(void) moveATile(w, first, 1);
+			(void) moveATile(w, first, 1);
 		} else if (n >= 4) {
 			if (((n & 1) == 0) && (NRAND(2) == 1)) {
 				T(w, n - 1, side, inv);
@@ -423,7 +422,8 @@ static void T(PanexWidget w, int n, Boolean side, Boolean inv)
 	}
 }
 
-static void TBar(PanexWidget w, int n,
+static void
+TBar(PanexWidget w, int n,
 	Boolean side, Boolean inv, Boolean vTrick, Boolean qTrick)
 {
 	int first, last;
@@ -437,19 +437,19 @@ static void TBar(PanexWidget w, int n,
 	}
 	if (inv) {
 		if (n == 1) {
-			(void) MoveATile(w, last, first);
+			(void) moveATile(w, last, first);
 		} else if (n == 2) {
-			(void) MoveATile(w, 1, first);
-			(void) MoveATile(w, last, first);
+			(void) moveATile(w, 1, first);
+			(void) moveATile(w, last, first);
 		} else if (n == 3) {
 			if (!vTrick) {
 				if (!qTrick)
-					(void) MoveATile(w, last, first);
-				(void) MoveATile(w, 1, first);
-				(void) MoveATile(w, 1, last);
-				(void) MoveATile(w, first, 1);
-				(void) MoveATile(w, first, 1);
-				(void) MoveATile(w, last, first);
+					(void) moveATile(w, last, first);
+				(void) moveATile(w, 1, first);
+				(void) moveATile(w, 1, last);
+				(void) moveATile(w, first, 1);
+				(void) moveATile(w, first, 1);
+				(void) moveATile(w, last, first);
 				T(w, 2, side, inv);
 			}
 		} else if (n >= 4) {
@@ -465,23 +465,23 @@ static void TBar(PanexWidget w, int n,
 		}
 	} else {
 		if (n == 1) {
-			(void) MoveATile(w, first, last);
+			(void) moveATile(w, first, last);
 		} else if (n == 2) {
-			(void) MoveATile(w, first, last);
-			(void) MoveATile(w, first, 1);
+			(void) moveATile(w, first, last);
+			(void) moveATile(w, first, 1);
 		} else if (n == 3) {
 			if (!vTrick) {
 				T(w, 2, side, inv);
-				(void) MoveATile(w, first, last);
-				(void) MoveATile(w, 1, first);
-				(void) MoveATile(w, 1, first);
-				(void) MoveATile(w, last, 1);
-				(void) MoveATile(w, first, 1);
+				(void) moveATile(w, first, last);
+				(void) moveATile(w, 1, first);
+				(void) moveATile(w, 1, first);
+				(void) moveATile(w, last, 1);
+				(void) moveATile(w, first, 1);
 				if (!qTrick)
-					(void) MoveATile(w, first, last);
+					(void) moveATile(w, first, last);
 			}
 		} else if (n >= 4) {
-			if (((n & 1) == 0) && (NRAND(2) == 1) && ! vTrick) {
+			if (((n & 1) == 0) && (NRAND(2) == 1) && !vTrick) {
 				T(w, n - 1, side, inv);
 				S(w, n - 1, side, inv);
 			} else {
@@ -494,7 +494,8 @@ static void TBar(PanexWidget w, int n,
 	}
 }
 
-static void S(PanexWidget w, int n, Boolean side, Boolean inv)
+static void
+S(PanexWidget w, int n, Boolean side, Boolean inv)
 {
 	int first, last;
 
@@ -508,13 +509,13 @@ static void S(PanexWidget w, int n, Boolean side, Boolean inv)
 	if (inv) {
 		if (n == 2) {
 			SBar(w, n, side, inv, False);
-			(void) MoveATile(w, last, 1);
+			(void) moveATile(w, last, 1);
 		} else if (n == 3) {
 			sideSwap(w, side);
-			(void) MoveATile(w, 1, last);
-			(void) MoveATile(w, first, 1);
-			(void) MoveATile(w, first, 1);
-			(void) MoveATile(w, last, first);
+			(void) moveATile(w, 1, last);
+			(void) moveATile(w, first, 1);
+			(void) moveATile(w, first, 1);
+			(void) moveATile(w, last, first);
 		} else if (n >= 4) {
 			if (((n & 1) == 1) && (NRAND(2) == 1)) {
 				T(w, n - 2, side, !inv);
@@ -528,13 +529,13 @@ static void S(PanexWidget w, int n, Boolean side, Boolean inv)
 		}
 	} else {
 		if (n == 2) {
-			(void) MoveATile(w, 1, last);
+			(void) moveATile(w, 1, last);
 			SBar(w, n, side, inv, False);
 		} else if (n == 3) {
-			(void) MoveATile(w, first, last);
-			(void) MoveATile(w, 1, first);
-			(void) MoveATile(w, 1, first);
-			(void) MoveATile(w, last, 1);
+			(void) moveATile(w, first, last);
+			(void) moveATile(w, 1, first);
+			(void) moveATile(w, 1, first);
+			(void) moveATile(w, last, 1);
 			sideSwap(w, side);
 		} else if (n >= 4) {
 			S(w, n - 1, side, inv);
@@ -550,7 +551,8 @@ static void S(PanexWidget w, int n, Boolean side, Boolean inv)
 	}
 }
 
-static void SBar(PanexWidget w, int n,
+static void
+SBar(PanexWidget w, int n,
 	Boolean side, Boolean inv, Boolean vTrick)
 {
 	int first, last;
@@ -564,17 +566,17 @@ static void SBar(PanexWidget w, int n,
 	}
 	if (inv) {
 		if (n == 2) {
-			(void) MoveATile(w, first, last);
-			(void) MoveATile(w, 1, first);
+			(void) moveATile(w, first, last);
+			(void) moveATile(w, 1, first);
 		} else if (n == 3) {
-			(void) MoveATile(w, first, 1);
-			(void) MoveATile(w, first, last);
-			(void) MoveATile(w, 1, first);
-			(void) MoveATile(w, 1, first);
-			(void) MoveATile(w, last, 1);
-			(void) MoveATile(w, first, 1);
-			(void) MoveATile(w, first, last);
-			(void) MoveATile(w, 1, first);
+			(void) moveATile(w, first, 1);
+			(void) moveATile(w, first, last);
+			(void) moveATile(w, 1, first);
+			(void) moveATile(w, 1, first);
+			(void) moveATile(w, last, 1);
+			(void) moveATile(w, first, 1);
+			(void) moveATile(w, first, last);
+			(void) moveATile(w, 1, first);
 		} else if (n >= 4) {
 			if (((n & 1) == 1) && (NRAND(2) == 1) && !vTrick) {
 				T(w, n - 2, side, !inv);
@@ -588,17 +590,17 @@ static void SBar(PanexWidget w, int n,
 		}
 	} else {
 		if (n == 2) {
-			(void) MoveATile(w, first, 1);
-			(void) MoveATile(w, last, first);
+			(void) moveATile(w, first, 1);
+			(void) moveATile(w, last, first);
 		} else if (n == 3) {
-			(void) MoveATile(w, first, 1);
-			(void) MoveATile(w, last, first);
-			(void) MoveATile(w, 1, first);
-			(void) MoveATile(w, 1, last);
-			(void) MoveATile(w, first, 1);
-			(void) MoveATile(w, first, 1);
-			(void) MoveATile(w, last, first);
-			(void) MoveATile(w, 1, first);
+			(void) moveATile(w, first, 1);
+			(void) moveATile(w, last, first);
+			(void) moveATile(w, 1, first);
+			(void) moveATile(w, 1, last);
+			(void) moveATile(w, first, 1);
+			(void) moveATile(w, first, 1);
+			(void) moveATile(w, last, first);
+			(void) moveATile(w, 1, first);
 		} else if (n >= 4) {
 			SBar(w, n - 1, side, inv, False);
 			centerSwap(w);
@@ -613,7 +615,8 @@ static void SBar(PanexWidget w, int n,
 	}
 }
 
-static void W(PanexWidget w, Boolean side, Boolean inv) {
+static void
+W(PanexWidget w, Boolean side, Boolean inv) {
 	int first, last;
 
 	if (side) {
@@ -624,37 +627,38 @@ static void W(PanexWidget w, Boolean side, Boolean inv) {
 		last = 2;
 	}
 	if (inv) {
-		(void) MoveATile(w, first, last);
-		(void) MoveATile(w, first, last);
-		(void) MoveATile(w, 1, first);
-		(void) MoveATile(w, last, first);
-		(void) MoveATile(w, last, 1);
-		(void) MoveATile(w, first, last);
-		(void) MoveATile(w, first, last);
-		(void) MoveATile(w, first, last);
-		(void) MoveATile(w, 1, first);
-		(void) MoveATile(w, 1, first);
-		(void) MoveATile(w, last, 1);
-		(void) MoveATile(w, first, 1);
-		(void) MoveATile(w, first, last);
+		(void) moveATile(w, first, last);
+		(void) moveATile(w, first, last);
+		(void) moveATile(w, 1, first);
+		(void) moveATile(w, last, first);
+		(void) moveATile(w, last, 1);
+		(void) moveATile(w, first, last);
+		(void) moveATile(w, first, last);
+		(void) moveATile(w, first, last);
+		(void) moveATile(w, 1, first);
+		(void) moveATile(w, 1, first);
+		(void) moveATile(w, last, 1);
+		(void) moveATile(w, first, 1);
+		(void) moveATile(w, first, last);
 	} else {
-		(void) MoveATile(w, last, first);
-		(void) MoveATile(w, 1, first);
-		(void) MoveATile(w, 1, last);
-		(void) MoveATile(w, first, 1);
-		(void) MoveATile(w, first, 1);
-		(void) MoveATile(w, last, first);
-		(void) MoveATile(w, last, first);
-		(void) MoveATile(w, last, first);
-		(void) MoveATile(w, 1, last);
-		(void) MoveATile(w, first, last);
-		(void) MoveATile(w, first, 1);
-		(void) MoveATile(w, last, first);
-		(void) MoveATile(w, last, first);
+		(void) moveATile(w, last, first);
+		(void) moveATile(w, 1, first);
+		(void) moveATile(w, 1, last);
+		(void) moveATile(w, first, 1);
+		(void) moveATile(w, first, 1);
+		(void) moveATile(w, last, first);
+		(void) moveATile(w, last, first);
+		(void) moveATile(w, last, first);
+		(void) moveATile(w, 1, last);
+		(void) moveATile(w, first, last);
+		(void) moveATile(w, first, 1);
+		(void) moveATile(w, last, first);
+		(void) moveATile(w, last, first);
 	}
 }
 
-static void VTrick(PanexWidget w, Boolean side, Boolean inv)
+static void
+VTrick(PanexWidget w, Boolean side, Boolean inv)
 {
 	int first, last;
 
@@ -666,25 +670,26 @@ static void VTrick(PanexWidget w, Boolean side, Boolean inv)
 		last = 2;
 	}
 	if (inv) {
-		(void) MoveATile(w, first, last);
-		(void) MoveATile(w, 1, last);
-		(void) MoveATile(w, 1, first);
-		(void) MoveATile(w, last, 1);
-		(void) MoveATile(w, last, 1);
-		(void) MoveATile(w, first, last);
+		(void) moveATile(w, first, last);
+		(void) moveATile(w, 1, last);
+		(void) moveATile(w, 1, first);
+		(void) moveATile(w, last, 1);
+		(void) moveATile(w, last, 1);
+		(void) moveATile(w, first, last);
 		W(w, side, inv);
 	} else {
 		W(w, side, inv);
-		(void) MoveATile(w, last, first);
-		(void) MoveATile(w, 1, last);
-		(void) MoveATile(w, 1, last);
-		(void) MoveATile(w, first, 1);
-		(void) MoveATile(w, last, 1);
-		(void) MoveATile(w, last, first);
+		(void) moveATile(w, last, first);
+		(void) moveATile(w, 1, last);
+		(void) moveATile(w, 1, last);
+		(void) moveATile(w, first, 1);
+		(void) moveATile(w, last, 1);
+		(void) moveATile(w, last, first);
 	}
 }
 
-static void V(PanexWidget w, int n, Boolean side, Boolean inv)
+static void
+V(PanexWidget w, int n, Boolean side, Boolean inv)
 {
 	if (inv) {
 		SBar(w, n, !side, !inv, True);
@@ -697,7 +702,8 @@ static void V(PanexWidget w, int n, Boolean side, Boolean inv)
 	}
 }
 
-static void Y(PanexWidget w, Boolean side, Boolean inv)
+static void
+Y(PanexWidget w, Boolean side, Boolean inv)
 {
 	int first, last;
 
@@ -709,41 +715,42 @@ static void Y(PanexWidget w, Boolean side, Boolean inv)
 		last = 2;
 	}
 	if (inv) {
-		(void) MoveATile(w, first, last);
-		(void) MoveATile(w, 1, first);
-		(void) MoveATile(w, last, first);
-		(void) MoveATile(w, 1, last);
-		(void) MoveATile(w, first, 1);
-		(void) MoveATile(w, first, 1);
-		(void) MoveATile(w, last, first);
-		(void) MoveATile(w, last, first);
-		(void) MoveATile(w, last, first);
-		(void) MoveATile(w, 1, last);
-		(void) MoveATile(w, 1, last);
-		(void) MoveATile(w, first, 1);
-		(void) MoveATile(w, last, 1);
-		(void) MoveATile(w, last, first);
-		(void) MoveATile(w, 1, last);
+		(void) moveATile(w, first, last);
+		(void) moveATile(w, 1, first);
+		(void) moveATile(w, last, first);
+		(void) moveATile(w, 1, last);
+		(void) moveATile(w, first, 1);
+		(void) moveATile(w, first, 1);
+		(void) moveATile(w, last, first);
+		(void) moveATile(w, last, first);
+		(void) moveATile(w, last, first);
+		(void) moveATile(w, 1, last);
+		(void) moveATile(w, 1, last);
+		(void) moveATile(w, first, 1);
+		(void) moveATile(w, last, 1);
+		(void) moveATile(w, last, first);
+		(void) moveATile(w, 1, last);
 	} else {
-		(void) MoveATile(w, last, 1);
-		(void) MoveATile(w, first, last);
-		(void) MoveATile(w, 1, last);
-		(void) MoveATile(w, 1, first);
-		(void) MoveATile(w, last, 1);
-		(void) MoveATile(w, last, 1);
-		(void) MoveATile(w, first, last);
-		(void) MoveATile(w, first, last);
-		(void) MoveATile(w, first, last);
-		(void) MoveATile(w, 1, first);
-		(void) MoveATile(w, 1, first);
-		(void) MoveATile(w, last, 1);
-		(void) MoveATile(w, first, last);
-		(void) MoveATile(w, first, 1);
-		(void) MoveATile(w, last, first);
+		(void) moveATile(w, last, 1);
+		(void) moveATile(w, first, last);
+		(void) moveATile(w, 1, last);
+		(void) moveATile(w, 1, first);
+		(void) moveATile(w, last, 1);
+		(void) moveATile(w, last, 1);
+		(void) moveATile(w, first, last);
+		(void) moveATile(w, first, last);
+		(void) moveATile(w, first, last);
+		(void) moveATile(w, 1, first);
+		(void) moveATile(w, 1, first);
+		(void) moveATile(w, last, 1);
+		(void) moveATile(w, first, last);
+		(void) moveATile(w, first, 1);
+		(void) moveATile(w, last, first);
 	}
 }
 
-static void YBar(PanexWidget w, Boolean side, Boolean inv)
+static void
+YBar(PanexWidget w, Boolean side, Boolean inv)
 {
 	int first, last;
 
@@ -755,41 +762,42 @@ static void YBar(PanexWidget w, Boolean side, Boolean inv)
 		last = 2;
 	}
 	if (inv) {
-		(void) MoveATile(w, first, 1);
-		(void) MoveATile(w, last, first);
-		(void) MoveATile(w, 1, first);
-		(void) MoveATile(w, 1, last);
-		(void) MoveATile(w, first, 1);
-		(void) MoveATile(w, first, 1);
-		(void) MoveATile(w, last, first);
-		(void) MoveATile(w, last, first);
-		(void) MoveATile(w, last, first);
-		(void) MoveATile(w, 1, last);
-		(void) MoveATile(w, 1, last);
-		(void) MoveATile(w, first, 1);
-		(void) MoveATile(w, last, 1);
-		(void) MoveATile(w, last, first);
-		(void) MoveATile(w, 1, last);
+		(void) moveATile(w, first, 1);
+		(void) moveATile(w, last, first);
+		(void) moveATile(w, 1, first);
+		(void) moveATile(w, 1, last);
+		(void) moveATile(w, first, 1);
+		(void) moveATile(w, first, 1);
+		(void) moveATile(w, last, first);
+		(void) moveATile(w, last, first);
+		(void) moveATile(w, last, first);
+		(void) moveATile(w, 1, last);
+		(void) moveATile(w, 1, last);
+		(void) moveATile(w, first, 1);
+		(void) moveATile(w, last, 1);
+		(void) moveATile(w, last, first);
+		(void) moveATile(w, 1, last);
 	} else {
-		(void) MoveATile(w, last, 1);
-		(void) MoveATile(w, first, last);
-		(void) MoveATile(w, 1, last);
-		(void) MoveATile(w, 1, first);
-		(void) MoveATile(w, last, 1);
-		(void) MoveATile(w, last, 1);
-		(void) MoveATile(w, first, last);
-		(void) MoveATile(w, first, last);
-		(void) MoveATile(w, first, last);
-		(void) MoveATile(w, 1, first);
-		(void) MoveATile(w, 1, first);
-		(void) MoveATile(w, last, 1);
-		(void) MoveATile(w, first, 1);
-		(void) MoveATile(w, first, last);
-		(void) MoveATile(w, 1, first);
+		(void) moveATile(w, last, 1);
+		(void) moveATile(w, first, last);
+		(void) moveATile(w, 1, last);
+		(void) moveATile(w, 1, first);
+		(void) moveATile(w, last, 1);
+		(void) moveATile(w, last, 1);
+		(void) moveATile(w, first, last);
+		(void) moveATile(w, first, last);
+		(void) moveATile(w, first, last);
+		(void) moveATile(w, 1, first);
+		(void) moveATile(w, 1, first);
+		(void) moveATile(w, last, 1);
+		(void) moveATile(w, first, 1);
+		(void) moveATile(w, first, last);
+		(void) moveATile(w, 1, first);
 	}
 }
 
-static void Z(PanexWidget w, Boolean side, Boolean inv)
+static void
+Z(PanexWidget w, Boolean side, Boolean inv)
 {
 	int first, last;
 
@@ -801,35 +809,36 @@ static void Z(PanexWidget w, Boolean side, Boolean inv)
 		last = 2;
 	}
 	if (inv) {
-		(void) MoveATile(w, last, first);
-		(void) MoveATile(w, last, 1);
-		(void) MoveATile(w, last, 1);
-		(void) MoveATile(w, first, last);
+		(void) moveATile(w, last, first);
+		(void) moveATile(w, last, 1);
+		(void) moveATile(w, last, 1);
+		(void) moveATile(w, first, last);
 		centerSwap(w);
-		(void) MoveATile(w, first, last);
-		(void) MoveATile(w, first, 1);
-		(void) MoveATile(w, last, first);
-		(void) MoveATile(w, last, first);
-		(void) MoveATile(w, 1, last);
-		(void) MoveATile(w, first, last);
-		(void) MoveATile(w, first, 1);
+		(void) moveATile(w, first, last);
+		(void) moveATile(w, first, 1);
+		(void) moveATile(w, last, first);
+		(void) moveATile(w, last, first);
+		(void) moveATile(w, 1, last);
+		(void) moveATile(w, first, last);
+		(void) moveATile(w, first, 1);
 	} else {
-		(void) MoveATile(w, 1, first);
-		(void) MoveATile(w, last, first);
-		(void) MoveATile(w, last, 1);
-		(void) MoveATile(w, first, last);
-		(void) MoveATile(w, first, last);
-		(void) MoveATile(w, 1, first);
-		(void) MoveATile(w, last, first);
+		(void) moveATile(w, 1, first);
+		(void) moveATile(w, last, first);
+		(void) moveATile(w, last, 1);
+		(void) moveATile(w, first, last);
+		(void) moveATile(w, first, last);
+		(void) moveATile(w, 1, first);
+		(void) moveATile(w, last, first);
 		centerSwap(w);
-		(void) MoveATile(w, last, first);
-		(void) MoveATile(w, 1, last);
-		(void) MoveATile(w, 1, last);
-		(void) MoveATile(w, first, last);
+		(void) moveATile(w, last, first);
+		(void) moveATile(w, 1, last);
+		(void) moveATile(w, 1, last);
+		(void) moveATile(w, first, last);
 	}
 }
 
-static void SQ(PanexWidget w, int n, Boolean side, Boolean inv)
+static void
+SQ(PanexWidget w, int n, Boolean side, Boolean inv)
 {
 	int first, last;
 
@@ -842,11 +851,11 @@ static void SQ(PanexWidget w, int n, Boolean side, Boolean inv)
 	}
 	if (inv) {
 		if (n == 1) {
-			(void) MoveATile(w, 1, first);
+			(void) moveATile(w, 1, first);
 		} else if (n == 2) {
-			(void) MoveATile(w, first, last);
-			(void) MoveATile(w, 1, first);
-			(void) MoveATile(w, last, first);
+			(void) moveATile(w, first, last);
+			(void) moveATile(w, 1, first);
+			(void) moveATile(w, last, first);
 		} else if (n >= 3) {
 			if (((n & 1) == 0) && (NRAND(2) == 1)) {
 				S(w, n, side, inv);
@@ -858,11 +867,11 @@ static void SQ(PanexWidget w, int n, Boolean side, Boolean inv)
 		}
 	} else {
 		if (n == 1) {
-			(void) MoveATile(w, first, 1);
+			(void) moveATile(w, first, 1);
 		} else if (n == 2) {
-			(void) MoveATile(w, first, last);
-			(void) MoveATile(w, first, 1);
-			(void) MoveATile(w, last, first);
+			(void) moveATile(w, first, last);
+			(void) moveATile(w, first, 1);
+			(void) moveATile(w, last, first);
 		} else if (n >= 3) {
 			if (((n & 1) == 0) && (NRAND(2) == 1)) {
 				T(w, n - 1, side, inv);
@@ -875,7 +884,8 @@ static void SQ(PanexWidget w, int n, Boolean side, Boolean inv)
 	}
 }
 
-static void DQ(PanexWidget w, int n, Boolean side, Boolean inv)
+static void
+DQ(PanexWidget w, int n, Boolean side, Boolean inv)
 {
 	int first, last;
 
@@ -891,9 +901,9 @@ static void DQ(PanexWidget w, int n, Boolean side, Boolean inv)
 	if (inv) {
 		if (n == 2) {
 			centerSwap(w);
-			(void) MoveATile(w, 1, last);
-			(void) MoveATile(w, 1, first);
-			(void) MoveATile(w, last, first);
+			(void) moveATile(w, 1, last);
+			(void) moveATile(w, 1, first);
+			(void) moveATile(w, last, first);
 		} else if (n >= 3) {
 			centerSwap(w);
 			if (((n & 1) == 0) && (NRAND(2) == 1)) {
@@ -906,9 +916,9 @@ static void DQ(PanexWidget w, int n, Boolean side, Boolean inv)
 		}
 	} else {
 		if (n == 2) {
-			(void) MoveATile(w, first, last);
-			(void) MoveATile(w, first, 1);
-			(void) MoveATile(w, last, 1);
+			(void) moveATile(w, first, last);
+			(void) moveATile(w, first, 1);
+			(void) moveATile(w, last, 1);
 			centerSwap(w);
 		} else if (n >= 3) {
 			if (((n & 1) == 0) && (NRAND(2) == 1)) {
@@ -923,7 +933,8 @@ static void DQ(PanexWidget w, int n, Boolean side, Boolean inv)
 	}
 }
 
-static void WB(PanexWidget w, int n, Boolean side, Boolean inv)
+static void
+WB(PanexWidget w, int n, Boolean side, Boolean inv)
 {
 	int first, last;
 
@@ -936,16 +947,16 @@ static void WB(PanexWidget w, int n, Boolean side, Boolean inv)
 	}
 	if (inv) {
 		if (n == 1) {
-			(void) MoveATile(w, first, last);
-			(void) MoveATile(w, 1, first);
+			(void) moveATile(w, first, last);
+			(void) moveATile(w, 1, first);
 		} else if (n == 2) {
 			sideSwap(w, side);
-			(void) MoveATile(w, last, 1);
-			(void) MoveATile(w, first, last);
-			(void) MoveATile(w, first, last);
-			(void) MoveATile(w, 1, last);
-			(void) MoveATile(w, 1, first);
-			(void) MoveATile(w, last, first);
+			(void) moveATile(w, last, 1);
+			(void) moveATile(w, first, last);
+			(void) moveATile(w, first, last);
+			(void) moveATile(w, 1, last);
+			(void) moveATile(w, 1, first);
+			(void) moveATile(w, last, first);
 		} else if (n >= 3) {
 			SQ(w, n, side, !inv);
 			SQ(w, n - 1, !side, !inv);
@@ -960,15 +971,15 @@ static void WB(PanexWidget w, int n, Boolean side, Boolean inv)
 		}
 	} else {
 		if (n == 1) {
-			(void) MoveATile(w, first, 1);
-			(void) MoveATile(w, last, first);
+			(void) moveATile(w, first, 1);
+			(void) moveATile(w, last, first);
 		} else if (n == 2) {
-			(void) MoveATile(w, first, last);
-			(void) MoveATile(w, first, 1);
-			(void) MoveATile(w, last, 1);
-			(void) MoveATile(w, last, first);
-			(void) MoveATile(w, last, first);
-			(void) MoveATile(w, 1, last);
+			(void) moveATile(w, first, last);
+			(void) moveATile(w, first, 1);
+			(void) moveATile(w, last, 1);
+			(void) moveATile(w, last, first);
+			(void) moveATile(w, last, first);
+			(void) moveATile(w, 1, last);
 			sideSwap(w, side);
 		} else if (n >= 3) {
 			DQ(w, n, side, inv);
@@ -986,7 +997,8 @@ static void WB(PanexWidget w, int n, Boolean side, Boolean inv)
 }
 
 #if defined(QUANTUM_ALG) || defined(QUANTUM_JANSEN_ALG)
-static void BQ(PanexWidget w, int n, Boolean side, Boolean inv)
+static void
+BQ(PanexWidget w, int n, Boolean side, Boolean inv)
 {
 	int first, last;
 
@@ -1011,7 +1023,8 @@ static void BQ(PanexWidget w, int n, Boolean side, Boolean inv)
 }
 #endif
 
-static void XSimple(PanexWidget w, int n, Boolean side, Boolean inv)
+static void
+XSimple(PanexWidget w, int n, Boolean side, Boolean inv)
 {
 	/* Yeah, it works but it takes a long time */
 	if (inv) {
@@ -1039,7 +1052,8 @@ static void XSimple(PanexWidget w, int n, Boolean side, Boolean inv)
 
 #ifdef BAXTER_ALG
 /* From Nick Baxter */
-static void XBaxter(PanexWidget w, int n, Boolean side, Boolean inv)
+static void
+XBaxter(PanexWidget w, int n, Boolean side, Boolean inv)
 {
 	if (inv) {
 		SQ(w, n, !side, !inv);
@@ -1053,7 +1067,8 @@ static void XBaxter(PanexWidget w, int n, Boolean side, Boolean inv)
 
 #if defined(QUANTUM_ALG) || defined(QUANTUM_JANSEN_ALG)
 /* From Quantum */
-static void XQuantum(PanexWidget w, int n, Boolean side, Boolean inv)
+static void
+XQuantum(PanexWidget w, int n, Boolean side, Boolean inv)
 {
 	int first, last, i;
 
@@ -1072,62 +1087,62 @@ static void XQuantum(PanexWidget w, int n, Boolean side, Boolean inv)
 		/* Original Algorithm */
 		for (i = n; i >= 3; i--)
 			BQ(w, i, side, inv);
-		(void) MoveATile(w, first, last);
-		(void) MoveATile(w, 1, first);
-		(void) MoveATile(w, last, first);
+		(void) moveATile(w, first, last);
+		(void) moveATile(w, 1, first);
+		(void) moveATile(w, last, first);
 #else /* QUANTUM_JANSEN_ALG */
 		/* Rene Jansen's one move improvement */
 		for (i = n; i >= 4; i--)
 			BQ(w, i, side, inv);
 		sideSwap(w, side);
-		(void) MoveATile(w, 1, last);
-		(void) MoveATile(w, first, 1);
-		(void) MoveATile(w, first, 1);
-		(void) MoveATile(w, last, first);
-		(void) MoveATile(w, 1, first);
-		(void) MoveATile(w, last, first);
-		(void) MoveATile(w, last, 1);
-		(void) MoveATile(w, first, last);
-		(void) MoveATile(w, 1, last);
-		(void) MoveATile(w, first, 1);
-		(void) MoveATile(w, last, first);
+		(void) moveATile(w, 1, last);
+		(void) moveATile(w, first, 1);
+		(void) moveATile(w, first, 1);
+		(void) moveATile(w, last, first);
+		(void) moveATile(w, 1, first);
+		(void) moveATile(w, last, first);
+		(void) moveATile(w, last, 1);
+		(void) moveATile(w, first, last);
+		(void) moveATile(w, 1, last);
+		(void) moveATile(w, first, 1);
+		(void) moveATile(w, last, first);
 #endif
-		(void) MoveATile(w, last, first);
+		(void) moveATile(w, last, first);
 		if ((n & 1) == 1)
-			(void) MoveATile(w, 1, last);
+			(void) moveATile(w, 1, last);
 		else
-			(void) MoveATile(w, 1, first);
+			(void) moveATile(w, 1, first);
 /* qTrick combine next (first, last) move to save a move if n odd */
 		TBar(w, n, !side, inv, False, ((n & 1) == 1));
 	} else {
 		TBar(w, n, !side, inv, False, ((n & 1) == 1));
 /* qTrick combine previous (last, first) move to save a move if n odd */
 		if ((n & 1) == 1)
-			(void) MoveATile(w, last, 1);
+			(void) moveATile(w, last, 1);
 		else
-			(void) MoveATile(w, first, 1);
-		(void) MoveATile(w, first, last);
+			(void) moveATile(w, first, 1);
+		(void) moveATile(w, first, last);
 
 #ifdef QUANTUM_ALG
 		/* Original Algorithm */
-		(void) MoveATile(w, 1, last);
-		(void) MoveATile(w, first, 1);
-		(void) MoveATile(w, last, first);
+		(void) moveATile(w, 1, last);
+		(void) moveATile(w, first, 1);
+		(void) moveATile(w, last, first);
 		for (int i = 3; i <= n; i++)
 			BQ(w, i, inv);
 #else /* QUANTUM_JANSEN_ALG */
 		/* Rene Jansen's one move improvement */
-		(void) MoveATile(w, first, last);
-		(void) MoveATile(w, 1, first);
-		(void) MoveATile(w, last, 1);
-		(void) MoveATile(w, last, first);
-		(void) MoveATile(w, 1, last);
-		(void) MoveATile(w, first, last);
-		(void) MoveATile(w, first, 1);
-		(void) MoveATile(w, first, last);
-		(void) MoveATile(w, 1, first);
-		(void) MoveATile(w, 1, first);
-		(void) MoveATile(w, last, 1);
+		(void) moveATile(w, first, last);
+		(void) moveATile(w, 1, first);
+		(void) moveATile(w, last, 1);
+		(void) moveATile(w, last, first);
+		(void) moveATile(w, 1, last);
+		(void) moveATile(w, first, last);
+		(void) moveATile(w, first, 1);
+		(void) moveATile(w, first, last);
+		(void) moveATile(w, 1, first);
+		(void) moveATile(w, 1, first);
+		(void) moveATile(w, last, 1);
 		sideSwap(w, side);
 		for (i = 4; i <= n; i++)
 			BQ(w, i, side, inv);
@@ -1138,7 +1153,8 @@ static void XQuantum(PanexWidget w, int n, Boolean side, Boolean inv)
 }
 #endif
 
-static void X(PanexWidget w, int n, Boolean side, Boolean inv)
+static void
+X(PanexWidget w, int n, Boolean side, Boolean inv)
 {
 	int first, last, i;
 
@@ -1152,35 +1168,35 @@ static void X(PanexWidget w, int n, Boolean side, Boolean inv)
 	if (n == 1) {
 		if (inv) {
 			T(w, 1, !side, !inv);
-			(void) MoveATile(w, first, last);
+			(void) moveATile(w, first, last);
 			T(w, 1, side, inv);
 		} else {
 			T(w, 1, side, inv);
-			(void) MoveATile(w, last, first);
+			(void) moveATile(w, last, first);
 			T(w, 1, !side, !inv);
 		}
 	} else if (n == 2) {
 		if (inv) {
 			TBar(w, 2, !side, !inv, False, False);
-			(void) MoveATile(w, first, last);
-			(void) MoveATile(w, first, 1);
-			(void) MoveATile(w, first, last);
-			(void) MoveATile(w, 1, first);
-			(void) MoveATile(w, last, first);
-			(void) MoveATile(w, last, 1);
-			(void) MoveATile(w, first, last);
-			(void) MoveATile(w, first, last);
+			(void) moveATile(w, first, last);
+			(void) moveATile(w, first, 1);
+			(void) moveATile(w, first, last);
+			(void) moveATile(w, 1, first);
+			(void) moveATile(w, last, first);
+			(void) moveATile(w, last, 1);
+			(void) moveATile(w, first, last);
+			(void) moveATile(w, first, last);
 			T(w, 2, side, inv);
 		} else {
 			T(w, 2, side, inv);
-			(void) MoveATile(w, last, first);
-			(void) MoveATile(w, last, first);
-			(void) MoveATile(w, 1, last);
-			(void) MoveATile(w, first, last);
-			(void) MoveATile(w, first, 1);
-			(void) MoveATile(w, last, first);
-			(void) MoveATile(w, 1, first);
-			(void) MoveATile(w, last, first);
+			(void) moveATile(w, last, first);
+			(void) moveATile(w, last, first);
+			(void) moveATile(w, 1, last);
+			(void) moveATile(w, first, last);
+			(void) moveATile(w, first, 1);
+			(void) moveATile(w, last, first);
+			(void) moveATile(w, 1, first);
+			(void) moveATile(w, last, first);
 			TBar(w, 2, !side, !inv, False, False);
 		}
 	} else if (n == 3) {
@@ -1279,15 +1295,15 @@ static void X(PanexWidget w, int n, Boolean side, Boolean inv)
 }
 
 static void
-SolvePanexMode(PanexWidget w)
+solvePanexMode(PanexWidget w)
 {
-	if (SolvingFlag)
+	if (solvingFlag)
 		return;
 #ifdef JMP
 	if (!setjmp(solve_env))
 #endif
 	{
-		SolvingFlag = True;
+		solvingFlag = True;
 
 #ifdef WINVER
 		(void) SRAND(time(NULL));
@@ -1331,11 +1347,11 @@ SolvePanexMode(PanexWidget w)
 	}
 #ifdef JMP
 	else {
-		DrawAllTiles(w);
+		drawAllTiles(w);
 	}
-	AbortSolvingFlag = False;
+	abortSolvingFlag = False;
 #endif
-	SolvingFlag = False;
+	solvingFlag = False;
 	w->panex.cheat = True; /* Assume the worst. */
 	setPuzzle(w, ACTION_COMPUTED);
 #ifdef DEBUG
@@ -1344,10 +1360,10 @@ SolvePanexMode(PanexWidget w)
 }
 
 void
-SolveTilesFromStart(PanexWidget w)
+solveTilesFromStart(PanexWidget w)
 {
 	if (w->panex.mode == PANEX)
-		SolvePanexMode(w);
+		solvePanexMode(w);
 	else
-		SolveHanoiMode(w);
+		solveHanoiMode(w);
 }
