@@ -1,27 +1,24 @@
-/*-
-# MOTIF/X-BASED PANEX(tm)
-#
-#  xpanex.c
-#
-###
-#
-#  Copyright (c) 1996 - 2007	David A. Bagley, bagleyd@tux.org
-#
-#                   All Rights Reserved
-#
-#  Permission to use, copy, modify, and distribute this software and
-#  its documentation for any purpose and without fee is hereby granted,
-#  provided that the above copyright notice appear in all copies and
-#  that both that copyright notice and this permission notice appear in
-#  supporting documentation, and that the name of the author not be
-#  used in advertising or publicity pertaining to distribution of the
-#  software without specific, written prior permission.
-#
-#  This program is distributed in the hope that it will be "playable",
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-#
-*/
+/*
+ * @(#)xpanex.c
+ *
+ * Copyright 1996 - 2008  David A. Bagley, bagleyd@tux.org
+ *
+ * All rights reserved.
+ *
+ * Permission to use, copy, modify, and distribute this software and
+ * its documentation for any purpose and without fee is hereby granted,
+ * provided that the above copyright notice appear in all copies and
+ * that both that copyright notice and this permission notice appear in
+ * supporting documentation, and that the name of the author not be
+ * used in advertising or publicity pertaining to distribution of the
+ * software without specific, written prior permission.
+ *
+ * This program is distributed in the hope that it will be "useful",
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ */
+
+/* Driver file for Panex */
 
 #include "file.h"
 #ifdef WINVER
@@ -58,7 +55,7 @@ static PanexRec widget;
 #include "pixmaps/mouse-l.xbm"
 #include "pixmaps/mouse-r.xbm"
 #endif
-#define PRINT_MESSAGE(b) PrintState(message, b)
+#define PRINT_MESSAGE(b) printState(message, b)
 #else
 #define PRINT_MESSAGE(b) XtWarning(b)
 #endif
@@ -90,7 +87,7 @@ static PanexRec widget;
 
 #ifndef WINVER
 static const char aboutHelp[] = {
-"Panex Version 7.3.3\n"
+"Panex Version 7.4\n"
 "Send bugs (reports or fixes) to the author: "
 "David Bagley <bagleyd@tux.org>\n"
 "The latest version is at: "
@@ -217,7 +214,8 @@ static char recordDsp[MESSAGE_LENGTH] = "NOT RECORDED";
 #ifdef HAVE_MOTIF
 #define MIN_SPEED 1
 #define MAX_SPEED 50
-static Widget moves, record, message, modes[MAX_MODES], tile, speed;
+static Widget movesText, recordText, message, modes[MAX_MODES];
+static Widget tileSlider, speedSlider;
 static char buff[21];
 static const char *modeString[] =
 {
@@ -244,19 +242,19 @@ static char userNameDsp[USER_NAME_LENGTH] = "";
 
 #ifdef HAVE_MOTIF
 static void
-PrintState(Widget w, char *msg)
+printState(Widget w, char *msg)
 {
 	XmString xmstr;
 
 	if (!XtIsSubclass(w, xmLabelWidgetClass))
-		XtError("PrintState() requires a Label Widget");
+		XtError("printState() requires a Label Widget");
 	xmstr = XmStringCreateLtoR(msg, XmSTRING_DEFAULT_CHARSET);
 	XtVaSetValues(w, XmNlabelString, xmstr, NULL);
 }
 #endif
 
 static void
-PrintRecords(void)
+printRecords(void)
 {
 	int i, mode;
 
@@ -274,7 +272,7 @@ PrintRecords(void)
 #endif
 
 static void
-InitRecords(void)
+initRecords(void)
 {
 	int i, mode;
 
@@ -287,7 +285,7 @@ InitRecords(void)
 }
 
 static void
-ReadRecords(void)
+readRecords(void)
 {
 	FILE *fp;
 	int i, mode, n;
@@ -346,7 +344,7 @@ ReadRecords(void)
 }
 
 static void
-WriteRecords(void)
+writeRecords(void)
 {
 	FILE *fp;
 	int i, mode;
@@ -395,7 +393,7 @@ WriteRecords(void)
 }
 
 static void
-PrintRecord(int tiles, int mode)
+printRecord(int tiles, int mode)
 {
 	int i = tiles - MIN_TILES, j = mode - HANOI;
 
@@ -409,21 +407,21 @@ PrintRecord(int tiles, int mode)
 
 	}
 #ifdef HAVE_MOTIF
-	PrintState(record, recordDsp);
+	printState(recordText, recordDsp);
 #endif
 }
 
 static void
-PrintStatus(char *msg, int nMoves
+printStatus(char *msg, int nMoves
 #ifndef HAVE_MOTIF
 		, int tiles
 #endif
 		)
 {
 #ifdef HAVE_MOTIF
-	PrintState(message, msg);
+	printState(message, msg);
 	(void) sprintf(buff, "%d", nMoves);
-	PrintState(moves, buff);
+	printState(movesText, buff);
 #else
 	(void) sprintf(titleDsp, "%s: %d@ (%d/%s) - %s",
 		progDsp, tiles, nMoves, recordDsp, msg);
@@ -436,25 +434,25 @@ PrintStatus(char *msg, int nMoves
 }
 
 static Boolean
-HandleSolved(int counter, int tiles, int mode)
+handleSolved(int counter, int tiles, int mode)
 {
 	int i = tiles - MIN_TILES, j = mode - HANOI;
 
 	if (tiles <= MAX_TILES && (counter < puzzleRecord[j][i].score ||
 			puzzleRecord[j][i].score <= NEVER)) {
-		ReadRecords();	/* Maybe its been updated by another */
+		readRecords();	/* Maybe its been updated by another */
 		puzzleRecord[j][i].score = counter;
 		(void) strncpy(puzzleRecord[j][i].name, userNameDsp,
 			USER_NAME_LENGTH);
-		WriteRecords();
-		PrintRecord(tiles, mode);
+		writeRecords();
+		printRecord(tiles, mode);
 		return True;
 	}
 	return False;
 }
 
 static void
-Initialize(
+initialize(
 #ifdef WINVER
 PanexWidget w, HBRUSH brush
 #else
@@ -466,7 +464,7 @@ Widget w
 	char *userName, *scoreFile;
 
 #ifdef WINVER
-	InitializePuzzle(w, brush);
+	initializePuzzle(w, brush);
 
 	tiles = w->panex.tiles;
 	mode = w->panex.mode;
@@ -491,9 +489,9 @@ Widget w
 	if (strcmp(scoreFile, ""))
 		(void) strncpy(scoreFileName, scoreFile, FILE_NAME_LENGTH);
 	if (scoreOnly) {
-		InitRecords();
-		ReadRecords();
-		PrintRecords();
+		initRecords();
+		readRecords();
+		printRecords();
 		exit(0);
 	}
 #ifdef HAVE_MOTIF
@@ -501,17 +499,18 @@ Widget w
 		int delay;
 
 		if (tiles > MAX_TILES)
-			XtVaSetValues(tile, XmNmaximum, tiles, NULL);
-		XmScaleSetValue(tile, tiles);
+			XtVaSetValues(tileSlider, XmNmaximum, tiles, NULL);
+		XmScaleSetValue(tileSlider, tiles);
 		XmToggleButtonSetState(modes[mode - HANOI], True, False);
 		XtVaGetValues(puzzle, XtNdelay, &delay, NULL);
-		XmScaleSetValue(speed, MAX_SPEED + MIN_SPEED - delay - 1);
+		XmScaleSetValue(speedSlider,
+			MAX_SPEED + MIN_SPEED - delay - 1);
 	}
 #endif
 #endif
 	/* SET_STARTED(w, False); */
-	InitRecords();
-	ReadRecords();
+	initRecords();
+	readRecords();
 #ifndef WINVER
 	(void) strncpy(userNameDsp, userName, USER_NAME_LENGTH);
 #endif
@@ -536,8 +535,8 @@ Widget w
 			(void) sprintf(userNameDsp, "%s", "guest");
 #endif
 	}
-	PrintRecord(tiles, mode);
-	PrintStatus(messageDsp, movesDsp
+	printRecord(tiles, mode);
+	printStatus(messageDsp, movesDsp
 #ifndef HAVE_MOTIF
 		, tiles
 #endif
@@ -549,7 +548,7 @@ void
 setPuzzle(PanexWidget w, int reason)
 #else
 static void
-CallbackPuzzle(Widget w, caddr_t clientData, panexCallbackStruct *callData)
+puzzleListener(Widget w, caddr_t clientData, panexCallbackStruct *callData)
 #endif
 {
 #ifndef WINVER
@@ -617,7 +616,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, panexCallbackStruct *callData)
 		if (cheat)
 			(void) sprintf(messageDsp,
 				"No cheating %s!!", userNameDsp);
-		else if (HandleSolved(movesDsp, tiles, mode))
+		else if (handleSolved(movesDsp, tiles, mode))
 			(void) sprintf(messageDsp,
 				"Congratulations %s!!", userNameDsp);
 		else
@@ -631,37 +630,37 @@ CallbackPuzzle(Widget w, caddr_t clientData, panexCallbackStruct *callData)
 	case ACTION_INCREMENT:
 		movesDsp = 0;
 		tiles++;
-		PrintRecord(tiles, mode);
+		printRecord(tiles, mode);
 #ifdef WINVER
 		w->panex.tiles = tiles;
 #else
 		XtVaSetValues(w, XtNtiles, tiles, NULL);
 #ifdef HAVE_MOTIF
 		if (tiles > MAX_TILES)
-			XtVaSetValues(tile, XmNmaximum, tiles, NULL);
-		XmScaleSetValue(tile, tiles);
+			XtVaSetValues(tileSlider, XmNmaximum, tiles, NULL);
+		XmScaleSetValue(tileSlider, tiles);
 #endif
 #endif
 		break;
 	case ACTION_DECREMENT:
 		movesDsp = 0;
 		tiles--;
-		PrintRecord(tiles, mode);
+		printRecord(tiles, mode);
 #ifdef WINVER
 		w->panex.tiles = tiles;
 #else
 		XtVaSetValues(w, XtNtiles, tiles, NULL);
 #ifdef HAVE_MOTIF
-		XmScaleSetValue(tile, tiles);
+		XmScaleSetValue(tileSlider, tiles);
 		if (tiles >= MAX_TILES)
-			XtVaSetValues(tile, XmNmaximum, tiles, NULL);
+			XtVaSetValues(tileSlider, XmNmaximum, tiles, NULL);
 #endif
 #endif
 		break;
 	case ACTION_MODE:
 		movesDsp = 0;
 		mode = (mode == PANEX) ? HANOI : PANEX;
-		PrintRecord(tiles, mode);
+		printRecord(tiles, mode);
 #ifdef WINVER
 		w->panex.mode = mode;
 #else
@@ -695,13 +694,13 @@ CallbackPuzzle(Widget w, caddr_t clientData, panexCallbackStruct *callData)
 				XtVaSetValues(w,
 					XtNdelay, delay, NULL);
 			}
-			XmScaleSetValue(speed,
+			XmScaleSetValue(speedSlider,
 				MAX_SPEED + MIN_SPEED - delay - 1);
 		}
 		return;
 #endif
 	}
-	PrintStatus(messageDsp, movesDsp
+	printStatus(messageDsp, movesDsp
 #ifndef HAVE_MOTIF
 		, tiles
 #endif
@@ -710,15 +709,11 @@ CallbackPuzzle(Widget w, caddr_t clientData, panexCallbackStruct *callData)
 
 #ifdef WINVER
 static LRESULT CALLBACK
-About(HWND hDlg, UINT message, WPARAM wParam, LPARAM lParam)
+about(HWND hDlg, UINT message, WPARAM wParam, LPARAM lParam)
 {
-	switch (message) {
-	case WM_COMMAND:
-		if (LOWORD(wParam) == IDOK) {
-			(void) EndDialog(hDlg, TRUE);
-			return TRUE;
-		}
-		break;
+	if (message == WM_COMMAND && LOWORD(wParam) == IDOK) {
+		(void) EndDialog(hDlg, TRUE);
+		return TRUE;
 	}
 	return FALSE;
 }
@@ -736,7 +731,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_BRUSH));
-			EnterPuzzle(&widget);
+			enterPuzzle(&widget);
 			(void) EndPaint(hWnd, &paint);
 		}
 	} else {
@@ -744,33 +739,33 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_BRUSH));
-			LeavePuzzle(&widget);
+			leavePuzzle(&widget);
 			(void) EndPaint(hWnd, &paint);
 		}
 	}
 	switch (message) {
 	case WM_CREATE:
-		Initialize(&widget, brush);
+		initialize(&widget, brush);
 		break;
 	case WM_DESTROY:
-		DestroyPuzzle(brush);
+		destroyPuzzle(brush);
 		break;
 	case WM_SIZE:
-		ResizePuzzle(&widget);
+		resizePuzzle(&widget);
 		(void) InvalidateRect(hWnd, NULL, TRUE);
 		break;
 	case WM_PAINT:
 		widget.core.hDC = BeginPaint(hWnd, &paint);
 		(void) SelectObject(widget.core.hDC,
 			GetStockObject(NULL_PEN));
-		ExposePuzzle(&widget);
+		exposePuzzle(&widget);
 		(void) EndPaint(hWnd, &paint);
 		break;
 	case WM_RBUTTONDOWN:
 		widget.core.hDC = GetDC(hWnd);
 		(void) SelectObject(widget.core.hDC,
 			GetStockObject(NULL_PEN));
-		ClearPuzzle(&widget);
+		clearPuzzle(&widget);
 		(void) ReleaseDC(hWnd, widget.core.hDC);
 		break;
 	case WM_LBUTTONDOWN:
@@ -778,7 +773,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 		widget.core.hDC = GetDC(hWnd);
 		(void) SelectObject(widget.core.hDC,
 			GetStockObject(NULL_PEN));
-		SelectPuzzle(&widget, LOWORD(lParam));
+		selectPuzzle(&widget, LOWORD(lParam));
 		(void) ReleaseDC(hWnd, widget.core.hDC);
 		break;
 	case WM_MOUSEMOVE:
@@ -787,7 +782,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 		widget.core.hDC = GetDC(hWnd);
 		(void) SelectObject(widget.core.hDC,
 			GetStockObject(NULL_PEN));
-		MotionPuzzle(&widget, LOWORD(lParam));
+		motionPuzzle(&widget, LOWORD(lParam));
 		(void) ReleaseDC(hWnd, widget.core.hDC);
 		break;
 	case WM_LBUTTONUP:
@@ -795,74 +790,74 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 		widget.core.hDC = GetDC(hWnd);
 		(void) SelectObject(widget.core.hDC,
 			GetStockObject(NULL_PEN));
-		ReleasePuzzle(&widget, LOWORD(lParam));
+		releasePuzzle(&widget, LOWORD(lParam));
 		(void) ReleaseDC(hWnd, widget.core.hDC);
 		break;
 	case WM_COMMAND:
 		switch (LOWORD(wParam)) {
 		case ACTION_GET:
-			GetPuzzle(&widget);
-			ResizePuzzle(&widget);
+			getPuzzle(&widget);
+			resizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
 		case ACTION_WRITE:
-			WritePuzzle(&widget);
+			writePuzzle(&widget);
 			break;
 		case ACTION_EXIT:
-			DestroyPuzzle(brush);
+			destroyPuzzle(brush);
 			break;
 		case ACTION_HIDE:
-			HidePuzzle(&widget);
+			hidePuzzle(&widget);
 			break;
 		case ACTION_UNDO:
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_PEN));
-			UndoPuzzle(&widget);
+			undoPuzzle(&widget);
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
 		case ACTION_REDO:
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_PEN));
-			RedoPuzzle(&widget);
+			redoPuzzle(&widget);
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
 		case ACTION_CLEAR:
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_PEN));
-			ClearPuzzle(&widget);
+			clearPuzzle(&widget);
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
 		case ACTION_SOLVE:
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_PEN));
-			SolvePuzzle(&widget);
+			solvePuzzle(&widget);
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
 		case ACTION_MODE:
-			(void) ModePuzzle(&widget);
-			SizePuzzle(&widget);
+			(void) modePuzzle(&widget);
+			sizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
 		case ACTION_INCREMENT:
 		case ACTION_DECREMENT:
 			((LOWORD(wParam) == ACTION_DECREMENT) ?
-				DecrementPuzzle(&widget) :
-				IncrementPuzzle(&widget));
-			SizePuzzle(&widget);
+				decrementPuzzle(&widget) :
+				incrementPuzzle(&widget));
+			sizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
 		case ACTION_SPEED:
-			SpeedPuzzle(&widget);
+			speedUpPuzzle(&widget);
 			break;
 		case ACTION_SLOW:
-			SlowPuzzle(&widget);
+			slowDownPuzzle(&widget);
 			break;
 		case ACTION_SOUND:
-			SoundPuzzle(&widget);
+			toggleSoundPuzzle(&widget);
 			break;
 		case ACTION_DESCRIPTION:
 			(void) MessageBox(hWnd, descriptionHelp,
@@ -878,7 +873,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			break;
 		case ACTION_ABOUT:
 			(void) DialogBox(widget.core.hInstance,
-				"About", hWnd, (DLGPROC) About);
+				"About", hWnd, (DLGPROC) about);
 			break;
 		}
 		break;
@@ -939,7 +934,7 @@ WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance, LPSTR lpCmdLine,
 #else
 
 static void
-Usage(char *programName)
+usage(char *programName)
 {
 	unsigned int i;
 
@@ -985,7 +980,7 @@ static XrmOptionDescRec options[] =
 
 #ifdef HAVE_MOTIF
 static void
-CallbackPuzzleClear(Widget w, XtPointer clientData, XmAnyCallbackStruct *cbs)
+puzzleClearListener(Widget w, XtPointer clientData, XmAnyCallbackStruct *cbs)
 {
 	if (cbs->reason == XmCR_OK) {
 		XtVaSetValues(puzzle, XtNmenu, ACTION_CLEAR, NULL);
@@ -993,7 +988,7 @@ CallbackPuzzleClear(Widget w, XtPointer clientData, XmAnyCallbackStruct *cbs)
 }
 
 static void
-TileSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
+tileChangeListener(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 {
 	int tiles = cbs->value, mode, old;
 
@@ -1006,10 +1001,10 @@ TileSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 		XtNtiles, tiles, NULL);
 	movesDsp = 0;
 	(void) sprintf(buff, "%d", movesDsp);
-	PrintState(moves, buff);
-	PrintRecord(tiles, mode);
+	printState(movesText, buff);
+	printRecord(tiles, mode);
 	(void) strcpy(messageDsp, "");
-	PrintState(message, messageDsp);
+	printState(message, messageDsp);
 }
 
 static void
@@ -1026,14 +1021,14 @@ ModeToggle(Widget w, int mode, XmToggleButtonCallbackStruct *cbs)
 		XtNmode, mode + HANOI, NULL);
 	movesDsp = 0;
 	(void) sprintf(buff, "%d", movesDsp);
-	PrintState(moves, buff);
-	PrintRecord(tiles, mode + HANOI);
+	printState(movesText, buff);
+	printRecord(tiles, mode + HANOI);
 	(void) strcpy(messageDsp, "");
-	PrintState(message, messageDsp);
+	printState(message, messageDsp);
 }
 
 static void
-SpeedSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
+speedChangeListener(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 {
 	int delay = MAX_SPEED + MIN_SPEED - cbs->value - 1, oldDelay;
 
@@ -1045,7 +1040,7 @@ SpeedSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 }
 
 static void
-fileCB(Widget w, void *value, void *clientData)
+fileMenuListener(Widget w, void *value, void *clientData)
 {
 	int val = (int) value + ACTION_GET;
 
@@ -1117,7 +1112,7 @@ createHelp(Widget w, char *text, char *title)
 }
 
 static void
-helpCB(Widget w, XtPointer value, XtPointer clientData)
+helpMenuListener(Widget w, XtPointer value, XtPointer clientData)
 {
 	int val = (int) value;
 
@@ -1141,7 +1136,7 @@ helpCB(Widget w, XtPointer value, XtPointer clientData)
 		{
 			char *buf;
 
-			intCat(&buf, "helpCB: %d", val);
+			intCat(&buf, "helpMenuListener: %d", val);
 			XtWarning(buf);
 			free(buf);
 		}
@@ -1170,7 +1165,7 @@ main(int argc, char **argv)
 	topLevel = XtInitialize(argv[0], "Panex",
 		options, XtNumber(options), &argc, argv);
 	if (argc != 1)
-		Usage(argv[0]);
+		usage(argv[0]);
 
 #ifdef HAVE_MOTIF
 	menuBarPanel = XtVaCreateManagedWidget("menuBarPanel",
@@ -1190,7 +1185,7 @@ main(int argc, char **argv)
 	writeString = XmStringCreateSimple((char *) "Write");
 	quitString = XmStringCreateSimple((char *) "Quit");
 	(void) XmVaCreateSimplePulldownMenu(menuBar, (char *) "file_menu",
-		0, fileCB,
+		0, fileMenuListener,
 		XmVaPUSHBUTTON, getString, 'G', NULL, NULL,
 		XmVaPUSHBUTTON, writeString, 'W', NULL, NULL,
 		XmVaSEPARATOR,
@@ -1242,23 +1237,23 @@ main(int argc, char **argv)
 	widget = XtVaCreateManagedWidget("Description",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'D', NULL);
-		XtAddCallback(widget, XmNactivateCallback, helpCB, (char *) 0);
+		XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 0);
 	widget = XtVaCreateManagedWidget("Features",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'F', NULL);
-	XtAddCallback(widget, XmNactivateCallback, helpCB, (char *) 1);
+	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 1);
 	widget = XtVaCreateManagedWidget("Options",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'O', NULL);
-	XtAddCallback(widget, XmNactivateCallback, helpCB, (char *) 2);
+	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 2);
 	widget = XtVaCreateManagedWidget("References",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'R', NULL);
-	XtAddCallback(widget, XmNactivateCallback, helpCB, (char *) 3);
+	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 3);
 	widget = XtVaCreateManagedWidget("About",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'A', NULL);
-	XtAddCallback(widget, XmNactivateCallback, helpCB, (char *) 4);
+	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 4);
 	XtManageChild(menuBar);
 	descriptionDialog = createHelp(menuBar, (char *) descriptionHelp,
 		(char *) "Description");
@@ -1273,7 +1268,7 @@ main(int argc, char **argv)
 	clearDialog = createQuery(topLevel,
 		(char *) "Are you sure you want to start over?",
 		(char *) "Clear Query",
-		(XtCallbackProc) CallbackPuzzleClear);
+		(XtCallbackProc) puzzleClearListener);
 	mainPanel = XtCreateManagedWidget("mainPanel",
 		xmPanedWindowWidgetClass, menuBarPanel,
 		NULL, 0);
@@ -1329,12 +1324,12 @@ main(int argc, char **argv)
 	(void) XtVaCreateManagedWidget("movesText",
 		xmLabelGadgetClass, movesRowCol,
 		XtVaTypedArg, XmNlabelString, XmRString, "Moves", 6, NULL);
-	moves = XtVaCreateManagedWidget("0",
+	movesText = XtVaCreateManagedWidget("0",
 		xmLabelWidgetClass, movesRowCol, NULL);
 	(void) XtVaCreateManagedWidget("recordText",
 		xmLabelGadgetClass, movesRowCol,
 		XtVaTypedArg, XmNlabelString, XmRString, "Record", 7, NULL);
-	record = XtVaCreateManagedWidget("0",
+	recordText = XtVaCreateManagedWidget("0",
 		xmLabelWidgetClass, movesRowCol, NULL);
 	radioRowCol = XtVaCreateManagedWidget("movesRowCol",
 		xmRowColumnWidgetClass, controlPanel,
@@ -1354,7 +1349,7 @@ main(int argc, char **argv)
 		XmNnumColumns, 1,
 		XmNorientation, XmHORIZONTAL,
 		XmNpacking, XmPACK_COLUMN, NULL);
-	tile = XtVaCreateManagedWidget("tile",
+	tileSlider = XtVaCreateManagedWidget("tileSlider",
 		xmScaleWidgetClass, tilesRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Size", 5,
 		XmNminimum, MIN_TILES,
@@ -1362,9 +1357,9 @@ main(int argc, char **argv)
 		XmNvalue, DEFAULT_TILES,
 		XmNshowValue, True,
 		XmNorientation, XmHORIZONTAL, NULL);
-	XtAddCallback(tile, XmNvalueChangedCallback,
-		(XtCallbackProc) TileSlider, (XtPointer) NULL);
-	speed = XtVaCreateManagedWidget("Animation Speed",
+	XtAddCallback(tileSlider, XmNvalueChangedCallback,
+		(XtCallbackProc) tileChangeListener, (XtPointer) NULL);
+	speedSlider = XtVaCreateManagedWidget("speedSlider",
 		xmScaleWidgetClass, tilesRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Animation Speed", 16,
 		XmNminimum, MIN_SPEED,
@@ -1372,8 +1367,8 @@ main(int argc, char **argv)
 		XmNvalue, MAX_SPEED - DEFAULT_DELAY,
 		XmNshowValue, True,
 		XmNorientation, XmHORIZONTAL, NULL);
-	XtAddCallback(speed, XmNvalueChangedCallback,
-		(XtCallbackProc) SpeedSlider, (XtPointer) NULL);
+	XtAddCallback(speedSlider, XmNvalueChangedCallback,
+		(XtCallbackProc) speedChangeListener, (XtPointer) NULL);
 	messageRowCol = XtVaCreateManagedWidget("messageRowCol",
 		xmRowColumnWidgetClass, controlPanel, NULL);
 	message = XtVaCreateManagedWidget("Play Panex!",
@@ -1417,14 +1412,14 @@ main(int argc, char **argv)
 #endif
 		XtNiconPixmap, pixmap, NULL);
 	XtAddCallback(puzzle, XtNselectCallback,
-		(XtCallbackProc) CallbackPuzzle, (XtPointer) NULL);
-	Initialize(puzzle);
+		(XtCallbackProc) puzzleListener, (XtPointer) NULL);
+	initialize(puzzle);
 	XtRealizeWidget(topLevel);
 	XGrabButton(XtDisplay(puzzle), (unsigned int) AnyButton, AnyModifier,
 		XtWindow(puzzle), TRUE, (unsigned int) (ButtonPressMask |
 		ButtonMotionMask | ButtonReleaseMask),
 		GrabModeAsync, GrabModeAsync, XtWindow(puzzle),
-		XCreateFontCursor(XtDisplay(puzzle), XC_crosshair));
+		XCreateFontCursor(XtDisplay(puzzle), XC_hand2));
 	XtMainLoop();
 
 #ifdef VMS
