@@ -1,27 +1,22 @@
-/*-
-# X-BASED PYRAMINX(tm)
-#
-#  PyraminxP.h
-#
-###
-#
-#  Copyright (c) 1994 - 2007	David A. Bagley, bagleyd@tux.org
-#
-#                   All Rights Reserved
-#
-#  Permission to use, copy, modify, and distribute this software and
-#  its documentation for any purpose and without fee is hereby granted,
-#  provided that the above copyright notice appear in all copies and
-#  that both that copyright notice and this permission notice appear in
-#  supporting documentation, and that the name of the author not be
-#  used in advertising or publicity pertaining to distribution of the
-#  software without specific, written prior permission.
-#
-#  This program is distributed in the hope that it will be "playable",
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-#
-*/
+/*
+ * @(#)PyraminxP.h
+ *
+ * Copyright 1994 - 2008  David A. Bagley, bagleyd@tux.org
+ *
+ * All rights reserved.
+ *
+ * Permission to use, copy, modify, and distribute this software and
+ * its documentation for any purpose and without fee is hereby granted,
+ * provided that the above copyright notice appear in all copies and
+ * that both that copyright notice and this permission notice appear in
+ * supporting documentation, and that the name of the author not be
+ * used in advertising or publicity pertaining to distribution of the
+ * software without specific, written prior permission.
+ *
+ * This program is distributed in the hope that it will be "useful",
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ */
 
 /* Private header file for Pyraminx */
 
@@ -33,40 +28,40 @@
 #include "Pyraminx.h"
 
 #ifdef WINVER
-extern void DestroyPuzzle(HBRUSH brush);
-extern void ResizePuzzle(PyraminxWidget w);
-extern void SizePuzzle(PyraminxWidget w);
-extern void InitializePuzzle(PyraminxWidget w, HBRUSH brush);
-extern void ExposePuzzle(PyraminxWidget w);
-extern void HidePuzzle(PyraminxWidget w);
-extern void SelectPuzzle(PyraminxWidget w,
+extern void destroyPuzzle(HBRUSH brush);
+extern void resizePuzzle(PyraminxWidget w);
+extern void sizePuzzle(PyraminxWidget w);
+extern void initializePuzzle(PyraminxWidget w, HBRUSH brush);
+extern void exposePuzzle(PyraminxWidget w);
+extern void hidePuzzle(PyraminxWidget w);
+extern void selectPuzzle(PyraminxWidget w,
 	const int x, const int y, const int control);
-extern void ReleasePuzzle(PyraminxWidget w,
+extern void releasePuzzle(PyraminxWidget w,
 	const int x, const int y, const int shift, const int control);
-extern void PracticePuzzle(PyraminxWidget w);
-extern void RandomizePuzzle(PyraminxWidget w);
-extern void GetPuzzle(PyraminxWidget w);
-extern void WritePuzzle(PyraminxWidget w);
-extern void UndoPuzzle(PyraminxWidget w);
-extern void RedoPuzzle(PyraminxWidget w);
-extern void ClearPuzzle(PyraminxWidget w);
-extern void SolvePuzzle(PyraminxWidget w);
-extern void IncrementPuzzle(PyraminxWidget w);
-extern Boolean DecrementPuzzle(PyraminxWidget w);
-extern void OrientizePuzzle(PyraminxWidget w);
-extern void StickyModePuzzle(PyraminxWidget w);
-extern void PeriodModePuzzle(PyraminxWidget w, const int mode);
-extern void Period2ModePuzzle(PyraminxWidget w);
-extern void Period3ModePuzzle(PyraminxWidget w);
-extern void BothModePuzzle(PyraminxWidget w);
-extern void SpeedPuzzle(PyraminxWidget w);
-extern void SlowPuzzle(PyraminxWidget w);
-extern void SoundPuzzle(PyraminxWidget w);
-extern void EnterPuzzle(PyraminxWidget w);
-extern void LeavePuzzle(PyraminxWidget w);
-extern void MovePuzzleInput(PyraminxWidget w,
+extern void practicePuzzle(PyraminxWidget w);
+extern void randomizePuzzle(PyraminxWidget w);
+extern void getPuzzle(PyraminxWidget w);
+extern void writePuzzle(PyraminxWidget w);
+extern void undoPuzzle(PyraminxWidget w);
+extern void redoPuzzle(PyraminxWidget w);
+extern void clearPuzzle(PyraminxWidget w);
+extern void solvePuzzle(PyraminxWidget w);
+extern void incrementPuzzle(PyraminxWidget w);
+extern Boolean decrementPuzzle(PyraminxWidget w);
+extern void orientizePuzzle(PyraminxWidget w);
+extern void stickymodePuzzle(PyraminxWidget w);
+extern void periodmodePuzzle(PyraminxWidget w, const int mode);
+extern void period2ModePuzzle(PyraminxWidget w);
+extern void period3modePuzzle(PyraminxWidget w);
+extern void bothmodePuzzle(PyraminxWidget w);
+extern void speedUpPuzzle(PyraminxWidget w);
+extern void slowDownPuzzle(PyraminxWidget w);
+extern void toggleSoundPuzzle(PyraminxWidget w);
+extern void enterPuzzle(PyraminxWidget w);
+extern void leavePuzzle(PyraminxWidget w);
+extern void movePuzzleInput(PyraminxWidget w,
 	int x, int y, int direction, int shift, int control);
-extern int  MovePuzzleDir(PyraminxWidget w, const int direction);
+extern int  movePuzzleDir(PyraminxWidget w, const int direction);
 
 #else
 
@@ -107,16 +102,16 @@ extern PyraminxClassRec pyraminxClassRec;
 #define MAX_SIDES (MAX_FACES/MAX_VIEWS)
 #define MAX_ORIENT (3*MAX_SIDES)
 
-typedef struct _MoveRecord {
+typedef struct _moveRecord {
 #if 0
 	int face, direction, style, control;
 #endif
 	unsigned short int packed;  /* This makes assumptions on the data. */
 	int position;		    /* Do not make assumptions on this one. */
-} MoveRecord;
+} moveRecord;
 
 typedef struct _MoveStack {
-	MoveRecord move;
+	moveRecord move;
 	struct _MoveStack *previous, *next;
 } MoveStack;
 
@@ -170,14 +165,14 @@ typedef struct _PyraminxRec {
 
 extern PyraminxLoc *startLoc[MAX_FACES];
 extern void setPuzzle(PyraminxWidget w, int reason);
-extern void MovePuzzle(PyraminxWidget w, int face, int position,
+extern void movePuzzle(PyraminxWidget w, int face, int position,
 	int direction, int style, int control);
-extern void MovePuzzleDelay(PyraminxWidget w, int face, int position,
+extern void movePuzzleDelay(PyraminxWidget w, int face, int position,
 	int direction, int style, int control);
 
-extern void SolveSomePieces(PyraminxWidget w);
-extern void DrawAllPieces(PyraminxWidget w);
-extern Boolean CheckSolved(PyraminxWidget w);
+extern void solveSomePieces(PyraminxWidget w);
+extern void drawAllPieces(PyraminxWidget w);
+extern Boolean checkSolved(PyraminxWidget w);
 extern void newMoves(PyraminxStack *s);
 extern void deleteMoves(PyraminxStack *s);
 extern void setMove(PyraminxStack *s,
