@@ -1,27 +1,22 @@
-/*-
-# X-BASED RUBIK'S CUBE(tm)
-#
-#  Rubik.c
-#
-###
-#
-#  Copyright (c) 1994 - 2007	David A. Bagley, bagleyd@tux.org
-#
-#                   All Rights Reserved
-#
-#  Permission to use, copy, modify, and distribute this software and
-#  its documentation for any purpose and without fee is hereby granted,
-#  provided that the above copyright notice appear in all copies and
-#  that both that copyright notice and this permission notice appear in
-#  supporting documentation, and that the name of the author not be
-#  used in advertising or publicity pertaining to distribution of the
-#  software without specific, written prior permission.
-#
-#  This program is distributed in the hope that it will be "playable",
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-#
-*/
+/*
+ * @(#)Rubik.c
+ *
+ * Copyright 1994 - 2008  David A. Bagley, bagleyd@tux.org
+ *
+ * All rights reserved.
+ *
+ * Permission to use, copy, modify, and distribute this software and
+ * its documentation for any purpose and without fee is hereby granted,
+ * provided that the above copyright notice appear in all copies and
+ * that both that copyright notice and this permission notice appear in
+ * supporting documentation, and that the name of the author not be
+ * used in advertising or publicity pertaining to distribution of the
+ * software without specific, written prior permission.
+ *
+ * This program is distributed in the hope that it will be "useful",
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ */
 
 /* Methods file for Rubik */
 
@@ -67,9 +62,9 @@ static const char faceColorChar[MAX_FACES] =
 #endif
 #endif
 
-static Boolean SetValuesPuzzle(Widget current, Widget request, Widget renew);
-static void DestroyPuzzle(Widget old);
-static void InitializePuzzle(Widget request, Widget renew);
+static Boolean setValuesPuzzle(Widget current, Widget request, Widget renew);
+static void destroyPuzzle(Widget old);
+static void initializePuzzle(Widget request, Widget renew);
 
 RubikClassRec rubikClassRec =
 {
@@ -80,7 +75,7 @@ RubikClassRec rubikClassRec =
 		NULL,		/* class initialize */
 		NULL,		/* class part initialize */
 		FALSE,		/* class inited */
-		(XtInitProc) InitializePuzzle,	/* initialize */
+		(XtInitProc) initializePuzzle,	/* initialize */
 		NULL,		/* initialize hook */
 		XtInheritRealize,	/* realize */
 		NULL,		/* actions */
@@ -92,10 +87,10 @@ RubikClassRec rubikClassRec =
 		TRUE,		/* compress exposure */
 		TRUE,		/* compress enterleave */
 		TRUE,		/* visible interest */
-		(XtWidgetProc) DestroyPuzzle,	/* destroy */
+		(XtWidgetProc) destroyPuzzle,	/* destroy */
 		NULL,		/* resize */
 		NULL,		/* expose */
-		(XtSetValuesFunc) SetValuesPuzzle,	/* set values */
+		(XtSetValuesFunc) setValuesPuzzle,	/* set values */
 		NULL,		/* set values hook */
 		XtInheritSetValuesAlmost,	/* set values almost */
 		NULL,		/* get values hook */
@@ -244,7 +239,7 @@ static RubikStack undo = {NULL, NULL, NULL, 0};
 static RubikStack redo = {NULL, NULL, NULL, 0};
 
 static void
-CheckPieces(RubikWidget w)
+checkPieces(RubikWidget w)
 {
 	char *buf1 = NULL, *buf2 = NULL;
 
@@ -365,7 +360,7 @@ checkFaceSquare(RubikWidget w, int face)
 }
 
 Boolean
-CheckSolved(const RubikWidget w, Boolean rotation)
+checkSolved(const RubikWidget w, Boolean rotation)
 {
 	int face, position;
 	RubikLoc test = {0, FALSE};
@@ -386,7 +381,7 @@ CheckSolved(const RubikWidget w, Boolean rotation)
 
 #ifdef DEBUG
 void
-PrintCube(RubikWidget w)
+printCube(RubikWidget w)
 {
 	int face, position, sizeOfRow, sizeOfColumn;
 
@@ -404,7 +399,7 @@ PrintCube(RubikWidget w)
 }
 
 void
-PrintRow(RubikWidget w, int orient, int size)
+printRow(RubikWidget w, int orient, int size)
 {
 	int i;
 
@@ -418,51 +413,51 @@ PrintRow(RubikWidget w, int orient, int size)
 #endif
 
 static void
-DrawSquare(const RubikWidget w, const int face, const int position, const int offset)
+drawSquare(const RubikWidget w, const int face, const int position, const int offset)
 {
 	if (w->rubik.dim == 2)
-		DrawSquare2D((Rubik2DWidget) w, face, position, offset);
+		drawSquare2D((Rubik2DWidget) w, face, position, offset);
 	else if (w->rubik.dim == 3)
-		DrawSquare3D((Rubik3DWidget) w, face, position, offset);
+		drawSquare3D((Rubik3DWidget) w, face, position, offset);
 }
 
 void
-DrawAllPieces(const RubikWidget w)
+drawAllPieces(const RubikWidget w)
 {
 	int face, position;
 
 #ifdef HAVE_OPENGL
 	if (w->rubik.dim == 4) {
-		DrawAllPiecesGL((RubikGLWidget) w);
+		drawAllPiecesGL((RubikGLWidget) w);
 		return;
 	}
 #endif
 	for (face = 0; face < MAX_FACES; face++)
 		for (position = 0; position < sizeFace(w, face); position++)
-			DrawSquare(w, face, position, FALSE);
+			drawSquare(w, face, position, FALSE);
 }
 
 static void
-DrawFrame(const RubikWidget w, const Boolean focus)
+drawFrame(const RubikWidget w, const Boolean focus)
 {
 	if (w->rubik.dim == 2)
-		DrawFrame2D((Rubik2DWidget) w, focus);
+		drawFrame2D((Rubik2DWidget) w, focus);
 	else if (w->rubik.dim == 3)
-		DrawFrame3D((Rubik3DWidget) w, focus);
+		drawFrame3D((Rubik3DWidget) w, focus);
 #ifdef HAVE_OPENGL
 	else if (w->rubik.dim == 4)
-		DrawFrameGL((RubikGLWidget) w, focus);
+		drawFrameGL((RubikGLWidget) w, focus);
 #endif
 }
 
 static void
-MoveNoPieces(RubikWidget w)
+moveNoPieces(RubikWidget w)
 {
 	setPuzzle(w, ACTION_ILLEGAL);
 }
 
 static void
-RotateFace(RubikWidget w, int face, int direction)
+rotateFace(RubikWidget w, int face, int direction)
 {
 	int position, i, j, sizeOfRow, sizeOfColumn, sizeOnPlane;
 	RubikLoc *faceLoc = NULL;
@@ -493,15 +488,14 @@ RotateFace(RubikWidget w, int face, int direction)
 		w->rubik.cubeLoc[face][position].rotation =
 			(w->rubik.cubeLoc[face][position].rotation +
 			 direction - MAX_ORIENT) % MAX_ORIENT;
-		DrawSquare(w, face, position, FALSE);
+		drawSquare(w, face, position, FALSE);
 	}
 	if (faceLoc != NULL)
 		free(faceLoc);
 }
 
-/* Yeah this is big and ugly */
 static void
-SlideRC(RubikWidget w, int face, int direction, int h, int sizeOnOppAxis,
+slideRC(RubikWidget w, int face, int direction, int h, int sizeOnOppAxis,
 	int *newFace, int *newDirection, int *newH,
 	int *rotate, Boolean *reverse)
 {
@@ -541,7 +535,7 @@ SlideRC(RubikWidget w, int face, int direction, int h, int sizeOnOppAxis,
 		{
 			char *buf;
 
-			intCat(&buf, "SlideRC: rotate ", *rotate);
+			intCat(&buf, "slideRC: rotate ", *rotate);
 			DISPLAY_WARNING(buf);
 			free(buf);
 		}
@@ -549,7 +543,7 @@ SlideRC(RubikWidget w, int face, int direction, int h, int sizeOnOppAxis,
 }
 
 static void
-ReadRC(RubikWidget w, int face, int dir, int h, int orient, int size)
+readRC(RubikWidget w, int face, int dir, int h, int orient, int size)
 {
 	int g, sizeOfRow;
 
@@ -565,7 +559,7 @@ ReadRC(RubikWidget w, int face, int dir, int h, int orient, int size)
 }
 
 static void
-RotateRC(RubikWidget w, int rotate, int orient, int size)
+rotateRC(RubikWidget w, int rotate, int orient, int size)
 {
 	int g;
 
@@ -575,7 +569,7 @@ RotateRC(RubikWidget w, int rotate, int orient, int size)
 }
 
 static void
-ReverseRC(RubikWidget w, int orient, int size)
+reverseRC(RubikWidget w, int orient, int size)
 {
 	int g;
 	RubikLoc temp;
@@ -588,7 +582,7 @@ ReverseRC(RubikWidget w, int orient, int size)
 }
 
 static void
-WriteRC(RubikWidget w, int face, int dir, int h, int orient, int size)
+writeRC(RubikWidget w, int face, int dir, int h, int orient, int size)
 {
 	int g, position, sizeOfRow;
 
@@ -597,37 +591,38 @@ WriteRC(RubikWidget w, int face, int dir, int h, int orient, int size)
 		for (g = 0; g < size; g++) {
 			position = g * sizeOfRow + h;
 			w->rubik.cubeLoc[face][position] = w->rubik.rowLoc[orient][g];
-			DrawSquare(w, face, position, FALSE);
+			drawSquare(w, face, position, FALSE);
 		}
 	} else {		/* dir == RIGHT || dir == LEFT */
 		for (g = 0; g < size; g++) {
 			position = h * sizeOfRow + g;
 			w->rubik.cubeLoc[face][position] = w->rubik.rowLoc[orient][g];
-			DrawSquare(w, face, position, FALSE);
+			drawSquare(w, face, position, FALSE);
 		}
 	}
 }
 
 static void
-MovePieces(RubikWidget w, int face, int position, int direction,
+movePieces(RubikWidget w, int face, int position, int direction,
 		Boolean control, int fast)
 {
+	int dir = direction, oldFace = face;
 	int newFace, newDirection, rotate;
 	int h, k, newH = 0;
 	int i, j, sizeOfRow, sizeOfColumn, sizeOnAxis, sizeOnOppAxis;
-	Boolean reverse = FALSE;
+	Boolean reverse = False;
 
 #ifdef HAVE_OPENGL
 	if (!control && fast != INSTANT && w->rubik.dim == 4) {
-		MovePiecesGL((RubikGLWidget) w, face, position, direction,
+		movePiecesGL((RubikGLWidget) w, oldFace, position, dir,
 			control, fast);
 	}
 #endif
-	faceSizes(w, face, &sizeOfRow, &sizeOfColumn);
+	faceSizes(w, oldFace, &sizeOfRow, &sizeOfColumn);
 	i = position % sizeOfRow;
 	j = position / sizeOfRow;
-	h = (direction == TOP || direction == BOTTOM) ? i : j;
-	if (direction == TOP || direction == BOTTOM) {
+	h = (dir == TOP || dir == BOTTOM) ? i : j;
+	if (dir == TOP || dir == BOTTOM) {
 		sizeOnAxis = sizeOfColumn;
 		sizeOnOppAxis = sizeOfRow;
 	} else {
@@ -637,91 +632,91 @@ MovePieces(RubikWidget w, int face, int position, int direction,
 	/* rotate sides CW or CCW or HALF */
 
 	if (h == sizeOnOppAxis - 1) {
-		newDirection = (direction == TOP || direction == BOTTOM) ?
+		newDirection = (dir == TOP || dir == BOTTOM) ?
 			TOP : RIGHT;
 		if (w->rubik.degreeTurn == 180)
-			RotateFace(w, rowToRotate[face][newDirection], HALF);
-		else if (direction == TOP || direction == RIGHT)
-			RotateFace(w, rowToRotate[face][newDirection], CW);
-		else		/* direction == BOTTOM || direction == LEFT */
-			RotateFace(w, rowToRotate[face][newDirection], CCW);
+			rotateFace(w, rowToRotate[oldFace][newDirection], HALF);
+		else if (dir == TOP || dir == RIGHT)
+			rotateFace(w, rowToRotate[oldFace][newDirection], CW);
+		else		/* dir == BOTTOM || dir == LEFT */
+			rotateFace(w, rowToRotate[oldFace][newDirection], CCW);
 	}
 	if (h == 0) {
-		newDirection = (direction == TOP || direction == BOTTOM) ?
+		newDirection = (dir == TOP || dir == BOTTOM) ?
 			BOTTOM : LEFT;
 		if (w->rubik.degreeTurn == 180)
-			RotateFace(w, rowToRotate[face][newDirection], HALF);
-		else if (direction == TOP || direction == RIGHT)
-			RotateFace(w, rowToRotate[face][newDirection], CCW);
-		else		/* direction == BOTTOM || direction == LEFT */
-			RotateFace(w, rowToRotate[face][newDirection], CW);
+			rotateFace(w, rowToRotate[oldFace][newDirection], HALF);
+		else if (dir == TOP || dir == RIGHT)
+			rotateFace(w, rowToRotate[oldFace][newDirection], CCW);
+		else		/* dir == BOTTOM || dir == LEFT */
+			rotateFace(w, rowToRotate[oldFace][newDirection], CW);
 	}
 	/* Slide rows */
-	ReadRC(w, face, direction, h, 0, sizeOnAxis);
+	readRC(w, oldFace, dir, h, 0, sizeOnAxis);
 	if (w->rubik.degreeTurn == 180) {
 		int sizeOnDepthAxis;
 
-		SlideRC(w, face, direction, h, sizeOnOppAxis,
+		slideRC(w, oldFace, dir, h, sizeOnOppAxis,
 			&newFace, &newDirection, &newH, &rotate, &reverse);
 		sizeOnDepthAxis = sizeFace(w, newFace) / sizeOnOppAxis;
-		ReadRC(w, newFace, newDirection, newH, 1, sizeOnDepthAxis);
-		RotateRC(w, rotate, 0, sizeOnAxis);
-		if (reverse == True)
-			ReverseRC(w, 0, sizeOnAxis);
-		face = newFace;
-		direction = newDirection;
+		readRC(w, newFace, newDirection, newH, 1, sizeOnDepthAxis);
+		rotateRC(w, rotate, 0, sizeOnAxis);
+		if (reverse)
+			reverseRC(w, 0, sizeOnAxis);
+		oldFace = newFace;
+		dir = newDirection;
 		h = newH;
 		for (k = 2; k <= MAX_ORIENT + 1; k++) {
-			SlideRC(w, face, direction, h, sizeOnOppAxis,
+			slideRC(w, oldFace, dir, h, sizeOnOppAxis,
 			  &newFace, &newDirection, &newH, &rotate, &reverse);
 			if (k != MAX_ORIENT && k != MAX_ORIENT + 1)
-				ReadRC(w, newFace, newDirection, newH, k,
-				     (k % 2) ? sizeOnDepthAxis : sizeOnAxis);
-			RotateRC(w, rotate, k - 2,
-				 (k % 2) ? sizeOnDepthAxis : sizeOnAxis);
+				readRC(w, newFace, newDirection, newH, k,
+				     ((k & 1) == 1) ? sizeOnDepthAxis : sizeOnAxis);
+			rotateRC(w, rotate, k - 2,
+				 ((k & 1) == 1) ? sizeOnDepthAxis : sizeOnAxis);
 			if (k != MAX_ORIENT + 1)
-				RotateRC(w, rotate, k - 1,
-				     (k % 2) ? sizeOnAxis : sizeOnDepthAxis);
-			if (reverse == True) {
-				ReverseRC(w, k - 2,
-				     (k % 2) ? sizeOnDepthAxis : sizeOnAxis);
+				rotateRC(w, rotate, k - 1,
+				     ((k & 1) == 1) ? sizeOnAxis : sizeOnDepthAxis);
+			if (reverse) {
+				reverseRC(w, k - 2,
+				     ((k & 1) == 1) ? sizeOnDepthAxis : sizeOnAxis);
 				if (k != MAX_ORIENT + 1)
-					ReverseRC(w, k - 1,
-						(k % 2) ? sizeOnAxis : sizeOnDepthAxis);
+					reverseRC(w, k - 1,
+						((k & 1) == 1) ? sizeOnAxis : sizeOnDepthAxis);
 			}
-			WriteRC(w, newFace, newDirection, newH, k - 2,
-				(k % 2) ? sizeOnDepthAxis : sizeOnAxis);
-			face = newFace;
-			direction = newDirection;
+			writeRC(w, newFace, newDirection, newH, k - 2,
+				((k & 1) == 1) ? sizeOnDepthAxis : sizeOnAxis);
+			oldFace = newFace;
+			dir = newDirection;
 			h = newH;
 		}
 	} else {
 		for (k = 1; k <= MAX_ORIENT; k++) {
-			SlideRC(w, face, direction, h, sizeOnOppAxis,
+			slideRC(w, oldFace, dir, h, sizeOnOppAxis,
 			  &newFace, &newDirection, &newH, &rotate, &reverse);
 			if (k != MAX_ORIENT)
-				ReadRC(w, newFace, newDirection, newH, k, sizeOnAxis);
-			RotateRC(w, rotate, k - 1, sizeOnAxis);
-			if (reverse == TRUE)
-				ReverseRC(w, k - 1, sizeOnAxis);
-			WriteRC(w, newFace, newDirection, newH, k - 1, sizeOnAxis);
-			face = newFace;
-			direction = newDirection;
+				readRC(w, newFace, newDirection, newH, k, sizeOnAxis);
+			rotateRC(w, rotate, k - 1, sizeOnAxis);
+			if (reverse)
+				reverseRC(w, k - 1, sizeOnAxis);
+			writeRC(w, newFace, newDirection, newH, k - 1, sizeOnAxis);
+			oldFace = newFace;
+			dir = newDirection;
 			h = newH;
 		}
 	}
 #ifdef HAVE_OPENGL
 	if (!control && fast == INSTANT && w->rubik.dim == 4) {
-		DrawAllPiecesGL((RubikGLWidget) w);
+		drawAllPiecesGL((RubikGLWidget) w);
 	}
 #endif
 #ifdef DEBUG
-	PrintCube(w);
+	printCube(w);
 #endif
 }
 
 static Boolean
-MoveAllPieces(RubikWidget w, const int face, const int position,
+moveAllPieces(RubikWidget w, const int face, const int position,
 		const int direction, const Boolean control, int fast)
 {
 	int sizeOfRow, sizeOfColumn, sizeOnOppAxis, factor;
@@ -745,29 +740,29 @@ MoveAllPieces(RubikWidget w, const int face, const int position,
 
 #ifdef HAVE_OPENGL
 		if (newControl && w->rubik.dim == 4) {
-			MovePiecesGL((RubikGLWidget) w, face, position,
+			movePiecesGL((RubikGLWidget) w, face, position,
 				direction, newControl, fast);
 			newFast = INSTANT;
 		}
 #endif
 		for (k = 0; k < sizeOnOppAxis; k++) {
 			newPosition = k * factor;
-			MovePieces(w, face, newPosition, direction,
+			movePieces(w, face, newPosition, direction,
 				newControl, newFast);
 		}
 	} else {
 		newControl = False;
-		MovePieces(w, face, position, direction, control, fast);
+		movePieces(w, face, position, direction, control, fast);
 	}
 	return newControl;
 }
 
 void
-MovePuzzle(RubikWidget w, const int face, const int position,
+movePuzzle(RubikWidget w, const int face, const int position,
 		const int direction, const Boolean control, int fast)
 {
 	setPuzzleMove(w, ACTION_MOVED, face, position, direction,
-		MoveAllPieces(w, face, position, direction, control, fast),
+		moveAllPieces(w, face, position, direction, control, fast),
 		fast);
 #ifdef USE_SOUND
 	if (w->rubik.sound) {
@@ -779,27 +774,27 @@ MovePuzzle(RubikWidget w, const int face, const int position,
 }
 
 void
-MovePuzzleDelay(RubikWidget w, const int face, const int position,
+movePuzzleDelay(RubikWidget w, const int face, const int position,
 		const int direction, const Boolean control)
 {
-	MovePuzzle(w, face, position, direction, control, NORMAL);
+	movePuzzle(w, face, position, direction, control, NORMAL);
 	Sleep((unsigned int) w->rubik.delay);
 }
 
 static Boolean
-SelectPieces(RubikWidget w, const int x, const int y, int *face, int *position)
+selectPieces(RubikWidget w, const int x, const int y, int *face, int *position)
 {
 	if (w->rubik.dim == 2)
-		return SelectPieces2D((Rubik2DWidget) w, x, y,
+		return selectPieces2D((Rubik2DWidget) w, x, y,
 					face, position);
 	else if (w->rubik.dim == 3)
-		return SelectPieces3D((Rubik3DWidget) w, x, y,
+		return selectPieces3D((Rubik3DWidget) w, x, y,
 					face, position);
 	return False;
 }
 
 static int
-CheckMoveDir(RubikWidget w, int face, int position1, int position2,
+checkMoveDir(RubikWidget w, int face, int position1, int position2,
 		int *direction)
 {
 	int count = 0;
@@ -823,43 +818,43 @@ CheckMoveDir(RubikWidget w, int face, int position1, int position2,
 
 
 static Boolean
-NarrowSelection(RubikWidget w, int *face, int *position, int *direction)
+narrowSelection(RubikWidget w, int *face, int *position, int *direction)
 {
 	if (w->rubik.dim == 2)
-		return NarrowSelection2D((Rubik2DWidget) w, face, position, direction);
+		return narrowSelection2D((Rubik2DWidget) w, face, position, direction);
 	else if (w->rubik.dim == 3)
-		return NarrowSelection3D((Rubik3DWidget) w, face, position, direction);
+		return narrowSelection3D((Rubik3DWidget) w, face, position, direction);
 	return False;
 }
 
 static Boolean
-PositionPieces(RubikWidget w, int x, int y, int *face, int *position, int *direction)
+positionPieces(RubikWidget w, int x, int y, int *face, int *position, int *direction)
 {
-	if (!SelectPieces(w, x, y, face, position))
+	if (!selectPieces(w, x, y, face, position))
 		return False;
-	return NarrowSelection(w, face, position, direction);
+	return narrowSelection(w, face, position, direction);
 }
 
 void
-MovePuzzleInput(RubikWidget w, int x, int y, int direction, int control)
+movePuzzleInput(RubikWidget w, int x, int y, int direction, int control)
 {
 	int face, position;
 
-	if (!w->rubik.practice && !control && CheckSolved(w, w->rubik.orient)) {
-		MoveNoPieces(w);
+	if (!w->rubik.practice && !control && checkSolved(w, w->rubik.orient)) {
+		moveNoPieces(w);
 		return;
 	}
-	if (!PositionPieces(w, x, y, &face, &position, &direction))
+	if (!positionPieces(w, x, y, &face, &position, &direction))
 		return;
 	control = (control) ? 1 : 0;
-	MovePuzzle(w, face, position, direction, control, NORMAL);
-	if (!control && CheckSolved(w, w->rubik.orient)) {
+	movePuzzle(w, face, position, direction, control, NORMAL);
+	if (!control && checkSolved(w, w->rubik.orient)) {
 		setPuzzle(w, ACTION_SOLVED);
 	}
 }
 
 void
-ResetPieces(RubikWidget w)
+resetPieces(RubikWidget w)
 {
 	int face, position, orient, sizeOfFace;
 
@@ -898,7 +893,7 @@ ResetPieces(RubikWidget w)
 }
 
 static void
-GetPieces(RubikWidget w)
+getPieces(RubikWidget w)
 {
 	FILE *fp;
 	int c, i, sizex, sizey, sizez, orient, practice, moves;
@@ -1019,7 +1014,7 @@ GetPieces(RubikWidget w)
 		setPuzzle(w, ACTION_PRACTICE);
 	}
 #ifdef WINVER
-	ResetPieces(w);
+	resetPieces(w);
 #endif
 	while ((c = getc(fp)) != EOF && c != SYMBOL);
 	(void) fscanf(fp, "%d", &moves);
@@ -1039,7 +1034,7 @@ GetPieces(RubikWidget w)
 }
 
 static void
-WritePieces(RubikWidget w)
+writePieces(RubikWidget w)
 {
 	FILE *fp;
 	char *buf1 = NULL, *buf2 = NULL;
@@ -1098,7 +1093,7 @@ WritePieces(RubikWidget w)
 }
 
 static void
-UndoPieces(RubikWidget w)
+undoPieces(RubikWidget w)
 {
 	if (madeMoves(&undo)) {
 		int face, position, direction, control;
@@ -1111,16 +1106,16 @@ UndoPieces(RubikWidget w)
 			(direction + MAX_ORIENT / 2) % MAX_ORIENT :
 			3 * MAX_ORIENT - direction;
 		setPuzzleMove(w, ACTION_UNDO, face, position, direction,
-			MoveAllPieces(w, face, position, direction, control,
+			moveAllPieces(w, face, position, direction, control,
 			DOUBLE), DOUBLE);
-		if (!control && CheckSolved(w, w->rubik.orient)) {
+		if (!control && checkSolved(w, w->rubik.orient)) {
 			setPuzzle(w, ACTION_SOLVED);
 		}
 	}
 }
 
 static void
-RedoPieces(RubikWidget w)
+redoPieces(RubikWidget w)
 {
 	if (madeMoves(&redo)) {
 		int face, position, direction, control;
@@ -1130,28 +1125,28 @@ RedoPieces(RubikWidget w)
 		setMove(&undo,
 			face, position, direction, control);
 		setPuzzleMove(w, ACTION_REDO, face, position, direction,
-			MoveAllPieces(w, face, position, direction, control,
+			moveAllPieces(w, face, position, direction, control,
 			DOUBLE), DOUBLE);
-		if (!control && CheckSolved(w, w->rubik.orient)) {
+		if (!control && checkSolved(w, w->rubik.orient)) {
 			setPuzzle(w, ACTION_SOLVED);
 		}
 	}
 }
 
 static void
-ClearPieces(RubikWidget w)
+clearPieces(RubikWidget w)
 {
 	setPuzzle(w, ACTION_CLEAR);
 }
 
 static void
-PracticePieces(RubikWidget w)
+practicePieces(RubikWidget w)
 {
 	setPuzzle(w, ACTION_PRACTICE);
 }
 
 static void
-RandomizePieces(RubikWidget w)
+randomizePieces(RubikWidget w)
 {
 	int face, position, direction;
 	int big = w->rubik.sizex * w->rubik.sizey * w->rubik.sizez *
@@ -1161,7 +1156,7 @@ RandomizePieces(RubikWidget w)
 	if (big > 100)
 		big = 100;
 	if (w->rubik.practice)
-		PracticePieces(w);
+		practicePieces(w);
 	setPuzzle(w, ACTION_RESET);
 #ifdef DEBUG
 	big = 3;
@@ -1170,37 +1165,37 @@ RandomizePieces(RubikWidget w)
 		face = NRAND(MAX_FACES);
 		position = NRAND(sizeFace(w, face));
 		direction = NRAND(MAX_ORIENT);
-		MovePuzzle(w, face, position, direction, FALSE, INSTANT);
+		movePuzzle(w, face, position, direction, FALSE, INSTANT);
 	}
 	flushMoves(w, &undo, TRUE);
 	flushMoves(w, &redo, FALSE);
 	setPuzzle(w, ACTION_RANDOMIZE);
-	if (CheckSolved(w, w->rubik.orient)) {
+	if (checkSolved(w, w->rubik.orient)) {
 		setPuzzle(w, ACTION_SOLVED);
 	}
 }
 
 static void
-SolvePieces(RubikWidget w)
+solvePieces(RubikWidget w)
 {
-	if (CheckSolved(w, w->rubik.orient))
+	if (checkSolved(w, w->rubik.orient))
 		return;
 	if ((w->rubik.sizex == 2 && w->rubik.sizey == 2 && w->rubik.sizez == 2) ||
 	    (w->rubik.sizex == 3 && w->rubik.sizey == 3 && w->rubik.sizez == 3))
-		SolveSomePieces(w);
+		solveSomePieces(w);
 	else {
 		setPuzzle(w, ACTION_SOLVE_MESSAGE);
 	}
 }
 
 static void
-OrientizePieces(RubikWidget w)
+orientizePieces(RubikWidget w)
 {
 	setPuzzle(w, ACTION_ORIENTIZE);
 }
 
 static void
-IncrementPieces(RubikWidget w)
+incrementPieces(RubikWidget w)
 {
 	setPuzzle(w, ACTION_INCX);
 	setPuzzle(w, ACTION_INCY);
@@ -1208,7 +1203,7 @@ IncrementPieces(RubikWidget w)
 }
 
 static void
-DecrementPieces(RubikWidget w)
+decrementPieces(RubikWidget w)
 {
 	if (w->rubik.sizex > MIN_FACETS) {
 		setPuzzle(w, ACTION_DECX);
@@ -1222,13 +1217,13 @@ DecrementPieces(RubikWidget w)
 }
 
 static void
-ViewPieces(RubikWidget w)
+viewPieces(RubikWidget w)
 {
 	setPuzzle(w, ACTION_VIEW);
 }
 
 static void
-SpeedPieces(RubikWidget w)
+speedPieces(RubikWidget w)
 {
 	w->rubik.delay -= 5;
 	if (w->rubik.delay < 0)
@@ -1239,7 +1234,7 @@ SpeedPieces(RubikWidget w)
 }
 
 static void
-SlowPieces(RubikWidget w)
+slowPieces(RubikWidget w)
 {
 	w->rubik.delay += 5;
 #ifdef HAVE_MOTIF
@@ -1248,14 +1243,14 @@ SlowPieces(RubikWidget w)
 }
 
 static void
-SoundPieces(RubikWidget w)
+soundPieces(RubikWidget w)
 {
 	w->rubik.sound = !w->rubik.sound;
 }
 
 #ifdef WINVER
 static void
-SetValuesPuzzle(RubikWidget w)
+setValuesPuzzle(RubikWidget w)
 {
 	struct tagColor {
 		int red, green, blue;
@@ -1323,7 +1318,7 @@ SetValuesPuzzle(RubikWidget w)
 }
 
 void
-DestroyPuzzle(HBRUSH brush)
+destroyPuzzle(HBRUSH brush)
 {
 	deleteMoves(&undo);
 	deleteMoves(&redo);
@@ -1332,41 +1327,41 @@ DestroyPuzzle(HBRUSH brush)
 }
 
 void
-ResizePuzzle(RubikWidget w)
+resizePuzzle(RubikWidget w)
 {
 	if (w->rubik.dim == 2)
-		ResizePuzzle2D((Rubik2DWidget) w);
+		resizePuzzle2D((Rubik2DWidget) w);
 	else if (w->rubik.dim == 3)
-		ResizePuzzle3D((Rubik3DWidget) w);
+		resizePuzzle3D((Rubik3DWidget) w);
 #ifdef HAVE_OPENGL
 	else if (w->rubik.dim == 4)
-		ResizePuzzleGL((RubikGLWidget) w);
+		resizePuzzleGL((RubikGLWidget) w);
 #endif
 }
 
 void
-SizePuzzle(RubikWidget w)
+sizePuzzle(RubikWidget w)
 {
-	ResetPieces(w);
-	ResizePuzzle(w);
+	resetPieces(w);
+	resizePuzzle(w);
 }
 
 void
-ExposePuzzle(RubikWidget w)
+exposePuzzle(RubikWidget w)
 {
 	if (w->rubik.dim == 2)
-		ExposePuzzle2D((Rubik2DWidget) w);
+		exposePuzzle2D((Rubik2DWidget) w);
 	else if (w->rubik.dim == 3)
-		ExposePuzzle3D((Rubik3DWidget) w);
+		exposePuzzle3D((Rubik3DWidget) w);
 #ifdef HAVE_OPENGL
 	else if (w->rubik.dim == 4)
-		ExposePuzzleGL((RubikGLWidget) w);
+		exposePuzzleGL((RubikGLWidget) w);
 #endif
 }
 
 #else
 static void
-GetColor(RubikWidget w, int face)
+getColor(RubikWidget w, int face)
 {
 	XGCValues values;
 	XtGCMask valueMask;
@@ -1421,7 +1416,7 @@ GetColor(RubikWidget w, int face)
 }
 
 void
-SetAllColors(RubikWidget w)
+setAllColors(RubikWidget w)
 {
 	XGCValues values;
 	XtGCMask valueMask;
@@ -1470,20 +1465,20 @@ SetAllColors(RubikWidget w)
 		XtReleaseGC((Widget) w, w->rubik.borderGC);
 	w->rubik.borderGC = XtGetGC((Widget) w, valueMask, &values);
 	for (face = 0; face < MAX_FACES; face++)
-		GetColor(w, face);
+		getColor(w, face);
 	if (w->rubik.fontInfo)
 		XSetFont(XtDisplay(w), w->rubik.borderGC,
 			w->rubik.fontInfo->fid);
 }
 
 static Boolean
-SetValuesPuzzle(Widget current, Widget request, Widget renew)
+setValuesPuzzle(Widget current, Widget request, Widget renew)
 {
 	RubikWidget c = (RubikWidget) current, w = (RubikWidget) renew;
 	Boolean redraw = False, setColors = False;
 	int face;
 
-	CheckPieces(w);
+	checkPieces(w);
 	for (face = 0; face < MAX_FACES; face++) {
 		if (strcmp(w->rubik.faceName[face], c->rubik.faceName[face])) {
 			setColors = True;
@@ -1495,19 +1490,19 @@ SetValuesPuzzle(Widget current, Widget request, Widget renew)
 			w->rubik.reverse != c->rubik.reverse ||
 			w->rubik.mono != c->rubik.mono) {
 		loadFont(w);
-		SetAllColors(w);
+		setAllColors(w);
 		redraw = True;
 	} else if (w->rubik.background != c->rubik.background ||
 			w->rubik.foreground != c->rubik.foreground ||
 			setColors) {
-		SetAllColors(w);
+		setAllColors(w);
 		redraw = True;
 	}
 	if (w->rubik.orient != c->rubik.orient) {
-		ResetPieces(w);
+		resetPieces(w);
 		redraw = True;
 	} else if (w->rubik.practice != c->rubik.practice) {
-		ResetPieces(w);
+		resetPieces(w);
 		redraw = True;
 	}
 	if (w->rubik.menu != ACTION_IGNORE) {
@@ -1516,49 +1511,49 @@ SetValuesPuzzle(Widget current, Widget request, Widget renew)
 		w->rubik.menu = ACTION_IGNORE;
 		switch (menu) {
 		case ACTION_GET:
-			GetPieces(w);
+			getPieces(w);
 			break;
 		case ACTION_WRITE:
-			WritePieces(w);
+			writePieces(w);
 			break;
 		case ACTION_UNDO:
-			UndoPieces(w);
+			undoPieces(w);
 			break;
 		case ACTION_REDO:
-			RedoPieces(w);
+			redoPieces(w);
 			break;
 		case ACTION_CLEAR:
-			ClearPieces(w);
+			clearPieces(w);
 			break;
 		case ACTION_PRACTICE:
-			PracticePieces(w);
+			practicePieces(w);
 			break;
 		case ACTION_RANDOMIZE:
-			RandomizePieces(w);
+			randomizePieces(w);
 			break;
 		case ACTION_SOLVE:
-			SolvePieces(w);
+			solvePieces(w);
 			break;
 		case ACTION_INCREMENT:
-			IncrementPieces(w);
+			incrementPieces(w);
 			break;
 		case ACTION_DECREMENT:
-			(void) DecrementPieces(w);
+			(void) decrementPieces(w);
 			break;
 		case ACTION_ORIENTIZE:
-			OrientizePieces(w);
+			orientizePieces(w);
 			break;
 		case ACTION_SPEED:
-			SpeedPieces(w);
+			speedPieces(w);
 			break;
 		case ACTION_SLOW:
-			SlowPieces(w);
+			slowPieces(w);
 			break;
 		case ACTION_SOUND:
-			SoundPieces(w);
+			soundPieces(w);
 			break;
 		case ACTION_VIEW:
-			ViewPieces(w);
+			viewPieces(w);
 			break;
 		default:
 			break;
@@ -1568,11 +1563,11 @@ SetValuesPuzzle(Widget current, Widget request, Widget renew)
 		setStartPosition(w);
 		w->rubik.currentDirection = IGNORE_DIR;
 	} else if (w->rubik.currentDirection == CLEAR_DIR) {
-		ResetPieces(w);
+		resetPieces(w);
 		redraw = True;
 		w->rubik.currentDirection = IGNORE_DIR;
 	} else if (w->rubik.currentDirection > IGNORE_DIR) {
-		(void) MoveAllPieces(w, w->rubik.currentFace,
+		(void) moveAllPieces(w, w->rubik.currentFace,
 			w->rubik.currentPosition, w->rubik.currentDirection,
 			w->rubik.currentControl, w->rubik.currentFast);
 		w->rubik.currentDirection = IGNORE_DIR;
@@ -1581,7 +1576,7 @@ SetValuesPuzzle(Widget current, Widget request, Widget renew)
 }
 
 static void
-DestroyPuzzle(Widget old)
+destroyPuzzle(Widget old)
 {
 	RubikWidget w = (RubikWidget) old;
 	Display *display = XtDisplay(w);
@@ -1602,7 +1597,7 @@ DestroyPuzzle(Widget old)
 }
 
 void
-QuitPuzzle(RubikWidget w, XEvent *event, char **args, int nArgs)
+quitPuzzle(RubikWidget w, XEvent *event, char **args, int nArgs)
 {
 	XtCloseDisplay(XtDisplay(w));
 	exit(0);
@@ -1613,7 +1608,7 @@ QuitPuzzle(RubikWidget w, XEvent *event, char **args, int nArgs)
 static
 #endif
 void
-InitializePuzzle(
+initializePuzzle(
 #ifdef WINVER
 RubikWidget w, HBRUSH brush
 #else
@@ -1623,7 +1618,7 @@ Widget request, Widget renew
 {
 	int face, orient;
 #ifdef WINVER
-	SetValuesPuzzle(w);
+	setValuesPuzzle(w);
 #else
 	RubikWidget w = (RubikWidget) renew;
 
@@ -1642,11 +1637,11 @@ Widget request, Widget renew
 		w->rubik.cubeLoc[face] = NULL;
 	for (orient = 0; orient < MAX_ORIENT; orient++)
 		w->rubik.rowLoc[orient] = NULL;
-	CheckPieces(w);
+	checkPieces(w);
 	newMoves(&undo);
 	newMoves(&redo);
 	w->rubik.cheat = False;
-	ResetPieces(w);
+	resetPieces(w);
 #ifdef WINVER
 	brush = CreateSolidBrush(w->rubik.inverseGC);
 	SETBACK(w->core.hWnd, brush);
@@ -1657,7 +1652,7 @@ Widget request, Widget renew
 }
 
 void
-HidePuzzle(RubikWidget w
+hidePuzzle(RubikWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
@@ -1667,7 +1662,7 @@ HidePuzzle(RubikWidget w
 }
 
 void
-SelectPuzzle(RubikWidget w
+selectPuzzle(RubikWidget w
 #ifdef WINVER
 , const int x, const int y, const int control
 #else
@@ -1680,10 +1675,10 @@ SelectPuzzle(RubikWidget w
 	int control = (int) (event->xkey.state & ControlMask);
 #endif
 
-	if (SelectPieces(w, x, y,
+	if (selectPieces(w, x, y,
 		     &(w->rubik.currentFace), &(w->rubik.currentPosition))) {
-		if (control || w->rubik.practice || !CheckSolved(w, w->rubik.orient))
-			DrawSquare(w, w->rubik.currentFace, w->rubik.currentPosition,
+		if (control || w->rubik.practice || !checkSolved(w, w->rubik.orient))
+			drawSquare(w, w->rubik.currentFace, w->rubik.currentPosition,
 				TRUE);
 	} else {
 		w->rubik.currentFace = IGNORE_DIR;
@@ -1692,7 +1687,7 @@ SelectPuzzle(RubikWidget w
 }
 
 void
-ReleasePuzzle(RubikWidget w
+releasePuzzle(RubikWidget w
 #ifdef WINVER
 , const int x, const int y, const int control
 #else
@@ -1708,13 +1703,13 @@ ReleasePuzzle(RubikWidget w
 
 	if (w->rubik.currentFace <= IGNORE_DIR)
 		return;
-	DrawSquare(w, w->rubik.currentFace, w->rubik.currentPosition, FALSE);
-	if (!control && !w->rubik.practice && CheckSolved(w, w->rubik.orient))
-		MoveNoPieces(w);
-	else if (SelectPieces(w, x, y, &face, &position)) {
+	drawSquare(w, w->rubik.currentFace, w->rubik.currentPosition, FALSE);
+	if (!control && !w->rubik.practice && checkSolved(w, w->rubik.orient))
+		moveNoPieces(w);
+	else if (selectPieces(w, x, y, &face, &position)) {
 		if (face == w->rubik.currentFace) {
 			if (position != w->rubik.currentPosition)
-				count = CheckMoveDir(w, face,
+				count = checkMoveDir(w, face,
 					w->rubik.currentPosition, position,
 					&direction);
 		} else {
@@ -1724,15 +1719,15 @@ ReleasePuzzle(RubikWidget w
 			must also be able to handle double moves */
 		}
 		if (count == 1) {
-			MovePuzzle(w, face, w->rubik.currentPosition,
+			movePuzzle(w, w->rubik.currentFace, w->rubik.currentPosition,
 				direction, (control) ? 1 : 0, NORMAL);
-			if (!control && CheckSolved(w, w->rubik.orient)) {
+			if (!control && checkSolved(w, w->rubik.orient)) {
 				setPuzzle(w, ACTION_SOLVED);
 			}
 		} else if (count == 2) {
 			setPuzzle(w, ACTION_AMBIGUOUS);
 		} else if (count == 0)
-			MoveNoPieces(w);
+			moveNoPieces(w);
 	}
 	w->rubik.currentFace = IGNORE_DIR;
 	w->rubik.currentDirection = IGNORE_DIR;
@@ -1740,12 +1735,12 @@ ReleasePuzzle(RubikWidget w
 
 #ifndef WINVER
 void
-PracticePuzzleMaybe(RubikWidget w
+practicePuzzleWithQuery(RubikWidget w
 , XEvent *event, char **args, int nArgs
 )
 {
 	if (!w->rubik.started)
-		PracticePieces(w);
+		practicePieces(w);
 #ifdef HAVE_MOTIF
 	else {
 		setPuzzle(w, ACTION_PRACTICE_QUERY);
@@ -1754,23 +1749,23 @@ PracticePuzzleMaybe(RubikWidget w
 }
 
 void
-PracticePuzzle2(RubikWidget w
+practicePuzzleWithDoubleClick(RubikWidget w
 , XEvent *event, char **args, int nArgs
 )
 {
 #ifdef HAVE_MOTIF
 	if (!w->rubik.started)
 #endif
-		PracticePieces(w);
+		practicePieces(w);
 }
 
 void
-RandomizePuzzleMaybe(RubikWidget w
+randomizePuzzleWithQuery(RubikWidget w
 , XEvent *event, char **args, int nArgs
 )
 {
 	if (!w->rubik.started)
-		RandomizePieces(w);
+		randomizePieces(w);
 #ifdef HAVE_MOTIF
 	else {
 		setPuzzle(w, ACTION_RANDOMIZE_QUERY);
@@ -1779,192 +1774,192 @@ RandomizePuzzleMaybe(RubikWidget w
 }
 
 void
-RandomizePuzzle2(RubikWidget w
+randomizePuzzleWithDoubleClick(RubikWidget w
 , XEvent *event, char **args, int nArgs
 )
 {
 #ifdef HAVE_MOTIF
 	if (!w->rubik.started)
 #endif
-		RandomizePieces(w);
+		randomizePieces(w);
 }
 #endif
 
 void
-GetPuzzle(RubikWidget w
+getPuzzle(RubikWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 )
 {
-	GetPieces(w);
+	getPieces(w);
 }
 
 void
-WritePuzzle(RubikWidget w
+writePuzzle(RubikWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 )
 {
-	WritePieces(w);
+	writePieces(w);
 }
 
 void
-UndoPuzzle(RubikWidget w
+undoPuzzle(RubikWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 )
 {
-	UndoPieces(w);
+	undoPieces(w);
 }
 
 void
-RedoPuzzle(RubikWidget w
+redoPuzzle(RubikWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 )
 {
-	RedoPieces(w);
+	redoPieces(w);
 }
 
 void
-ClearPuzzle(RubikWidget w
+clearPuzzle(RubikWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 )
 {
-	ClearPieces(w);
+	clearPieces(w);
 }
 
 void
-RandomizePuzzle(RubikWidget w
+randomizePuzzle(RubikWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 )
 {
-	RandomizePieces(w);
+	randomizePieces(w);
 }
 
 void
-SolvePuzzle(RubikWidget w
+solvePuzzle(RubikWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 )
 {
-	SolvePieces(w);
+	solvePieces(w);
 }
 
 void
-PracticePuzzle(RubikWidget w
+practicePuzzle(RubikWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 )
 {
-	PracticePieces(w);
+	practicePieces(w);
 }
 
 void
-OrientizePuzzle(RubikWidget w
+orientizePuzzle(RubikWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 )
 {
-	OrientizePieces(w);
+	orientizePieces(w);
 }
 
 void
-DecrementPuzzle(RubikWidget w
+decrementPuzzle(RubikWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 )
 {
-	DecrementPieces(w);
+	decrementPieces(w);
 }
 
 void
-IncrementPuzzle(RubikWidget w
+incrementPuzzle(RubikWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 )
 {
-	IncrementPieces(w);
+	incrementPieces(w);
 }
 
 void
-ViewPuzzle(RubikWidget w
+viewPuzzle(RubikWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 )
 {
-	ViewPieces(w);
+	viewPieces(w);
 }
 
 void
-SpeedPuzzle(RubikWidget w
+speedUpPuzzle(RubikWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 )
 {
-	SpeedPieces(w);
+	speedPieces(w);
 }
 
 void
-SlowPuzzle(RubikWidget w
+slowDownPuzzle(RubikWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 )
 {
-	SlowPieces(w);
+	slowPieces(w);
 }
 
 void
-SoundPuzzle(RubikWidget w
+toggleSoundPuzzle(RubikWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 )
 {
-	SoundPieces(w);
+	soundPieces(w);
 }
 
 void
-EnterPuzzle(RubikWidget w
+enterPuzzle(RubikWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 )
 {
 	w->rubik.focus = True;
-	DrawFrame(w, w->rubik.focus);
+	drawFrame(w, w->rubik.focus);
 }
 
 void
-LeavePuzzle(RubikWidget w
+leavePuzzle(RubikWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 )
 {
 	w->rubik.focus = False;
-	DrawFrame(w, w->rubik.focus);
+	drawFrame(w, w->rubik.focus);
 }
 
 #ifdef WINVER
 void
-IncrementAxisPuzzle(RubikWidget w, char axis)
+incrementAxisPuzzle(RubikWidget w, char axis)
 {
 	switch (axis) {
 	case 'X':
@@ -1993,14 +1988,14 @@ IncrementAxisPuzzle(RubikWidget w, char axis)
 }
 
 void
-DimPuzzle(RubikWidget w)
+dimPuzzle(RubikWidget w)
 {
 	setPuzzle(w, ACTION_DIM);
 }
 
 #else
 void
-IncrementXPuzzle(RubikWidget w, XEvent *event, char **args, int nArgs)
+incrementXPuzzle(RubikWidget w, XEvent *event, char **args, int nArgs)
 {
 	if (event->xbutton.state & (ShiftMask | LockMask)) {
 		if (w->rubik.sizex <= MIN_FACETS)
@@ -2011,7 +2006,7 @@ IncrementXPuzzle(RubikWidget w, XEvent *event, char **args, int nArgs)
 }
 
 void
-IncrementYPuzzle(RubikWidget w , XEvent *event, char **args, int nArgs)
+incrementYPuzzle(RubikWidget w , XEvent *event, char **args, int nArgs)
 {
 	if (event->xbutton.state & (ShiftMask | LockMask)) {
 		if (w->rubik.sizey <= MIN_FACETS)
@@ -2022,7 +2017,7 @@ IncrementYPuzzle(RubikWidget w , XEvent *event, char **args, int nArgs)
 }
 
 void
-IncrementZPuzzle(RubikWidget w , XEvent *event, char **args, int nArgs)
+incrementZPuzzle(RubikWidget w , XEvent *event, char **args, int nArgs)
 {
 	if (event->xbutton.state & (ShiftMask | LockMask)) {
 		if (w->rubik.sizez <= MIN_FACETS)
@@ -2033,16 +2028,16 @@ IncrementZPuzzle(RubikWidget w , XEvent *event, char **args, int nArgs)
 }
 
 void
-MovePuzzleCcw(RubikWidget w, XEvent *event, char **args, int nArgs)
+movePuzzleCcw(RubikWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput(w, event->xbutton.x, event->xbutton.y, CCW,
+	movePuzzleInput(w, event->xbutton.x, event->xbutton.y, CCW,
 		(int) (event->xbutton.state & ControlMask));
 }
 
 void
-MovePuzzleCw(RubikWidget w, XEvent *event, char **args, int nArgs)
+movePuzzleCw(RubikWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput(w, event->xbutton.x, event->xbutton.y, CW,
+	movePuzzleInput(w, event->xbutton.x, event->xbutton.y, CW,
 		(int) (event->xkey.state & ControlMask));
 }
 #endif
