@@ -1,27 +1,22 @@
-/*-
-# X-BASED RUBIK'S CUBE(tm)
-#
-#  Rubik3d.c
-#
-###
-#
-#  Copyright (c) 1994 - 2007	David A. Bagley, bagleyd@tux.org
-#
-#                   All Rights Reserved
-#
-#  Permission to use, copy, modify, and distribute this software and
-#  its documentation for any purpose and without fee is hereby granted,
-#  provided that the above copyright notice appear in all copies and
-#  that both that copyright notice and this permission notice appear in
-#  supporting documentation, and that the name of the author not be
-#  used in advertising or publicity pertaining to distribution of the
-#  software without specific, written prior permission.
-#
-#  This program is distributed in the hope that it will be "playable",
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-#
-*/
+/*
+ * @(#)Rubik3d.c
+ *
+ * Copyright 1994 - 2008  David A. Bagley, bagleyd@tux.org
+ *
+ * All rights reserved.
+ *
+ * Permission to use, copy, modify, and distribute this software and
+ * its documentation for any purpose and without fee is hereby granted,
+ * provided that the above copyright notice appear in all copies and
+ * that both that copyright notice and this permission notice appear in
+ * supporting documentation, and that the name of the author not be
+ * used in advertising or publicity pertaining to distribution of the
+ * software without specific, written prior permission.
+ *
+ * This program is distributed in the hope that it will be "useful",
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ */
 
 /* Methods file for Rubik3d */
 
@@ -29,28 +24,28 @@
 #include "Rubik3dP.h"
 
 #ifndef WINVER
-static Boolean SetValuesPuzzle3D(Widget current, Widget request, Widget renew);
-static void ResizePuzzle3D(Rubik3DWidget w);
-static void InitializePuzzle3D(Widget request, Widget renew);
-static void ExposePuzzle3D(Widget renew, XEvent *event, Region region);
-static void MovePuzzle3DTl(Rubik3DWidget w,
+static Boolean setValuesPuzzle3D(Widget current, Widget request, Widget renew);
+static void resizePuzzle3D(Rubik3DWidget w);
+static void initializePuzzle3D(Widget request, Widget renew);
+static void exposePuzzle3D(Widget renew, XEvent *event, Region region);
+static void movePuzzle3DTl(Rubik3DWidget w,
 	XEvent *event, char **args, int nArgs);
-static void MovePuzzle3DTop(Rubik3DWidget w,
+static void movePuzzle3DTop(Rubik3DWidget w,
 	XEvent *event, char **args, int nArgs);
-static void MovePuzzle3DTr(Rubik3DWidget w,
+static void movePuzzle3DTr(Rubik3DWidget w,
 	XEvent *event, char **args, int nArgs);
-static void MovePuzzle3DLeft(Rubik3DWidget w,
+static void movePuzzle3DLeft(Rubik3DWidget w,
 	XEvent *event, char **args, int nArgs);
-static void MovePuzzle3DRight(Rubik3DWidget w,
+static void movePuzzle3DRight(Rubik3DWidget w,
 	XEvent *event, char **args, int nArgs);
-static void MovePuzzle3DBl(Rubik3DWidget w,
+static void movePuzzle3DBl(Rubik3DWidget w,
 	XEvent *event, char **args, int nArgs);
-static void MovePuzzle3DBottom(Rubik3DWidget w,
+static void movePuzzle3DBottom(Rubik3DWidget w,
 	XEvent *event, char **args, int nArgs);
-static void MovePuzzle3DBr(Rubik3DWidget w,
+static void movePuzzle3DBr(Rubik3DWidget w,
 	XEvent *event, char **args, int nArgs);
 
-static char defaultTranslationsPuzzle3D[] =
+static char translations3D[] =
 "<KeyPress>q: Quit()\n\
  Ctrl<KeyPress>C: Quit()\n\
  <KeyPress>osfCancel: Hide()\n\
@@ -126,49 +121,49 @@ static char defaultTranslationsPuzzle3D[] =
  <EnterWindow>: Enter()\n\
  <LeaveWindow>: Leave()";
 
-static XtActionsRec actionsListPuzzle3D[] =
+static XtActionsRec actionsList3D[] =
 {
-	{(char *) "Quit", (XtActionProc) QuitPuzzle},
-	{(char *) "Hide", (XtActionProc) HidePuzzle},
-	{(char *) "MoveCcw", (XtActionProc) MovePuzzleCcw},
-	{(char *) "MoveTl", (XtActionProc) MovePuzzle3DTl},
-	{(char *) "MoveTop", (XtActionProc) MovePuzzle3DTop},
-	{(char *) "MoveTr", (XtActionProc) MovePuzzle3DTr},
-	{(char *) "MoveLeft", (XtActionProc) MovePuzzle3DLeft},
-	{(char *) "MoveCw", (XtActionProc) MovePuzzleCw},
-	{(char *) "MoveRight", (XtActionProc) MovePuzzle3DRight},
-	{(char *) "MoveBl", (XtActionProc) MovePuzzle3DBl},
-	{(char *) "MoveBottom", (XtActionProc) MovePuzzle3DBottom},
-	{(char *) "MoveBr", (XtActionProc) MovePuzzle3DBr},
-	{(char *) "Select", (XtActionProc) SelectPuzzle},
-	{(char *) "Release", (XtActionProc) ReleasePuzzle},
-	{(char *) "PracticeMaybe", (XtActionProc) PracticePuzzleMaybe},
-	{(char *) "Practice2", (XtActionProc) PracticePuzzle2},
-	{(char *) "RandomizeMaybe", (XtActionProc) RandomizePuzzleMaybe},
-	{(char *) "Randomize2", (XtActionProc) RandomizePuzzle2},
-	{(char *) "Get", (XtActionProc) GetPuzzle},
-	{(char *) "Write", (XtActionProc) WritePuzzle},
-	{(char *) "Undo", (XtActionProc) UndoPuzzle},
-	{(char *) "Redo", (XtActionProc) RedoPuzzle},
-	{(char *) "Clear", (XtActionProc) ClearPuzzle},
-	{(char *) "Randomize", (XtActionProc) RandomizePuzzle},
-	{(char *) "Solve", (XtActionProc) SolvePuzzle},
-	{(char *) "Practice", (XtActionProc) PracticePuzzle},
-	{(char *) "Increment", (XtActionProc) IncrementPuzzle},
-	{(char *) "Decrement", (XtActionProc) DecrementPuzzle},
-	{(char *) "IncrementX", (XtActionProc) IncrementXPuzzle},
-	{(char *) "IncrementY", (XtActionProc) IncrementYPuzzle},
-	{(char *) "IncrementZ", (XtActionProc) IncrementZPuzzle},
-	{(char *) "Orientize", (XtActionProc) OrientizePuzzle},
-	{(char *) "View", (XtActionProc) ViewPuzzle},
-	{(char *) "Speed", (XtActionProc) SpeedPuzzle},
-	{(char *) "Slow", (XtActionProc) SlowPuzzle},
-	{(char *) "Sound", (XtActionProc) SoundPuzzle},
-	{(char *) "Enter", (XtActionProc) EnterPuzzle},
-	{(char *) "Leave", (XtActionProc) LeavePuzzle}
+	{(char *) "Quit", (XtActionProc) quitPuzzle},
+	{(char *) "Hide", (XtActionProc) hidePuzzle},
+	{(char *) "MoveCcw", (XtActionProc) movePuzzleCcw},
+	{(char *) "MoveTl", (XtActionProc) movePuzzle3DTl},
+	{(char *) "MoveTop", (XtActionProc) movePuzzle3DTop},
+	{(char *) "MoveTr", (XtActionProc) movePuzzle3DTr},
+	{(char *) "MoveLeft", (XtActionProc) movePuzzle3DLeft},
+	{(char *) "MoveCw", (XtActionProc) movePuzzleCw},
+	{(char *) "MoveRight", (XtActionProc) movePuzzle3DRight},
+	{(char *) "MoveBl", (XtActionProc) movePuzzle3DBl},
+	{(char *) "MoveBottom", (XtActionProc) movePuzzle3DBottom},
+	{(char *) "MoveBr", (XtActionProc) movePuzzle3DBr},
+	{(char *) "Select", (XtActionProc) selectPuzzle},
+	{(char *) "Release", (XtActionProc) releasePuzzle},
+	{(char *) "PracticeMaybe", (XtActionProc) practicePuzzleWithQuery},
+	{(char *) "Practice2", (XtActionProc) practicePuzzleWithDoubleClick},
+	{(char *) "RandomizeMaybe", (XtActionProc) randomizePuzzleWithQuery},
+	{(char *) "Randomize2", (XtActionProc) randomizePuzzleWithDoubleClick},
+	{(char *) "Get", (XtActionProc) getPuzzle},
+	{(char *) "Write", (XtActionProc) writePuzzle},
+	{(char *) "Undo", (XtActionProc) undoPuzzle},
+	{(char *) "Redo", (XtActionProc) redoPuzzle},
+	{(char *) "Clear", (XtActionProc) clearPuzzle},
+	{(char *) "Randomize", (XtActionProc) randomizePuzzle},
+	{(char *) "Solve", (XtActionProc) solvePuzzle},
+	{(char *) "Practice", (XtActionProc) practicePuzzle},
+	{(char *) "Increment", (XtActionProc) incrementPuzzle},
+	{(char *) "Decrement", (XtActionProc) decrementPuzzle},
+	{(char *) "IncrementX", (XtActionProc) incrementXPuzzle},
+	{(char *) "IncrementY", (XtActionProc) incrementYPuzzle},
+	{(char *) "IncrementZ", (XtActionProc) incrementZPuzzle},
+	{(char *) "Orientize", (XtActionProc) orientizePuzzle},
+	{(char *) "View", (XtActionProc) viewPuzzle},
+	{(char *) "Speed", (XtActionProc) speedUpPuzzle},
+	{(char *) "Slow", (XtActionProc) slowDownPuzzle},
+	{(char *) "Sound", (XtActionProc) toggleSoundPuzzle},
+	{(char *) "Enter", (XtActionProc) enterPuzzle},
+	{(char *) "Leave", (XtActionProc) leavePuzzle}
 };
 
-static XtResource resourcesPuzzle3D[] =
+static XtResource resources3D[] =
 {
 	{XtNwidth, XtCWidth, XtRDimension, sizeof (Dimension),
 	 XtOffset(RubikWidget, core.width),
@@ -187,7 +182,7 @@ static XtResource resourcesPuzzle3D[] =
 	 XtRString, (caddr_t) XtDefaultForeground},
 	{XtNbackground, XtCBackground, XtRPixel, sizeof (Pixel),
 	 XtOffset(RubikWidget, rubik.background),
-	 XtRString, (caddr_t) XtDefaultBackground},
+	 XtRString, (caddr_t) "#AEB2C3" /*XtDefaultBackground*/},
 	{XtNframeColor, XtCColor, XtRPixel, sizeof (Pixel),
 	 XtOffset(RubikWidget, rubik.frameColor),
 	 XtRString, (caddr_t) "cyan" /*XtDefaultForeground*/},
@@ -292,29 +287,29 @@ Rubik3DClassRec rubik3dClassRec =
 		NULL,		/* class initialize */
 		NULL,		/* class part initialize */
 		FALSE,		/* class inited */
-		(XtInitProc) InitializePuzzle3D,	/* initialize */
+		(XtInitProc) initializePuzzle3D,	/* initialize */
 		NULL,		/* initialize hook */
 		XtInheritRealize,	/* realize */
-		actionsListPuzzle3D,	/* actions */
-		XtNumber(actionsListPuzzle3D),	/* num actions */
-		resourcesPuzzle3D,	/* resources */
-		XtNumber(resourcesPuzzle3D),	/* num resources */
+		actionsList3D,	/* actions */
+		XtNumber(actionsList3D),	/* num actions */
+		resources3D,	/* resources */
+		XtNumber(resources3D),	/* num resources */
 		NULLQUARK,	/* xrm class */
 		TRUE,		/* compress motion */
 		TRUE,		/* compress exposure */
 		TRUE,		/* compress enterleave */
 		TRUE,		/* visible interest */
 		NULL,		/* destroy */
-		(XtWidgetProc) ResizePuzzle3D,	/* resize */
-		(XtExposeProc) ExposePuzzle3D,	/* expose */
-		(XtSetValuesFunc) SetValuesPuzzle3D,	/* set values */
+		(XtWidgetProc) resizePuzzle3D,	/* resize */
+		(XtExposeProc) exposePuzzle3D,	/* expose */
+		(XtSetValuesFunc) setValuesPuzzle3D,	/* set values */
 		NULL,		/* set values hook */
 		XtInheritSetValuesAlmost,	/* set values almost */
 		NULL,		/* get values hook */
 		XtInheritAcceptFocus,	/* accept focus */
 		XtVersion,	/* version */
 		NULL,		/* callback private */
-		defaultTranslationsPuzzle3D,	/* tm table */
+		translations3D,	/* tm table */
 		NULL,		/* query geometry */
 		NULL,		/* display accelerator */
 		NULL		/* extension */
@@ -347,7 +342,7 @@ static RowNext rotateToRow[MAX_FACES] =	/* CW to min face */
 static Pixmap dr = 0; /* dummy for future double buffering */
 
 static void
-CubeOffset3D(Rubik3DWidget w, int face, int x, int y, int *dx, int *dy)
+cubeOffset3D(Rubik3DWidget w, int face, int x, int y, int *dx, int *dy)
 {
 	char *buf;
 	if (w->rubik.vertical)
@@ -400,7 +395,7 @@ CubeOffset3D(Rubik3DWidget w, int face, int x, int y, int *dx, int *dy)
 				x * (w->rubik3d.cubeSizey.y + w->rubik.delta);
 			break;
 		default:
-			intCat(&buf, "CubeOffset3D: face ", face);
+			intCat(&buf, "cubeOffset3D: face ", face);
 			DISPLAY_WARNING(buf);
 			free(buf);
 	} else
@@ -453,14 +448,14 @@ CubeOffset3D(Rubik3DWidget w, int face, int x, int y, int *dx, int *dy)
 				y * (w->rubik3d.cubeDiagonalx + w->rubik.delta);
 			break;
 		default:
-			intCat(&buf, "CubeOffset3D: face ", face);
+			intCat(&buf, "cubeOffset3D: face ", face);
 			DISPLAY_WARNING(buf);
 			free(buf);
 	}
 }
 
 static void
-MapTo3D(Rubik3DWidget w, int face, int i, int j, int *x, int *y)
+mapTo3D(Rubik3DWidget w, int face, int i, int j, int *x, int *y)
 {
 	switch (face) {
 	case 0:
@@ -491,7 +486,7 @@ MapTo3D(Rubik3DWidget w, int face, int i, int j, int *x, int *y)
 		{
 			char *buf;
 
-			intCat(&buf, "MapTo3D: face ", face);
+			intCat(&buf, "mapTo3D: face ", face);
 			DISPLAY_WARNING(buf);
 			free(buf);
 		}
@@ -500,7 +495,7 @@ MapTo3D(Rubik3DWidget w, int face, int i, int j, int *x, int *y)
 
 #ifdef DEBUG
 static void
-MapFrom3D(Rubik3DWidget w, int face, int x, int y, int *i, int *j)
+mapFrom3D(Rubik3DWidget w, int face, int x, int y, int *i, int *j)
 {
 	switch (face) {
 	case 0:
@@ -531,7 +526,7 @@ MapFrom3D(Rubik3DWidget w, int face, int x, int y, int *i, int *j)
 		{
 			char *buf;
 
-			intCat(&buf, "MapFrom3D: face ", face);
+			intCat(&buf, "mapFrom3D: face ", face);
 			DISPLAY_WARNING(buf);
 			free(buf);
 		}
@@ -541,7 +536,7 @@ MapFrom3D(Rubik3DWidget w, int face, int x, int y, int *i, int *j)
 #endif
 
 static void
-MapOrientFrom3D(Rubik3DWidget w, int face, int corner, int *side)
+mapOrientFrom3D(Rubik3DWidget w, int face, int corner, int *side)
 {
 	switch (face) {
 	case 0:
@@ -566,7 +561,7 @@ MapOrientFrom3D(Rubik3DWidget w, int face, int corner, int *side)
 		{
 			char *buf;
 
-			intCat(&buf, "MapOrientFrom3D: face ", face);
+			intCat(&buf, "mapOrientFrom3D: face ", face);
 			DISPLAY_WARNING(buf);
 			free(buf);
 		}
@@ -574,7 +569,7 @@ MapOrientFrom3D(Rubik3DWidget w, int face, int corner, int *side)
 }
 
 void
-DrawSquare3D(Rubik3DWidget w, int face, int position, int offset)
+drawSquare3D(Rubik3DWidget w, int face, int position, int offset)
 {
 	GC faceGC, borderGC;
 	int x = 0, y = 0, dx = 0, dy = 0, i, j, sizeOfRow;
@@ -582,8 +577,8 @@ DrawSquare3D(Rubik3DWidget w, int face, int position, int offset)
 	sizeOfRow = sizeRow((RubikWidget) w, face);
 	i = position % sizeOfRow;
 	j = position / sizeOfRow;
-	MapTo3D(w, face, i, j, &x, &y);
-	CubeOffset3D(w, face, x, y, &dx, &dy);
+	mapTo3D(w, face, i, j, &x, &y);
+	cubeOffset3D(w, face, x, y, &dx, &dy);
 	cubeLoc3D[face][0].x = dx;
 	cubeLoc3D[face][0].y = dy;
 	if (offset) {
@@ -632,7 +627,7 @@ DrawSquare3D(Rubik3DWidget w, int face, int position, int offset)
 }
 
 void
-DrawFrame3D(Rubik3DWidget w, Boolean focus)
+drawFrame3D(Rubik3DWidget w, Boolean focus)
 {
 	int face, dx, dy;
 	GC gc = (focus) ? w->rubik.frameGC : w->rubik.borderGC;
@@ -669,7 +664,7 @@ DrawFrame3D(Rubik3DWidget w, Boolean focus)
 }
 
 static void
-ResizePieces(Rubik3DWidget w)
+resizePieces(Rubik3DWidget w)
 {
 	int face, orient, side, corner, sizex, sizey;
 	Point subcubeLoc3D[MAX_FACES][MAX_ORIENT];
@@ -896,7 +891,7 @@ ResizePieces(Rubik3DWidget w)
 		subdiamondLoc3D[face][orient].y = (subcubeLoc3D[face][MAX_ORIENT - 1].y -
 			subcubeLoc3D[face][MAX_ORIENT / 2].y) / 2;
 
-		MapOrientFrom3D(w, face, 1, &corner);
+		mapOrientFrom3D(w, face, 1, &corner);
 		orient3DList[face][corner][0].x = cubeLoc3D[face][1].x / 2;
 		orient3DList[face][corner][0].y = cubeLoc3D[face][1].y / 2;
 		orient3DList[face][corner][1].x = orient3DList[face][corner][0].x +
@@ -905,7 +900,7 @@ ResizePieces(Rubik3DWidget w)
 			(cubeLoc3D[face][2].y - subcubeLoc3D[face][2].y) / 2;
 		for (orient = 1; orient < MAX_ORIENT; orient++) {
 			side = corner;
-			MapOrientFrom3D(w, face, (orient + 1) % MAX_ORIENT,
+			mapOrientFrom3D(w, face, (orient + 1) % MAX_ORIENT,
 				&corner);
 			orient3DList[face][corner][0].x =
 				orient3DList[face][side][0].x + diamondLoc3D[face][orient].x;
@@ -920,7 +915,7 @@ ResizePieces(Rubik3DWidget w)
 }
 
 Boolean
-SelectPieces3D(Rubik3DWidget w, int x, int y, int *face, int *position)
+selectPieces3D(Rubik3DWidget w, int x, int y, int *face, int *position)
 {
 	int u, v, front, tl, ur, ul, i, j;
 	int tempx = x, tempy = y, sizeOfRow, sizeOfColumn;
@@ -1072,7 +1067,7 @@ SelectPieces3D(Rubik3DWidget w, int x, int y, int *face, int *position)
 }
 
 Boolean
-NarrowSelection3D(Rubik3DWidget w, int *face, int *position, int *direction)
+narrowSelection3D(Rubik3DWidget w, int *face, int *position, int *direction)
 {
 	switch (*direction) {
 	case TOP:
@@ -1195,7 +1190,7 @@ NarrowSelection3D(Rubik3DWidget w, int *face, int *position, int *direction)
 
 #ifndef WINVER
 static Boolean
-SetValuesPuzzle3D(Widget current, Widget request, Widget renew)
+setValuesPuzzle3D(Widget current, Widget request, Widget renew)
 {
 	Rubik3DWidget c = (Rubik3DWidget) current, w = (Rubik3DWidget) renew;
 	Boolean redraw = False;
@@ -1203,8 +1198,8 @@ SetValuesPuzzle3D(Widget current, Widget request, Widget renew)
 	if (w->rubik.sizex != c->rubik.sizex ||
 			w->rubik.sizey != c->rubik.sizey ||
 			w->rubik.sizez != c->rubik.sizez) {
-		ResetPieces((RubikWidget) w);
-		ResizePuzzle3D(w);
+		resetPieces((RubikWidget) w);
+		resizePuzzle3D(w);
 		redraw = True;
 	}
 	if (w->rubik3d.cubeSizex.x != c->rubik3d.cubeSizex.x ||
@@ -1213,7 +1208,7 @@ SetValuesPuzzle3D(Widget current, Widget request, Widget renew)
 			w->rubik3d.cubeSizex.y != c->rubik3d.cubeSizex.y ||
 			w->rubik3d.cubeSizey.y != c->rubik3d.cubeSizey.y ||
 			w->rubik3d.cubeSizez.y != c->rubik3d.cubeSizez.y) {
-		ResizePuzzle3D(w);
+		resizePuzzle3D(w);
 		redraw = True;
 	}
 	return (redraw);
@@ -1224,7 +1219,7 @@ SetValuesPuzzle3D(Widget current, Widget request, Widget renew)
 static
 #endif
 void
-ResizePuzzle3D(Rubik3DWidget w)
+resizePuzzle3D(Rubik3DWidget w)
 {
 #ifdef WINVER
 	RECT rect;
@@ -1271,14 +1266,14 @@ ResizePuzzle3D(Rubik3DWidget w)
 	}
 	w->rubik.puzzleOffset.x = ((int) w->core.width - w->rubik.puzzleSize.x) / 2;
 	w->rubik.puzzleOffset.y = ((int) w->core.height - w->rubik.puzzleSize.y) / 2;
-	ResizePieces(w);
+	resizePieces(w);
 }
 
 #ifndef WINVER
 static
 #endif
 void
-InitializePuzzle3D(
+initializePuzzle3D(
 #ifdef WINVER
 Rubik3DWidget w
 #else
@@ -1289,17 +1284,17 @@ Widget request, Widget renew
 #ifndef WINVER
 	Rubik3DWidget w = (Rubik3DWidget) renew;
 
-	SetAllColors((RubikWidget) w);
+	setAllColors((RubikWidget) w);
 #endif
 	w->rubik.dim = 3;
-	ResizePuzzle3D(w);
+	resizePuzzle3D(w);
 }
 
 #ifndef WINVER
 static
 #endif
 void
-ExposePuzzle3D(
+exposePuzzle3D(
 #ifdef WINVER
 Rubik3DWidget w
 #else
@@ -1315,64 +1310,64 @@ Widget renew, XEvent *event, Region region
 #endif
 	FILLRECTANGLE(w, dr, w->rubik.inverseGC,
 		0, 0, w->core.width, w->core.height);
-	DrawFrame3D(w, w->rubik.focus);
-	DrawAllPieces((RubikWidget) w);
+	drawFrame3D(w, w->rubik.focus);
+	drawAllPieces((RubikWidget) w);
 }
 
 #ifndef WINVER
 static void
-MovePuzzle3DTl(Rubik3DWidget w, XEvent *event, char **args, int nArgs)
+movePuzzle3DTl(Rubik3DWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((RubikWidget) w, event->xbutton.x, event->xbutton.y,
+	movePuzzleInput((RubikWidget) w, event->xbutton.x, event->xbutton.y,
 		TL, (int) (event->xkey.state & ControlMask));
 }
 
 static void
-MovePuzzle3DTop(Rubik3DWidget w, XEvent *event, char **args, int nArgs)
+movePuzzle3DTop(Rubik3DWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((RubikWidget) w, event->xbutton.x, event->xbutton.y,
+	movePuzzleInput((RubikWidget) w, event->xbutton.x, event->xbutton.y,
 		TOP, (int) (event->xkey.state & ControlMask));
 }
 
 static void
-MovePuzzle3DTr(Rubik3DWidget w, XEvent *event, char **args, int nArgs)
+movePuzzle3DTr(Rubik3DWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((RubikWidget) w, event->xbutton.x, event->xbutton.y,
+	movePuzzleInput((RubikWidget) w, event->xbutton.x, event->xbutton.y,
 		TR, (int) (event->xkey.state & ControlMask));
 }
 
 static void
-MovePuzzle3DLeft(Rubik3DWidget w, XEvent *event, char **args, int nArgs)
+movePuzzle3DLeft(Rubik3DWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((RubikWidget) w, event->xbutton.x, event->xbutton.y,
+	movePuzzleInput((RubikWidget) w, event->xbutton.x, event->xbutton.y,
 		LEFT, (int) (event->xkey.state & ControlMask));
 }
 
 static void
-MovePuzzle3DRight(Rubik3DWidget w, XEvent *event, char **args, int nArgs)
+movePuzzle3DRight(Rubik3DWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((RubikWidget) w, event->xbutton.x, event->xbutton.y,
+	movePuzzleInput((RubikWidget) w, event->xbutton.x, event->xbutton.y,
 		RIGHT, (int) (event->xkey.state & ControlMask));
 }
 
 static void
-MovePuzzle3DBl(Rubik3DWidget w, XEvent *event, char **args, int nArgs)
+movePuzzle3DBl(Rubik3DWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((RubikWidget) w, event->xbutton.x, event->xbutton.y,
+	movePuzzleInput((RubikWidget) w, event->xbutton.x, event->xbutton.y,
 		BL, (int) (event->xkey.state & ControlMask));
 }
 
 static void
-MovePuzzle3DBottom(Rubik3DWidget w, XEvent *event, char **args, int nArgs)
+movePuzzle3DBottom(Rubik3DWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((RubikWidget) w, event->xbutton.x, event->xbutton.y,
+	movePuzzleInput((RubikWidget) w, event->xbutton.x, event->xbutton.y,
 		BOTTOM, (int) (event->xkey.state & ControlMask));
 }
 
 static void
-MovePuzzle3DBr(Rubik3DWidget w, XEvent *event, char **args, int nArgs)
+movePuzzle3DBr(Rubik3DWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((RubikWidget) w, event->xbutton.x, event->xbutton.y,
+	movePuzzleInput((RubikWidget) w, event->xbutton.x, event->xbutton.y,
 		BR, (int) (event->xkey.state & ControlMask));
 }
 #endif
