@@ -1,27 +1,22 @@
-/*-
-# X-BASED RUBIK'S CUBE(tm)
-#
-#  RubikGLP.h
-#
-###
-#
-#  Copyright (c) 2003 - 2006	David A. Bagley, bagleyd@tux.org
-#
-#                   All Rights Reserved
-#
-#  Permission to use, copy, modify, and distribute this software and
-#  its documentation for any purpose and without fee is hereby granted,
-#  provided that the above copyright notice appear in all copies and
-#  that both that copyright notice and this permission notice appear in
-#  supporting documentation, and that the name of the author not be
-#  used in advertising or publicity pertaining to distribution of the
-#  software without specific, written prior permission.
-#
-#  This program is distributed in the hope that it will be "playable",
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-#
-*/
+/*
+ * @(#)RubikGLP.h
+ *
+ * Copyright 2003 - 2008  David A. Bagley, bagleyd@tux.org
+ *
+ * All rights reserved.
+ *
+ * Permission to use, copy, modify, and distribute this software and
+ * its documentation for any purpose and without fee is hereby granted,
+ * provided that the above copyright notice appear in all copies and
+ * that both that copyright notice and this permission notice appear in
+ * supporting documentation, and that the name of the author not be
+ * used in advertising or publicity pertaining to distribution of the
+ * software without specific, written prior permission.
+ *
+ * This program is distributed in the hope that it will be "useful",
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ */
 
 /* Private header file for RubikGL */
 
@@ -120,17 +115,17 @@ typedef struct _RubikGLRec {
 	RubikGLPart rubikGL;
 } RubikGLRec;
 
-extern Boolean SelectPiecesGL(RubikGLWidget w, int x, int y,
+extern Boolean selectPiecesGL(RubikGLWidget w, int x, int y,
 	int *face, int *position);
-extern void DrawFrameGL(RubikGLWidget w, Boolean focus);
-extern void DrawAllPiecesGL(RubikGLWidget w);
-extern void MoveAllPiecesGL(RubikGLWidget w, int face, int direction,
+extern void drawFrameGL(RubikGLWidget w, Boolean focus);
+extern void drawAllPiecesGL(RubikGLWidget w);
+extern void moveAllPiecesGL(RubikGLWidget w, int face, int direction,
 	int fast);
-extern void MovePiecesGL(RubikGLWidget w, int face, int position,
+extern void movePiecesGL(RubikGLWidget w, int face, int position,
 	int direction, Boolean control, int fast);
 #ifdef WINVER
-extern void ResizePuzzleGL(RubikGLWidget w);
-extern void ExposePuzzleGL(RubikGLWidget w);
+extern void resizePuzzleGL(RubikGLWidget w);
+extern void exposePuzzleGL(RubikGLWidget w);
 #endif
 
 #endif /* _RubikGLP_h */
