@@ -1,27 +1,24 @@
-/*-
-# MOTIF/X-BASED RUBIK'S CUBE(tm)
-#
-#  xrubik.c
-#
-###
-#
-#  Copyright (c) 1993 - 2007	David A. Bagley, bagleyd@tux.org
-#
-#                   All Rights Reserved
-#
-#  Permission to use, copy, modify, and distribute this software and
-#  its documentation for any purpose and without fee is hereby granted,
-#  provided that the above copyright notice appear in all copies and
-#  that both that copyright notice and this permission notice appear in
-#  supporting documentation, and that the name of the author not be
-#  used in advertising or publicity pertaining to distribution of the
-#  software without specific, written prior permission.
-#
-#  This program is distributed in the hope that it will be "playable",
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-#
-*/
+/*
+ * @(#)xrubik.c
+ *
+ * Copyright 1993 - 2008  David A. Bagley, bagleyd@tux.org
+ *
+ * All rights reserved.
+ *
+ * Permission to use, copy, modify, and distribute this software and
+ * its documentation for any purpose and without fee is hereby granted,
+ * provided that the above copyright notice appear in all copies and
+ * that both that copyright notice and this permission notice appear in
+ * supporting documentation, and that the name of the author not be
+ * used in advertising or publicity pertaining to distribution of the
+ * software without specific, written prior permission.
+ *
+ * This program is distributed in the hope that it will be "useful",
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ */
+
+/* Driver file for Rubik */
 
 #include "file.h"
 #ifdef WINVER
@@ -57,7 +54,7 @@ static RubikRec widget;
 #include "pixmaps/mouse-l.xbm"
 #include "pixmaps/mouse-r.xbm"
 #endif
-#define PRINT_MESSAGE(b) PrintState(message, b)
+#define PRINT_MESSAGE(b) printState(message, b)
 #else
 #define PRINT_MESSAGE(b) XtWarning(b)
 #endif
@@ -94,7 +91,7 @@ static RubikRec widget;
 
 #ifndef WINVER
 static const char aboutHelp[] = {
-"Rubik Version 7.3.2\n"
+"Rubik Version 7.4\n"
 "Send bugs (reports or fixes) to the author: "
 "David Bagley <bagleyd@tux.org>\n"
 "The latest version is at: "
@@ -281,8 +278,9 @@ static char userNameDsp[USER_NAME_LENGTH] = "Guest";
 #ifdef HAVE_MOTIF
 #define MIN_SPEED 1
 #define MAX_SPEED 50
-static Widget moves, record, message, cubesx, cubesy, cubesz;
-static Widget orientizeSwitch, practiceSwitch, speed;
+static Widget movesText, recordText, message;
+static Widget cubesXSlider, cubesYSlider, cubesZSlider, speedSlider;
+static Widget orientizeSwitch, practiceSwitch;
 static char buff[21];
 static Widget descriptionDialog, featuresDialog;
 static Widget optionsDialog, referencesDialog, aboutDialog;
@@ -304,19 +302,19 @@ static char userNameDsp[USER_NAME_LENGTH] = "";
 
 #ifdef HAVE_MOTIF
 static void
-PrintState(Widget w, char *msg)
+printState(Widget w, char *msg)
 {
 	XmString xmstr;
 
 	if (!XtIsSubclass(w, xmLabelWidgetClass))
-		XtError("PrintState() requires a Label Widget");
+		XtError("printState() requires a Label Widget");
 	xmstr = XmStringCreateLtoR(msg, XmSTRING_DEFAULT_CHARSET);
 	XtVaSetValues(w, XmNlabelString, xmstr, NULL);
 }
 #endif
 
 static void
-PrintRecords(void)
+printRecords(void)
 {
 	int i, j, k, orient;
 
@@ -336,7 +334,7 @@ PrintRecords(void)
 #endif
 
 static void
-InitRecords(void)
+initRecords(void)
 {
 	int i, j, k, orient;
 
@@ -363,7 +361,7 @@ InitRecords(void)
 }
 
 static void
-ReadRecords(void)
+readRecords(void)
 {
 	FILE *fp;
 	int i, j, k, n, orient;
@@ -436,7 +434,7 @@ ReadRecords(void)
 }
 
 static void
-WriteRecords(void)
+writeRecords(void)
 {
 	FILE *fp;
 	int i, j, k, orient;
@@ -492,7 +490,7 @@ WriteRecords(void)
 }
 
 static void
-PrintRecord(int sizex, int sizey, int sizez, Boolean orient, Boolean practice)
+printRecord(int sizex, int sizey, int sizez, Boolean orient, Boolean practice)
 {
 	int i = sizex - MIN_FACETS, j = sizey - MIN_FACETS, k = sizez - MIN_FACETS;
 	int l = (orient) ? 1 : 0;
@@ -510,7 +508,7 @@ PrintRecord(int sizex, int sizey, int sizez, Boolean orient, Boolean practice)
 			puzzleRecord[l][i][j][k].name);
 	}
 #ifdef HAVE_MOTIF
-	PrintState(record, recordDsp);
+	printState(recordText, recordDsp);
 #endif
 }
 
@@ -518,7 +516,7 @@ PrintRecord(int sizex, int sizey, int sizez, Boolean orient, Boolean practice)
 /* There is probably a better way to assure that they are the same
  * but I do not know it off hand. */
 static void
-MakeEquivalent(String *userName, String *scoreFile,
+makeEquivalent(String *userName, String *scoreFile,
 		int *sizex, int *sizey, int *sizez,
 		Boolean *orient, Boolean *practice, int *delay)
 {
@@ -556,9 +554,9 @@ MakeEquivalent(String *userName, String *scoreFile,
 	if (strcmp(*scoreFile, ""))
 		(void) strncpy(scoreFileName, *scoreFile, FILE_NAME_LENGTH);
 	if (scoreOnly) {
-		InitRecords();
-		ReadRecords();
-		PrintRecords();
+		initRecords();
+		readRecords();
+		printRecords();
 		exit(0);
 	}
 	XtVaSetValues(puzzle2d,
@@ -612,16 +610,16 @@ MakeEquivalent(String *userName, String *scoreFile,
 #endif
 
 static void
-PrintStatus(char *msg, int nMoves
+printStatus(char *msg, int nMoves
 #ifndef HAVE_MOTIF
 		, int dim, int sizeX, int sizeY, int sizeZ
 #endif
 		)
 {
 #ifdef HAVE_MOTIF
-	PrintState(message, msg);
+	printState(message, msg);
 	(void) sprintf(buff, "%d", nMoves);
-	PrintState(moves, buff);
+	printState(movesText, buff);
 #else
 #ifdef HAVE_OPENGL
 	if (dim == 4)
@@ -648,7 +646,7 @@ PrintStatus(char *msg, int nMoves
 }
 
 static Boolean
-HandleSolved(int counter, int sizex, int sizey, int sizez, Boolean orient)
+handleSolved(int counter, int sizex, int sizey, int sizez, Boolean orient)
 {
 	int i = sizex - MIN_FACETS, j = sizey - MIN_FACETS, k = sizez - MIN_FACETS;
 	int l = (orient) ? 1 : 0;
@@ -656,7 +654,7 @@ HandleSolved(int counter, int sizex, int sizey, int sizez, Boolean orient)
 	if (sizex <= MAX_FACETS && sizey <= MAX_FACETS && sizez <= MAX_FACETS &&
 			(counter < puzzleRecord[l][i][j][k].score ||
 			puzzleRecord[l][i][j][k].score <= NEVER)) {
-		ReadRecords();	/* Maybe its been updated by another */
+		readRecords();	/* Maybe its been updated by another */
 		puzzleRecord[l][i][j][k].score = counter;
 		(void) strncpy(puzzleRecord[l][i][j][k].name, userNameDsp,
 			USER_NAME_LENGTH);
@@ -668,15 +666,15 @@ HandleSolved(int counter, int sizex, int sizey, int sizez, Boolean orient)
 			(void) strncpy(puzzleRecord[!l][i][j][k].name,
 				userNameDsp, USER_NAME_LENGTH);
 		}
-		WriteRecords();
-		PrintRecord(sizex, sizey, sizez, orient, False);
+		writeRecords();
+		printRecord(sizex, sizey, sizez, orient, False);
 		return True;
 	}
 	return False;
 }
 
 static void
-Initialize(
+initialize(
 #ifdef WINVER
 RubikWidget w, HBRUSH brush
 #else
@@ -690,7 +688,7 @@ void
 #ifdef WINVER
 	int dim;
 
-	InitializePuzzle(w, brush);
+	initializePuzzle(w, brush);
 
 	sizex = w->rubik.sizex;
 	sizey = w->rubik.sizey;
@@ -706,25 +704,25 @@ void
 #else
 	int delay;
 
-	MakeEquivalent(&userName, &scoreFile, &sizex, &sizey, &sizez,
+	makeEquivalent(&userName, &scoreFile, &sizex, &sizey, &sizez,
 		&orient, &practice, &delay);
 #ifdef HAVE_MOTIF
 	if (sizex > MAX_FACETS)
-		XtVaSetValues(cubesx, XmNmaximum, sizex, NULL);
-	XmScaleSetValue(cubesx, sizex);
+		XtVaSetValues(cubesXSlider, XmNmaximum, sizex, NULL);
+	XmScaleSetValue(cubesXSlider, sizex);
 	if (sizey > MAX_FACETS)
-		XtVaSetValues(cubesy, XmNmaximum, sizey, NULL);
-	XmScaleSetValue(cubesy, sizey);
+		XtVaSetValues(cubesYSlider, XmNmaximum, sizey, NULL);
+	XmScaleSetValue(cubesYSlider, sizey);
 	if (sizez > MAX_FACETS)
-		XtVaSetValues(cubesz, XmNmaximum, sizez, NULL);
-	XmScaleSetValue(cubesz, sizez);
+		XtVaSetValues(cubesZSlider, XmNmaximum, sizez, NULL);
+	XmScaleSetValue(cubesZSlider, sizez);
 	XmToggleButtonSetState(orientizeSwitch, orient, True);
 	XmToggleButtonSetState(practiceSwitch, practice, True);
-	XmScaleSetValue(speed, MAX_SPEED + MIN_SPEED - delay - 1);
+	XmScaleSetValue(speedSlider, MAX_SPEED + MIN_SPEED - delay - 1);
 #endif
 #endif
-	InitRecords();
-	ReadRecords();
+	initRecords();
+	readRecords();
 #ifndef WINVER
 	(void) strncpy(userNameDsp, userName, USER_NAME_LENGTH);
 #endif
@@ -749,17 +747,17 @@ void
 			(void) sprintf(userNameDsp, "%s", "guest");
 #endif
 	}
-	PrintRecord(sizex, sizey, sizez, orient, practice);
+	printRecord(sizex, sizey, sizez, orient, practice);
 #ifdef WINVER
-	PrintStatus(messageDsp, movesDsp, dim, sizex, sizey, sizez);
+	printStatus(messageDsp, movesDsp, dim, sizex, sizey, sizez);
 #else
 #ifdef HAVE_MOTIF
-	PrintStatus(messageDsp, movesDsp);
+	printStatus(messageDsp, movesDsp);
 #else
-	PrintStatus(messageDsp, movesDsp, 2, sizex, sizey, sizez);
-	PrintStatus(messageDsp, movesDsp, 3, sizex, sizey, sizez);
+	printStatus(messageDsp, movesDsp, 2, sizex, sizey, sizez);
+	printStatus(messageDsp, movesDsp, 3, sizex, sizey, sizez);
 #ifdef HAVE_OPENGL
-	PrintStatus(messageDsp, movesDsp, 4, sizex, sizey, sizez);
+	printStatus(messageDsp, movesDsp, 4, sizex, sizey, sizez);
 #endif
 #endif
 #endif
@@ -770,7 +768,7 @@ void
 setPuzzle(RubikWidget w, int reason)
 #else
 static void
-CallbackPuzzle(Widget w, caddr_t clientData, rubikCallbackStruct *callData)
+puzzleListener(Widget w, caddr_t clientData, rubikCallbackStruct *callData)
 #endif
 {
 	int sizex, sizey, sizez;
@@ -900,7 +898,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, rubikCallbackStruct *callData)
 			(void) strncpy(recordDsp, "practice",
 				MESSAGE_LENGTH);
 #ifdef HAVE_MOTIF
-			PrintState(record, recordDsp);
+			printState(recordText, recordDsp);
 #endif
 		}
 		movesDsp = 0;
@@ -991,7 +989,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, rubikCallbackStruct *callData)
 		else if (cheat)
 			(void) sprintf(messageDsp,
 				"No cheating %s!!", userNameDsp);
-		else if (HandleSolved(movesDsp, sizex, sizey, sizez,
+		else if (handleSolved(movesDsp, sizex, sizey, sizez,
 				orient))
 			(void) sprintf(messageDsp,
 				"Congratulations %s!!", userNameDsp);
@@ -1025,7 +1023,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, rubikCallbackStruct *callData)
 		if (!practice)
 			(void) strncpy(messageDsp, "Randomize to start",
 				MESSAGE_LENGTH);
-		PrintRecord(sizex, sizey, sizez, orient, practice);
+		printRecord(sizex, sizey, sizez, orient, practice);
 #ifdef WINVER
 		w->rubik.practice = practice;
 		w->rubik.started = False;
@@ -1090,7 +1088,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, rubikCallbackStruct *callData)
 	case ACTION_ORIENTIZE:
 		movesDsp = 0;
 		orient = !orient;
-		PrintRecord(sizex, sizey, sizez, orient, practice);
+		printRecord(sizex, sizey, sizez, orient, practice);
 #ifdef WINVER
 		w->rubik.orient = orient;
 #else
@@ -1107,7 +1105,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, rubikCallbackStruct *callData)
 	case ACTION_INCX:
 		movesDsp = 0;
 		sizex++;
-		PrintRecord(sizex, sizey, sizez, orient, practice);
+		printRecord(sizex, sizey, sizez, orient, practice);
 #ifdef WINVER
 		w->rubik.sizex = sizex;
 #else
@@ -1118,15 +1116,15 @@ CallbackPuzzle(Widget w, caddr_t clientData, rubikCallbackStruct *callData)
 		XtVaSetValues(otherw1, XtNsizex, sizex, NULL);
 #ifdef HAVE_MOTIF
 		if (sizex > MAX_FACETS)
-			XtVaSetValues(cubesx, XmNmaximum, sizex, NULL);
-		XmScaleSetValue(cubesx, sizex);
+			XtVaSetValues(cubesXSlider, XmNmaximum, sizex, NULL);
+		XmScaleSetValue(cubesXSlider, sizex);
 #endif
 #endif
 		break;
 	case ACTION_DECX:
 		movesDsp = 0;
 		sizex--;
-		PrintRecord(sizex, sizey, sizez, orient, practice);
+		printRecord(sizex, sizey, sizez, orient, practice);
 #ifdef WINVER
 		w->rubik.sizex = sizex;
 #else
@@ -1136,16 +1134,16 @@ CallbackPuzzle(Widget w, caddr_t clientData, rubikCallbackStruct *callData)
 #endif
 		XtVaSetValues(otherw1, XtNsizex, sizex, NULL);
 #ifdef HAVE_MOTIF
-		XmScaleSetValue(cubesx, sizex);
+		XmScaleSetValue(cubesXSlider, sizex);
 		if (sizex >= MAX_FACETS)
-			XtVaSetValues(cubesx, XmNmaximum, sizex, NULL);
+			XtVaSetValues(cubesXSlider, XmNmaximum, sizex, NULL);
 #endif
 #endif
 		break;
 	case ACTION_INCY:
 		movesDsp = 0;
 		sizey++;
-		PrintRecord(sizex, sizey, sizez, orient, practice);
+		printRecord(sizex, sizey, sizez, orient, practice);
 #ifdef WINVER
 		w->rubik.sizey = sizey;
 #else
@@ -1156,15 +1154,15 @@ CallbackPuzzle(Widget w, caddr_t clientData, rubikCallbackStruct *callData)
 		XtVaSetValues(otherw1, XtNsizey, sizey, NULL);
 #ifdef HAVE_MOTIF
 		if (sizey > MAX_FACETS)
-			XtVaSetValues(cubesy, XmNmaximum, sizey, NULL);
-		XmScaleSetValue(cubesy, sizey);
+			XtVaSetValues(cubesYSlider, XmNmaximum, sizey, NULL);
+		XmScaleSetValue(cubesYSlider, sizey);
 #endif
 #endif
 		break;
 	case ACTION_DECY:
 		movesDsp = 0;
 		sizey--;
-		PrintRecord(sizex, sizey, sizez, orient, practice);
+		printRecord(sizex, sizey, sizez, orient, practice);
 #ifdef WINVER
 		w->rubik.sizey = sizey;
 #else
@@ -1174,16 +1172,16 @@ CallbackPuzzle(Widget w, caddr_t clientData, rubikCallbackStruct *callData)
 #endif
 		XtVaSetValues(otherw1, XtNsizey, sizey, NULL);
 #ifdef HAVE_MOTIF
-		XmScaleSetValue(cubesy, sizey);
+		XmScaleSetValue(cubesYSlider, sizey);
 		if (sizey >= MAX_FACETS)
-			XtVaSetValues(cubesy, XmNmaximum, sizey, NULL);
+			XtVaSetValues(cubesYSlider, XmNmaximum, sizey, NULL);
 #endif
 #endif
 		break;
 	case ACTION_INCZ:
 		movesDsp = 0;
 		sizez++;
-		PrintRecord(sizex, sizey, sizez, orient, practice);
+		printRecord(sizex, sizey, sizez, orient, practice);
 #ifdef WINVER
 		w->rubik.sizez = sizez;
 #else
@@ -1194,15 +1192,15 @@ CallbackPuzzle(Widget w, caddr_t clientData, rubikCallbackStruct *callData)
 		XtVaSetValues(otherw1, XtNsizez, sizez, NULL);
 #ifdef HAVE_MOTIF
 		if (sizez > MAX_FACETS)
-			XtVaSetValues(cubesz, XmNmaximum, sizez, NULL);
-		XmScaleSetValue(cubesz, sizez);
+			XtVaSetValues(cubesZSlider, XmNmaximum, sizez, NULL);
+		XmScaleSetValue(cubesZSlider, sizez);
 #endif
 #endif
 		break;
 	case ACTION_DECZ:
 		movesDsp = 0;
 		sizez--;
-		PrintRecord(sizex, sizey, sizez, orient, practice);
+		printRecord(sizex, sizey, sizez, orient, practice);
 #ifdef WINVER
 		w->rubik.sizez = sizez;
 #else
@@ -1212,9 +1210,9 @@ CallbackPuzzle(Widget w, caddr_t clientData, rubikCallbackStruct *callData)
 #endif
 		XtVaSetValues(otherw1, XtNsizez, sizez, NULL);
 #ifdef HAVE_MOTIF
-		XmScaleSetValue(cubesz, sizez);
+		XmScaleSetValue(cubesZSlider, sizez);
 		if (sizez >= MAX_FACETS)
-			XtVaSetValues(cubesz, XmNmaximum, sizez, NULL);
+			XtVaSetValues(cubesZSlider, XmNmaximum, sizez, NULL);
 #endif
 #endif
 		break;
@@ -1308,15 +1306,15 @@ CallbackPuzzle(Widget w, caddr_t clientData, rubikCallbackStruct *callData)
 #endif
 	}
 #ifdef WINVER
-	PrintStatus(messageDsp, movesDsp, dim, sizex, sizey, sizez);
+	printStatus(messageDsp, movesDsp, dim, sizex, sizey, sizez);
 #else
 #ifdef HAVE_MOTIF
-	PrintStatus(messageDsp, movesDsp);
+	printStatus(messageDsp, movesDsp);
 #else
-	PrintStatus(messageDsp, movesDsp, dim, sizex, sizey, sizez);
-	PrintStatus(messageDsp, movesDsp, otherdim1, sizex, sizey, sizez);
+	printStatus(messageDsp, movesDsp, dim, sizex, sizey, sizez);
+	printStatus(messageDsp, movesDsp, otherdim1, sizex, sizey, sizez);
 #ifdef HAVE_OPENGL
-	PrintStatus(messageDsp, movesDsp, otherdim2, sizex, sizey, sizez);
+	printStatus(messageDsp, movesDsp, otherdim2, sizex, sizey, sizez);
 #endif
 #endif
 #endif
@@ -1361,19 +1359,15 @@ setPuzzleMove(RubikWidget w, int reason, int face, int position, int direction,
 		}
 		break;
 	}
-	PrintStatus(messageDsp, movesDsp, dim, sizex, sizey, sizez);
+	printStatus(messageDsp, movesDsp, dim, sizex, sizey, sizez);
 }
 
 static LRESULT CALLBACK
-About(HWND hDlg, UINT message, WPARAM wParam, LPARAM lParam)
+about(HWND hDlg, UINT message, WPARAM wParam, LPARAM lParam)
 {
-	switch (message) {
-	case WM_COMMAND:
-		if (LOWORD(wParam) == IDOK) {
-			(void) EndDialog(hDlg, TRUE);
-			return TRUE;
-		}
-		break;
+	if (message == WM_COMMAND && LOWORD(wParam) == IDOK) {
+		(void) EndDialog(hDlg, TRUE);
+		return TRUE;
 	}
 	return FALSE;
 }
@@ -1390,7 +1384,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_BRUSH));
-			EnterPuzzle(&widget);
+			enterPuzzle(&widget);
 			(void) EndPaint(hWnd, &paint);
 		}
 	} else {
@@ -1398,40 +1392,40 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_BRUSH));
-			LeavePuzzle(&widget);
+			leavePuzzle(&widget);
 			(void) EndPaint(hWnd, &paint);
 		}
 	}
 	switch (message) {
 	case WM_CREATE:
-		Initialize(&widget, brush);
+		initialize(&widget, brush);
 		break;
 	case WM_DESTROY:
-		DestroyPuzzle(brush);
+		destroyPuzzle(brush);
 		break;
 	case WM_SIZE:
-		ResizePuzzle(&widget);
+		resizePuzzle(&widget);
 		(void) InvalidateRect(hWnd, NULL, TRUE);
 		break;
 	case WM_PAINT:
 		widget.core.hDC = BeginPaint(hWnd, &paint);
 		(void) SelectObject(widget.core.hDC,
 			GetStockObject(NULL_PEN));
-		ExposePuzzle(&widget);
+		exposePuzzle(&widget);
 		(void) EndPaint(hWnd, &paint);
 		break;
 	case WM_RBUTTONDOWN:
 		widget.core.hDC = GetDC(hWnd);
 		(void) SelectObject(widget.core.hDC,
 			GetStockObject(NULL_PEN));
-		RandomizePuzzle(&widget);
+		randomizePuzzle(&widget);
 		(void) ReleaseDC(hWnd, widget.core.hDC);
 		break;
 	case WM_LBUTTONDOWN:
 		widget.core.hDC = GetDC(hWnd);
 		(void) SelectObject(widget.core.hDC,
 			GetStockObject(NULL_PEN));
-		SelectPuzzle(&widget, LOWORD(lParam), HIWORD(lParam),
+		selectPuzzle(&widget, LOWORD(lParam), HIWORD(lParam),
 			(GetKeyState(VK_CONTROL) >> 1) ? 1 : 0);
 		(void) ReleaseDC(hWnd, widget.core.hDC);
 		break;
@@ -1439,7 +1433,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 		widget.core.hDC = GetDC(hWnd);
 		(void) SelectObject(widget.core.hDC,
 			GetStockObject(NULL_PEN));
-		ReleasePuzzle(&widget, LOWORD(lParam), HIWORD(lParam),
+		releasePuzzle(&widget, LOWORD(lParam), HIWORD(lParam),
 			(GetKeyState(VK_CONTROL) >> 1) ? 1 : 0);
 		(void) ReleaseDC(hWnd, widget.core.hDC);
 		break;
@@ -1456,13 +1450,13 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			ClientToScreen(hWnd, &origin);
 			(void) GetCursorPos(&cursor);
 			if (zDelta > (WHEEL_DELTA >> 1)) {
-				MovePuzzleInput(&widget,
+				movePuzzleInput(&widget,
 					cursor.x - origin.x,
 					cursor.y - origin.y,
 					TOP,
 					(GetKeyState(VK_CONTROL) >> 1) ? 1 : 0);
 			} else if (zDelta < -(WHEEL_DELTA >> 1)) {
-				MovePuzzleInput(&widget,
+				movePuzzleInput(&widget,
 					cursor.x - origin.x,
 					cursor.y - origin.y,
 					BOTTOM,
@@ -1475,70 +1469,70 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 	case WM_COMMAND:
 		switch (LOWORD(wParam)) {
 		case ACTION_GET:
-			GetPuzzle(&widget);
-			ResizePuzzle(&widget);
+			getPuzzle(&widget);
+			resizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
 		case ACTION_WRITE:
-			WritePuzzle(&widget);
+			writePuzzle(&widget);
 			break;
 		case ACTION_EXIT:
-			DestroyPuzzle(brush);
+			destroyPuzzle(brush);
 			break;
 		case ACTION_HIDE:
-			HidePuzzle(&widget);
+			hidePuzzle(&widget);
 			break;
 		case ACTION_UNDO:
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_PEN));
-			UndoPuzzle(&widget);
+			undoPuzzle(&widget);
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
 		case ACTION_REDO:
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_PEN));
-			RedoPuzzle(&widget);
+			redoPuzzle(&widget);
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
 		case ACTION_CLEAR:
-			ClearPuzzle(&widget);
-			SizePuzzle(&widget);
+			clearPuzzle(&widget);
+			sizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
 		case ACTION_RANDOMIZE:
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_PEN));
-			RandomizePuzzle(&widget);
+			randomizePuzzle(&widget);
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
 		case ACTION_PRACTICE:
-			PracticePuzzle(&widget);
-			SizePuzzle(&widget);
+			practicePuzzle(&widget);
+			sizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
 		case ACTION_SOLVE:
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_PEN));
-			SolvePuzzle(&widget);
+			solvePuzzle(&widget);
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
 		case ACTION_ORIENTIZE:
-			OrientizePuzzle(&widget);
-			SizePuzzle(&widget);
+			orientizePuzzle(&widget);
+			sizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
 		case ACTION_DIM:
-			(void) DimPuzzle(&widget);
-			ResizePuzzle(&widget);
+			(void) dimPuzzle(&widget);
+			resizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
 		case ACTION_VIEW:
-			(void) ViewPuzzle(&widget);
-			SizePuzzle(&widget);
+			(void) viewPuzzle(&widget);
+			sizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
 		case ACTION_TOP:
@@ -1560,7 +1554,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 				origin.x = 0, origin.y = 0;
 				ClientToScreen(hWnd, &origin);
 				(void) GetCursorPos(&cursor);
-				(void) MovePuzzleInput(&widget,
+				(void) movePuzzleInput(&widget,
 					cursor.x - origin.x,
 					cursor.y - origin.y,
 					(int) LOWORD(wParam) - ACTION_TOP,
@@ -1585,7 +1579,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 				origin.x = 0, origin.y = 0;
 				ClientToScreen(hWnd, &origin);
 				(void) GetCursorPos(&cursor);
-				(void) MovePuzzleInput(&widget,
+				(void) movePuzzleInput(&widget,
 					cursor.x - origin.x,
 					cursor.y - origin.y,
 					(int) LOWORD(wParam) - ACTION_CONTROL_TOP,
@@ -1594,53 +1588,53 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			}
 			break;
 		case ACTION_INCREMENT:
-			IncrementPuzzle(&widget);
-			SizePuzzle(&widget);
+			incrementPuzzle(&widget);
+			sizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
 		case ACTION_DECREMENT:
-			DecrementPuzzle(&widget);
-			SizePuzzle(&widget);
+			decrementPuzzle(&widget);
+			sizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
 		case ACTION_INCX:
-			IncrementAxisPuzzle(&widget, 'x');
-			SizePuzzle(&widget);
+			incrementAxisPuzzle(&widget, 'x');
+			sizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
 		case ACTION_DECX:
-			IncrementAxisPuzzle(&widget, 'X');
-			SizePuzzle(&widget);
+			incrementAxisPuzzle(&widget, 'X');
+			sizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
 		case ACTION_INCY:
-			IncrementAxisPuzzle(&widget, 'y');
-			SizePuzzle(&widget);
+			incrementAxisPuzzle(&widget, 'y');
+			sizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
 		case ACTION_DECY:
-			IncrementAxisPuzzle(&widget, 'Y');
-			SizePuzzle(&widget);
+			incrementAxisPuzzle(&widget, 'Y');
+			sizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
 		case ACTION_INCZ:
-			IncrementAxisPuzzle(&widget, 'z');
-			SizePuzzle(&widget);
+			incrementAxisPuzzle(&widget, 'z');
+			sizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
 		case ACTION_DECZ:
-			IncrementAxisPuzzle(&widget, 'Z');
-			SizePuzzle(&widget);
+			incrementAxisPuzzle(&widget, 'Z');
+			sizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
 		case ACTION_SPEED:
-			SpeedPuzzle(&widget);
+			speedUpPuzzle(&widget);
 			break;
 		case ACTION_SLOW:
-			SlowPuzzle(&widget);
+			slowDownPuzzle(&widget);
 			break;
 		case ACTION_SOUND:
-			SoundPuzzle(&widget);
+			toggleSoundPuzzle(&widget);
 			break;
 		case ACTION_DESCRIPTION:
 			(void) MessageBox(hWnd, descriptionHelp,
@@ -1656,7 +1650,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			break;
 		case ACTION_ABOUT:
 			(void) DialogBox(widget.core.hInstance,
-				"About", hWnd, (DLGPROC) About);
+				"About", hWnd, (DLGPROC) about);
 			break;
 		}
 		break;
@@ -1716,7 +1710,7 @@ WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance, LPSTR lpCmdLine,
 
 #else
 static void
-Usage(char *programName)
+usage(char *programName)
 {
 	unsigned int i;
 
@@ -1771,7 +1765,7 @@ static XrmOptionDescRec options[] =
 
 #ifdef HAVE_MOTIF
 static void
-CallbackPuzzlePractice(Widget w, XtPointer clientData,
+puzzlePracticeListener(Widget w, XtPointer clientData,
 		XmAnyCallbackStruct *cbs)
 {
 	if (cbs->reason == XmCR_OK) {
@@ -1780,7 +1774,7 @@ CallbackPuzzlePractice(Widget w, XtPointer clientData,
 }
 
 static void
-CallbackPuzzleRandomize(Widget w, XtPointer clientData,
+puzzleRandomizeListener(Widget w, XtPointer clientData,
 		XmAnyCallbackStruct *cbs)
 {
 	if (cbs->reason == XmCR_OK) {
@@ -1789,7 +1783,7 @@ CallbackPuzzleRandomize(Widget w, XtPointer clientData,
 }
 
 static void
-CubesXSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
+cubesXChangeListener(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 {
 	int sizex = cbs->value, old, sizey, sizez;
 	Boolean orient, practice;
@@ -1811,15 +1805,15 @@ CubesXSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 #endif
 		movesDsp = 0;
 		(void) sprintf(buff, "%d", movesDsp);
-		PrintState(moves, buff);
-		PrintRecord(sizex, sizey, sizez, orient, practice);
+		printState(movesText, buff);
+		printRecord(sizex, sizey, sizez, orient, practice);
 		(void) strcpy(messageDsp, "");
-		PrintState(message, messageDsp);
+		printState(message, messageDsp);
 	}
 }
 
 static void
-CubesYSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
+cubesYChangeListener(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 {
 	int sizey = cbs->value, old, sizex, sizez;
 	Boolean orient, practice;
@@ -1841,15 +1835,15 @@ CubesYSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 #endif
 		movesDsp = 0;
 		(void) sprintf(buff, "%d", movesDsp);
-		PrintState(moves, buff);
-		PrintRecord(sizex, sizey, sizez, orient, practice);
+		printState(movesText, buff);
+		printRecord(sizex, sizey, sizez, orient, practice);
 		(void) strcpy(messageDsp, "");
-		PrintState(message, messageDsp);
+		printState(message, messageDsp);
 	}
 }
 
 static void
-CubesZSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
+cubesZChangeListener(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 {
 	int sizez = cbs->value, old, sizex, sizey;
 	Boolean orient, practice;
@@ -1871,15 +1865,15 @@ CubesZSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 #endif
 		movesDsp = 0;
 		(void) sprintf(buff, "%d", movesDsp);
-		PrintState(moves, buff);
-		PrintRecord(sizex, sizey, sizez, orient, practice);
+		printState(movesText, buff);
+		printRecord(sizex, sizey, sizez, orient, practice);
 		(void) strcpy(messageDsp, "");
-		PrintState(message, messageDsp);
+		printState(message, messageDsp);
 	}
 }
 
 static void
-OrientToggle(Widget w, XtPointer clientData, XmToggleButtonCallbackStruct *cbs)
+orientToggle(Widget w, XtPointer clientData, XmToggleButtonCallbackStruct *cbs)
 {
 	int sizex, sizey, sizez;
 	Boolean orient = cbs->set, practice;
@@ -1899,14 +1893,14 @@ OrientToggle(Widget w, XtPointer clientData, XmToggleButtonCallbackStruct *cbs)
 #endif
 	movesDsp = 0;
 	(void) sprintf(buff, "%d", movesDsp);
-	PrintState(moves, buff);
-	PrintRecord(sizex, sizey, sizez, orient, practice);
+	printState(movesText, buff);
+	printRecord(sizex, sizey, sizez, orient, practice);
 	(void) strcpy(messageDsp, "");
-	PrintState(message, messageDsp);
+	printState(message, messageDsp);
 }
 
 static void
-PracticeToggle(Widget w, XtPointer clientData, XmToggleButtonCallbackStruct *cbs)
+practiceToggle(Widget w, XtPointer clientData, XmToggleButtonCallbackStruct *cbs)
 {
 	int sizex, sizey, sizez;
 	Boolean orient, practice = cbs->set;
@@ -1929,17 +1923,17 @@ PracticeToggle(Widget w, XtPointer clientData, XmToggleButtonCallbackStruct *cbs
 		XtNpractice, &orient, NULL);
 	movesDsp = 0;
 	(void) sprintf(buff, "%d", movesDsp);
-	PrintState(moves, buff);
-	PrintRecord(sizex, sizey, sizez, orient, practice);
+	printState(movesText, buff);
+	printRecord(sizex, sizey, sizez, orient, practice);
 	if (practice)
 		(void) strcpy(messageDsp, "");
 	else
 		(void) strncpy(messageDsp, "Randomize to start", MESSAGE_LENGTH);
-	PrintState(message, messageDsp);
+	printState(message, messageDsp);
 }
 
 static void
-SpeedSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
+speedChangeListener(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 {
 	int delay = MAX_SPEED + MIN_SPEED - cbs->value - 1, oldDelay;
 
@@ -1955,7 +1949,7 @@ SpeedSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 }
 
 static void
-fileCB(Widget w, void *value, void *clientData)
+fileMenuListener(Widget w, void *value, void *clientData)
 {
 	int val = (int) value + ACTION_GET;
 
@@ -2027,7 +2021,7 @@ createHelp(Widget w, char *text, char *title)
 }
 
 static void
-helpCB(Widget w, XtPointer value, XtPointer clientData)
+helpMenuListener(Widget w, XtPointer value, XtPointer clientData)
 {
 	int val = (int) value;
 
@@ -2051,7 +2045,7 @@ helpCB(Widget w, XtPointer value, XtPointer clientData)
 		{
 			char *buf;
 
-			intCat(&buf, "helpCB: %d", val);
+			intCat(&buf, "helpMenuListener: %d", val);
 			XtWarning(buf);
 			free(buf);
 		}
@@ -2079,7 +2073,7 @@ main(int argc, char **argv)
 	topLevel = XtInitialize(argv[0], "Rubik",
 		options, XtNumber(options), &argc, argv);
 	if (argc != 1)
-		Usage(argv[0]);
+		usage(argv[0]);
 
 #ifdef HAVE_MOTIF
 	menuBarPanel = XtVaCreateManagedWidget("menuBarPanel",
@@ -2099,7 +2093,7 @@ main(int argc, char **argv)
 	writeString = XmStringCreateSimple((char *) "Write");
 	quitString = XmStringCreateSimple((char *) "Quit");
 	(void) XmVaCreateSimplePulldownMenu(menuBar, (char *) "file_menu",
-		0, fileCB,
+		0, fileMenuListener,
 		XmVaPUSHBUTTON, getString, 'G', NULL, NULL,
 		XmVaPUSHBUTTON, writeString, 'W', NULL, NULL,
 		XmVaSEPARATOR,
@@ -2160,23 +2154,23 @@ main(int argc, char **argv)
 	widget = XtVaCreateManagedWidget("Description",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'D', NULL);
-	XtAddCallback(widget, XmNactivateCallback, helpCB, (char *) 0);
+	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 0);
 	widget = XtVaCreateManagedWidget("FeaTures",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'F', NULL);
-	XtAddCallback(widget, XmNactivateCallback, helpCB, (char *) 1);
+	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 1);
 	widget = XtVaCreateManagedWidget("Options",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'O', NULL);
-	XtAddCallback(widget, XmNactivateCallback, helpCB, (char *) 2);
+	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 2);
 	widget = XtVaCreateManagedWidget("References",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'R', NULL);
-	XtAddCallback(widget, XmNactivateCallback, helpCB, (char *) 3);
+	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 3);
 	widget = XtVaCreateManagedWidget("About",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'A', NULL);
-	XtAddCallback(widget, XmNactivateCallback, helpCB, (char *) 4);
+	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 4);
 	XtManageChild(menuBar);
 	descriptionDialog = createHelp(menuBar, (char *) descriptionHelp,
 		(char *) "Description");
@@ -2193,11 +2187,11 @@ main(int argc, char **argv)
 	practiceDialog = createQuery(topLevel,
 		(char *) "Are you sure you want to toggle the practice mode?",
 		(char *) "Practice Query",
-		(XtCallbackProc) CallbackPuzzlePractice);
+		(XtCallbackProc) puzzlePracticeListener);
 	randomizeDialog = createQuery(topLevel,
 		(char *) "Are you sure you want to randomize?",
 		(char *) "Randomize Query",
-		(XtCallbackProc) CallbackPuzzleRandomize);
+		(XtCallbackProc) puzzleRandomizeListener);
 	mainPanel = XtCreateManagedWidget("mainPanel",
 		xmPanedWindowWidgetClass, menuBarPanel,
 		NULL, 0);
@@ -2253,12 +2247,12 @@ main(int argc, char **argv)
 	(void) XtVaCreateManagedWidget("movesText",
 		xmLabelGadgetClass, movesRowCol,
 		XtVaTypedArg, XmNlabelString, XmRString, "Moves", 6, NULL);
-	moves = XtVaCreateManagedWidget("0",
+	movesText = XtVaCreateManagedWidget("0",
 		xmLabelWidgetClass, movesRowCol, NULL);
 	(void) XtVaCreateManagedWidget("recordText",
 		xmLabelGadgetClass, movesRowCol,
 		XtVaTypedArg, XmNlabelString, XmRString, "Record", 7, NULL);
-	record = XtVaCreateManagedWidget("0",
+	recordText = XtVaCreateManagedWidget("0",
 		xmLabelWidgetClass, movesRowCol, NULL);
 
 	cubesRowCol = XtVaCreateManagedWidget("cubesRowCol",
@@ -2266,7 +2260,7 @@ main(int argc, char **argv)
 		XmNnumColumns, 1,
 		XmNorientation, XmHORIZONTAL,
 		XmNpacking, XmPACK_COLUMN, NULL);
-	cubesx = XtVaCreateManagedWidget("cubesx",
+	cubesXSlider = XtVaCreateManagedWidget("cubesXSlider",
 		xmScaleWidgetClass, cubesRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Size X", 7,
 		XmNminimum, MIN_FACETS,
@@ -2274,9 +2268,9 @@ main(int argc, char **argv)
 		XmNvalue, MIN_FACETS,
 		XmNshowValue, True,
 		XmNorientation, XmHORIZONTAL, NULL);
-	XtAddCallback(cubesx, XmNvalueChangedCallback,
-		(XtCallbackProc) CubesXSlider, (XtPointer) NULL);
-	cubesy = XtVaCreateManagedWidget("cubesy",
+	XtAddCallback(cubesXSlider, XmNvalueChangedCallback,
+		(XtCallbackProc) cubesXChangeListener, (XtPointer) NULL);
+	cubesYSlider = XtVaCreateManagedWidget("cubesYSlider",
 		xmScaleWidgetClass, cubesRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Size Y", 7,
 		XmNminimum, MIN_FACETS,
@@ -2284,9 +2278,9 @@ main(int argc, char **argv)
 		XmNvalue, MIN_FACETS,
 		XmNshowValue, True,
 		XmNorientation, XmHORIZONTAL, NULL);
-	XtAddCallback(cubesy, XmNvalueChangedCallback,
-		(XtCallbackProc) CubesYSlider, (XtPointer) NULL);
-	cubesz = XtVaCreateManagedWidget("cubesz",
+	XtAddCallback(cubesYSlider, XmNvalueChangedCallback,
+		(XtCallbackProc) cubesYChangeListener, (XtPointer) NULL);
+	cubesZSlider = XtVaCreateManagedWidget("cubesZSlider",
 		xmScaleWidgetClass, cubesRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Size Z", 7,
 		XmNminimum, MIN_FACETS,
@@ -2294,8 +2288,8 @@ main(int argc, char **argv)
 		XmNvalue, MIN_FACETS,
 		XmNshowValue, True,
 		XmNorientation, XmHORIZONTAL, NULL);
-	XtAddCallback(cubesz, XmNvalueChangedCallback,
-		(XtCallbackProc) CubesZSlider, (XtPointer) NULL);
+	XtAddCallback(cubesZSlider, XmNvalueChangedCallback,
+		(XtCallbackProc) cubesZChangeListener, (XtPointer) NULL);
 	switchRowCol = XtVaCreateManagedWidget("switchRowCol",
 		xmRowColumnWidgetClass, controlPanel,
 		XmNnumColumns, 1,
@@ -2305,13 +2299,13 @@ main(int argc, char **argv)
 		xmToggleButtonWidgetClass, switchRowCol,
 		XmNset, DEFAULT_ORIENT, NULL);
 	XtAddCallback(orientizeSwitch, XmNvalueChangedCallback,
-		(XtCallbackProc) OrientToggle, (XtPointer) NULL);
+		(XtCallbackProc) orientToggle, (XtPointer) NULL);
 	practiceSwitch = XtVaCreateManagedWidget("Practice",
 		xmToggleButtonWidgetClass, switchRowCol,
 		XmNset, DEFAULT_PRACTICE, NULL);
 	XtAddCallback(practiceSwitch, XmNvalueChangedCallback,
-		(XtCallbackProc) PracticeToggle, (XtPointer) NULL);
-	speed = XtVaCreateManagedWidget("speed",
+		(XtCallbackProc) practiceToggle, (XtPointer) NULL);
+	speedSlider = XtVaCreateManagedWidget("speedSlider",
 		xmScaleWidgetClass, switchRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Animation Speed", 16,
 		XmNminimum, MIN_SPEED,
@@ -2319,8 +2313,8 @@ main(int argc, char **argv)
 		XmNvalue, MAX_SPEED - 10,
 		XmNshowValue, True,
 		XmNorientation, XmHORIZONTAL, NULL);
-	XtAddCallback(speed, XmNvalueChangedCallback,
-		(XtCallbackProc) SpeedSlider, (XtPointer) NULL);
+	XtAddCallback(speedSlider, XmNvalueChangedCallback,
+		(XtCallbackProc) speedChangeListener, (XtPointer) NULL);
 	messageRowCol = XtVaCreateManagedWidget("messageRowCol",
 		xmRowColumnWidgetClass, controlPanel, NULL);
 	message = XtVaCreateManagedWidget("Play Rubik's Cube! (use mouse and keypad)",
@@ -2330,7 +2324,7 @@ main(int argc, char **argv)
 	XtVaSetValues(puzzle2d,
 		XtNheight, 200, NULL);
 	XtAddCallback(puzzle2d, XtNselectCallback,
-		(XtCallbackProc) CallbackPuzzle, (XtPointer) NULL);
+		(XtCallbackProc) puzzleListener, (XtPointer) NULL);
 	puzzle3d = XtCreateManagedWidget("rubik",
 		rubik3dWidgetClass, mainPanel, NULL, 0);
 	XtVaSetValues(puzzle3d,
@@ -2394,10 +2388,8 @@ main(int argc, char **argv)
 		XtNinput, True,
 		XtNiconPixmap, pixmap, NULL);
 #endif
-	XtAddCallback(puzzle2d, XtNselectCallback,
-		(XtCallbackProc) CallbackPuzzle, (XtPointer) NULL);
 	XtAddCallback(puzzle3d, XtNselectCallback,
-		(XtCallbackProc) CallbackPuzzle, (XtPointer) NULL);
+		(XtCallbackProc) puzzleListener, (XtPointer) NULL);
 #ifdef HAVE_OPENGL
 #ifndef HAVE_MOTIF
 	XtVaSetValues(shellGL,
@@ -2405,9 +2397,9 @@ main(int argc, char **argv)
 		XtNiconPixmap, pixmap, NULL);
 #endif
 	XtAddCallback(puzzleGL, XtNselectCallback,
-		(XtCallbackProc) CallbackPuzzle, (XtPointer) NULL);
+		(XtCallbackProc) puzzleListener, (XtPointer) NULL);
 #endif
-	Initialize();
+	initialize();
 	XtRealizeWidget(topLevel);
 #ifndef HAVE_MOTIF
 	XtRealizeWidget(shell);
@@ -2419,12 +2411,12 @@ main(int argc, char **argv)
 		XtWindow(puzzle2d), TRUE, (unsigned int) (ButtonPressMask |
 		ButtonMotionMask | ButtonReleaseMask),
 		GrabModeAsync, GrabModeAsync, XtWindow(puzzle2d),
-		XCreateFontCursor(XtDisplay(puzzle2d), XC_crosshair));
+		XCreateFontCursor(XtDisplay(puzzle2d), XC_hand2));
 	XGrabButton(XtDisplay(puzzle3d), (unsigned int) AnyButton, AnyModifier,
 		XtWindow(puzzle3d), TRUE, (unsigned int) (ButtonPressMask |
 		ButtonMotionMask | ButtonReleaseMask),
 		GrabModeAsync, GrabModeAsync, XtWindow(puzzle3d),
-		XCreateFontCursor(XtDisplay(puzzle3d), XC_crosshair));
+		XCreateFontCursor(XtDisplay(puzzle3d), XC_hand2));
 #ifdef HAVE_OPENGL
 	XGrabButton(XtDisplay(puzzleGL), (unsigned int) AnyButton, AnyModifier,
 		XtWindow(puzzleGL), TRUE, (unsigned int) (ButtonPressMask |
