@@ -1,27 +1,22 @@
-/*-
-# X-BASED SKEWB
-#
-#  Skewb.c
-#
-###
-#
-#  Copyright (c) 1994 - 2007	David A. Bagley, bagleyd@tux.org
-#
-#                   All Rights Reserved
-#
-#  Permission to use, copy, modify, and distribute this software and
-#  its documentation for any purpose and without fee is hereby granted,
-#  provided that the above copyright notice appear in all copies and
-#  that both that copyright notice and this permission notice appear in
-#  supporting documentation, and that the name of the author not be
-#  used in advertising or publicity pertaining to distribution of the
-#  software without specific, written prior permission.
-#
-#  This program is distributed in the hope that it will be "playable",
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-#
-*/
+/*
+ * @(#)Skewb.c
+ *
+ * Copyright 1994 - 2008  David A. Bagley, bagleyd@tux.org
+ *
+ * All rights reserved.
+ *
+ * Permission to use, copy, modify, and distribute this software and
+ * its documentation for any purpose and without fee is hereby granted,
+ * provided that the above copyright notice appear in all copies and
+ * that both that copyright notice and this permission notice appear in
+ * supporting documentation, and that the name of the author not be
+ * used in advertising or publicity pertaining to distribution of the
+ * software without specific, written prior permission.
+ *
+ * This program is distributed in the hope that it will be "useful",
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ */
 
 /* Methods file for Skewb */
 
@@ -67,9 +62,9 @@ static const char faceColorChar[MAX_FACES] =
 #endif
 #endif
 
-static Boolean SetValuesPuzzle(Widget current, Widget request, Widget renew);
-static void DestroyPuzzle(Widget old);
-static void InitializePuzzle(Widget request, Widget renew);
+static Boolean setValuesPuzzle(Widget current, Widget request, Widget renew);
+static void destroyPuzzle(Widget old);
+static void initializePuzzle(Widget request, Widget renew);
 
 SkewbClassRec skewbClassRec =
 {
@@ -80,7 +75,7 @@ SkewbClassRec skewbClassRec =
 		NULL,		/* class initialize */
 		NULL,		/* class part initialize */
 		FALSE,		/* class inited */
-		(XtInitProc) InitializePuzzle,	/* initialize */
+		(XtInitProc) initializePuzzle,	/* initialize */
 		NULL,		/* initialize hook */
 		XtInheritRealize,	/* realize */
 		NULL,		/* actions */
@@ -92,10 +87,10 @@ SkewbClassRec skewbClassRec =
 		TRUE,		/* compress exposure */
 		TRUE,		/* compress enterleave */
 		TRUE,		/* visible interest */
-		(XtWidgetProc) DestroyPuzzle,	/* destroy */
+		(XtWidgetProc) destroyPuzzle,	/* destroy */
 		NULL,		/* resize */
 		NULL,		/* expose */
-		(XtSetValuesFunc) SetValuesPuzzle,	/* set values */
+		(XtSetValuesFunc) setValuesPuzzle,	/* set values */
 		NULL,		/* set values hook */
 		XtInheritSetValuesAlmost,	/* set values almost */
 		NULL,		/* get values hook */
@@ -188,7 +183,7 @@ static int facesToDirection[MAX_FACES][MAX_FACES] =
 	{-1, TOP, TOP, TOP, -1, BOTTOM},
 	{BOTTOM, RIGHT, -1, LEFT, TOP, -1}
 };
-static int facesToPosition[MAX_FACES][MAX_FACES][MAX_ORIENT] =
+static int facestoPosition[MAX_FACES][MAX_FACES][MAX_ORIENT] =
 {
 	{
 		{-1, -1, -1, -1},
@@ -603,7 +598,7 @@ static SkewbLocPos orthToDiag[MAX_FACES][MAX_ORIENT][MAX_ORIENT] =
 static SkewbStack undo, redo;
 
 Boolean
-CheckSolved(SkewbWidget w)
+checkSolved(SkewbWidget w)
 {
 	int face, position;
 	SkewbLoc test = {0, FALSE};
@@ -625,7 +620,7 @@ CheckSolved(SkewbWidget w)
 #ifdef DEBUG
 
 void
-PrintCube(SkewbWidget w)
+printCube(SkewbWidget w)
 {
 	int face, position;
 
@@ -641,61 +636,61 @@ PrintCube(SkewbWidget w)
 #endif
 
 static void
-DrawDiamond(SkewbWidget w, int face, int offset)
+drawDiamond(SkewbWidget w, int face, int offset)
 {
 	if (w->skewb.dim == 2)
-		DrawDiamond2D((Skewb2DWidget) w, face, offset);
+		drawDiamond2D((Skewb2DWidget) w, face, offset);
 	else if (w->skewb.dim == 3)
-		DrawDiamond3D((Skewb3DWidget) w, face, offset);
+		drawDiamond3D((Skewb3DWidget) w, face, offset);
 }
 
 static void
-DrawTriangle(SkewbWidget w, int face, int position, int offset)
+drawTriangle(SkewbWidget w, int face, int position, int offset)
 {
 	if (w->skewb.dim == 2)
-		DrawTriangle2D((Skewb2DWidget) w, face, position, offset);
+		drawTriangle2D((Skewb2DWidget) w, face, position, offset);
 	else if (w->skewb.dim == 3)
-		DrawTriangle3D((Skewb3DWidget) w, face, position, offset);
+		drawTriangle3D((Skewb3DWidget) w, face, position, offset);
 }
 
 void
-DrawAllPieces(SkewbWidget w)
+drawAllPieces(SkewbWidget w)
 {
 	int face, position;
 
 #ifdef HAVE_OPENGL
 	if (w->skewb.dim == 4) {
-		DrawAllPiecesGL((SkewbGLWidget) w);
+		drawAllPiecesGL((SkewbGLWidget) w);
 	}
 #endif
 	for (face = 0; face < MAX_FACES; face++) {
-		DrawDiamond(w, face, FALSE);
+		drawDiamond(w, face, FALSE);
 		for (position = 0; position < MAX_ORIENT; position++)
-			DrawTriangle(w, face, position, FALSE);
+			drawTriangle(w, face, position, FALSE);
 	}
 }
 
 static void
-DrawFrame(const SkewbWidget w, const Boolean focus)
+drawFrame(const SkewbWidget w, const Boolean focus)
 {
 	if (w->skewb.dim == 2)
-		DrawFrame2D((Skewb2DWidget) w, focus);
+		drawFrame2D((Skewb2DWidget) w, focus);
 	else if (w->skewb.dim == 3)
-		DrawFrame3D((Skewb3DWidget) w, focus);
+		drawFrame3D((Skewb3DWidget) w, focus);
 #ifdef HAVE_OPENGL
 	else if (w->skewb.dim == 4)
-		DrawFrameGL((SkewbGLWidget) w, focus);
+		drawFrameGL((SkewbGLWidget) w, focus);
 #endif
 }
 
 static void
-MoveNoPieces(SkewbWidget w)
+moveNoPieces(SkewbWidget w)
 {
 	setPuzzle(w, ACTION_ILLEGAL);
 }
 
 static void
-RotateFace(SkewbWidget w, int face, int direction)
+rotateFace(SkewbWidget w, int face, int direction)
 {
 	int corner;
 
@@ -708,21 +703,23 @@ RotateFace(SkewbWidget w, int face, int direction)
 			w->skewb.faceLoc[(corner + MAX_ORIENT - 1) % MAX_ORIENT] :
 			w->skewb.faceLoc[(corner + 1) % MAX_ORIENT];
 		w->skewb.cubeLoc[face][corner].rotation =
-			(w->skewb.cubeLoc[face][corner].rotation + direction) % MAX_ORIENT;
-		DrawTriangle(w, face, corner, FALSE);
+			(w->skewb.cubeLoc[face][corner].rotation + direction) %
+			MAX_ORIENT;
+		drawTriangle(w, face, corner, FALSE);
 	}
 	w->skewb.cubeLoc[face][MAX_ORIENT].rotation =
-		(w->skewb.cubeLoc[face][MAX_ORIENT].rotation + direction) % MAX_ORIENT;
-	DrawDiamond(w, face, FALSE);
+		(w->skewb.cubeLoc[face][MAX_ORIENT].rotation + direction) %
+		MAX_ORIENT;
+	drawDiamond(w, face, FALSE);
 #ifdef HAVE_OPENGL
 	if (w->skewb.dim == 4) {
-		DrawAllPiecesGL((SkewbGLWidget) w);
+		drawAllPiecesGL((SkewbGLWidget) w);
 	}
 #endif
 }
 
 static void
-ReadFace(SkewbWidget w, int face, int h)
+readFace(SkewbWidget w, int face, int h)
 {
 	int position;
 
@@ -731,7 +728,7 @@ ReadFace(SkewbWidget w, int face, int h)
 }
 
 static void
-WriteFace(SkewbWidget w, int face, int rotate, int h)
+writeFace(SkewbWidget w, int face, int rotate, int h)
 {
 	int corner, newCorner;
 
@@ -739,22 +736,24 @@ WriteFace(SkewbWidget w, int face, int rotate, int h)
 		newCorner = (corner + rotate) % MAX_ORIENT;
 		w->skewb.cubeLoc[face][newCorner] = w->skewb.rowLoc[h][corner];
 		w->skewb.cubeLoc[face][newCorner].rotation =
-			(w->skewb.cubeLoc[face][newCorner].rotation + rotate) % MAX_ORIENT;
-		DrawTriangle(w, face, (corner + rotate) % MAX_ORIENT, FALSE);
+			(w->skewb.cubeLoc[face][newCorner].rotation + rotate) %
+			MAX_ORIENT;
+		drawTriangle(w, face, (corner + rotate) % MAX_ORIENT, FALSE);
 	}
 	w->skewb.cubeLoc[face][MAX_ORIENT] = w->skewb.rowLoc[h][MAX_ORIENT];
 	w->skewb.cubeLoc[face][MAX_ORIENT].rotation =
-		(w->skewb.cubeLoc[face][MAX_ORIENT].rotation + rotate) % MAX_ORIENT;
-	DrawDiamond(w, face, FALSE);
+		(w->skewb.cubeLoc[face][MAX_ORIENT].rotation + rotate) %
+		MAX_ORIENT;
+	drawDiamond(w, face, FALSE);
 #ifdef HAVE_OPENGL
 	if (w->skewb.dim == 4) {
-		DrawAllPiecesGL((SkewbGLWidget) w);
+		drawAllPiecesGL((SkewbGLWidget) w);
 	}
 #endif
 }
 
 static void
-ReadDiagonal(SkewbWidget w, int face, int corner, int orient, int size)
+readDiagonal(SkewbWidget w, int face, int corner, int orient, int size)
 {
 	int g;
 
@@ -763,14 +762,15 @@ ReadDiagonal(SkewbWidget w, int face, int corner, int orient, int size)
 	else {			/* size == MAJOR */
 		for (g = 1; g < MAX_ORIENT; g++)
 			w->skewb.majorLoc[orient][g - 1] =
-				w->skewb.cubeLoc[face][(corner + g) % MAX_ORIENT];
+				w->skewb.cubeLoc[face][(corner + g) %
+				MAX_ORIENT];
 		w->skewb.majorLoc[orient][MAX_ORIENT - 1] =
 			w->skewb.cubeLoc[face][MAX_ORIENT];
 	}
 }
 
 static void
-RotateDiagonal(SkewbWidget w, int rotate, int orient, int size)
+rotateDiagonal(SkewbWidget w, int rotate, int orient, int size)
 {
 	int g;
 
@@ -784,116 +784,118 @@ RotateDiagonal(SkewbWidget w, int rotate, int orient, int size)
 }
 
 static void
-WriteDiagonal(SkewbWidget w, int face, int corner, int orient, int size)
+writeDiagonal(SkewbWidget w, int face, int corner, int orient, int size)
 {
 	int g, h;
 
 	if (size == MINOR) {
 		w->skewb.cubeLoc[face][corner] = w->skewb.minorLoc[orient];
-		DrawTriangle(w, face, corner, FALSE);
+		drawTriangle(w, face, corner, FALSE);
 	} else {		/* size == MAJOR */
 		w->skewb.cubeLoc[face][MAX_ORIENT] =
 			w->skewb.majorLoc[orient][MAX_ORIENT - 1];
-		DrawDiamond(w, face, FALSE);
+		drawDiamond(w, face, FALSE);
 		for (g = 1; g < MAX_ORIENT; g++) {
 			h = (corner + g) % MAX_ORIENT;
 			w->skewb.cubeLoc[face][h] = w->skewb.majorLoc[orient][g - 1];
-			DrawTriangle(w, face, h, FALSE);
+			drawTriangle(w, face, h, FALSE);
 		}
 	}
 #ifdef HAVE_OPENGL
 	if (w->skewb.dim == 4) {
-		DrawAllPiecesGL((SkewbGLWidget) w);
+		drawAllPiecesGL((SkewbGLWidget) w);
 	}
 #endif
 
 }
 
 static void
-MovePieces(SkewbWidget w, int face, int position, int direction)
+movePieces(SkewbWidget w, int face, int position, int direction)
 {
+	int oldFace = face, pos = position, dir = direction;
 	int newFace, newDirection, newCorner, k, size, rotate;
 
-	if (direction < 2 * MAX_ORIENT) {
+	if (dir < 2 * MAX_ORIENT) {
 		/* position as MAX_ORIENT is ambiguous */
 		for (size = MINOR; size <= MAJOR; size++) {
-			ReadDiagonal((SkewbWidget) w, face, position, 0, size);
+			readDiagonal((SkewbWidget) w, oldFace, pos, 0, size);
 			for (k = 1; k <= MAX_ROTATE; k++) {
-				newFace = slideNextRow[face][position][direction / 2].face;
-				rotate = slideNextRow[face][position][direction / 2].rotation %
+				newFace = slideNextRow[oldFace][pos][dir / 2].face;
+				rotate = slideNextRow[oldFace][pos][dir / 2].rotation %
 					MAX_ORIENT;
-				newDirection = (rotate + direction) % MAX_ORIENT;
-				newCorner = (rotate + position) % MAX_ORIENT;
+				newDirection = (rotate + dir) % MAX_ORIENT;
+				newCorner = (rotate + pos) % MAX_ORIENT;
 				if (k != MAX_ROTATE)
-					ReadDiagonal((SkewbWidget) w, newFace, newCorner, k, size);
-				RotateDiagonal((SkewbWidget) w, rotate, k - 1, size);
-				WriteDiagonal(w, newFace, newCorner, k - 1, size);
-				face = newFace;
-				position = newCorner;
-				direction = newDirection;
+					readDiagonal((SkewbWidget) w, newFace, newCorner, k, size);
+				rotateDiagonal((SkewbWidget) w, rotate, k - 1, size);
+				writeDiagonal(w, newFace, newCorner, k - 1, size);
+				oldFace = newFace;
+				pos = newCorner;
+				dir = newDirection;
 			}
 			if (size == MINOR) {
-				newFace = minToMaj[face][position].face;
-				rotate = minToMaj[face][position].rotation % MAX_ORIENT;
-				direction = (rotate + direction) % MAX_ORIENT;
-				position = (position + rotate + 2) % MAX_ORIENT;
-				face = newFace;
+				newFace = minToMaj[oldFace][pos].face;
+				rotate = minToMaj[oldFace][pos].rotation % MAX_ORIENT;
+				dir = (rotate + dir) % MAX_ORIENT;
+				pos = (pos + rotate + 2) % MAX_ORIENT;
+				oldFace = newFace;
 			}
 		}
 	} else {
-		RotateFace(w, faceToRotate[face][direction % MAX_ORIENT], CW);
-		RotateFace(w, faceToRotate[face][(direction + 2) % MAX_ORIENT], CCW);
-		ReadFace((SkewbWidget) w, face, 0);
+		rotateFace(w, faceToRotate[oldFace][dir % MAX_ORIENT], CW);
+		rotateFace(w, faceToRotate[oldFace][(dir + 2) % MAX_ORIENT], CCW);
+		readFace((SkewbWidget) w, oldFace, 0);
 		for (k = 1; k <= MAX_ORIENT; k++) {
-			newFace = slideNextFace[face][direction % MAX_ORIENT].face;
-			rotate = slideNextFace[face][direction % MAX_ORIENT].rotation;
-			newDirection = (rotate + direction) % MAX_ORIENT;
+			newFace = slideNextFace[oldFace][dir % MAX_ORIENT].face;
+			rotate = slideNextFace[oldFace][dir % MAX_ORIENT].rotation;
+			newDirection = (rotate + dir) % MAX_ORIENT;
 			if (k != MAX_ORIENT)
-				ReadFace((SkewbWidget) w, newFace, k);
-			WriteFace(w, newFace, rotate, k - 1);
-			face = newFace;
-			direction = newDirection;
+				readFace((SkewbWidget) w, newFace, k);
+			writeFace(w, newFace, rotate, k - 1);
+			oldFace = newFace;
+			dir = newDirection;
 		}
 	}
 }
 
 static void
-MoveControlCb(SkewbWidget w, int face, int position, int direction)
+moveControlCb(SkewbWidget w, int face, int position, int direction)
 {
+	int oldFace = face, pos = position, dir = direction;
 	int newFace, rotate;
 
-	if (direction >= 2 * MAX_ORIENT) {
+	if (dir >= 2 * MAX_ORIENT) {
 		SkewbLocPos newpos;
 
-		newpos = orthToDiag[face][position][direction % MAX_ORIENT];
-		face = newpos.face;
-		position = newpos.position;
-		direction = newpos.direction;
+		newpos = orthToDiag[oldFace][pos][dir % MAX_ORIENT];
+		oldFace = newpos.face;
+		pos = newpos.position;
+		dir = newpos.direction;
 	}
-	MovePieces(w, face, position, direction);
-	setPuzzleMove(w, ACTION_CONTROL, face, position, direction);
-	newFace = minToMaj[face][position].face;
-	rotate = minToMaj[face][position].rotation % MAX_ORIENT;
-	direction = (rotate + direction) % MAX_ORIENT;
-	position = (position + rotate + 2) % MAX_ORIENT;
-	MovePieces(w, newFace, position, direction);
-	setPuzzleMove(w, ACTION_CONTROL, newFace, position, direction);
+	movePieces(w, oldFace, pos, dir);
+	setPuzzleMove(w, ACTION_CONTROL, oldFace, pos, dir);
+	newFace = minToMaj[oldFace][pos].face;
+	rotate = minToMaj[oldFace][pos].rotation % MAX_ORIENT;
+	dir = (rotate + dir) % MAX_ORIENT;
+	pos = (pos + rotate + 2) % MAX_ORIENT;
+	movePieces(w, newFace, pos, dir);
+	setPuzzleMove(w, ACTION_CONTROL, newFace, pos, dir);
 }
 
 static void
-MoveAltCb(SkewbWidget w, int face, int position, int direction)
+moveAltCb(SkewbWidget w, int face, int position, int direction)
 {
-	MovePieces(w, face, position, direction);
+	movePieces(w, face, position, direction);
 	setPuzzleMove(w, ACTION_CONTROL, face, position, direction);
 }
 
 void
-MovePuzzle(SkewbWidget w, int face, int position, int direction, int control)
+movePuzzle(SkewbWidget w, int face, int position, int direction, int control)
 {
 	if (control == 2)
-		MoveAltCb(w, face, position, direction);
+		moveAltCb(w, face, position, direction);
 	else if (control)
-		MoveControlCb(w, face, position, direction);
+		moveControlCb(w, face, position, direction);
 	else {
 		SkewbLocPos newpos;
 
@@ -902,7 +904,7 @@ MovePuzzle(SkewbWidget w, int face, int position, int direction, int control)
 		newpos.direction = direction;
 		if (direction >= 2 * MAX_ORIENT)
 			newpos = orthToDiag[face][position][direction % MAX_ORIENT];
-		MovePieces(w, newpos.face, newpos.position, newpos.direction);
+		movePieces(w, newpos.face, newpos.position, newpos.direction);
 		setPuzzleMove(w, ACTION_MOVED, newpos.face, newpos.position,
 			newpos.direction);
 	}
@@ -916,19 +918,19 @@ MovePuzzle(SkewbWidget w, int face, int position, int direction, int control)
 }
 
 static Boolean
-SelectPieces(SkewbWidget w, int x, int y, int *face, int *position)
+selectPieces(SkewbWidget w, int x, int y, int *face, int *position)
 {
 	if (w->skewb.dim == 2)
-		return SelectPieces2D((Skewb2DWidget) w, x, y,
+		return selectPieces2D((Skewb2DWidget) w, x, y,
 			face, position);
 	else if (w->skewb.dim == 3)
-		return SelectPieces3D((Skewb3DWidget) w, x, y,
+		return selectPieces3D((Skewb3DWidget) w, x, y,
 			face, position);
 	return False;
 }
 
 static int
-CheckMoveDir(int position1, int position2, int *direction)
+checkMoveDir(int position1, int position2, int *direction)
 {
 	if (position1 == position2)
 		return 2;
@@ -955,34 +957,34 @@ CheckMoveDir(int position1, int position2, int *direction)
 }
 
 static Boolean
-NarrowSelection(SkewbWidget w, int *face, int *position, int *direction)
+narrowSelection(SkewbWidget w, int *face, int *position, int *direction)
 {
 	if (w->skewb.dim == 2)
-		return NarrowSelection2D((Skewb2DWidget) w, face, position, direction);
+		return narrowSelection2D((Skewb2DWidget) w, face, position, direction);
 	else if (w->skewb.dim == 3)
-		return NarrowSelection3D((Skewb3DWidget) w, face, position, direction);
+		return narrowSelection3D((Skewb3DWidget) w, face, position, direction);
 	return False;
 }
 
 static Boolean
-PositionPieces(SkewbWidget w, int x, int y, int *face, int *position, int *direction)
+positionPieces(SkewbWidget w, int x, int y, int *face, int *position, int *direction)
 {
-	if (!SelectPieces(w, x, y, face, position))
+	if (!selectPieces(w, x, y, face, position))
 		return False;
-	return NarrowSelection(w, face, position, direction);
+	return narrowSelection(w, face, position, direction);
 }
 
 void
-MovePuzzleInput(SkewbWidget w, int x, int y, int direction, int control,
+movePuzzleInput(SkewbWidget w, int x, int y, int direction, int control,
 		int alt)
 {
 	int face, position;
 
-	if (!w->skewb.practice && !control && !alt && CheckSolved(w)) {
-		MoveNoPieces(w);
+	if (!w->skewb.practice && !control && !alt && checkSolved(w)) {
+		moveNoPieces(w);
 		return;
 	}
-	if (!PositionPieces(w, x, y, &face, &position, &direction))
+	if (!positionPieces(w, x, y, &face, &position, &direction))
 		return;
 	if (alt)
 		control = 2;
@@ -990,14 +992,14 @@ MovePuzzleInput(SkewbWidget w, int x, int y, int direction, int control,
 		control = (control) ? 1 : 0;
 	if (position == MAX_ORIENT)
 		return;
-	MovePuzzle(w, face, position, direction, control);
-	if (!control && CheckSolved(w)) {
+	movePuzzle(w, face, position, direction, control);
+	if (!control && checkSolved(w)) {
 		setPuzzle(w, ACTION_SOLVED);
 	}
 }
 
 static void
-ResetPieces(SkewbWidget w)
+resetPieces(SkewbWidget w)
 {
 	int face, position;
 
@@ -1014,7 +1016,7 @@ ResetPieces(SkewbWidget w)
 }
 
 static void
-GetPieces(SkewbWidget w)
+getPieces(SkewbWidget w)
 {
 	FILE *fp;
 	int c, orient, practice, moves;
@@ -1069,7 +1071,7 @@ GetPieces(SkewbWidget w)
 		setPuzzle(w, ACTION_PRACTICE);
 	}
 #ifdef WINVER
-	ResetPieces(w);
+	resetPieces(w);
 #endif
 	while ((c = getc(fp)) != EOF && c != SYMBOL);
 	(void) fscanf(fp, "%d", &moves);
@@ -1088,7 +1090,7 @@ GetPieces(SkewbWidget w)
 }
 
 static void
-WritePieces(SkewbWidget w)
+writePieces(SkewbWidget w)
 {
 	FILE *fp;
 	char *buf1 = NULL, *buf2 = NULL;
@@ -1144,7 +1146,7 @@ WritePieces(SkewbWidget w)
 }
 
 static void
-UndoPieces(SkewbWidget w)
+undoPieces(SkewbWidget w)
 {
 	if (madeMoves(&undo)) {
 		int face, position, direction, control;
@@ -1162,9 +1164,9 @@ UndoPieces(SkewbWidget w)
 				2 * MAX_ORIENT;
 		}
 		if (control == 2)
-			MoveAltCb(w, face, position, direction);
-		else if (control)
-			MoveControlCb(w, face, position, direction);
+			moveAltCb(w, face, position, direction);
+		else if (control == 1)
+			moveControlCb(w, face, position, direction);
 		else {
 			if (direction >= 2 * MAX_ORIENT) {
 				SkewbLocPos newpos;
@@ -1174,9 +1176,9 @@ UndoPieces(SkewbWidget w)
 				position = newpos.position;
 				direction = newpos.direction;
 			}
-			MovePieces(w, face, position, direction);
+			movePieces(w, face, position, direction);
 			setPuzzleMove(w, ACTION_UNDO, face, position, direction);
-			if (CheckSolved(w)) {
+			if (checkSolved(w)) {
 				setPuzzle(w, ACTION_SOLVED);
 			}
 		}
@@ -1184,7 +1186,7 @@ UndoPieces(SkewbWidget w)
 }
 
 static void
-RedoPieces(SkewbWidget w)
+redoPieces(SkewbWidget w)
 {
 	if (madeMoves(&redo)) {
 		int face, position, direction, control;
@@ -1194,9 +1196,9 @@ RedoPieces(SkewbWidget w)
 		setMove(&undo,
 			face, position, direction, control);
 		if (control == 2)
-			MoveAltCb(w, face, position, direction);
-		else if (control)
-			MoveControlCb(w, face, position, direction);
+			moveAltCb(w, face, position, direction);
+		else if (control == 1)
+			moveControlCb(w, face, position, direction);
 		else {
 			if (direction >= 2 * MAX_ORIENT) {
 				SkewbLocPos newpos;
@@ -1206,9 +1208,9 @@ RedoPieces(SkewbWidget w)
 				position = newpos.position;
 				direction = newpos.direction;
 			}
-			MovePieces(w, face, position, direction);
+			movePieces(w, face, position, direction);
 			setPuzzleMove(w, ACTION_REDO, face, position, direction);
-			if (CheckSolved(w)) {
+			if (checkSolved(w)) {
 				setPuzzle(w, ACTION_SOLVED);
 			}
 		}
@@ -1216,26 +1218,26 @@ RedoPieces(SkewbWidget w)
 }
 
 static void
-ClearPieces(SkewbWidget w)
+clearPieces(SkewbWidget w)
 {
 	setPuzzle(w, ACTION_CLEAR);
 }
 
 static void
-PracticePieces(SkewbWidget w)
+practicePieces(SkewbWidget w)
 {
 	setPuzzle(w, ACTION_PRACTICE);
 }
 
 static void
-RandomizePieces(SkewbWidget w)
+randomizePieces(SkewbWidget w)
 {
 	int face, position, direction;
 	int big = MAX_CUBES * 3 + NRAND(2);
 
 	w->skewb.cheat = False;
 	if (w->skewb.practice)
-		PracticePieces(w);
+		practicePieces(w);
 	setPuzzle(w, ACTION_RESET);
 
 #ifdef DEBUG
@@ -1246,20 +1248,20 @@ RandomizePieces(SkewbWidget w)
 		face = NRAND(MAX_FACES);
 		position = NRAND(MAX_ORIENT);
 		direction = ((NRAND(2)) ? position + 1 : position + 3) % MAX_ORIENT;
-		MovePuzzle(w, face, position, direction, FALSE);
+		movePuzzle(w, face, position, direction, FALSE);
 	}
 	flushMoves(w, &undo, TRUE);
 	flushMoves(w, &redo, FALSE);
 	setPuzzle(w, ACTION_RANDOMIZE);
-	if (CheckSolved(w)) {
+	if (checkSolved(w)) {
 		setPuzzle(w, ACTION_SOLVED);
 	}
 }
 
 static void
-SolvePieces(SkewbWidget w)
+solvePieces(SkewbWidget w)
 {
-	if (CheckSolved(w))
+	if (checkSolved(w))
 		return;
 	{
 		setPuzzle(w, ACTION_SOLVE_MESSAGE);
@@ -1267,19 +1269,19 @@ SolvePieces(SkewbWidget w)
 }
 
 static void
-OrientizePieces(SkewbWidget w)
+orientizePieces(SkewbWidget w)
 {
 	setPuzzle(w, ACTION_ORIENTIZE);
 }
 
 static void
-ViewPieces(SkewbWidget w)
+viewPieces(SkewbWidget w)
 {
 	setPuzzle(w, ACTION_VIEW);
 }
 
 static void
-SpeedPieces(SkewbWidget w)
+speedPieces(SkewbWidget w)
 {
 	w->skewb.delay -= 5;
 	if (w->skewb.delay < 0)
@@ -1290,7 +1292,7 @@ SpeedPieces(SkewbWidget w)
 }
 
 static void
-SlowPieces(SkewbWidget w)
+slowPieces(SkewbWidget w)
 {
 	w->skewb.delay += 5;
 #ifdef HAVE_MOTIF
@@ -1299,14 +1301,14 @@ SlowPieces(SkewbWidget w)
 }
 
 static void
-SoundPieces(SkewbWidget w)
+soundPieces(SkewbWidget w)
 {
 	w->skewb.sound = !w->skewb.sound;
 }
 
 #ifdef WINVER
 static void
-SetValuesPuzzle(SkewbWidget w)
+setValuesPuzzle(SkewbWidget w)
 {
 	struct tagColor {
 		int red, green, blue;
@@ -1368,7 +1370,7 @@ SetValuesPuzzle(SkewbWidget w)
 }
 
 void
-DestroyPuzzle(HBRUSH brush)
+destroyPuzzle(HBRUSH brush)
 {
 	deleteMoves(&undo);
 	deleteMoves(&redo);
@@ -1377,41 +1379,41 @@ DestroyPuzzle(HBRUSH brush)
 }
 
 void
-ResizePuzzle(SkewbWidget w)
+resizePuzzle(SkewbWidget w)
 {
 	if (w->skewb.dim == 2)
-		ResizePuzzle2D((Skewb2DWidget) w);
+		resizePuzzle2D((Skewb2DWidget) w);
 	else if (w->skewb.dim == 3)
-		ResizePuzzle3D((Skewb3DWidget) w);
+		resizePuzzle3D((Skewb3DWidget) w);
 #ifdef HAVE_OPENGL
 	else if (w->skewb.dim == 4)
-		ResizePuzzleGL((SkewbGLWidget) w);
+		resizePuzzleGL((SkewbGLWidget) w);
 #endif
 }
 
 void
-SizePuzzle(SkewbWidget w)
+sizePuzzle(SkewbWidget w)
 {
-	ResetPieces(w);
-	ResizePuzzle(w);
+	resetPieces(w);
+	resizePuzzle(w);
 }
 
 void
-ExposePuzzle(SkewbWidget w)
+exposePuzzle(SkewbWidget w)
 {
 	if (w->skewb.dim == 2)
-		ExposePuzzle2D((Skewb2DWidget) w);
+		exposePuzzle2D((Skewb2DWidget) w);
 	else if (w->skewb.dim == 3)
-		ExposePuzzle3D((Skewb3DWidget) w);
+		exposePuzzle3D((Skewb3DWidget) w);
 #ifdef HAVE_OPENGL
 	else if (w->skewb.dim == 4)
-		ExposePuzzleGL((SkewbGLWidget) w);
+		exposePuzzleGL((SkewbGLWidget) w);
 #endif
 }
 
 #else
 static void
-GetColor(SkewbWidget w, int face)
+getColor(SkewbWidget w, int face)
 {
 	XGCValues values;
 	XtGCMask valueMask;
@@ -1464,7 +1466,7 @@ GetColor(SkewbWidget w, int face)
 }
 
 void
-SetAllColors(SkewbWidget w)
+setAllColors(SkewbWidget w)
 {
 	XGCValues values;
 	XtGCMask valueMask;
@@ -1513,14 +1515,14 @@ SetAllColors(SkewbWidget w)
 		XtReleaseGC((Widget) w, w->skewb.borderGC);
 	w->skewb.borderGC = XtGetGC((Widget) w, valueMask, &values);
 	for (face = 0; face < MAX_FACES; face++)
-		GetColor(w, face);
+		getColor(w, face);
 	if (w->skewb.fontInfo)
 		XSetFont(XtDisplay(w), w->skewb.borderGC,
 			w->skewb.fontInfo->fid);
 }
 
 static Boolean
-SetValuesPuzzle(Widget current, Widget request, Widget renew)
+setValuesPuzzle(Widget current, Widget request, Widget renew)
 {
 	SkewbWidget c = (SkewbWidget) current, w = (SkewbWidget) renew;
 	Boolean redraw = False, setColors = False;
@@ -1537,19 +1539,19 @@ SetValuesPuzzle(Widget current, Widget request, Widget renew)
 			w->skewb.reverse != c->skewb.reverse ||
 			w->skewb.mono != c->skewb.mono) {
 		loadFont(w);
-		SetAllColors(w);
+		setAllColors(w);
 		redraw = True;
 	} else if (w->skewb.background != c->skewb.background ||
 			w->skewb.foreground != c->skewb.foreground ||
 			setColors) {
-		SetAllColors(w);
+		setAllColors(w);
 		redraw = True;
 	}
 	if (w->skewb.orient != c->skewb.orient) {
-		ResetPieces(w);
+		resetPieces(w);
 		redraw = True;
 	} else if (w->skewb.practice != c->skewb.practice) {
-		ResetPieces(w);
+		resetPieces(w);
 		redraw = True;
 	}
 	if (w->skewb.menu != ACTION_IGNORE) {
@@ -1558,43 +1560,43 @@ SetValuesPuzzle(Widget current, Widget request, Widget renew)
 		w->skewb.menu = ACTION_IGNORE;
 		switch (menu) {
 		case ACTION_GET:
-			GetPieces(w);
+			getPieces(w);
 			break;
 		case ACTION_WRITE:
-			WritePieces(w);
+			writePieces(w);
 			break;
 		case ACTION_UNDO:
-			UndoPieces(w);
+			undoPieces(w);
 			break;
 		case ACTION_REDO:
-			RedoPieces(w);
+			redoPieces(w);
 			break;
 		case ACTION_CLEAR:
-			ClearPieces(w);
+			clearPieces(w);
 			break;
 		case ACTION_PRACTICE:
-			PracticePieces(w);
+			practicePieces(w);
 			break;
 		case ACTION_RANDOMIZE:
-			RandomizePieces(w);
+			randomizePieces(w);
 			break;
 		case ACTION_SOLVE:
-			SolvePieces(w);
+			solvePieces(w);
 			break;
 		case ACTION_ORIENTIZE:
-			OrientizePieces(w);
+			orientizePieces(w);
 			break;
 		case ACTION_SPEED:
-			SpeedPieces(w);
+			speedPieces(w);
 			break;
 		case ACTION_SLOW:
-			SlowPieces(w);
+			slowPieces(w);
 			break;
 		case ACTION_SOUND:
-			SoundPieces(w);
+			soundPieces(w);
 			break;
 		case ACTION_VIEW:
-			ViewPieces(w);
+			viewPieces(w);
 			break;
 		default:
 			break;
@@ -1604,11 +1606,11 @@ SetValuesPuzzle(Widget current, Widget request, Widget renew)
 		setStartPosition(w);
 		w->skewb.currentDirection = IGNORE_DIR;
 	} else if (w->skewb.currentDirection == CLEAR_DIR) {
-		ResetPieces(w);
+		resetPieces(w);
 		redraw = True;
 		w->skewb.currentDirection = IGNORE_DIR;
 	} else if (w->skewb.currentDirection > IGNORE_DIR) {
-		MovePieces(w, w->skewb.currentFace, w->skewb.currentPosition,
+		movePieces(w, w->skewb.currentFace, w->skewb.currentPosition,
 			w->skewb.currentDirection);
 		w->skewb.currentDirection = IGNORE_DIR;
 	}
@@ -1616,7 +1618,7 @@ SetValuesPuzzle(Widget current, Widget request, Widget renew)
 }
 
 static void
-DestroyPuzzle(Widget old)
+destroyPuzzle(Widget old)
 {
 	SkewbWidget w = (SkewbWidget) old;
 	Display *display = XtDisplay(w);
@@ -1637,7 +1639,7 @@ DestroyPuzzle(Widget old)
 }
 
 void
-QuitPuzzle(SkewbWidget w, XEvent *event, char **args, int nArgs)
+quitPuzzle(SkewbWidget w, XEvent *event, char **args, int nArgs)
 {
 	XtCloseDisplay(XtDisplay(w));
 	exit(0);
@@ -1648,7 +1650,7 @@ QuitPuzzle(SkewbWidget w, XEvent *event, char **args, int nArgs)
 static
 #endif
 void
-InitializePuzzle(
+initializePuzzle(
 #ifdef WINVER
 SkewbWidget w, HBRUSH brush
 #else
@@ -1657,7 +1659,7 @@ Widget request, Widget renew
 )
 {
 #ifdef WINVER
-	SetValuesPuzzle(w);
+	setValuesPuzzle(w);
 #else
 	SkewbWidget w = (SkewbWidget) renew;
 	int face;
@@ -1676,7 +1678,7 @@ Widget request, Widget renew
 	newMoves(&undo);
 	newMoves(&redo);
 	w->skewb.cheat = False;
-	ResetPieces(w);
+	resetPieces(w);
 #ifdef WINVER
 	brush = CreateSolidBrush(w->skewb.inverseGC);
 	SETBACK(w->core.hWnd, brush);
@@ -1687,7 +1689,7 @@ Widget request, Widget renew
 }
 
 void
-HidePuzzle(SkewbWidget w
+hidePuzzle(SkewbWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
@@ -1697,7 +1699,7 @@ HidePuzzle(SkewbWidget w
 }
 
 void
-SelectPuzzle(SkewbWidget w
+selectPuzzle(SkewbWidget w
 #ifdef WINVER
 , const int x, const int y, const int control, const int alt
 #else
@@ -1711,19 +1713,19 @@ SelectPuzzle(SkewbWidget w
 	int alt = (int) (event->xkey.state & Mod1Mask);
 #endif
 
-	if (SelectPieces(w, x, y, &(w->skewb.currentFace),
+	if (selectPieces(w, x, y, &(w->skewb.currentFace),
 			&(w->skewb.currentPosition))) {
 		if (w->skewb.currentPosition == MAX_ORIENT) {
-			if (control || alt || w->skewb.practice || !CheckSolved(w)) {
-				DrawDiamond(w, w->skewb.currentFace, TRUE);
+			if (control || alt || w->skewb.practice || !checkSolved(w)) {
+				drawDiamond(w, w->skewb.currentFace, TRUE);
 				FLUSH(w);
 				Sleep(100);
-				DrawDiamond(w, w->skewb.currentFace, FALSE);
+				drawDiamond(w, w->skewb.currentFace, FALSE);
 				w->skewb.currentFace = IGNORE_DIR;
 				w->skewb.currentDirection = IGNORE_DIR;
 			}
-		} else if (control || alt || w->skewb.practice || !CheckSolved(w)) {
-			DrawTriangle(w, w->skewb.currentFace, w->skewb.currentPosition,
+		} else if (control || alt || w->skewb.practice || !checkSolved(w)) {
+			drawTriangle(w, w->skewb.currentFace, w->skewb.currentPosition,
 				TRUE);
 		}
 	} else {
@@ -1733,7 +1735,7 @@ SelectPuzzle(SkewbWidget w
 }
 
 void
-ReleasePuzzle(SkewbWidget w
+releasePuzzle(SkewbWidget w
 #ifdef WINVER
 , const int x, const int y, const int control, const int alt
 #else
@@ -1751,11 +1753,11 @@ ReleasePuzzle(SkewbWidget w
 	if (w->skewb.currentFace <= IGNORE_DIR)
 		return;
 	if (w->skewb.currentPosition != MAX_ORIENT)
-		DrawTriangle(w, w->skewb.currentFace, w->skewb.currentPosition,
+		drawTriangle(w, w->skewb.currentFace, w->skewb.currentPosition,
 			FALSE);
-	if (!control && !alt && !w->skewb.practice && CheckSolved(w))
-		MoveNoPieces(w);
-	else if (SelectPieces(w, x, y, &face, &position)) {
+	if (!control && !alt && !w->skewb.practice && checkSolved(w))
+		moveNoPieces(w);
+	else if (selectPieces(w, x, y, &face, &position)) {
 		if (alt)
 			ctrl = 2;
 		else
@@ -1764,7 +1766,7 @@ ReleasePuzzle(SkewbWidget w
 			if (position == MAX_ORIENT)
 				count = -1;
 			else
-				count = CheckMoveDir(w->skewb.currentPosition,
+				count = checkMoveDir(w->skewb.currentPosition,
 					position, &direction);
 			/* count == 2 too annoying */
 			if (count == 2)
@@ -1772,7 +1774,7 @@ ReleasePuzzle(SkewbWidget w
 		} else {
 			direction = facesToDirection[w->skewb.currentFace][face];
 			w->skewb.currentPosition =
-				facesToPosition[w->skewb.currentFace][face][w->skewb.currentPosition];
+				facestoPosition[w->skewb.currentFace][face][w->skewb.currentPosition];
 			count = face;
 			face = w->skewb.currentFace;
 			w->skewb.currentFace = count;
@@ -1782,14 +1784,14 @@ ReleasePuzzle(SkewbWidget w
 				count = 0;
 		}
 		if (count == 1) {
-			MovePuzzle(w, w->skewb.currentFace,
+			movePuzzle(w, w->skewb.currentFace,
 				w->skewb.currentPosition, direction,
 				ctrl);
-			if (!ctrl && CheckSolved(w)) {
+			if (!ctrl && checkSolved(w)) {
 				setPuzzle(w, ACTION_SOLVED);
 			}
 		} else if (count == 0)
-			MoveNoPieces(w);
+			moveNoPieces(w);
 	}
 	w->skewb.currentFace = IGNORE_DIR;
 	w->skewb.currentDirection = IGNORE_DIR;
@@ -1797,12 +1799,12 @@ ReleasePuzzle(SkewbWidget w
 
 #ifndef WINVER
 void
-PracticePuzzleMaybe(SkewbWidget w
+practicePuzzleWithQuery(SkewbWidget w
 , XEvent *event, char **args, int nArgs
 )
 {
 	if (!w->skewb.started)
-		PracticePieces(w);
+		practicePieces(w);
 #ifdef HAVE_MOTIF
 	else {
 		setPuzzle(w, ACTION_PRACTICE_QUERY);
@@ -1811,23 +1813,23 @@ PracticePuzzleMaybe(SkewbWidget w
 }
 
 void
-PracticePuzzle2(SkewbWidget w
+practicePuzzleWithDoubleClick(SkewbWidget w
 , XEvent *event, char **args, int nArgs
 )
 {
 #ifdef HAVE_MOTIF
 	if (!w->skewb.started)
 #endif
-		PracticePieces(w);
+		practicePieces(w);
 }
 
 void
-RandomizePuzzleMaybe(SkewbWidget w
+randomizePuzzleWithQuery(SkewbWidget w
 , XEvent *event, char **args, int nArgs
 )
 {
 	if (!w->skewb.started)
-		RandomizePieces(w);
+		randomizePieces(w);
 #ifdef HAVE_MOTIF
 	else {
 		setPuzzle(w, ACTION_RANDOMIZE_QUERY);
@@ -1836,188 +1838,188 @@ RandomizePuzzleMaybe(SkewbWidget w
 }
 
 void
-RandomizePuzzle2(SkewbWidget w
+randomizePuzzleWithDoubleClick(SkewbWidget w
 , XEvent *event, char **args, int nArgs
 )
 {
 #ifdef HAVE_MOTIF
 	if (!w->skewb.started)
 #endif
-		RandomizePieces(w);
+		randomizePieces(w);
 }
 #endif
 
 void
-GetPuzzle(SkewbWidget w
+getPuzzle(SkewbWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 )
 {
-	GetPieces(w);
+	getPieces(w);
 }
 
 void
-WritePuzzle(SkewbWidget w
+writePuzzle(SkewbWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 )
 {
-	WritePieces(w);
+	writePieces(w);
 }
 
 void
-UndoPuzzle(SkewbWidget w
+undoPuzzle(SkewbWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 )
 {
-	UndoPieces(w);
+	undoPieces(w);
 }
 
 void
-RedoPuzzle(SkewbWidget w
+redoPuzzle(SkewbWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 )
 {
-	RedoPieces(w);
+	redoPieces(w);
 }
 
 void
-ClearPuzzle(SkewbWidget w
+clearPuzzle(SkewbWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 )
 {
-	ClearPieces(w);
+	clearPieces(w);
 }
 
 void
-RandomizePuzzle(SkewbWidget w
+randomizePuzzle(SkewbWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 )
 {
-	RandomizePieces(w);
+	randomizePieces(w);
 }
 
 void
-SolvePuzzle(SkewbWidget w
+solvePuzzle(SkewbWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 )
 {
-	SolvePieces(w);
+	solvePieces(w);
 }
 
 void
-PracticePuzzle(SkewbWidget w
+practicePuzzle(SkewbWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 )
 {
-	PracticePieces(w);
+	practicePieces(w);
 }
 
 void
-OrientizePuzzle(SkewbWidget w
+orientizePuzzle(SkewbWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 )
 {
-	OrientizePieces(w);
+	orientizePieces(w);
 }
 
 void
-ViewPuzzle(SkewbWidget w
+viewPuzzle(SkewbWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 )
 {
-	ViewPieces(w);
+	viewPieces(w);
 }
 
 void
-SpeedPuzzle(SkewbWidget w
+speedUpPuzzle(SkewbWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 )
 {
-	SpeedPieces(w);
+	speedPieces(w);
 }
 
 void
-SlowPuzzle(SkewbWidget w
+slowDownPuzzle(SkewbWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 )
 {
-	SlowPieces(w);
+	slowPieces(w);
 }
 
 void
-SoundPuzzle(SkewbWidget w
+toggleSoundPuzzle(SkewbWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 )
 {
-	SoundPieces(w);
+	soundPieces(w);
 }
 
 void
-EnterPuzzle(SkewbWidget w
+enterPuzzle(SkewbWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 )
 {
 	w->skewb.focus = True;
-	DrawFrame(w, w->skewb.focus);
+	drawFrame(w, w->skewb.focus);
 }
 
 void
-LeavePuzzle(SkewbWidget w
+leavePuzzle(SkewbWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 )
 {
 	w->skewb.focus = False;
-	DrawFrame(w, w->skewb.focus);
+	drawFrame(w, w->skewb.focus);
 }
 
 #ifdef WINVER
 void
-DimPuzzle(SkewbWidget w)
+dimPuzzle(SkewbWidget w)
 {
 	setPuzzle(w, ACTION_DIM);
 }
 
 #else
 void
-MovePuzzleCcw(SkewbWidget w, XEvent *event, char **args, int nArgs)
+movePuzzleCcw(SkewbWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput(w, event->xbutton.x, event->xbutton.y, CCW,
+	movePuzzleInput(w, event->xbutton.x, event->xbutton.y, CCW,
 		(int) (event->xbutton.state & ControlMask), FALSE);
 }
 
 void
-MovePuzzleCw(SkewbWidget w, XEvent *event, char **args, int nArgs)
+movePuzzleCw(SkewbWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput(w, event->xbutton.x, event->xbutton.y, CW,
+	movePuzzleInput(w, event->xbutton.x, event->xbutton.y, CW,
 		(int) (event->xkey.state & ControlMask), FALSE);
 }
 #endif
