@@ -1,27 +1,22 @@
-/*-
-# X-BASED SKEWB
-#
-#  Skewb2d.c
-#
-###
-#
-#  Copyright (c) 1994 - 2007	David A. Bagley, bagleyd@tux.org
-#
-#                   All Rights Reserved
-#
-#  Permission to use, copy, modify, and distribute this software and
-#  its documentation for any purpose and without fee is hereby granted,
-#  provided that the above copyright notice appear in all copies and
-#  that both that copyright notice and this permission notice appear in
-#  supporting documentation, and that the name of the author not be
-#  used in advertising or publicity pertaining to distribution of the
-#  software without specific, written prior permission.
-#
-#  This program is distributed in the hope that it will be "playable",
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-#
-*/
+/*
+ * @(#)Skewb2d.c
+ *
+ * Copyright 1994 - 2008  David A. Bagley, bagleyd@tux.org
+ *
+ * All rights reserved.
+ *
+ * Permission to use, copy, modify, and distribute this software and
+ * its documentation for any purpose and without fee is hereby granted,
+ * provided that the above copyright notice appear in all copies and
+ * that both that copyright notice and this permission notice appear in
+ * supporting documentation, and that the name of the author not be
+ * used in advertising or publicity pertaining to distribution of the
+ * software without specific, written prior permission.
+ *
+ * This program is distributed in the hope that it will be "useful",
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ */
 
 /* Methods file for Skewb2d */
 
@@ -29,28 +24,28 @@
 #include "Skewb2dP.h"
 
 #ifndef WINVER
-static Boolean SetValuesPuzzle2D(Widget current, Widget request, Widget renew);
-static void ResizePuzzle2D(Skewb2DWidget w);
-static void InitializePuzzle2D(Widget request, Widget renew);
-static void ExposePuzzle2D(Widget renew, XEvent *event, Region region);
-static void MovePuzzle2DTl(Skewb2DWidget w,
+static Boolean setValuesPuzzle2D(Widget current, Widget request, Widget renew);
+static void resizePuzzle2D(Skewb2DWidget w);
+static void initializePuzzle2D(Widget request, Widget renew);
+static void exposePuzzle2D(Widget renew, XEvent *event, Region region);
+static void movePuzzle2DTl(Skewb2DWidget w,
 	XEvent *event, char **args, int nArgs);
-static void MovePuzzle2DTop(Skewb2DWidget w,
+static void movePuzzle2DTop(Skewb2DWidget w,
 	XEvent *event, char **args, int nArgs);
-static void MovePuzzle2DTr(Skewb2DWidget w,
+static void movePuzzle2DTr(Skewb2DWidget w,
 	XEvent *event, char **args, int nArgs);
-static void MovePuzzle2DLeft(Skewb2DWidget w,
+static void movePuzzle2DLeft(Skewb2DWidget w,
 	XEvent *event, char **args, int nArgs);
-static void MovePuzzle2dRight(Skewb2DWidget w,
+static void movePuzzle2dRight(Skewb2DWidget w,
 	XEvent *event, char **args, int nArgs);
-static void MovePuzzle2DBl(Skewb2DWidget w,
+static void movePuzzle2DBl(Skewb2DWidget w,
 	XEvent *event, char **args, int nArgs);
-static void MovePuzzle2DBottom(Skewb2DWidget w,
+static void movePuzzle2DBottom(Skewb2DWidget w,
 	XEvent *event, char **args, int nArgs);
-static void MovePuzzle2DBr(Skewb2DWidget w,
+static void movePuzzle2DBr(Skewb2DWidget w,
 	XEvent *event, char **args, int nArgs);
 
-static char defaultTranslationsPuzzle2D[] =
+static char translations2D[] =
 "<KeyPress>q: Quit()\n\
  Ctrl<KeyPress>C: Quit()\n\
  <KeyPress>osfCancel: Hide()\n\
@@ -121,44 +116,44 @@ static char defaultTranslationsPuzzle2D[] =
  <EnterWindow>: Enter()\n\
  <LeaveWindow>: Leave()";
 
-static XtActionsRec actionsListPuzzle2D[] =
+static XtActionsRec actionsList2D[] =
 {
-	{(char *) "Quit", (XtActionProc) QuitPuzzle},
-	{(char *) "Hide", (XtActionProc) HidePuzzle},
-	{(char *) "MoveCcw", (XtActionProc) MovePuzzleCcw},
-	{(char *) "MoveTl", (XtActionProc) MovePuzzle2DTl},
-	{(char *) "MoveTop", (XtActionProc) MovePuzzle2DTop},
-	{(char *) "MoveTr", (XtActionProc) MovePuzzle2DTr},
-	{(char *) "MoveLeft", (XtActionProc) MovePuzzle2DLeft},
-	{(char *) "MoveCw", (XtActionProc) MovePuzzleCw},
-	{(char *) "MoveRight", (XtActionProc) MovePuzzle2dRight},
-	{(char *) "MoveBl", (XtActionProc) MovePuzzle2DBl},
-	{(char *) "MoveBottom", (XtActionProc) MovePuzzle2DBottom},
-	{(char *) "MoveBr", (XtActionProc) MovePuzzle2DBr},
-	{(char *) "Select", (XtActionProc) SelectPuzzle},
-	{(char *) "Release", (XtActionProc) ReleasePuzzle},
-	{(char *) "PracticeMaybe", (XtActionProc) PracticePuzzleMaybe},
-	{(char *) "Practice2", (XtActionProc) PracticePuzzle2},
-	{(char *) "RandomizeMaybe", (XtActionProc) RandomizePuzzleMaybe},
-	{(char *) "Randomize2", (XtActionProc) RandomizePuzzle2},
-	{(char *) "Get", (XtActionProc) GetPuzzle},
-	{(char *) "Write", (XtActionProc) WritePuzzle},
-	{(char *) "Undo", (XtActionProc) UndoPuzzle},
-	{(char *) "Redo", (XtActionProc) RedoPuzzle},
-	{(char *) "Clear", (XtActionProc) ClearPuzzle},
-	{(char *) "Randomize", (XtActionProc) RandomizePuzzle},
-	{(char *) "Solve", (XtActionProc) SolvePuzzle},
-	{(char *) "Practice", (XtActionProc) PracticePuzzle},
-	{(char *) "Orientize", (XtActionProc) OrientizePuzzle},
-	{(char *) "View", (XtActionProc) ViewPuzzle},
-	{(char *) "Speed", (XtActionProc) SpeedPuzzle},
-	{(char *) "Slow", (XtActionProc) SlowPuzzle},
-	{(char *) "Sound", (XtActionProc) SoundPuzzle},
-	{(char *) "Enter", (XtActionProc) EnterPuzzle},
-	{(char *) "Leave", (XtActionProc) LeavePuzzle}
+	{(char *) "Quit", (XtActionProc) quitPuzzle},
+	{(char *) "Hide", (XtActionProc) hidePuzzle},
+	{(char *) "MoveCcw", (XtActionProc) movePuzzleCcw},
+	{(char *) "MoveTl", (XtActionProc) movePuzzle2DTl},
+	{(char *) "MoveTop", (XtActionProc) movePuzzle2DTop},
+	{(char *) "MoveTr", (XtActionProc) movePuzzle2DTr},
+	{(char *) "MoveLeft", (XtActionProc) movePuzzle2DLeft},
+	{(char *) "MoveCw", (XtActionProc) movePuzzleCw},
+	{(char *) "MoveRight", (XtActionProc) movePuzzle2dRight},
+	{(char *) "MoveBl", (XtActionProc) movePuzzle2DBl},
+	{(char *) "MoveBottom", (XtActionProc) movePuzzle2DBottom},
+	{(char *) "MoveBr", (XtActionProc) movePuzzle2DBr},
+	{(char *) "Select", (XtActionProc) selectPuzzle},
+	{(char *) "Release", (XtActionProc) releasePuzzle},
+	{(char *) "PracticeMaybe", (XtActionProc) practicePuzzleWithQuery},
+	{(char *) "Practice2", (XtActionProc) practicePuzzleWithDoubleClick},
+	{(char *) "RandomizeMaybe", (XtActionProc) randomizePuzzleWithQuery},
+	{(char *) "Randomize2", (XtActionProc) randomizePuzzleWithDoubleClick},
+	{(char *) "Get", (XtActionProc) getPuzzle},
+	{(char *) "Write", (XtActionProc) writePuzzle},
+	{(char *) "Undo", (XtActionProc) undoPuzzle},
+	{(char *) "Redo", (XtActionProc) redoPuzzle},
+	{(char *) "Clear", (XtActionProc) clearPuzzle},
+	{(char *) "Randomize", (XtActionProc) randomizePuzzle},
+	{(char *) "Solve", (XtActionProc) solvePuzzle},
+	{(char *) "Practice", (XtActionProc) practicePuzzle},
+	{(char *) "Orientize", (XtActionProc) orientizePuzzle},
+	{(char *) "View", (XtActionProc) viewPuzzle},
+	{(char *) "Speed", (XtActionProc) speedUpPuzzle},
+	{(char *) "Slow", (XtActionProc) slowDownPuzzle},
+	{(char *) "Sound", (XtActionProc) toggleSoundPuzzle},
+	{(char *) "Enter", (XtActionProc) enterPuzzle},
+	{(char *) "Leave", (XtActionProc) leavePuzzle}
 };
 
-static XtResource resourcesPuzzle2D[] =
+static XtResource resources2D[] =
 {
 	{XtNwidth, XtCWidth, XtRDimension, sizeof (Dimension),
 	 XtOffset(SkewbWidget, core.width),
@@ -177,7 +172,7 @@ static XtResource resourcesPuzzle2D[] =
 	 XtRString, (caddr_t) XtDefaultForeground},
 	{XtNbackground, XtCBackground, XtRPixel, sizeof (Pixel),
 	 XtOffset(SkewbWidget, skewb.background),
-	 XtRString, (caddr_t) XtDefaultBackground},
+	 XtRString, (caddr_t) "#AEB2C3" /*XtDefaultBackground*/},
 	{XtNframeColor, XtCColor, XtRPixel, sizeof (Pixel),
 	 XtOffset(SkewbWidget, skewb.frameColor),
 	 XtRString, (caddr_t) "cyan" /*XtDefaultForeground*/},
@@ -267,29 +262,29 @@ Skewb2DClassRec skewb2dClassRec =
 		NULL,		/* class initialize */
 		NULL,		/* class part initialize */
 		FALSE,		/* class inited */
-		(XtInitProc) InitializePuzzle2D,	/* initialize */
+		(XtInitProc) initializePuzzle2D,	/* initialize */
 		NULL,		/* initialize hook */
 		XtInheritRealize,	/* realize */
-		actionsListPuzzle2D,	/* actions */
-		XtNumber(actionsListPuzzle2D),	/* num actions */
-		resourcesPuzzle2D,	/* resources */
-		XtNumber(resourcesPuzzle2D),	/* num resources */
+		actionsList2D,	/* actions */
+		XtNumber(actionsList2D),	/* num actions */
+		resources2D,	/* resources */
+		XtNumber(resources2D),	/* num resources */
 		NULLQUARK,	/* xrm class */
 		TRUE,		/* compress motion */
 		TRUE,		/* compress exposure */
 		TRUE,		/* compress enterleave */
 		TRUE,		/* visible interest */
 		NULL,		/* destroy */
-		(XtWidgetProc) ResizePuzzle2D,	/* resize */
-		(XtExposeProc) ExposePuzzle2D,	/* expose */
-		(XtSetValuesFunc) SetValuesPuzzle2D,	/* set values */
+		(XtWidgetProc) resizePuzzle2D,	/* resize */
+		(XtExposeProc) exposePuzzle2D,	/* expose */
+		(XtSetValuesFunc) setValuesPuzzle2D,	/* set values */
 		NULL,		/* set values hook */
 		XtInheritSetValuesAlmost,	/* set values almost */
 		NULL,		/* get values hook */
 		XtInheritAcceptFocus,	/* accept focus */
 		XtVersion,	/* version */
 		NULL,		/* callback private */
-		defaultTranslationsPuzzle2D,	/* tm table */
+		translations2D,	/* tm table */
 		NULL,		/* query geometry */
 		NULL,		/* display accelerator */
 		NULL		/* extension */
@@ -358,7 +353,7 @@ static Point letterList[MAX_CUBES], offsetList[MAX_CUBES];
 static Pixmap dr = 0; /* dummy for future double buffering */
 
 static void
-DrawOrientLine(Skewb2DWidget w, int cube, int orient, int dx, int dy,
+drawOrientLine(Skewb2DWidget w, int cube, int orient, int dx, int dy,
 		GC borderGC)
 {
 	char *buf;
@@ -398,7 +393,7 @@ DrawOrientLine(Skewb2DWidget w, int cube, int orient, int dx, int dy,
 				dy + w->skewb2d.diamondLength / 2 - 2);
 				return;
 			default:
-				intCat(&buf, "DrawOrientLine: orient ",
+				intCat(&buf, "drawOrientLine: orient ",
 					orient);
 				DISPLAY_WARNING(buf);
 				free(buf);
@@ -438,7 +433,7 @@ DrawOrientLine(Skewb2DWidget w, int cube, int orient, int dx, int dy,
 				dy);
 			return;
 		default:
-			intCat(&buf, "DrawOrientLine: orient ",
+			intCat(&buf, "drawOrientLine: orient ",
 				orient);
 			DISPLAY_WARNING(buf);
 			free(buf);
@@ -447,7 +442,7 @@ DrawOrientLine(Skewb2DWidget w, int cube, int orient, int dx, int dy,
 }
 
 void
-DrawDiamond2D(Skewb2DWidget w, int face, int offset)
+drawDiamond2D(Skewb2DWidget w, int face, int offset)
 {
 	GC faceGC, borderGC;
 	int dx, dy, orient;
@@ -506,11 +501,11 @@ DrawDiamond2D(Skewb2DWidget w, int face, int offset)
 			letterX, letterY, buf, 1);
 	}
 	if (w->skewb.orient)
-		DrawOrientLine(w, MAX_ORIENT, orient, dx, dy, borderGC);
+		drawOrientLine(w, MAX_ORIENT, orient, dx, dy, borderGC);
 }
 
 void
-DrawTriangle2D(Skewb2DWidget w, int face, int position, int offset)
+drawTriangle2D(Skewb2DWidget w, int face, int position, int offset)
 {
 	GC faceGC, borderGC;
 	int dx, dy, letterX, letterY, orient, newCorner;
@@ -569,14 +564,14 @@ DrawTriangle2D(Skewb2DWidget w, int face, int position, int offset)
 		DRAWTEXT(w, dr, borderGC, letterX, letterY, buf, 1);
 	}
 	if (w->skewb.orient)
-		DrawOrientLine(w, newCorner, orient,
+		drawOrientLine(w, newCorner, orient,
 			letterX - w->skewb.letterOffset.x,
 			letterY - w->skewb.letterOffset.y,
 			borderGC);
 }
 
 void
-DrawFrame2D(Skewb2DWidget w, Boolean focus)
+drawFrame2D(Skewb2DWidget w, Boolean focus)
 {
 	int i;
 	Point pos[MAXXY + 1], letters;
@@ -616,7 +611,7 @@ DrawFrame2D(Skewb2DWidget w, Boolean focus)
 }
 
 static void
-ResizePieces(Skewb2DWidget w)
+resizePieces(Skewb2DWidget w)
 {
 	int i, j;
 
@@ -694,12 +689,13 @@ ResizePieces(Skewb2DWidget w)
 }
 
 Boolean
-SelectPieces2D(Skewb2DWidget w, int x, int y, int *face, int *position)
+selectPieces2D(Skewb2DWidget w, int positionX, int positionY,
+		int *face, int *position)
 {
 	int faceX, faceY, i, j;
+	int x = positionX - w->skewb.puzzleOffset.x;
+	int y = positionY - w->skewb.puzzleOffset.y;
 
-	x -= w->skewb.puzzleOffset.x;
-	y -= w->skewb.puzzleOffset.y;
 	faceX = x / w->skewb2d.viewLength;
 	faceY = y / w->skewb2d.viewLength;
 	i = x - faceX * w->skewb2d.viewLength;
@@ -728,7 +724,7 @@ SelectPieces2D(Skewb2DWidget w, int x, int y, int *face, int *position)
 }
 
 Boolean
-NarrowSelection2D(Skewb2DWidget w, int *face, int *position, int *direction)
+narrowSelection2D(Skewb2DWidget w, int *face, int *position, int *direction)
 {
 	if (*face == MAX_FACES - 1 && *direction < MAX_ORIENT &&
 			!w->skewb.vertical) {
@@ -752,13 +748,13 @@ NarrowSelection2D(Skewb2DWidget w, int *face, int *position, int *direction)
 
 #ifndef WINVER
 static Boolean
-SetValuesPuzzle2D(Widget current, Widget request, Widget renew)
+setValuesPuzzle2D(Widget current, Widget request, Widget renew)
 {
 	Skewb2DWidget c = (Skewb2DWidget) current, w = (Skewb2DWidget) renew;
 	Boolean redraw = False;
 
 	if (w->skewb2d.diamondLength != c->skewb2d.diamondLength) {
-		ResizePuzzle2D(w);
+		resizePuzzle2D(w);
 		redraw = True;
 	}
 	return (redraw);
@@ -769,7 +765,7 @@ SetValuesPuzzle2D(Widget current, Widget request, Widget renew)
 static
 #endif
 void
-ResizePuzzle2D(Skewb2DWidget w)
+resizePuzzle2D(Skewb2DWidget w)
 {
 #ifdef WINVER
 	RECT rect;
@@ -806,14 +802,14 @@ ResizePuzzle2D(Skewb2DWidget w)
 		/ 2;
 	w->skewb.puzzleOffset.y = ((int) w->core.height - w->skewb.puzzleSize.y)
 		/ 2;
-	ResizePieces(w);
+	resizePieces(w);
 }
 
 #ifndef WINVER
 static
 #endif
 void
-InitializePuzzle2D(
+initializePuzzle2D(
 #ifdef WINVER
 Skewb2DWidget w
 #else
@@ -824,9 +820,9 @@ Widget request, Widget renew
 #ifndef WINVER
 	Skewb2DWidget w = (Skewb2DWidget) renew;
 
-	SetAllColors((SkewbWidget) w);
+	setAllColors((SkewbWidget) w);
 	w->skewb.dim = 2;
-	ResizePuzzle2D(w);
+	resizePuzzle2D(w);
 #endif
 }
 
@@ -834,7 +830,7 @@ Widget request, Widget renew
 static
 #endif
 void
-ExposePuzzle2D(
+exposePuzzle2D(
 #ifdef WINVER
 Skewb2DWidget w
 #else
@@ -850,72 +846,72 @@ Widget renew, XEvent *event, Region region
 #endif
 	FILLRECTANGLE(w, dr, w->skewb.inverseGC,
 		0, 0, w->core.width, w->core.height);
-	DrawFrame2D(w, w->skewb.focus);
-	DrawAllPieces((SkewbWidget) w);
+	drawFrame2D(w, w->skewb.focus);
+	drawAllPieces((SkewbWidget) w);
 }
 
 #ifndef WINVER
 static void
-MovePuzzle2DTl(Skewb2DWidget w, XEvent *event, char **args, int nArgs)
+movePuzzle2DTl(Skewb2DWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((SkewbWidget) w, event->xbutton.x, event->xbutton.y,
+	movePuzzleInput((SkewbWidget) w, event->xbutton.x, event->xbutton.y,
 		TL, (int) (event->xkey.state & ControlMask), FALSE);
 }
 
 static void
-MovePuzzle2DTop(Skewb2DWidget w, XEvent *event, char **args, int nArgs)
+movePuzzle2DTop(Skewb2DWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((SkewbWidget) w, event->xbutton.x, event->xbutton.y,
+	movePuzzleInput((SkewbWidget) w, event->xbutton.x, event->xbutton.y,
 		TOP,
 		(int) (event->xkey.state & ControlMask),
 		(int) (event->xkey.state & Mod1Mask));
 }
 
 static void
-MovePuzzle2DTr(Skewb2DWidget w, XEvent *event, char **args, int nArgs)
+movePuzzle2DTr(Skewb2DWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((SkewbWidget) w, event->xbutton.x, event->xbutton.y,
+	movePuzzleInput((SkewbWidget) w, event->xbutton.x, event->xbutton.y,
 		TR, (int) (event->xkey.state & ControlMask), FALSE);
 }
 
 static void
-MovePuzzle2DLeft(Skewb2DWidget w, XEvent *event, char **args, int nArgs)
+movePuzzle2DLeft(Skewb2DWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((SkewbWidget) w, event->xbutton.x, event->xbutton.y,
+	movePuzzleInput((SkewbWidget) w, event->xbutton.x, event->xbutton.y,
 		LEFT,
 		(int) (event->xkey.state & ControlMask),
 		(int) (event->xkey.state & Mod1Mask));
 }
 
 static void
-MovePuzzle2dRight(Skewb2DWidget w, XEvent *event, char **args, int nArgs)
+movePuzzle2dRight(Skewb2DWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((SkewbWidget) w, event->xbutton.x, event->xbutton.y,
+	movePuzzleInput((SkewbWidget) w, event->xbutton.x, event->xbutton.y,
 		RIGHT,
 		(int) (event->xkey.state & ControlMask),
 		(int) (event->xkey.state & Mod1Mask));
 }
 
 static void
-MovePuzzle2DBl(Skewb2DWidget w, XEvent *event, char **args, int nArgs)
+movePuzzle2DBl(Skewb2DWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((SkewbWidget) w, event->xbutton.x, event->xbutton.y,
+	movePuzzleInput((SkewbWidget) w, event->xbutton.x, event->xbutton.y,
 		BL, (int) (event->xkey.state & ControlMask), FALSE);
 }
 
 static void
-MovePuzzle2DBottom(Skewb2DWidget w, XEvent *event, char **args, int nArgs)
+movePuzzle2DBottom(Skewb2DWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((SkewbWidget) w, event->xbutton.x, event->xbutton.y,
+	movePuzzleInput((SkewbWidget) w, event->xbutton.x, event->xbutton.y,
 		BOTTOM,
 		(int) (event->xkey.state & ControlMask),
 		(int) (event->xkey.state & Mod1Mask));
 }
 
 static void
-MovePuzzle2DBr(Skewb2DWidget w, XEvent *event, char **args, int nArgs)
+movePuzzle2DBr(Skewb2DWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((SkewbWidget) w, event->xbutton.x, event->xbutton.y,
+	movePuzzleInput((SkewbWidget) w, event->xbutton.x, event->xbutton.y,
 		BR, (int) (event->xkey.state & ControlMask), FALSE);
 }
 #endif
