@@ -1,27 +1,22 @@
-/*-
-# X-BASED SKEWB
-#
-#  Skewb3d.c
-#
-###
-#
-#  Copyright (c) 1994 - 2007	David A. Bagley, bagleyd@tux.org
-#
-#                   All Rights Reserved
-#
-#  Permission to use, copy, modify, and distribute this software and
-#  its documentation for any purpose and without fee is hereby granted,
-#  provided that the above copyright notice appear in all copies and
-#  that both that copyright notice and this permission notice appear in
-#  supporting documentation, and that the name of the author not be
-#  used in advertising or publicity pertaining to distribution of the
-#  software without specific, written prior permission.
-#
-#  This program is distributed in the hope that it will be "playable",
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-#
-*/
+/*
+ * @(#)Skewb3d.c
+ *
+ * Copyright 1994 - 2008  David A. Bagley, bagleyd@tux.org
+ *
+ * All rights reserved.
+ *
+ * Permission to use, copy, modify, and distribute this software and
+ * its documentation for any purpose and without fee is hereby granted,
+ * provided that the above copyright notice appear in all copies and
+ * that both that copyright notice and this permission notice appear in
+ * supporting documentation, and that the name of the author not be
+ * used in advertising or publicity pertaining to distribution of the
+ * software without specific, written prior permission.
+ *
+ * This program is distributed in the hope that it will be "useful",
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ */
 
 /* Methods file for Skewb3d */
 
@@ -29,20 +24,20 @@
 #include "Skewb3dP.h"
 
 #ifndef WINVER
-static Boolean SetValuesPuzzle3D(Widget current, Widget request, Widget renew);
-static void ResizePuzzle3D(Skewb3DWidget w);
-static void InitializePuzzle3D(Widget request, Widget renew);
-static void ExposePuzzle3D(Widget renew, XEvent *event, Region region);
-static void MovePuzzle3DTl(Skewb3DWidget w, XEvent *event, char **args, int nArgs);
-static void MovePuzzle3DTop(Skewb3DWidget w, XEvent *event, char **args, int nArgs);
-static void MovePuzzle3DTr(Skewb3DWidget w, XEvent *event, char **args, int nArgs);
-static void MovePuzzle3DLeft(Skewb3DWidget w, XEvent *event, char **args, int nArgs);
-static void MovePuzzle3DRight(Skewb3DWidget w, XEvent *event, char **args, int nArgs);
-static void MovePuzzle3DBl(Skewb3DWidget w, XEvent *event, char **args, int nArgs);
-static void MovePuzzle3DBottom(Skewb3DWidget w, XEvent *event, char **args, int nArgs);
-static void MovePuzzle3DBr(Skewb3DWidget w, XEvent *event, char **args, int nArgs);
+static Boolean setValuesPuzzle3D(Widget current, Widget request, Widget renew);
+static void resizePuzzle3D(Skewb3DWidget w);
+static void initializePuzzle3D(Widget request, Widget renew);
+static void exposePuzzle3D(Widget renew, XEvent *event, Region region);
+static void movePuzzle3DTl(Skewb3DWidget w, XEvent *event, char **args, int nArgs);
+static void movePuzzle3DTop(Skewb3DWidget w, XEvent *event, char **args, int nArgs);
+static void movePuzzle3DTr(Skewb3DWidget w, XEvent *event, char **args, int nArgs);
+static void movePuzzle3DLeft(Skewb3DWidget w, XEvent *event, char **args, int nArgs);
+static void movePuzzle3DRight(Skewb3DWidget w, XEvent *event, char **args, int nArgs);
+static void movePuzzle3DBl(Skewb3DWidget w, XEvent *event, char **args, int nArgs);
+static void movePuzzle3DBottom(Skewb3DWidget w, XEvent *event, char **args, int nArgs);
+static void movePuzzle3DBr(Skewb3DWidget w, XEvent *event, char **args, int nArgs);
 
-static char defaultTranslationsPuzzle3D[] =
+static char translations3D[] =
 "<KeyPress>q: Quit()\n\
  Ctrl<KeyPress>C: Quit()\n\
  <KeyPress>osfCancel: Hide()\n\
@@ -113,44 +108,44 @@ static char defaultTranslationsPuzzle3D[] =
  <EnterWindow>: Enter()\n\
  <LeaveWindow>: Leave()";
 
-static XtActionsRec actionsListPuzzle3D[] =
+static XtActionsRec actionsList3D[] =
 {
-	{(char *) "Quit", (XtActionProc) QuitPuzzle},
-	{(char *) "Hide", (XtActionProc) HidePuzzle},
-	{(char *) "MoveCcw", (XtActionProc) MovePuzzleCcw},
-	{(char *) "MoveTl", (XtActionProc) MovePuzzle3DTl},
-	{(char *) "MoveTop", (XtActionProc) MovePuzzle3DTop},
-	{(char *) "MoveTr", (XtActionProc) MovePuzzle3DTr},
-	{(char *) "MoveLeft", (XtActionProc) MovePuzzle3DLeft},
-	{(char *) "MoveCw", (XtActionProc) MovePuzzleCw},
-	{(char *) "MoveRight", (XtActionProc) MovePuzzle3DRight},
-	{(char *) "MoveBl", (XtActionProc) MovePuzzle3DBl},
-	{(char *) "MoveBottom", (XtActionProc) MovePuzzle3DBottom},
-	{(char *) "MoveBr", (XtActionProc) MovePuzzle3DBr},
-	{(char *) "Select", (XtActionProc) SelectPuzzle},
-	{(char *) "Release", (XtActionProc) ReleasePuzzle},
-	{(char *) "PracticeMaybe", (XtActionProc) PracticePuzzleMaybe},
-	{(char *) "Practice2", (XtActionProc) PracticePuzzle2},
-	{(char *) "RandomizeMaybe", (XtActionProc) RandomizePuzzleMaybe},
-	{(char *) "Randomize2", (XtActionProc) RandomizePuzzle2},
-	{(char *) "Get", (XtActionProc) GetPuzzle},
-	{(char *) "Write", (XtActionProc) WritePuzzle},
-	{(char *) "Undo", (XtActionProc) UndoPuzzle},
-	{(char *) "Redo", (XtActionProc) RedoPuzzle},
-	{(char *) "Clear", (XtActionProc) ClearPuzzle},
-	{(char *) "Randomize", (XtActionProc) RandomizePuzzle},
-	{(char *) "Solve", (XtActionProc) SolvePuzzle},
-	{(char *) "Practice", (XtActionProc) PracticePuzzle},
-	{(char *) "Orientize", (XtActionProc) OrientizePuzzle},
-	{(char *) "View", (XtActionProc) ViewPuzzle},
-	{(char *) "Speed", (XtActionProc) SpeedPuzzle},
-	{(char *) "Slow", (XtActionProc) SlowPuzzle},
-	{(char *) "Sound", (XtActionProc) SoundPuzzle},
-	{(char *) "Enter", (XtActionProc) EnterPuzzle},
-	{(char *) "Leave", (XtActionProc) LeavePuzzle}
+	{(char *) "Quit", (XtActionProc) quitPuzzle},
+	{(char *) "Hide", (XtActionProc) hidePuzzle},
+	{(char *) "MoveCcw", (XtActionProc) movePuzzleCcw},
+	{(char *) "MoveTl", (XtActionProc) movePuzzle3DTl},
+	{(char *) "MoveTop", (XtActionProc) movePuzzle3DTop},
+	{(char *) "MoveTr", (XtActionProc) movePuzzle3DTr},
+	{(char *) "MoveLeft", (XtActionProc) movePuzzle3DLeft},
+	{(char *) "MoveCw", (XtActionProc) movePuzzleCw},
+	{(char *) "MoveRight", (XtActionProc) movePuzzle3DRight},
+	{(char *) "MoveBl", (XtActionProc) movePuzzle3DBl},
+	{(char *) "MoveBottom", (XtActionProc) movePuzzle3DBottom},
+	{(char *) "MoveBr", (XtActionProc) movePuzzle3DBr},
+	{(char *) "Select", (XtActionProc) selectPuzzle},
+	{(char *) "Release", (XtActionProc) releasePuzzle},
+	{(char *) "PracticeMaybe", (XtActionProc) practicePuzzleWithQuery},
+	{(char *) "Practice2", (XtActionProc) practicePuzzleWithDoubleClick},
+	{(char *) "RandomizeMaybe", (XtActionProc) randomizePuzzleWithQuery},
+	{(char *) "Randomize2", (XtActionProc) randomizePuzzleWithDoubleClick},
+	{(char *) "Get", (XtActionProc) getPuzzle},
+	{(char *) "Write", (XtActionProc) writePuzzle},
+	{(char *) "Undo", (XtActionProc) undoPuzzle},
+	{(char *) "Redo", (XtActionProc) redoPuzzle},
+	{(char *) "Clear", (XtActionProc) clearPuzzle},
+	{(char *) "Randomize", (XtActionProc) randomizePuzzle},
+	{(char *) "Solve", (XtActionProc) solvePuzzle},
+	{(char *) "Practice", (XtActionProc) practicePuzzle},
+	{(char *) "Orientize", (XtActionProc) orientizePuzzle},
+	{(char *) "View", (XtActionProc) viewPuzzle},
+	{(char *) "Speed", (XtActionProc) speedUpPuzzle},
+	{(char *) "Slow", (XtActionProc) slowDownPuzzle},
+	{(char *) "Sound", (XtActionProc) toggleSoundPuzzle},
+	{(char *) "Enter", (XtActionProc) enterPuzzle},
+	{(char *) "Leave", (XtActionProc) leavePuzzle}
 };
 
-static XtResource resourcesPuzzle3D[] =
+static XtResource resources3D[] =
 {
 	{XtNwidth, XtCWidth, XtRDimension, sizeof (Dimension),
 	 XtOffset(SkewbWidget, core.width),
@@ -169,7 +164,7 @@ static XtResource resourcesPuzzle3D[] =
 	 XtRString, (caddr_t) XtDefaultForeground},
 	{XtNbackground, XtCBackground, XtRPixel, sizeof (Pixel),
 	 XtOffset(SkewbWidget, skewb.background),
-	 XtRString, (caddr_t) XtDefaultBackground},
+	 XtRString, (caddr_t) "#AEB2C3" /*XtDefaultBackground*/},
 	{XtNframeColor, XtCColor, XtRPixel, sizeof (Pixel),
 	 XtOffset(SkewbWidget, skewb.frameColor),
 	 XtRString, (caddr_t) "cyan" /*XtDefaultForeground*/},
@@ -259,29 +254,29 @@ Skewb3DClassRec skewb3dClassRec =
 		NULL,		/* class initialize */
 		NULL,		/* class part initialize */
 		FALSE,		/* class inited */
-		(XtInitProc) InitializePuzzle3D,	/* initialize */
+		(XtInitProc) initializePuzzle3D,	/* initialize */
 		NULL,		/* initialize hook */
 		XtInheritRealize,	/* realize */
-		actionsListPuzzle3D,	/* actions */
-		XtNumber(actionsListPuzzle3D),	/* num actions */
-		resourcesPuzzle3D,	/* resources */
-		XtNumber(resourcesPuzzle3D),	/* num resources */
+		actionsList3D,	/* actions */
+		XtNumber(actionsList3D),	/* num actions */
+		resources3D,	/* resources */
+		XtNumber(resources3D),	/* num resources */
 		NULLQUARK,	/* xrm class */
 		TRUE,		/* compress motion */
 		TRUE,		/* compress exposure */
 		TRUE,		/* compress enterleave */
 		TRUE,		/* visible interest */
 		NULL,		/* destroy */
-		(XtWidgetProc) ResizePuzzle3D,	/* resize */
-		(XtExposeProc) ExposePuzzle3D,	/* expose */
-		(XtSetValuesFunc) SetValuesPuzzle3D,	/* set values */
+		(XtWidgetProc) resizePuzzle3D,	/* resize */
+		(XtExposeProc) exposePuzzle3D,	/* expose */
+		(XtSetValuesFunc) setValuesPuzzle3D,	/* set values */
 		NULL,		/* set values hook */
 		XtInheritSetValuesAlmost,	/* set values almost */
 		NULL,		/* get values hook */
 		XtInheritAcceptFocus,	/* accept focus */
 		XtVersion,	/* version */
 		NULL,		/* callback private */
-		defaultTranslationsPuzzle3D,	/* tm table */
+		translations3D,	/* tm table */
 		NULL,		/* query geometry */
 		NULL,		/* display accelerator */
 		NULL		/* extension */
@@ -308,7 +303,7 @@ static Point orientTriangle[MAX_FACES][MAX_ORIENT][2];
 static Pixmap dr = 0; /* dummy for future double buffering */
 
 static void
-DiamondOffset3D(Skewb3DWidget w, int face, int *dx, int *dy)
+diamondOffset3D(Skewb3DWidget w, int face, int *dx, int *dy)
 {
 	char *buf;
 
@@ -342,7 +337,7 @@ DiamondOffset3D(Skewb3DWidget w, int face, int *dx, int *dy)
 				2 * w->skewb.delta + 2;
 			break;
 		default:
-			intCat(&buf, "DiamondOffset3D: face ", face);
+			intCat(&buf, "diamondOffset3D: face ", face);
 			DISPLAY_WARNING(buf);
 			free(buf);
 		}
@@ -376,7 +371,7 @@ DiamondOffset3D(Skewb3DWidget w, int face, int *dx, int *dy)
 			*dy = w->skewb3d.viewMiddle.y - w->skewb.delta;
 			break;
 		default:
-			intCat(&buf, "DiamondOffset3D: face ", face);
+			intCat(&buf, "diamondOffset3D: face ", face);
 			DISPLAY_WARNING(buf);
 			free(buf);
 		}
@@ -384,11 +379,11 @@ DiamondOffset3D(Skewb3DWidget w, int face, int *dx, int *dy)
 }
 
 static void
-CubeOffset3D(Skewb3DWidget w, int face, int corner, int *dx, int *dy)
+cubeOffset3D(Skewb3DWidget w, int face, int corner, int *dx, int *dy)
 {
 	int side;
 
-	DiamondOffset3D(w, face, dx, dy);
+	diamondOffset3D(w, face, dx, dy);
 	for (side = 1; side <= corner; side++) {
 		*dx += cubeLoc3D[face][side].x;
 		*dy += cubeLoc3D[face][side].y;
@@ -396,7 +391,7 @@ CubeOffset3D(Skewb3DWidget w, int face, int corner, int *dx, int *dy)
 }
 
 static void
-MapTo3D(Skewb3DWidget w, int face, int side, int *corner)
+mapTo3D(Skewb3DWidget w, int face, int side, int *corner)
 {
 	switch (face) {
 	case 0:
@@ -417,7 +412,7 @@ MapTo3D(Skewb3DWidget w, int face, int side, int *corner)
 		{
 			char *buf;
 
-			intCat(&buf, "MapTo3D: face ", face);
+			intCat(&buf, "mapTo3D: face ", face);
 			DISPLAY_WARNING(buf);
 			free(buf);
 		}
@@ -425,7 +420,7 @@ MapTo3D(Skewb3DWidget w, int face, int side, int *corner)
 }
 
 static void
-MapFrom3D(Skewb3DWidget w, int face, int corner, int *side)
+mapFrom3D(Skewb3DWidget w, int face, int corner, int *side)
 {
 	switch (face) {
 	case 0:
@@ -446,7 +441,7 @@ MapFrom3D(Skewb3DWidget w, int face, int corner, int *side)
 		{
 			char *buf;
 
-			intCat(&buf, "MapFrom3D: face ", face);
+			intCat(&buf, "mapFrom3D: face ", face);
 			DISPLAY_WARNING(buf);
 			free(buf);
 		}
@@ -454,13 +449,13 @@ MapFrom3D(Skewb3DWidget w, int face, int corner, int *side)
 }
 
 void
-DrawTriangle3D(Skewb3DWidget w, int face, int position, int offset)
+drawTriangle3D(Skewb3DWidget w, int face, int position, int offset)
 {
 	GC faceGC, borderGC;
 	int side = 0, dx, dy, rotation, letterX, letterY;
 
-	MapTo3D(w, face, position, &side);
-	CubeOffset3D(w, face, side, &dx, &dy);
+	mapTo3D(w, face, position, &side);
+	cubeOffset3D(w, face, side, &dx, &dy);
 	rotation = w->skewb.cubeLoc[face][position].rotation;
 	letterX = dx + letter3DList[face][side].x;
 	letterY = dy + letter3DList[face][side].y;
@@ -515,12 +510,12 @@ DrawTriangle3D(Skewb3DWidget w, int face, int position, int offset)
 }
 
 void
-DrawDiamond3D(Skewb3DWidget w, int face, int offset)
+drawDiamond3D(Skewb3DWidget w, int face, int offset)
 {
 	GC faceGC, borderGC;
 	int dx, dy, rotation;
 
-	DiamondOffset3D(w, face, &dx, &dy);
+	diamondOffset3D(w, face, &dx, &dy);
 	rotation = w->skewb.cubeLoc[face][MAX_ORIENT].rotation;
 	diamondLoc3D[face][0].x = dx + cubeLoc3D[face][1].x / 2;
 	diamondLoc3D[face][0].y = dy + cubeLoc3D[face][1].y / 2;
@@ -574,7 +569,7 @@ DrawDiamond3D(Skewb3DWidget w, int face, int offset)
 }
 
 void
-DrawFrame3D(Skewb3DWidget w, Boolean focus)
+drawFrame3D(Skewb3DWidget w, Boolean focus)
 {
 	int face, dx, dy;
 	GC gc = (focus) ? w->skewb.frameGC : w->skewb.borderGC;
@@ -611,7 +606,7 @@ DrawFrame3D(Skewb3DWidget w, Boolean focus)
 }
 
 static void
-ResizePieces(Skewb3DWidget w)
+resizePieces(Skewb3DWidget w)
 {
 	int face, orient, side, corner;
 	Point subcubeLoc3D[MAX_FACES][MAX_ORIENT];
@@ -860,7 +855,7 @@ ResizePieces(Skewb3DWidget w)
 			(orientCubeLoc3D[1][face][MAX_ORIENT - 1].y -
 			 orientCubeLoc3D[1][face][MAX_ORIENT / 2].y) / 2;
 
-		MapFrom3D(w, face, 1, &corner);
+		mapFrom3D(w, face, 1, &corner);
 		orientDiamond[face][corner][0].x = cubeLoc3D[face][1].x / 2;
 		orientDiamond[face][corner][0].y = cubeLoc3D[face][1].y / 2;
 		orientDiamond[face][corner][1].x = orientDiamond[face][corner][0].x +
@@ -873,7 +868,7 @@ ResizePieces(Skewb3DWidget w)
 		orientTriangle[face][corner][1].y = -orientCubeLoc3D[1][face][2].y / 2;
 		for (orient = 1; orient < MAX_ORIENT; orient++) {
 			side = corner;
-			MapFrom3D(w, face, (orient + 1) % MAX_ORIENT, &corner);
+			mapFrom3D(w, face, (orient + 1) % MAX_ORIENT, &corner);
 			orientDiamond[face][corner][0].x =
 				orientDiamond[face][side][0].x +
 				diamondLoc3D[face][orient].x;
@@ -903,7 +898,7 @@ ResizePieces(Skewb3DWidget w)
 }
 
 Boolean
-SelectPieces3D(Skewb3DWidget w, int x, int y, int *face, int *position)
+selectPieces3D(Skewb3DWidget w, int x, int y, int *face, int *position)
 {
 	int u, v, front, tl, ur, ul, found, side, dx, dy;
 	int x_1, y_1, x_2, y_2;
@@ -958,7 +953,7 @@ SelectPieces3D(Skewb3DWidget w, int x, int y, int *face, int *position)
 	x = x_1;
 	y = y_1;
 	found = 0;
-	DiamondOffset3D(w, *face, &dx, &dy);
+	diamondOffset3D(w, *face, &dx, &dy);
 	for (side = 0; side < MAX_ORIENT; side++) {
 		x_1 = dx + orientDiamond[*face][side][0].x;
 		y_1 = dy + orientDiamond[*face][side][0].y;
@@ -977,7 +972,7 @@ SelectPieces3D(Skewb3DWidget w, int x, int y, int *face, int *position)
 }
 
 Boolean
-NarrowSelection3D(Skewb3DWidget w, int *face, int *position, int *direction)
+narrowSelection3D(Skewb3DWidget w, int *face, int *position, int *direction)
 {
 	switch (*direction) {
 	case TR:
@@ -1040,13 +1035,13 @@ NarrowSelection3D(Skewb3DWidget w, int *face, int *position, int *direction)
 
 #ifndef WINVER
 static Boolean
-SetValuesPuzzle3D(Widget current, Widget request, Widget renew)
+setValuesPuzzle3D(Widget current, Widget request, Widget renew)
 {
 	Skewb3DWidget c = (Skewb3DWidget) current, w = (Skewb3DWidget) renew;
 	Boolean redraw = False;
 
 	if (w->skewb3d.cubeSize.x != c->skewb3d.cubeSize.x) {
-		ResizePuzzle3D(w);
+		resizePuzzle3D(w);
 		redraw = True;
 	}
 	return (redraw);
@@ -1057,7 +1052,7 @@ SetValuesPuzzle3D(Widget current, Widget request, Widget renew)
 static
 #endif
 void
-ResizePuzzle3D(Skewb3DWidget w)
+resizePuzzle3D(Skewb3DWidget w)
 {
 	Point tempSize;
 #ifdef WINVER
@@ -1115,14 +1110,14 @@ ResizePuzzle3D(Skewb3DWidget w)
 	w->skewb.puzzleOffset.x = ((int) w->core.width - w->skewb.puzzleSize.x) / 2;
 	w->skewb.puzzleOffset.y = ((int) w->core.height - w->skewb.puzzleSize.y) /
 		2;
-	ResizePieces(w);
+	resizePieces(w);
 }
 
 #ifndef WINVER
 static
 #endif
 void
-InitializePuzzle3D(
+initializePuzzle3D(
 #ifdef WINVER
 Skewb3DWidget w
 #else
@@ -1133,9 +1128,9 @@ Widget request, Widget renew
 #ifndef WINVER
 	Skewb3DWidget w = (Skewb3DWidget) renew;
 
-	SetAllColors((SkewbWidget) w);
+	setAllColors((SkewbWidget) w);
 	w->skewb.dim = 3;
-	ResizePuzzle3D(w);
+	resizePuzzle3D(w);
 #endif
 }
 
@@ -1143,7 +1138,7 @@ Widget request, Widget renew
 static
 #endif
 void
-ExposePuzzle3D(
+exposePuzzle3D(
 #ifdef WINVER
 Skewb3DWidget w
 #else
@@ -1159,78 +1154,78 @@ Widget renew, XEvent *event, Region region
 #endif
 	FILLRECTANGLE(w, dr, w->skewb.inverseGC,
 		0, 0, w->core.width, w->core.height);
-	DrawFrame3D(w, w->skewb.focus);
-	DrawAllPieces((SkewbWidget) w);
+	drawFrame3D(w, w->skewb.focus);
+	drawAllPieces((SkewbWidget) w);
 }
 
 #ifndef WINVER
 static void
-MovePuzzle3DTl(Skewb3DWidget w, XEvent *event, char **args, int nArgs)
+movePuzzle3DTl(Skewb3DWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((SkewbWidget) w, event->xbutton.x, event->xbutton.y,
+	movePuzzleInput((SkewbWidget) w, event->xbutton.x, event->xbutton.y,
 		TL,
 		(int) (event->xkey.state & ControlMask),
 		(int) (event->xkey.state & Mod1Mask));
 }
 
 static void
-MovePuzzle3DTop(Skewb3DWidget w, XEvent *event, char **args, int nArgs)
+movePuzzle3DTop(Skewb3DWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((SkewbWidget) w, event->xbutton.x, event->xbutton.y,
+	movePuzzleInput((SkewbWidget) w, event->xbutton.x, event->xbutton.y,
 		TOP,
 		(int) (event->xkey.state & ControlMask),
 		(int) (event->xkey.state & Mod1Mask));
 }
 
 static void
-MovePuzzle3DTr(Skewb3DWidget w, XEvent *event, char **args, int nArgs)
+movePuzzle3DTr(Skewb3DWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((SkewbWidget) w, event->xbutton.x, event->xbutton.y,
+	movePuzzleInput((SkewbWidget) w, event->xbutton.x, event->xbutton.y,
 		TR,
 		(int) (event->xkey.state & ControlMask),
 		(int) (event->xkey.state & Mod1Mask));
 }
 
 static void
-MovePuzzle3DLeft(Skewb3DWidget w, XEvent *event, char **args, int nArgs)
+movePuzzle3DLeft(Skewb3DWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((SkewbWidget) w, event->xbutton.x, event->xbutton.y,
+	movePuzzleInput((SkewbWidget) w, event->xbutton.x, event->xbutton.y,
 		LEFT,
 		(int) (event->xkey.state & ControlMask),
 		(int) (event->xkey.state & Mod1Mask));
 }
 
 static void
-MovePuzzle3DRight(Skewb3DWidget w, XEvent *event, char **args, int nArgs)
+movePuzzle3DRight(Skewb3DWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((SkewbWidget) w, event->xbutton.x, event->xbutton.y,
+	movePuzzleInput((SkewbWidget) w, event->xbutton.x, event->xbutton.y,
 		RIGHT,
 		(int) (event->xkey.state & ControlMask),
 		(int) (event->xkey.state & Mod1Mask));
 }
 
 static void
-MovePuzzle3DBl(Skewb3DWidget w, XEvent *event, char **args, int nArgs)
+movePuzzle3DBl(Skewb3DWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((SkewbWidget) w, event->xbutton.x, event->xbutton.y,
+	movePuzzleInput((SkewbWidget) w, event->xbutton.x, event->xbutton.y,
 		BL,
 		(int) (event->xkey.state & ControlMask),
 		(int) (event->xkey.state & Mod1Mask));
 }
 
 static void
-MovePuzzle3DBottom(Skewb3DWidget w, XEvent *event, char **args, int nArgs)
+movePuzzle3DBottom(Skewb3DWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((SkewbWidget) w, event->xbutton.x, event->xbutton.y,
+	movePuzzleInput((SkewbWidget) w, event->xbutton.x, event->xbutton.y,
 		BOTTOM,
 		(int) (event->xkey.state & ControlMask),
 		(int) (event->xkey.state & Mod1Mask));
 }
 
 static void
-MovePuzzle3DBr(Skewb3DWidget w, XEvent *event, char **args, int nArgs)
+movePuzzle3DBr(Skewb3DWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((SkewbWidget) w, event->xbutton.x, event->xbutton.y,
+	movePuzzleInput((SkewbWidget) w, event->xbutton.x, event->xbutton.y,
 		BR,
 		(int) (event->xkey.state & ControlMask),
 		(int) (event->xkey.state & Mod1Mask));
