@@ -1,27 +1,22 @@
-/*-
-# X-BASED SKEWB
-#
-#  SkewbGLP.h
-#
-###
-#
-#  Copyright (c) 2003 - 2008	David A. Bagley, bagleyd@tux.org
-#
-#                   All Rights Reserved
-#
-#  Permission to use, copy, modify, and distribute this software and
-#  its documentation for any purpose and without fee is hereby granted,
-#  provided that the above copyright notice appear in all copies and
-#  that both that copyright notice and this permission notice appear in
-#  supporting documentation, and that the name of the author not be
-#  used in advertising or publicity pertaining to distribution of the
-#  software without specific, written prior permission.
-#
-#  This program is distributed in the hope that it will be "playable",
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-#
-*/
+/*
+ * @(#)SkewbGLP.h
+ *
+ * Copyright 2003 - 2008  David A. Bagley, bagleyd@tux.org
+ *
+ * All rights reserved.
+ *
+ * Permission to use, copy, modify, and distribute this software and
+ * its documentation for any purpose and without fee is hereby granted,
+ * provided that the above copyright notice appear in all copies and
+ * that both that copyright notice and this permission notice appear in
+ * supporting documentation, and that the name of the author not be
+ * used in advertising or publicity pertaining to distribution of the
+ * software without specific, written prior permission.
+ *
+ * This program is distributed in the hope that it will be "useful",
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ */
 
 /* Private header file for SkewbGL */
 
@@ -113,13 +108,13 @@ typedef struct _SkewbGLRec {
 	SkewbGLPart skewbGL;
 } SkewbGLRec;
 
-extern Boolean SelectPiecesGL(SkewbGLWidget w, int x, int y,
+extern Boolean selectPiecesGL(SkewbGLWidget w, int x, int y,
 	int *face, int *position);
-extern void DrawFrameGL(SkewbGLWidget w, Boolean focus);
-extern void DrawAllPiecesGL(SkewbGLWidget w);
+extern void drawFrameGL(SkewbGLWidget w, Boolean focus);
+extern void drawAllPiecesGL(SkewbGLWidget w);
 #ifdef WINVER
-extern void ResizePuzzleGL(SkewbGLWidget w);
-extern void ExposePuzzleGL(SkewbGLWidget w);
+extern void resizePuzzleGL(SkewbGLWidget w);
+extern void exposePuzzleGL(SkewbGLWidget w);
 #endif
 
 #endif /* _SkewbGLP_h */
