@@ -1,27 +1,22 @@
-/*-
-# X-BASED SKEWB
-#
-#  SkewbP.h
-#
-###
-#
-#  Copyright (c) 1994 - 2007	David A. Bagley, bagleyd@tux.org
-#
-#                   All Rights Reserved
-#
-#  Permission to use, copy, modify, and distribute this software and
-#  its documentation for any purpose and without fee is hereby granted,
-#  provided that the above copyright notice appear in all copies and
-#  that both that copyright notice and this permission notice appear in
-#  supporting documentation, and that the name of the author not be
-#  used in advertising or publicity pertaining to distribution of the
-#  software without specific, written prior permission.
-#
-#  This program is distributed in the hope that it will be "playable",
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-#
-*/
+/*
+ * @(#)SkewbP.h
+ *
+ * Copyright 1994 - 2008  David A. Bagley, bagleyd@tux.org
+ *
+ * All rights reserved.
+ *
+ * Permission to use, copy, modify, and distribute this software and
+ * its documentation for any purpose and without fee is hereby granted,
+ * provided that the above copyright notice appear in all copies and
+ * that both that copyright notice and this permission notice appear in
+ * supporting documentation, and that the name of the author not be
+ * used in advertising or publicity pertaining to distribution of the
+ * software without specific, written prior permission.
+ *
+ * This program is distributed in the hope that it will be "useful",
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ */
 
 /* Private header file for Skewb */
 
@@ -33,13 +28,13 @@
 #include "Skewb.h"
 
 #ifdef WINVER
-extern void DestroyPuzzle(HBRUSH brush);
-extern void ResizePuzzle(SkewbWidget w);
-extern void SizePuzzle(SkewbWidget w);
-extern void InitializePuzzle(SkewbWidget w, HBRUSH brush);
-extern void ExposePuzzle(SkewbWidget w);
-extern void DimPuzzle(SkewbWidget w);
-extern int  MovePuzzleDir(SkewbWidget w, const int direction);
+extern void destroyPuzzle(HBRUSH brush);
+extern void resizePuzzle(SkewbWidget w);
+extern void sizePuzzle(SkewbWidget w);
+extern void initializePuzzle(SkewbWidget w, HBRUSH brush);
+extern void exposePuzzle(SkewbWidget w);
+extern void dimPuzzle(SkewbWidget w);
+extern int  movePuzzleDir(SkewbWidget w, const int direction);
 extern void setPuzzle(SkewbWidget w, int reason);
 extern void setPuzzleMove(SkewbWidget w, int reason, int face, int position,
 	int direction);
@@ -58,9 +53,9 @@ typedef struct _SkewbClassRec {
 
 extern SkewbClassRec skewbClassRec;
 
-extern void QuitPuzzle(SkewbWidget w, XEvent *event, char **args, int nArgs);
-extern void MovePuzzleCw(SkewbWidget w, XEvent *event, char **args, int nArgs);
-extern void MovePuzzleCcw(SkewbWidget w, XEvent *event, char **args,
+extern void quitPuzzle(SkewbWidget w, XEvent *event, char **args, int nArgs);
+extern void movePuzzleCw(SkewbWidget w, XEvent *event, char **args, int nArgs);
+extern void movePuzzleCcw(SkewbWidget w, XEvent *event, char **args,
 	int nArgs);
 #endif
 
@@ -92,15 +87,15 @@ typedef struct _SkewbLocPos {
 	int         face, position, direction;
 } SkewbLocPos;
 
-typedef struct _MoveRecord {
+typedef struct _moveRecord {
 #if 0
 	int face, position, direction, control;
 #endif
 	unsigned short int packed;  /* This makes assumptions on the data. */
-} MoveRecord;
+} moveRecord;
 
 typedef struct _MoveStack {
-	MoveRecord move;
+	moveRecord move;
 	struct _MoveStack *previous, *next;
 } MoveStack;
 
@@ -156,21 +151,21 @@ typedef struct _RowNext {
 	int         face, direction, sideFace;
 } RowNext;
 
-extern void HidePuzzle(
+extern void hidePuzzle(
 #ifdef WINVER
 const SkewbWidget w
 #else
 SkewbWidget w, XEvent *event, char **args, int nArgs
 #endif
 );
-extern void SelectPuzzle(SkewbWidget w
+extern void selectPuzzle(SkewbWidget w
 #ifdef WINVER
 , const int x, const int y, const int control, const int alt
 #else
 , XEvent *event, char **args, int nArgs
 #endif
 );
-extern void ReleasePuzzle(SkewbWidget w
+extern void releasePuzzle(SkewbWidget w
 #ifdef WINVER
 , const int x, const int y, const int control, const int alt
 #else
@@ -178,107 +173,107 @@ extern void ReleasePuzzle(SkewbWidget w
 #endif
 );
 #ifndef WINVER
-extern void PracticePuzzleMaybe(SkewbWidget w
+extern void practicePuzzleWithQuery(SkewbWidget w
 , XEvent *event, char **args, int nArgs
 );
-extern void PracticePuzzle2(SkewbWidget w
+extern void practicePuzzleWithDoubleClick(SkewbWidget w
 , XEvent *event, char **args, int nArgs
 );
-extern void RandomizePuzzleMaybe(SkewbWidget w
+extern void randomizePuzzleWithQuery(SkewbWidget w
 , XEvent *event, char **args, int nArgs
 );
-extern void RandomizePuzzle2(SkewbWidget w
+extern void randomizePuzzleWithDoubleClick(SkewbWidget w
 , XEvent *event, char **args, int nArgs
 );
 #endif
-extern void GetPuzzle(SkewbWidget w
+extern void getPuzzle(SkewbWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 );
-extern void WritePuzzle(SkewbWidget w
+extern void writePuzzle(SkewbWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 );
-extern void UndoPuzzle(SkewbWidget w
+extern void undoPuzzle(SkewbWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 );
-extern void RedoPuzzle(SkewbWidget w
+extern void redoPuzzle(SkewbWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 );
-extern void ClearPuzzle(SkewbWidget w
+extern void clearPuzzle(SkewbWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 );
-extern void RandomizePuzzle(SkewbWidget w
+extern void randomizePuzzle(SkewbWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 );
-extern void SolvePuzzle(SkewbWidget w
+extern void solvePuzzle(SkewbWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 );
-extern void PracticePuzzle(SkewbWidget w
+extern void practicePuzzle(SkewbWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 );
-extern void OrientizePuzzle(SkewbWidget w
+extern void orientizePuzzle(SkewbWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 );
-extern void ViewPuzzle(SkewbWidget w
+extern void viewPuzzle(SkewbWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 );
-extern void SpeedPuzzle(SkewbWidget w
+extern void speedUpPuzzle(SkewbWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 );
-extern void SlowPuzzle(SkewbWidget w
+extern void slowDownPuzzle(SkewbWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 );
-extern void SoundPuzzle(SkewbWidget w
+extern void toggleSoundPuzzle(SkewbWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 );
-extern void EnterPuzzle(SkewbWidget w
+extern void enterPuzzle(SkewbWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 );
-extern void LeavePuzzle(SkewbWidget w
+extern void leavePuzzle(SkewbWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 );
 
-extern void MovePuzzleInput(SkewbWidget w, int x, int y, int direction,
+extern void movePuzzleInput(SkewbWidget w, int x, int y, int direction,
 	int control, int alt);
-extern void MovePuzzle(SkewbWidget w, int face, int position, int direction,
+extern void movePuzzle(SkewbWidget w, int face, int position, int direction,
 	int control);
-extern void SetAllColors(SkewbWidget w);
+extern void setAllColors(SkewbWidget w);
 #if 0
 /* For future auto-solver */
-extern void SolvePieces(SkewbWidget w);
+extern void solvePieces(SkewbWidget w);
 
 #endif
-extern void DrawAllPieces(SkewbWidget w);
-extern Boolean CheckSolved(SkewbWidget w);
+extern void drawAllPieces(SkewbWidget w);
+extern Boolean checkSolved(SkewbWidget w);
 extern void newMoves(SkewbStack *s);
 extern void deleteMoves(SkewbStack *s);
 extern void setMove(SkewbStack *s,
@@ -295,7 +290,7 @@ extern void printStartPosition(FILE *fp, SkewbWidget w);
 extern void setStartPosition(SkewbWidget w);
 
 #ifdef DEBUG
-extern void PrintCube(SkewbWidget w);
+extern void printCube(SkewbWidget w);
 
 #endif
 
