@@ -1,27 +1,24 @@
-/*-
-# MOTIF/X-BASED SKEWB
-#
-#  xskewb.c
-#
-###
-#
-#  Copyright (c) 1993 - 2007	David A. Bagley, bagleyd@tux.org
-#
-#                   All Rights Reserved
-#
-#  Permission to use, copy, modify, and distribute this software and
-#  its documentation for any purpose and without fee is hereby granted,
-#  provided that the above copyright notice appear in all copies and
-#  that both that copyright notice and this permission notice appear in
-#  supporting documentation, and that the name of the author not be
-#  used in advertising or publicity pertaining to distribution of the
-#  software without specific, written prior permission.
-#
-#  This program is distributed in the hope that it will be "playable",
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-#
-*/
+/*
+ * @(#)xskewb.c
+ *
+ * Copyright 1993 - 2008  David A. Bagley, bagleyd@tux.org
+ *
+ * All rights reserved.
+ *
+ * Permission to use, copy, modify, and distribute this software and
+ * its documentation for any purpose and without fee is hereby granted,
+ * provided that the above copyright notice appear in all copies and
+ * that both that copyright notice and this permission notice appear in
+ * supporting documentation, and that the name of the author not be
+ * used in advertising or publicity pertaining to distribution of the
+ * software without specific, written prior permission.
+ *
+ * This program is distributed in the hope that it will be "useful",
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ */
+
+/* Driver file for Skewb */
 
 #include "file.h"
 #ifdef WINVER
@@ -56,7 +53,7 @@ static SkewbRec widget;
 #include "pixmaps/mouse-l.xbm"
 #include "pixmaps/mouse-r.xbm"
 #endif
-#define PRINT_MESSAGE(b) PrintState(message, b)
+#define PRINT_MESSAGE(b) printState(message, b)
 #else
 #define PRINT_MESSAGE(b) XtWarning(b)
 #endif
@@ -93,7 +90,7 @@ static SkewbRec widget;
 
 #ifndef WINVER
 static const char aboutHelp[] = {
-"Skewb Version 7.3.2\n"
+"Skewb Version 7.4\n"
 "Send bugs (reports or fixes) to the author: "
 "David Bagley <bagleyd@tux.org>\n"
 "The latest version is at: "
@@ -267,7 +264,7 @@ static char progDsp[PROGRAM_NAME_LENGTH] = TITLE;
 static char userNameDsp[USER_NAME_LENGTH] = "Guest";
 #else
 #ifdef HAVE_MOTIF
-static Widget moves, record, message, orientizeSwitch, practiceSwitch;
+static Widget movesText, recordText, message, orientizeSwitch, practiceSwitch;
 static char buff[21];
 static Widget descriptionDialog, featuresDialog;
 static Widget optionsDialog, referencesDialog, aboutDialog;
@@ -289,19 +286,19 @@ static char userNameDsp[USER_NAME_LENGTH] = "";
 
 #ifdef HAVE_MOTIF
 static void
-PrintState(Widget w, char *msg)
+printState(Widget w, char *msg)
 {
 	XmString xmstr;
 
 	if (!XtIsSubclass(w, xmLabelWidgetClass))
-		XtError("PrintState() requires a Label Widget");
+		XtError("printState() requires a Label Widget");
 	xmstr = XmStringCreateLtoR(msg, XmSTRING_DEFAULT_CHARSET);
 	XtVaSetValues(w, XmNlabelString, xmstr, NULL);
 }
 #endif
 
 static void
-PrintRecords(void)
+printRecords(void)
 {
 	int orient;
 
@@ -318,7 +315,7 @@ PrintRecords(void)
 #endif
 
 static void
-InitRecords(void)
+initRecords(void)
 {
 	int orient;
 
@@ -329,7 +326,7 @@ InitRecords(void)
 }
 
 static void
-ReadRecords(void)
+readRecords(void)
 {
 	FILE *fp;
 	int n, orient;
@@ -387,7 +384,7 @@ ReadRecords(void)
 }
 
 static void
-WriteRecords(void)
+writeRecords(void)
 {
 	FILE *fp;
 	int orient;
@@ -432,7 +429,7 @@ WriteRecords(void)
 }
 
 static void
-PrintRecord(Boolean orient, Boolean practice)
+printRecord(Boolean orient, Boolean practice)
 {
 	int i = (orient) ? 1 : 0;
 
@@ -445,7 +442,7 @@ PrintRecord(Boolean orient, Boolean practice)
 			puzzleRecord[i].score, puzzleRecord[i].name);
 	}
 #ifdef HAVE_MOTIF
-	PrintState(record, recordDsp);
+	printState(recordText, recordDsp);
 #endif
 }
 
@@ -453,7 +450,7 @@ PrintRecord(Boolean orient, Boolean practice)
 /* There is probably a better way to assure that they are the same
  * but I do not know it off hand. */
 static void
-MakeEquivalent(String *userName, String *scoreFile,
+makeEquivalent(String *userName, String *scoreFile,
 		Boolean *orient, Boolean *practice)
 {
 	Boolean mono, reverse;
@@ -486,9 +483,9 @@ MakeEquivalent(String *userName, String *scoreFile,
 	if (strcmp(*scoreFile, ""))
 		(void) strncpy(scoreFileName, *scoreFile, FILE_NAME_LENGTH);
 	if (scoreOnly) {
-		InitRecords();
-		ReadRecords();
-		PrintRecords();
+		initRecords();
+		readRecords();
+		printRecords();
 		exit(0);
 	}
 	XtVaSetValues(puzzle2d,
@@ -534,16 +531,16 @@ MakeEquivalent(String *userName, String *scoreFile,
 #endif
 
 static void
-PrintStatus(char *msg, int nMoves
+printStatus(char *msg, int nMoves
 #ifndef HAVE_MOTIF
 		, int dim
 #endif
 		)
 {
 #ifdef HAVE_MOTIF
-	PrintState(message, msg);
+	printState(message, msg);
 	(void) sprintf(buff, "%d", nMoves);
-	PrintState(moves, buff);
+	printState(movesText, buff);
 #else
 #ifdef HAVE_OPENGL
 	if (dim == 4)
@@ -568,12 +565,12 @@ PrintStatus(char *msg, int nMoves
 }
 
 static Boolean
-HandleSolved(int counter, Boolean orient)
+handleSolved(int counter, Boolean orient)
 {
 	int i = (orient) ? 1 : 0;
 
 	if (counter < puzzleRecord[i].score || puzzleRecord[i].score <= NEVER) {
-		ReadRecords();	/* Maybe its been updated by another */
+		readRecords();	/* Maybe its been updated by another */
 		puzzleRecord[i].score = counter;
 		(void) strncpy(puzzleRecord[i].name, userNameDsp, USER_NAME_LENGTH);
 		if (orient && (counter < puzzleRecord[!i].score ||
@@ -582,15 +579,15 @@ HandleSolved(int counter, Boolean orient)
 			(void) strncpy(puzzleRecord[!i].name, userNameDsp,
 				USER_NAME_LENGTH);
 		}
-		WriteRecords();
-		PrintRecord(orient, False);
+		writeRecords();
+		printRecord(orient, False);
 		return True;
 	}
 	return False;
 }
 
 static void
-Initialize(
+initialize(
 #ifdef WINVER
 SkewbWidget w, HBRUSH brush
 #else
@@ -603,7 +600,7 @@ void
 #ifdef WINVER
 	int dim;
 
-	InitializePuzzle(w, brush);
+	initializePuzzle(w, brush);
 
 	orient = w->skewb.orient;
 	practice = w->skewb.practice;
@@ -614,14 +611,14 @@ void
 	if (strcmp(scoreFile, ""))
 		(void) strncpy(scoreFileName, scoreFile, FILE_NAME_LENGTH);
 #else
-	MakeEquivalent(&userName, &scoreFile, &orient, &practice);
+	makeEquivalent(&userName, &scoreFile, &orient, &practice);
 #ifdef HAVE_MOTIF
 	XmToggleButtonSetState(orientizeSwitch, orient, True);
 	XmToggleButtonSetState(practiceSwitch, practice, True);
 #endif
 #endif
-	InitRecords();
-	ReadRecords();
+	initRecords();
+	readRecords();
 #ifndef WINVER
 	(void) strncpy(userNameDsp, userName, USER_NAME_LENGTH);
 #endif
@@ -646,17 +643,17 @@ void
 			(void) sprintf(userNameDsp, "%s", "guest");
 #endif
 	}
-	PrintRecord(orient, practice);
+	printRecord(orient, practice);
 #ifdef WINVER
-	PrintStatus(messageDsp, movesDsp, dim);
+	printStatus(messageDsp, movesDsp, dim);
 #else
 #ifdef HAVE_MOTIF
-	PrintStatus(messageDsp, movesDsp);
+	printStatus(messageDsp, movesDsp);
 #else
-	PrintStatus(messageDsp, movesDsp, 2);
-	PrintStatus(messageDsp, movesDsp, 3);
+	printStatus(messageDsp, movesDsp, 2);
+	printStatus(messageDsp, movesDsp, 3);
 #ifdef HAVE_OPENGL
-	PrintStatus(messageDsp, movesDsp, 4);
+	printStatus(messageDsp, movesDsp, 4);
 #endif
 #endif
 #endif
@@ -667,7 +664,7 @@ void
 setPuzzle(SkewbWidget w, int reason)
 #else
 static void
-CallbackPuzzle(Widget w, caddr_t clientData, skewbCallbackStruct *callData)
+puzzleListener(Widget w, caddr_t clientData, skewbCallbackStruct *callData)
 #endif
 {
 	Boolean orient, practice, start, cheat;
@@ -790,7 +787,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, skewbCallbackStruct *callData)
 			(void) strncpy(recordDsp, "practice",
 				MESSAGE_LENGTH);
 #ifdef HAVE_MOTIF
-			PrintState(record, recordDsp);
+			printState(recordText, recordDsp);
 #endif
 		}
 		movesDsp = 0;
@@ -868,7 +865,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, skewbCallbackStruct *callData)
 		else if (cheat)
 			(void) sprintf(messageDsp,
 				"No cheating %s!!", userNameDsp);
-		else if (HandleSolved(movesDsp, orient))
+		else if (handleSolved(movesDsp, orient))
 			(void) sprintf(messageDsp,
 				"Congratulations %s!!", userNameDsp);
 		else
@@ -901,7 +898,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, skewbCallbackStruct *callData)
 		if (!practice)
 			(void) strncpy(messageDsp, "Randomize to start",
 				MESSAGE_LENGTH);
-		PrintRecord(orient, practice);
+		printRecord(orient, practice);
 #ifdef WINVER
 		w->skewb.practice = practice;
 		w->skewb.started = False;
@@ -966,7 +963,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, skewbCallbackStruct *callData)
 	case ACTION_ORIENTIZE:
 		movesDsp = 0;
 		orient = !orient;
-		PrintRecord(orient, practice);
+		printRecord(orient, practice);
 #ifdef WINVER
 		w->skewb.orient = orient;
 #else
@@ -1034,15 +1031,15 @@ CallbackPuzzle(Widget w, caddr_t clientData, skewbCallbackStruct *callData)
 
 	}
 #ifdef WINVER
-	PrintStatus(messageDsp, movesDsp, dim);
+	printStatus(messageDsp, movesDsp, dim);
 #else
 #ifdef HAVE_MOTIF
-	PrintStatus(messageDsp, movesDsp);
+	printStatus(messageDsp, movesDsp);
 #else
-	PrintStatus(messageDsp, movesDsp, dim);
-	PrintStatus(messageDsp, movesDsp, otherdim1);
+	printStatus(messageDsp, movesDsp, dim);
+	printStatus(messageDsp, movesDsp, otherdim1);
 #ifdef HAVE_OPENGL
-	PrintStatus(messageDsp, movesDsp, otherdim2);
+	printStatus(messageDsp, movesDsp, otherdim2);
 #endif
 #endif
 #endif
@@ -1078,19 +1075,15 @@ setPuzzleMove(SkewbWidget w, int reason, int face, int position, int direction)
 		SET_STARTED(w, True);
 		break;
 	}
-	PrintStatus(messageDsp, movesDsp, dim);
+	printStatus(messageDsp, movesDsp, dim);
 }
 
 static LRESULT CALLBACK
-About(HWND hDlg, UINT message, WPARAM wParam, LPARAM lParam)
+about(HWND hDlg, UINT message, WPARAM wParam, LPARAM lParam)
 {
-	switch (message) {
-	case WM_COMMAND:
-		if (LOWORD(wParam) == IDOK) {
-			(void) EndDialog(hDlg, TRUE);
-			return TRUE;
-		}
-		break;
+	if (message == WM_COMMAND && LOWORD(wParam) == IDOK) {
+		(void) EndDialog(hDlg, TRUE);
+		return TRUE;
 	}
 	return FALSE;
 }
@@ -1107,7 +1100,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_BRUSH));
-			EnterPuzzle(&widget);
+			enterPuzzle(&widget);
 			(void) EndPaint(hWnd, &paint);
 		}
 	} else {
@@ -1115,40 +1108,40 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_BRUSH));
-			LeavePuzzle(&widget);
+			leavePuzzle(&widget);
 			(void) EndPaint(hWnd, &paint);
 		}
 	}
 	switch (message) {
 	case WM_CREATE:
-		Initialize(&widget, brush);
+		initialize(&widget, brush);
 		break;
 	case WM_DESTROY:
-		DestroyPuzzle(brush);
+		destroyPuzzle(brush);
 		break;
 	case WM_SIZE:
-		ResizePuzzle(&widget);
+		resizePuzzle(&widget);
 		(void) InvalidateRect(hWnd, NULL, TRUE);
 		break;
 	case WM_PAINT:
 		widget.core.hDC = BeginPaint(hWnd, &paint);
 		(void) SelectObject(widget.core.hDC,
 			GetStockObject(NULL_PEN));
-		ExposePuzzle(&widget);
+		exposePuzzle(&widget);
 		(void) EndPaint(hWnd, &paint);
 		break;
 	case WM_RBUTTONDOWN:
 		widget.core.hDC = GetDC(hWnd);
 		(void) SelectObject(widget.core.hDC,
 			GetStockObject(NULL_PEN));
-		RandomizePuzzle(&widget);
+		randomizePuzzle(&widget);
 		(void) ReleaseDC(hWnd, widget.core.hDC);
 		break;
 	case WM_LBUTTONDOWN:
 		widget.core.hDC = GetDC(hWnd);
 		(void) SelectObject(widget.core.hDC,
 			GetStockObject(NULL_PEN));
-		SelectPuzzle(&widget, LOWORD(lParam), HIWORD(lParam),
+		selectPuzzle(&widget, LOWORD(lParam), HIWORD(lParam),
 			(GetKeyState(VK_CONTROL) >> 1) ? 1 : 0,
 			(GetKeyState(VK_TAB) >> 1) ? 1 : 0);
 		(void) ReleaseDC(hWnd, widget.core.hDC);
@@ -1157,7 +1150,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 		widget.core.hDC = GetDC(hWnd);
 		(void) SelectObject(widget.core.hDC,
 			GetStockObject(NULL_PEN));
-		ReleasePuzzle(&widget, LOWORD(lParam), HIWORD(lParam),
+		releasePuzzle(&widget, LOWORD(lParam), HIWORD(lParam),
 			(GetKeyState(VK_CONTROL) >> 1) ? 1 : 0,
 			(GetKeyState(VK_TAB) >> 1) ? 1 : 0);
 		(void) ReleaseDC(hWnd, widget.core.hDC);
@@ -1175,14 +1168,14 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			ClientToScreen(hWnd, &origin);
 			(void) GetCursorPos(&cursor);
 			if (zDelta > (WHEEL_DELTA >> 1)) {
-				MovePuzzleInput(&widget,
+				movePuzzleInput(&widget,
 					cursor.x - origin.x,
 					cursor.y - origin.y,
 					TOP,
 					(GetKeyState(VK_CONTROL) >> 1) ? 1 : 0,
 					(GetKeyState(VK_TAB) >> 1) ? 1 : 0);
 			} else if (zDelta < -(WHEEL_DELTA >> 1)) {
-				MovePuzzleInput(&widget,
+				movePuzzleInput(&widget,
 					cursor.x - origin.x,
 					cursor.y - origin.y,
 					BOTTOM,
@@ -1196,70 +1189,70 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 	case WM_COMMAND:
 		switch (LOWORD(wParam)) {
 		case ACTION_GET:
-			GetPuzzle(&widget);
-			ResizePuzzle(&widget);
+			getPuzzle(&widget);
+			resizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
 		case ACTION_WRITE:
-			WritePuzzle(&widget);
+			writePuzzle(&widget);
 			break;
 		case ACTION_EXIT:
-			DestroyPuzzle(brush);
+			destroyPuzzle(brush);
 			break;
 		case ACTION_HIDE:
-			HidePuzzle(&widget);
+			hidePuzzle(&widget);
 			break;
 		case ACTION_UNDO:
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_PEN));
-			UndoPuzzle(&widget);
+			undoPuzzle(&widget);
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
 		case ACTION_REDO:
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_PEN));
-			RedoPuzzle(&widget);
+			redoPuzzle(&widget);
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
 		case ACTION_CLEAR:
-			ClearPuzzle(&widget);
-			SizePuzzle(&widget);
+			clearPuzzle(&widget);
+			sizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
 		case ACTION_RANDOMIZE:
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_PEN));
-			RandomizePuzzle(&widget);
+			randomizePuzzle(&widget);
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
 		case ACTION_PRACTICE:
-			PracticePuzzle(&widget);
-			SizePuzzle(&widget);
+			practicePuzzle(&widget);
+			sizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
 		case ACTION_SOLVE:
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_PEN));
-			SolvePuzzle(&widget);
+			solvePuzzle(&widget);
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
 		case ACTION_ORIENTIZE:
-			OrientizePuzzle(&widget);
-			SizePuzzle(&widget);
+			orientizePuzzle(&widget);
+			sizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
 		case ACTION_DIM:
-			(void) DimPuzzle(&widget);
-			ResizePuzzle(&widget);
+			(void) dimPuzzle(&widget);
+			resizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
 		case ACTION_VIEW:
-			(void) ViewPuzzle(&widget);
-			SizePuzzle(&widget);
+			(void) viewPuzzle(&widget);
+			sizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
 		case ACTION_TR:
@@ -1281,7 +1274,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 				origin.x = 0, origin.y = 0;
 				ClientToScreen(hWnd, &origin);
 				(void) GetCursorPos(&cursor);
-				(void) MovePuzzleInput(&widget,
+				(void) movePuzzleInput(&widget,
 					cursor.x - origin.x,
 					cursor.y - origin.y,
 					(int) LOWORD(wParam) - ACTION_TR,
@@ -1308,7 +1301,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 				origin.x = 0, origin.y = 0;
 				ClientToScreen(hWnd, &origin);
 				(void) GetCursorPos(&cursor);
-				(void) MovePuzzleInput(&widget,
+				(void) movePuzzleInput(&widget,
 					cursor.x - origin.x,
 					cursor.y - origin.y,
 					(int) LOWORD(wParam) - ACTION_CONTROL_TR,
@@ -1317,13 +1310,13 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			}
 			break;
 		case ACTION_SPEED:
-			SpeedPuzzle(&widget);
+			speedUpPuzzle(&widget);
 			break;
 		case ACTION_SLOW:
-			SlowPuzzle(&widget);
+			slowDownPuzzle(&widget);
 			break;
 		case ACTION_SOUND:
-			SoundPuzzle(&widget);
+			toggleSoundPuzzle(&widget);
 			break;
 		case ACTION_DESCRIPTION:
 			(void) MessageBox(hWnd, descriptionHelp,
@@ -1339,7 +1332,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			break;
 		case ACTION_ABOUT:
 			(void) DialogBox(widget.core.hInstance,
-				"About", hWnd, (DLGPROC) About);
+				"About", hWnd, (DLGPROC) about);
 			break;
 		}
 		break;
@@ -1399,7 +1392,7 @@ WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance, LPSTR lpCmdLine,
 
 #else
 static void
-Usage(char *programName)
+usage(char *programName)
 {
 	unsigned int i;
 
@@ -1450,7 +1443,7 @@ static XrmOptionDescRec options[] =
 
 #ifdef HAVE_MOTIF
 static void
-CallbackPuzzlePractice(Widget w, XtPointer clientData, XmAnyCallbackStruct *cbs)
+puzzlePracticeListener(Widget w, XtPointer clientData, XmAnyCallbackStruct *cbs)
 {
 	if (cbs->reason == XmCR_OK) {
 		XtVaSetValues(puzzle2d, XtNmenu, ACTION_PRACTICE, NULL);
@@ -1458,7 +1451,7 @@ CallbackPuzzlePractice(Widget w, XtPointer clientData, XmAnyCallbackStruct *cbs)
 }
 
 static void
-CallbackPuzzleRandomize(Widget w, XtPointer clientData, XmAnyCallbackStruct *cbs)
+puzzleRandomizeListener(Widget w, XtPointer clientData, XmAnyCallbackStruct *cbs)
 {
 	if (cbs->reason == XmCR_OK) {
 		XtVaSetValues(puzzle2d, XtNmenu, ACTION_RANDOMIZE, NULL);
@@ -1466,7 +1459,7 @@ CallbackPuzzleRandomize(Widget w, XtPointer clientData, XmAnyCallbackStruct *cbs
 }
 
 static void
-OrientToggle(Widget w, XtPointer clientData, XmToggleButtonCallbackStruct *cbs)
+orientToggle(Widget w, XtPointer clientData, XmToggleButtonCallbackStruct *cbs)
 {
 	Boolean orient = cbs->set, practice;
 
@@ -1482,14 +1475,14 @@ OrientToggle(Widget w, XtPointer clientData, XmToggleButtonCallbackStruct *cbs)
 #endif
 	movesDsp = 0;
 	(void) sprintf(buff, "%d", movesDsp);
-	PrintState(moves, buff);
-	PrintRecord(orient, practice);
+	printState(movesText, buff);
+	printRecord(orient, practice);
 	(void) strcpy(messageDsp, "");
-	PrintState(message, messageDsp);
+	printState(message, messageDsp);
 }
 
 static void
-PracticeToggle(Widget w, XtPointer clientData,
+practiceToggle(Widget w, XtPointer clientData,
 		XmToggleButtonCallbackStruct *cbs)
 {
 	Boolean orient, practice = cbs->set;
@@ -1509,17 +1502,17 @@ PracticeToggle(Widget w, XtPointer clientData,
 		XtNpractice, &orient, NULL);
 	movesDsp = 0;
 	(void) sprintf(buff, "%d", movesDsp);
-	PrintState(moves, buff);
-	PrintRecord(orient, practice);
+	printState(movesText, buff);
+	printRecord(orient, practice);
 	if (practice)
 		(void) strcpy(messageDsp, "");
 	else
 		(void) strncpy(messageDsp, "Randomize to start", MESSAGE_LENGTH);
-	PrintState(message, messageDsp);
+	printState(message, messageDsp);
 }
 
 static void
-fileCB(Widget w, void *value, void *clientData)
+fileMenuListener(Widget w, void *value, void *clientData)
 {
 	int val = (int) value + ACTION_GET;
 
@@ -1591,7 +1584,7 @@ createHelp(Widget w, char *text, char *title)
 }
 
 static void
-helpCB(Widget w, XtPointer value, XtPointer clientData)
+helpMenuListener(Widget w, XtPointer value, XtPointer clientData)
 {
 	int val = (int) value;
 
@@ -1615,7 +1608,7 @@ helpCB(Widget w, XtPointer value, XtPointer clientData)
 		{
 			char *buf;
 
-			intCat(&buf, "helpCB: %d", val);
+			intCat(&buf, "helpMenuListener: %d", val);
 			XtWarning(buf);
 			free(buf);
 		}
@@ -1643,7 +1636,7 @@ main(int argc, char **argv)
 	topLevel = XtInitialize(argv[0], "Skewb",
 		options, XtNumber(options), &argc, argv);
 	if (argc != 1)
-		Usage(argv[0]);
+		usage(argv[0]);
 
 #ifdef HAVE_MOTIF
 	menuBarPanel = XtVaCreateManagedWidget("menuBarPanel",
@@ -1663,7 +1656,7 @@ main(int argc, char **argv)
 	writeString = XmStringCreateSimple((char *) "Write");
 	quitString = XmStringCreateSimple((char *) "Quit");
 	(void) XmVaCreateSimplePulldownMenu(menuBar, (char *) "file_menu",
-		0, fileCB,
+		0, fileMenuListener,
 		XmVaPUSHBUTTON, getString, 'G', NULL, NULL,
 		XmVaPUSHBUTTON, writeString, 'W', NULL, NULL,
 		XmVaSEPARATOR,
@@ -1718,23 +1711,23 @@ main(int argc, char **argv)
 	widget = XtVaCreateManagedWidget("Description",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'D', NULL);
-	XtAddCallback(widget, XmNactivateCallback, helpCB, (char *) 0);
+	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 0);
 	widget = XtVaCreateManagedWidget("Features",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'F', NULL);
-	XtAddCallback(widget, XmNactivateCallback, helpCB, (char *) 1);
+	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 1);
 	widget = XtVaCreateManagedWidget("Options",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'O', NULL);
-	XtAddCallback(widget, XmNactivateCallback, helpCB, (char *) 2);
+	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 2);
 	widget = XtVaCreateManagedWidget("References",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'R', NULL);
-	XtAddCallback(widget, XmNactivateCallback, helpCB, (char *) 3);
+	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 3);
 	widget = XtVaCreateManagedWidget("About",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'A', NULL);
-	XtAddCallback(widget, XmNactivateCallback, helpCB, (char *) 4);
+	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 4);
 	XtManageChild(menuBar);
 	descriptionDialog = createHelp(menuBar, (char *) descriptionHelp,
 		(char *) "Description");
@@ -1751,11 +1744,11 @@ main(int argc, char **argv)
 	practiceDialog = createQuery(topLevel,
 		(char *) "Are you sure you want to toggle the practice mode?",
 		(char *) "Practice Query",
-		(XtCallbackProc) CallbackPuzzlePractice);
+		(XtCallbackProc) puzzlePracticeListener);
 	randomizeDialog = createQuery(topLevel,
 		(char *) "Are you sure you want to randomize?",
 		(char *) "Randomize Query",
-		(XtCallbackProc) CallbackPuzzleRandomize);
+		(XtCallbackProc) puzzleRandomizeListener);
 	mainPanel = XtCreateManagedWidget("mainPanel",
 		xmPanedWindowWidgetClass, menuBarPanel,
 		NULL, 0);
@@ -1811,12 +1804,12 @@ main(int argc, char **argv)
 	(void) XtVaCreateManagedWidget("movesText",
 		xmLabelGadgetClass, movesRowCol,
 		XtVaTypedArg, XmNlabelString, XmRString, "Moves", 6, NULL);
-	moves = XtVaCreateManagedWidget("0",
+	movesText = XtVaCreateManagedWidget("0",
 		xmLabelWidgetClass, movesRowCol, NULL);
 	(void) XtVaCreateManagedWidget("recordText",
 		xmLabelGadgetClass, movesRowCol,
 		XtVaTypedArg, XmNlabelString, XmRString, "Record", 7, NULL);
-	record = XtVaCreateManagedWidget("0",
+	recordText = XtVaCreateManagedWidget("0",
 		xmLabelWidgetClass, movesRowCol, NULL);
 
 	switchRowCol = XtVaCreateManagedWidget("switchRowCol",
@@ -1828,12 +1821,12 @@ main(int argc, char **argv)
 		xmToggleButtonWidgetClass, switchRowCol,
 		XmNset, DEFAULT_ORIENT, NULL);
 	XtAddCallback(orientizeSwitch, XmNvalueChangedCallback,
-		(XtCallbackProc) OrientToggle, (XtPointer) NULL);
+		(XtCallbackProc) orientToggle, (XtPointer) NULL);
 	practiceSwitch = XtVaCreateManagedWidget("Practice",
 		xmToggleButtonWidgetClass, switchRowCol,
 		XmNset, DEFAULT_PRACTICE, NULL);
 	XtAddCallback(practiceSwitch, XmNvalueChangedCallback,
-		(XtCallbackProc) PracticeToggle, (XtPointer) NULL);
+		(XtCallbackProc) practiceToggle, (XtPointer) NULL);
 	messageRowCol = XtVaCreateManagedWidget("messageRowCol",
 		xmRowColumnWidgetClass, controlPanel, NULL);
 	message = XtVaCreateManagedWidget("Play Skewb! (use mouse and keypad)",
@@ -1843,7 +1836,7 @@ main(int argc, char **argv)
 	XtVaSetValues(puzzle2d,
 		XtNheight, 200, NULL);
 	XtAddCallback(puzzle2d, XtNselectCallback,
-		(XtCallbackProc) CallbackPuzzle, (XtPointer) NULL);
+		(XtCallbackProc) puzzleListener, (XtPointer) NULL);
 	puzzle3d = XtCreateManagedWidget("skewb",
 		skewb3dWidgetClass, mainPanel, NULL, 0);
 	XtVaSetValues(puzzle3d,
@@ -1907,10 +1900,8 @@ main(int argc, char **argv)
 		XtNinput, True,
 		XtNiconPixmap, pixmap, NULL);
 #endif
-	XtAddCallback(puzzle2d, XtNselectCallback,
-		(XtCallbackProc) CallbackPuzzle, (XtPointer) NULL);
 	XtAddCallback(puzzle3d, XtNselectCallback,
-		(XtCallbackProc) CallbackPuzzle, (XtPointer) NULL);
+		(XtCallbackProc) puzzleListener, (XtPointer) NULL);
 #ifdef HAVE_OPENGL
 #ifndef HAVE_MOTIF
 	XtVaSetValues(shellGL,
@@ -1918,9 +1909,9 @@ main(int argc, char **argv)
 		XtNiconPixmap, pixmap, NULL);
 #endif
 	XtAddCallback(puzzleGL, XtNselectCallback,
-		(XtCallbackProc) CallbackPuzzle, (XtPointer) NULL);
+		(XtCallbackProc) puzzleListener, (XtPointer) NULL);
 #endif
-	Initialize();
+	initialize();
 	XtRealizeWidget(topLevel);
 #ifndef HAVE_MOTIF
 	XtRealizeWidget(shell);
@@ -1932,12 +1923,12 @@ main(int argc, char **argv)
 		XtWindow(puzzle2d), TRUE, (unsigned int) (ButtonPressMask |
 		ButtonMotionMask | ButtonReleaseMask),
 		GrabModeAsync, GrabModeAsync, XtWindow(puzzle2d),
-		XCreateFontCursor(XtDisplay(puzzle2d), XC_crosshair));
+		XCreateFontCursor(XtDisplay(puzzle2d), XC_hand2));
 	XGrabButton(XtDisplay(puzzle3d), (unsigned int) AnyButton, AnyModifier,
 		XtWindow(puzzle3d), TRUE, (unsigned int) (ButtonPressMask |
 		ButtonMotionMask | ButtonReleaseMask),
 		GrabModeAsync, GrabModeAsync, XtWindow(puzzle3d),
-		XCreateFontCursor(XtDisplay(puzzle3d), XC_crosshair));
+		XCreateFontCursor(XtDisplay(puzzle3d), XC_hand2));
 #ifdef HAVE_OPENGL
 	XGrabButton(XtDisplay(puzzleGL), (unsigned int) AnyButton, AnyModifier,
 		XtWindow(puzzleGL), TRUE, (unsigned int) (ButtonPressMask |
