@@ -1,27 +1,22 @@
 /*
-# X-BASED THREED
-#
-#  Threed.c
-#
-###
-#
-#  Copyright (c) 1994 - 2008	David A. Bagley, bagleyd@tux.org
-#
-#		   All Rights Reserved
-#
-#  Permission to use, copy, modify, and distribute this software and
-#  its documentation for any purpose and without fee is hereby granted,
-#  provided that the above copyright notice appear in all copies and
-#  that both that copyright notice and this permission notice appear in
-#  supporting documentation, and that the name of the author not be
-#  used in advertising or publicity pertaining to distribution of the
-#  software without specific, written prior permission.
-#
-#  This program is distributed in the hope that it will be "useful",
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-#
-*/
+ * @(#)Threed.c
+ *
+ * Copyright 1994 - 2008  David A. Bagley, bagleyd@tux.org
+ *
+ * All rights reserved.
+ *
+ * Permission to use, copy, modify, and distribute this software and
+ * its documentation for any purpose and without fee is hereby granted,
+ * provided that the above copyright notice appear in all copies and
+ * that both that copyright notice and this permission notice appear in
+ * supporting documentation, and that the name of the author not be
+ * used in advertising or publicity pertaining to distribution of the
+ * software without specific, written prior permission.
+ *
+ * This program is distributed in the hope that it will be "useful",
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ */
 
 /* Methods file for Threed */
 
@@ -44,65 +39,65 @@
 #define DATAFILE "threed.dat"
 #endif
 
-static void InitializeThreeD(Widget request, Widget renew);
-static void ExposeThreeD(Widget renew, XEvent *event, Region region);
-static void ResizeThreeD(ThreeDWidget w);
-static void DestroyThreeD(Widget old);
-static Boolean SetValuesThreeD(Widget current, Widget request, Widget renew);
-static void QuitThreeD(ThreeDWidget w, XEvent *event, char **args,
+static void initializeThreeD(Widget request, Widget renew);
+static void exposeThreeD(Widget renew, XEvent *event, Region region);
+static void resizeThreeD(ThreeDWidget w);
+static void destroyThreeD(Widget old);
+static Boolean setValuesThreeD(Widget current, Widget request, Widget renew);
+static void quitThreeD(ThreeDWidget w, XEvent *event, char **args,
 	int n_args);
-static void HideThreeD(ThreeDWidget w, XEvent *event, char **args,
+static void hideThreeD(ThreeDWidget w, XEvent *event, char **args,
 	int n_args);
-static void SurfaceThreeD(ThreeDWidget w, XEvent *event, char **args,
+static void surfaceThreeD(ThreeDWidget w, XEvent *event, char **args,
 	int n_args);
-static void ObjectThreeD(ThreeDWidget w, XEvent *event, char **args,
+static void objectThreeD(ThreeDWidget w, XEvent *event, char **args,
 	int n_args);
-static void SpeedThreeD(ThreeDWidget w, XEvent *event, char **args, int nArgs);
-static void SlowThreeD(ThreeDWidget w, XEvent *event, char **args, int nArgs);
-static void SoundThreeD(ThreeDWidget w, XEvent *event, char **args, int nArgs);
-static void EnterThreeD(ThreeDWidget w, XEvent *event, char **args,
+static void speedThreeD(ThreeDWidget w, XEvent *event, char **args, int nArgs);
+static void slowThreeD(ThreeDWidget w, XEvent *event, char **args, int nArgs);
+static void soundThreeD(ThreeDWidget w, XEvent *event, char **args, int nArgs);
+static void enterThreeD(ThreeDWidget w, XEvent *event, char **args,
 	int nArgs);
-static void LeaveThreeD(ThreeDWidget w, XEvent *event, char **args,
+static void leaveThreeD(ThreeDWidget w, XEvent *event, char **args,
 	int nArgs);
-static void MoveRaisePsiThreeD(ThreeDWidget w, XEvent *event, char **args,
+static void moveRaisePsiThreeD(ThreeDWidget w, XEvent *event, char **args,
 	int n_args);
-static void MoveRaisePhiThreeD(ThreeDWidget w, XEvent *event, char **args,
+static void moveRaisePhiThreeD(ThreeDWidget w, XEvent *event, char **args,
 	int n_args);
-static void MoveLowerPhiThreeD(ThreeDWidget w, XEvent *event, char **args,
+static void moveLowerPhiThreeD(ThreeDWidget w, XEvent *event, char **args,
 	int n_args);
-static void MoveLowerThetaThreeD(ThreeDWidget w, XEvent *event, char **args,
+static void moveLowerThetaThreeD(ThreeDWidget w, XEvent *event, char **args,
 	int n_args);
-static void MoveLowerPsiThreeD(ThreeDWidget w, XEvent *event, char **args,
+static void moveLowerPsiThreeD(ThreeDWidget w, XEvent *event, char **args,
 	int n_args);
-static void MoveRaiseThetaThreeD(ThreeDWidget w, XEvent *event, char **args,
+static void moveRaiseThetaThreeD(ThreeDWidget w, XEvent *event, char **args,
 	int n_args);
-static void MoveRaisePhiThreeD(ThreeDWidget w, XEvent *event, char **args,
+static void moveRaisePhiThreeD(ThreeDWidget w, XEvent *event, char **args,
 	int n_args);
-static void MoveLowerThetaLowerPhiThreeD(ThreeDWidget w, XEvent *event,
+static void moveLowerThetaLowerPhiThreeD(ThreeDWidget w, XEvent *event,
 	char **args, int n_args);
-static void MoveLowerThetaRaisePhiThreeD(ThreeDWidget w, XEvent *event,
+static void moveLowerThetaRaisePhiThreeD(ThreeDWidget w, XEvent *event,
 	char **args, int n_args);
-static void MoveRaiseThetaLowerPhiThreeD(ThreeDWidget w, XEvent *event,
+static void oveRaiseThetaLowerPhiThreeD(ThreeDWidget w, XEvent *event,
 	char **args, int n_args);
-static void MoveRaiseThetaRaisePhiThreeD(ThreeDWidget w, XEvent *event,
+static void moveRaiseThetaRaisePhiThreeD(ThreeDWidget w, XEvent *event,
 	char **args, int n_args);
-static void MoveLeftThreeD(ThreeDWidget w, XEvent *event, char **args,
+static void moveLeftThreeD(ThreeDWidget w, XEvent *event, char **args,
 	int n_args);
-static void MoveRightThreeD(ThreeDWidget w, XEvent *event, char **args,
+static void moveRightThreeD(ThreeDWidget w, XEvent *event, char **args,
 	int n_args);
-static void MoveUpThreeD(ThreeDWidget w, XEvent *event, char **args,
+static void moveUpThreeD(ThreeDWidget w, XEvent *event, char **args,
 	int n_args);
-static void MoveDownThreeD(ThreeDWidget w, XEvent *event, char **args,
+static void moveDownThreeD(ThreeDWidget w, XEvent *event, char **args,
 	int n_args);
-static void MoveOutThreeD(ThreeDWidget w, XEvent *event, char **args,
+static void moveOutThreeD(ThreeDWidget w, XEvent *event, char **args,
 	int n_args);
-static void MoveInThreeD(ThreeDWidget w, XEvent *event, char **args,
+static void moveInThreeD(ThreeDWidget w, XEvent *event, char **args,
 	int n_args);
-static void SelectThreeD(ThreeDWidget w, XEvent *event, char **args,
+static void selectThreeD(ThreeDWidget w, XEvent *event, char **args,
 	int nArgs);
-static void MotionThreeD(ThreeDWidget w, XEvent *event, char **args,
+static void motionThreeD(ThreeDWidget w, XEvent *event, char **args,
 	int nArgs);
-static void ReleaseThreeD(ThreeDWidget w, XEvent *event, char **args,
+static void releaseThreeD(ThreeDWidget w, XEvent *event, char **args,
 	int nArgs);
 
 static char defaultTranslationsThreeD[] =
@@ -159,8 +154,8 @@ static char defaultTranslationsThreeD[] =
  <KeyPress>R15: MoveLowerThetaLowerPhi()\n\
  <KeyPress>l: MoveLeft()\n\
  <KeyPress>r: MoveRight()\n\
- <KeyPress>u: MoveUp()\n\
- <KeyPress>d: MoveDown()\n\
+ <KeyPress>u: moveUp()\n\
+ <KeyPress>d: moveDown()\n\
  <KeyPress>o: MoveOut()\n\
  <KeyPress>i: MoveIn()\n\
  <Btn1Down>: Select()\n\
@@ -172,38 +167,38 @@ static char defaultTranslationsThreeD[] =
  <LeaveWindow>: Leave()";
 
 static XtActionsRec actionsListThreeD[] = {
-	{(char *) "Quit", (XtActionProc) QuitThreeD},
-	{(char *) "Hide", (XtActionProc) HideThreeD},
-	{(char *) "MoveRaisePsi", (XtActionProc) MoveRaisePsiThreeD},
-	{(char *) "MoveLowerPhi", (XtActionProc) MoveLowerPhiThreeD},
-	{(char *) "MoveLowerTheta", (XtActionProc) MoveLowerThetaThreeD},
-	{(char *) "MoveLowerPsi", (XtActionProc) MoveLowerPsiThreeD},
-	{(char *) "MoveRaiseTheta", (XtActionProc) MoveRaiseThetaThreeD},
-	{(char *) "MoveRaisePhi", (XtActionProc) MoveRaisePhiThreeD},
+	{(char *) "Quit", (XtActionProc) quitThreeD},
+	{(char *) "Hide", (XtActionProc) hideThreeD},
+	{(char *) "MoveRaisePsi", (XtActionProc) moveRaisePsiThreeD},
+	{(char *) "MoveLowerPhi", (XtActionProc) moveLowerPhiThreeD},
+	{(char *) "MoveLowerTheta", (XtActionProc) moveLowerThetaThreeD},
+	{(char *) "MoveLowerPsi", (XtActionProc) moveLowerPsiThreeD},
+	{(char *) "MoveRaiseTheta", (XtActionProc) moveRaiseThetaThreeD},
+	{(char *) "MoveRaisePhi", (XtActionProc) moveRaisePhiThreeD},
 	{(char *) "MoveLowerThetaLowerPhi",
-		(XtActionProc) MoveLowerThetaLowerPhiThreeD},
+		(XtActionProc) moveLowerThetaLowerPhiThreeD},
 	{(char *) "MoveLowerThetaRaisePhi",
-		(XtActionProc) MoveLowerThetaRaisePhiThreeD},
+		(XtActionProc) moveLowerThetaRaisePhiThreeD},
 	{(char *) "MoveRaiseThetaLowerPhi",
-		(XtActionProc) MoveRaiseThetaLowerPhiThreeD},
+		(XtActionProc) oveRaiseThetaLowerPhiThreeD},
 	{(char *) "MoveRaiseThetaRaisePhi",
-		(XtActionProc) MoveRaiseThetaRaisePhiThreeD},
-	{(char *) "MoveLeft", (XtActionProc) MoveLeftThreeD},
-	{(char *) "MoveRight", (XtActionProc) MoveRightThreeD},
-	{(char *) "MoveUp", (XtActionProc) MoveUpThreeD},
-	{(char *) "MoveDown", (XtActionProc) MoveDownThreeD},
-	{(char *) "MoveOut", (XtActionProc) MoveOutThreeD},
-	{(char *) "MoveIn", (XtActionProc) MoveInThreeD},
-	{(char *) "Select", (XtActionProc) SelectThreeD},
-	{(char *) "Motion", (XtActionProc) MotionThreeD},
-	{(char *) "Release", (XtActionProc) ReleaseThreeD},
-	{(char *) "Surface", (XtActionProc) SurfaceThreeD},
-	{(char *) "Object", (XtActionProc) ObjectThreeD},
-	{(char *) "Speed", (XtActionProc) SpeedThreeD},
-	{(char *) "Slow", (XtActionProc) SlowThreeD},
-	{(char *) "Sound", (XtActionProc) SoundThreeD},
-	{(char *) "Enter", (XtActionProc) EnterThreeD},
-	{(char *) "Leave", (XtActionProc) LeaveThreeD}
+		(XtActionProc) moveRaiseThetaRaisePhiThreeD},
+	{(char *) "MoveLeft", (XtActionProc) moveLeftThreeD},
+	{(char *) "MoveRight", (XtActionProc) moveRightThreeD},
+	{(char *) "moveUp", (XtActionProc) moveUpThreeD},
+	{(char *) "moveDown", (XtActionProc) moveDownThreeD},
+	{(char *) "MoveOut", (XtActionProc) moveOutThreeD},
+	{(char *) "MoveIn", (XtActionProc) moveInThreeD},
+	{(char *) "Select", (XtActionProc) selectThreeD},
+	{(char *) "Motion", (XtActionProc) motionThreeD},
+	{(char *) "Release", (XtActionProc) releaseThreeD},
+	{(char *) "Surface", (XtActionProc) surfaceThreeD},
+	{(char *) "Object", (XtActionProc) objectThreeD},
+	{(char *) "Speed", (XtActionProc) speedThreeD},
+	{(char *) "Slow", (XtActionProc) slowThreeD},
+	{(char *) "Sound", (XtActionProc) soundThreeD},
+	{(char *) "Enter", (XtActionProc) enterThreeD},
+	{(char *) "Leave", (XtActionProc) leaveThreeD}
 };
 
 static XtResource resourcesThreeD[] = {
@@ -224,7 +219,7 @@ static XtResource resourcesThreeD[] = {
 	 XtRString, (caddr_t) XtDefaultForeground},
 	{XtNbackground, XtCBackground, XtRPixel, sizeof (Pixel),
 	 XtOffset(ThreeDWidget, threed.background),
-	 XtRString, (caddr_t) XtDefaultBackground},
+	 XtRString, (caddr_t) "#AEB2C3" /*XtDefaultBackground*/},
 	{XtNframeColor, XtCColor, XtRPixel, sizeof (Pixel),
 	 XtOffset(ThreeDWidget, threed.frameColor),
 	 XtRString, (caddr_t) "cyan" /* XtDefaultForeground*/},
@@ -316,7 +311,7 @@ ThreeDClassRec threedClassRec =
 		 NULL,		/* class initialize */
 		 NULL,		/* class part initialize */
 		 FALSE,		/* class inited */
-		 (XtInitProc) InitializeThreeD,	/* initialize */
+		 (XtInitProc) initializeThreeD,	/* initialize */
 		 NULL,		/* initialize hook */
 		 XtInheritRealize,	/* realize */
 		 actionsListThreeD,	/* actions */
@@ -328,10 +323,10 @@ ThreeDClassRec threedClassRec =
 		 TRUE,		/* compress exposure */
 		 TRUE,		/* compress enterleave */
 		 TRUE,		/* visible interest */
-		 (XtWidgetProc) DestroyThreeD,	/* destroy */
-		 (XtWidgetProc) ResizeThreeD,	/* resize */
-		 (XtExposeProc) ExposeThreeD,	/* expose */
-		 (XtSetValuesFunc) SetValuesThreeD,	/* set values */
+		 (XtWidgetProc) destroyThreeD,	/* destroy */
+		 (XtWidgetProc) resizeThreeD,	/* resize */
+		 (XtExposeProc) exposeThreeD,	/* expose */
+		 (XtSetValuesFunc) setValuesThreeD,	/* set values */
 		 NULL,		/* set values hook */
 		 XtInheritSetValuesAlmost,	/* set values almost */
 		 NULL,		/* get values hook */
@@ -370,7 +365,7 @@ static Object3D *OBJ;
 #endif
 
 static void
-CheckGraphicsThreeD(ThreeDWidget w)
+checkGraphicsThreeD(ThreeDWidget w)
 {
 	char *buf1 = NULL, *buf2 = NULL;
 
@@ -464,7 +459,7 @@ static int
 #ifdef WINVER
 __cdecl
 #endif
-CompareObject(const void *elem1, const void *elem2)
+compareObject(const void *elem1, const void *elem2)
 #ifdef DEPTHINDEX
 {
 	double z1, z2;
@@ -499,7 +494,7 @@ CompareObject(const void *elem1, const void *elem2)
 #define viewDistance ((w->core.width + w->core.height) / 2)
 
 static void
-RealizeObject(ThreeDWidget w, Object3D *obj)
+realizeObject(ThreeDWidget w, Object3D *obj)
 {
 	int vert, surf;
 	double z;
@@ -551,14 +546,16 @@ RealizeObject(ThreeDWidget w, Object3D *obj)
 }
 
 static void
-DrawObject(ThreeDWidget w, Object3D *obj)
+drawObject(ThreeDWidget w, Object3D *obj)
 {
 	int surf, vert, vertex, mapIndex, clickSurface = -1;
 	Point points[MAX_POLYGON_VERTICES + 1];
+	Point thePoints[MAX_POLYGON_VERTICES + 1];
 	Pixmap *dr;
 	double s1 = 0.0, s2 = 0.0, s3 = 0.0;
 	Point3D *v1, *v2, *v3;
-	GC lineGC, fillGC;
+	GC lineGC, fillGC, theFillGC = NULL;
+	int theVert = -1;
 
 	dr = &(w->threed.bufferObjects[0]);
 	/* compute position of object in world */
@@ -568,7 +565,7 @@ DrawObject(ThreeDWidget w, Object3D *obj)
 #endif
 		(void) qsort((void *) obj->surface,
 			(unsigned int) obj->numSurfaces,
-			sizeof(Surface), CompareObject);
+			sizeof(Surface), compareObject);
 	}
 	for (surf = 0; surf < obj->numSurfaces; surf++) {
 		mapIndex = obj->surface[surf].mapIndex;
@@ -615,7 +612,7 @@ DrawObject(ThreeDWidget w, Object3D *obj)
 				vert++, mapIndex++) {
 			vertex = obj->map[mapIndex];
 			if (vert < MAX_POLYGON_VERTICES) {
-				/* Its not dynamic but we really after
+				/* Its not dynamic but we are really after
 				   speed here */
 				points[vert].x = obj->vertex[vertex].screen.x;
 				points[vert].y = obj->vertex[vertex].screen.y;
@@ -626,14 +623,23 @@ DrawObject(ThreeDWidget w, Object3D *obj)
 		points[vert].x = points[0].x;
 		points[vert].y = points[0].y;
 		if (surf == clickSurface) {
+			theFillGC = w->threed.shadeGC[obj->surface[surf].color];
 			fillGC = w->threed.frameGC;
+			lineGC = w->threed.frameGC;
+			for (theVert = 0; theVert <= obj->surface[surf].numVertices;
+					theVert++) {
+				thePoints[theVert].x = points[theVert].x;
+				thePoints[theVert].y = points[theVert].y;
+			}
 		} else {
 			fillGC = w->threed.shadeGC[obj->surface[surf].color];
+			lineGC = w->threed.shadeGC[obj->surface[surf].color];
 		}
-		lineGC = w->threed.shadeGC[obj->surface[surf].color];
 		if (!w->threed.surface || obj->surface[surf].visible == 0) {
-			POLYLINE(w, *dr, fillGC,
-				&points[0], vert + 1, True);
+			if (surf != clickSurface) {
+				POLYLINE(w, *dr, fillGC,
+					&points[0], vert + 1, True);
+			}
 		} else {
 			POLYGON(w, *dr, fillGC, lineGC,
 				&points[0], vert, obj->convex, True);
@@ -660,6 +666,11 @@ DrawObject(ThreeDWidget w, Object3D *obj)
 #endif
 		}
 	}
+	if (theVert > 0) {
+		POLYLINE(w, *dr, (w->threed.surface && theFillGC != NULL) ?
+			theFillGC : w->threed.frameGC,
+			&thePoints[0], theVert, True);
+	}
 #ifdef USE_SOUND
 	if (w->threed.sound) {
 		static int oldSurface = -1;
@@ -676,7 +687,7 @@ DrawObject(ThreeDWidget w, Object3D *obj)
 }
 
 static void
-CopyFromBuffer(ThreeDWidget w)
+copyFromBuffer(ThreeDWidget w)
 {
 #ifdef WINVER
 	w->core.hOldBitmap = (HBITMAP) SelectObject(w->core.memDC,
@@ -698,10 +709,27 @@ CopyFromBuffer(ThreeDWidget w)
 #endif
 }
 
-#ifndef WINVER
-#define BRIGHT_FACTOR 0.7
-#define DARK_FACTOR 0.7
+#define BRIGHT_FACTOR 0.8
+#define DARK_FACTOR 0.75
+#ifdef WINVER
+#define MAX_INTENSITY 0xFF
+static int
+brighter(const int light)
+{
+	int i = (int) ((1 - BRIGHT_FACTOR) * MAX_INTENSITY);
+	int temp = light;
 
+	if (temp < i)
+		temp = i;
+	return MIN(temp / BRIGHT_FACTOR, MAX_INTENSITY);
+}
+
+static int
+darker(const int light) {
+	return (int) (light * DARK_FACTOR);
+}
+
+#else
 #define MAX_INTENSITY 0xFFFF
 
 static Pixel
@@ -744,7 +772,7 @@ darker(ThreeDWidget w, Pixel pixel)
 }
 
 static void
-Draw3DFrame(const ThreeDWidget w, Pixmap dr, Boolean inside,
+draw3DFrame(const ThreeDWidget w, Pixmap dr, Boolean inside,
 	int x, int y, int width, int height)
 {
 	GC gc;
@@ -778,7 +806,7 @@ Draw3DFrame(const ThreeDWidget w, Pixmap dr, Boolean inside,
 
 #if 0
 static void
-EraseFrame(ThreeDWidget w, Pixmap dr, Boolean focus)
+eraseFrame(ThreeDWidget w, Pixmap dr, Boolean focus)
 {
 	FILLRECTANGLE(w, dr, w->threed.inverseGC[1],
 		0, 0, w->core.width, w->core.height);
@@ -786,13 +814,13 @@ EraseFrame(ThreeDWidget w, Pixmap dr, Boolean focus)
 #endif
 
 static void
-DrawFrame(ThreeDWidget w, Pixmap dr, Boolean focus)
+drawFrame(ThreeDWidget w, Pixmap dr, Boolean focus)
 {
 #ifdef WINVER
 	DRAWRECTANGLE(w, dr, (focus) ? w->threed.frameGC : w->threed.borderGC,
-			0, 0, w->core.width - 1, w->core.height - 1);
+		0, 0, w->core.width - 1, w->core.height - 1);
 #else
-	Draw3DFrame(w, dr, focus,
+	draw3DFrame(w, dr, focus,
 		1, 1, w->core.width - 2, w->core.height - 2);
 	if (focus) {
 		DRAWRECTANGLE(w, dr, w->threed.frameGC,
@@ -805,7 +833,7 @@ DrawFrame(ThreeDWidget w, Pixmap dr, Boolean focus)
 }
 
 static void
-SpeedObjects(ThreeDWidget w)
+speedObjects(ThreeDWidget w)
 {
 	w->threed.delay -= 5;
 	if (w->threed.delay < 0)
@@ -816,7 +844,7 @@ SpeedObjects(ThreeDWidget w)
 }
 
 static void
-SlowObjects(ThreeDWidget w)
+slowObjects(ThreeDWidget w)
 {
 	w->threed.delay += 5;
 #ifdef HAVE_MOTIF
@@ -825,7 +853,7 @@ SlowObjects(ThreeDWidget w)
 }
 
 static void
-SoundObjects(ThreeDWidget w)
+soundObjects(ThreeDWidget w)
 {
 	w->threed.sound = !w->threed.sound;
 }
@@ -1094,7 +1122,7 @@ readCommon(ThreeDWidget w, FILE *fp, char *buffer)
 
 #ifdef WINVER
 static FILE *
-OpenIni(const HWND hWnd, const char *filename)
+openIni(const HWND hWnd, const char *filename)
 {
 	unsigned short wReturn;
 	char buf[256], szBuf[144];
@@ -1122,7 +1150,7 @@ OpenIni(const HWND hWnd, const char *filename)
 		if ((fp = fopen(buf, "r")) == NULL) {
 			(void) sprintf(buf,
 				"%s: does not exist in \".\" or windows directory", filename);
-			(void) MessageBox(hWnd, buf, "OpenIni", MB_ICONEXCLAMATION);
+			(void) MessageBox(hWnd, buf, "openIni", MB_ICONEXCLAMATION);
 #ifdef DEBUG
 			(void) fclose(fp);
 #endif
@@ -1130,7 +1158,7 @@ OpenIni(const HWND hWnd, const char *filename)
 		}
 	}
 #ifdef DEBUG
-	(void) fprintf(stderr, "Exiting OpenIni\n");
+	(void) fprintf(stderr, "Exiting openIni\n");
 #endif
 
 	return fp;
@@ -1141,7 +1169,7 @@ OpenIni(const HWND hWnd, const char *filename)
    i.e. information left of "=" is not read.
  */
 static void
-ReadThreeD(ThreeDWidget w)
+readThreeD(ThreeDWidget w)
 {
 	FILE *fp;
 	char buffer[MAX_LINE];
@@ -1151,14 +1179,30 @@ ReadThreeD(ThreeDWidget w)
 		int red, green, blue;
 	} color;
 
-	fp = OpenIni(w->core.hWnd, DATAFILE);
-	for (i = 0; i <= COLORS; i++) {
+	fp = openIni(w->core.hWnd, DATAFILE);
+	string = readLine(fp, buffer, SYMBOL);
+	(void) sscanf(string, "%d %d %d",
+		&(color.red), &(color.green), &(color.blue));
+	w->threed.frameGC = RGB(color.red, color.green, color.blue);
+	string = readLine(fp, buffer, SYMBOL);
+	(void) sscanf(string, "%d %d %d",
+		&(color.red), &(color.green), &(color.blue));
+	w->threed.inverseGC[1] = RGB(color.red, color.green, color.blue);
+	w->threed.inverseGC[0] = RGB(brighter(color.red),
+		brighter(color.green), brighter(color.blue));
+	w->threed.inverseGC[2] = RGB(darker(color.red),
+		darker(color.green), darker(color.blue));
+	for (i = 0; i < COLORS; i++) {
 		string = readLine(fp, buffer, SYMBOL);
 		(void) sscanf(string, "%d %d %d",
 			&(color.red), &(color.green), &(color.blue));
 		w->threed.shadeGC[i] = RGB(color.red, color.green, color.blue);
 	}
 	string = readLine(fp, buffer, SYMBOL);
+	(void) sscanf(string, "%d %d %d",
+		&(color.red), &(color.green), &(color.blue));
+	w->threed.borderGC = RGB(color.red, color.green, color.blue);
+	string = readLine(fp, buffer, SYMBOL);
 	(void) sscanf(string, "%d", &(w->threed.delay));
 	string = readLine(fp, buffer, SYMBOL);
 	(void) sscanf(string, "%d", &i);
@@ -1173,21 +1217,34 @@ ReadThreeD(ThreeDWidget w)
 	string = readLine(fp, buffer, SYMBOL);
 	(void) sscanf(string, "%d", &(w->threed.object));
 #ifdef DEBUG
-	for (i = 0; i <= COLORS; i++)
+	(void) fprintf(stderr, "foreground%c%d %d %d\n", SYMBOL,
+		GetRValue(w->threed.frameGC),
+		GetGValue(w->threed.frameGC),
+		GetBValue(w->threed.frameGC));
+	for (i = 0; i < BG_SHADES; i++)
+		(void) fprintf(stderr, "inverse%d%c%d %d %d\n", i, SYMBOL,
+			GetRValue(w->threed.inverseGC[i]),
+			GetGValue(w->threed.inverseGC[i]),
+			GetBValue(w->threed.inverseGC[i]));
+	for (i = 0; i < COLORS; i++)
 		(void) fprintf(stderr, "brush%d%c%d %d %d\n", i, SYMBOL,
 			GetRValue(w->threed.shadeGC[i]),
 			GetGValue(w->threed.shadeGC[i]),
 			GetBValue(w->threed.shadeGC[i]));
-	(void) fprintf(stderr, "Surface%c%d\n", SYMBOL,
+	(void) fprintf(stderr, "border%c%d %d %d\n", SYMBOL,
+		GetRValue(w->threed.borderGC),
+		GetGValue(w->threed.borderGC),
+		GetBValue(w->threed.borderGC));
+	(void) fprintf(stderr, "surface%c%d\n", SYMBOL,
 		(w->threed.surface) ? 1 : 0 );
-	(void) fprintf(stderr, "Object%c%d\n", SYMBOL, w->threed.object);
+	(void) fprintf(stderr, "object%c%d\n", SYMBOL, w->threed.object);
 #endif
 	readCommon(w, fp, buffer);
 	(void) fclose(fp);
 }
 
 void
-DestroyThreeD(HBRUSH brush)
+destroyThreeD(HBRUSH brush)
 {
 	(void) DeleteObject(brush);
 	PostQuitMessage(0);
@@ -1196,7 +1253,7 @@ DestroyThreeD(HBRUSH brush)
 #else
 
 static void
-ReadThreeD(ThreeDWidget w)
+readThreeD(ThreeDWidget w)
 {
 	FILE *fp;
 	char buffer[MAX_LINE];
@@ -1231,14 +1288,14 @@ ReadThreeD(ThreeDWidget w)
 }
 
 static Boolean
-SetValuesThreeD(Widget current, Widget request, Widget renew)
+setValuesThreeD(Widget current, Widget request, Widget renew)
 {
 	ThreeDWidget c = (ThreeDWidget) current, w = (ThreeDWidget) renew;
 	Boolean redraw = FALSE;
 
 	if (w->threed.numObjects == 0)
 		return False;
-	CheckGraphicsThreeD(w);
+	checkGraphicsThreeD(w);
 	if (w->threed.foreground != c->threed.foreground) {
 		XGCValues values;
 		XtGCMask valueMask;
@@ -1268,7 +1325,7 @@ SetValuesThreeD(Widget current, Widget request, Widget renew)
 			c->threed.angle.phi;
 		w->threed.deltaAngle.psi = w->threed.angle.psi -
 			c->threed.angle.psi;
-		ResizeThreeD(w);
+		resizeThreeD(w);
 		redraw = TRUE;
 	}
 	if (w->threed.menu != ACTION_IGNORE) {
@@ -1277,13 +1334,13 @@ SetValuesThreeD(Widget current, Widget request, Widget renew)
 		w->threed.menu = ACTION_IGNORE;
 		switch (menu) {
 		case ACTION_SPEED:
-			SpeedObjects(w);
+			speedObjects(w);
 			break;
 		case ACTION_SLOW:
-			SlowObjects(w);
+			slowObjects(w);
 			break;
 		case ACTION_SOUND:
-			SoundObjects(w);
+			soundObjects(w);
 			break;
 		default:
 			break;
@@ -1293,7 +1350,7 @@ SetValuesThreeD(Widget current, Widget request, Widget renew)
 }
 
 static void
-SetAllColors(ThreeDWidget w)
+setAllColors(ThreeDWidget w)
 {
 	XGCValues values;
 	XtGCMask valueMask;
@@ -1376,14 +1433,14 @@ SetAllColors(ThreeDWidget w)
 }
 
 static void
-QuitThreeD(ThreeDWidget w, XEvent *event, char **args, int n_args)
+quitThreeD(ThreeDWidget w, XEvent *event, char **args, int n_args)
 {
 	XtCloseDisplay(XtDisplay(w));
 	exit(0);
 }
 
 static void
-DestroyThreeD(Widget old)
+destroyThreeD(Widget old)
 {
 	ThreeDWidget w = (ThreeDWidget) old;
 	int i;
@@ -1400,7 +1457,7 @@ DestroyThreeD(Widget old)
 #endif
 
 static void
-RepaintGraphicsThreeD(ThreeDWidget w)
+repaintGraphicsThreeD(ThreeDWidget w)
 {
 	int sel;
 
@@ -1448,26 +1505,23 @@ RepaintGraphicsThreeD(ThreeDWidget w)
 #endif
 	}
 #ifndef WINVER
-	SetAllColors(w);
+	setAllColors(w);
 #endif
-	/*EraseFrame(w, 0, w->threed.focus);*/
-	/*DrawAllBufferedGraphics(w);
-	DrawAllGraphics(w);
+	/*eraseFrame(w, 0, w->threed.focus);*/
+	/*drawAllBufferedGraphics(w);
+	drawAllGraphics(w);
 #ifndef WINVER
 	XClearWindow(XtDisplay(w), XtWindow(w));
 #endif */
-#ifndef WINVER
-	/* Clear buffer */
-	XFillRectangle(XtDisplay(w), w->threed.bufferObjects[0],
-		w->threed.inverseGC[1], 0, 0, w->core.width, w->core.height);
-#endif
-	RealizeObject(w, &(w->threed.objects[w->threed.object]));
-	DrawObject(w, &(w->threed.objects[w->threed.object]));
-	CopyFromBuffer(w);
+	FILLRECTANGLE(w, w->threed.bufferObjects[0], w->threed.inverseGC[1],
+		0, 0, w->core.width, w->core.height);
+	realizeObject(w, &(w->threed.objects[w->threed.object]));
+	drawObject(w, &(w->threed.objects[w->threed.object]));
+	copyFromBuffer(w);
 }
 
 static void
-ResizeThreeD(ThreeDWidget w)
+resizeThreeD(ThreeDWidget w)
 {
 #ifdef WINVER
 	RECT rect;
@@ -1488,7 +1542,7 @@ ResizeThreeD(ThreeDWidget w)
 static
 #endif
 void
-InitializeThreeD(
+initializeThreeD(
 #ifdef WINVER
 ThreeDWidget w, HBRUSH brush
 #else
@@ -1499,6 +1553,7 @@ Widget request, Widget renew
 	int i;
 
 #ifdef WINVER
+
 	w->threed.mono = DEFAULT_MONO;
 	w->threed.reverse = DEFAULT_REVERSE;
 	w->threed.bufferObjects[0] = NULL;
@@ -1522,8 +1577,8 @@ Widget request, Widget renew
 		w->threed.inverseGC[i] = NULL;
 #endif
 	createTrigTables();
-	ReadThreeD(w);
-	CheckGraphicsThreeD(w);
+	readThreeD(w);
+	checkGraphicsThreeD(w);
 	if (w->threed.numObjects > 0) {
 		w->threed.name = w->threed.objects[w->threed.object].name;
 		if (!(w->threed.list = (char **) calloc((unsigned int)
@@ -1536,7 +1591,7 @@ Widget request, Widget renew
 	w->threed.deltaAngle.theta = w->threed.angle.theta;
 	w->threed.deltaAngle.phi = w->threed.angle.phi;
 	w->threed.deltaAngle.psi = w->threed.angle.psi;
-	ResizeThreeD(w);
+	resizeThreeD(w);
 #ifdef DEBUG
 	(void) printf("%s\n", w->threed.name);
 #endif
@@ -1544,7 +1599,7 @@ Widget request, Widget renew
 	brush = CreateSolidBrush(w->threed.inverseGC[1]);
 	SETBACK(w->core.hWnd, brush);
 #else
-	SetAllColors(w);
+	setAllColors(w);
 #endif
 }
 
@@ -1552,7 +1607,7 @@ Widget request, Widget renew
 static
 #endif
 void
-ExposeThreeD(
+exposeThreeD(
 #ifdef WINVER
 ThreeDWidget w
 #else
@@ -1566,15 +1621,15 @@ Widget renew, XEvent *event, Region region
 	if (!w->core.visible)
 		return;
 #endif
-	DrawFrame(w, 0, w->threed.focus);
-	RepaintGraphicsThreeD(w);
+	drawFrame(w, 0, w->threed.focus);
+	repaintGraphicsThreeD(w);
 }
 
 #ifndef WINVER
 static
 #endif
 void
-HideThreeD(ThreeDWidget w
+hideThreeD(ThreeDWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
@@ -1587,7 +1642,7 @@ HideThreeD(ThreeDWidget w
 static
 #endif
 void
-SelectThreeD(ThreeDWidget w
+selectThreeD(ThreeDWidget w
 #ifdef WINVER
 , const int x, const int y/*, const int control*/
 #else
@@ -1601,14 +1656,14 @@ SelectThreeD(ThreeDWidget w
 #endif
 	w->threed.currentPosition.x = x;
 	w->threed.currentPosition.y = y;
-	RepaintGraphicsThreeD(w);
+	repaintGraphicsThreeD(w);
 }
 
 #ifndef WINVER
 static
 #endif
 void
-MotionThreeD(ThreeDWidget w
+motionThreeD(ThreeDWidget w
 #ifdef WINVER
 , const int x, const int y/*, const int shift, const int control*/
 #else
@@ -1638,7 +1693,7 @@ MotionThreeD(ThreeDWidget w
 	w->threed.deltaAngle.theta = w->threed.angle.theta - oldAngleTheta;
 	w->threed.deltaAngle.phi = w->threed.angle.phi - oldAnglePhi;
 	setThreed(w, ACTION_SET);
-	RepaintGraphicsThreeD(w);
+	repaintGraphicsThreeD(w);
 	w->threed.currentPosition.x = x;
 	w->threed.currentPosition.y = y;
 }
@@ -1647,7 +1702,7 @@ MotionThreeD(ThreeDWidget w
 static
 #endif
 void
-ReleaseThreeD(ThreeDWidget w
+releaseThreeD(ThreeDWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
@@ -1655,96 +1710,98 @@ ReleaseThreeD(ThreeDWidget w
 {
 	w->threed.currentPosition.x = 2 * w->core.width;
 	w->threed.currentPosition.y = 2 * w->core.height;
-	RepaintGraphicsThreeD(w);
+	repaintGraphicsThreeD(w);
 }
 
 void
-SpeedThreeD(ThreeDWidget w
+speedThreeD(ThreeDWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 )
 {
-	SpeedObjects(w);
+	speedObjects(w);
 }
 
 void
-SlowThreeD(ThreeDWidget w
+slowThreeD(ThreeDWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 )
 {
-	SlowObjects(w);
+	slowObjects(w);
 }
 
 void
-SoundThreeD(ThreeDWidget w
+soundThreeD(ThreeDWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 )
 {
-	SoundObjects(w);
+	soundObjects(w);
 }
 
-#ifdef WINVER
-void
-setSurfaceThreeD(ThreeDWidget w , Boolean surface)
-{
-	w->threed.surface = surface;
-}
-
-void
-setObjectThreeD(ThreeDWidget w, int object3D)
-{
-	w->threed.object = object3D;
-}
-
-#else
-
+#ifndef WINVER
 static
+#endif
 void
-SurfaceThreeD(ThreeDWidget w
+surfaceThreeD(ThreeDWidget w
+#ifndef WINVER
 , XEvent *event, char **args, int n_args
+#endif
 )
 {
 	setThreed(w, ACTION_SURFACE);
 }
 
+#ifndef WINVER
 static
+#endif
 void
-ObjectThreeD(ThreeDWidget w
+objectThreeD(ThreeDWidget w
+#ifndef WINVER
 , XEvent *event, char **args, int n_args
+#endif
 )
 {
 	setThreed(w, ACTION_OBJECT);
 }
 
+#ifdef WINVER
 void
-EnterThreeD(ThreeDWidget w
+setobjectThreeD(ThreeDWidget w, int object3D)
+{
+	w->threed.object = object3D;
+}
+#endif
+
+#ifndef WINVER
+void
+enterThreeD(ThreeDWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 )
 {
 	w->threed.focus = True;
-	DrawFrame(w, 0, w->threed.focus);
+	drawFrame(w, 0, w->threed.focus);
 }
 
 void
-LeaveThreeD(ThreeDWidget w
+leaveThreeD(ThreeDWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 )
 {
 	w->threed.focus = False;
-	DrawFrame(w, 0, w->threed.focus);
+	drawFrame(w, 0, w->threed.focus);
 }
 
 static void
-MoveLowerPhiThreeD(ThreeDWidget w, XEvent *event, char **args, int n_args)
+moveLowerPhiThreeD(ThreeDWidget w, XEvent *event, char **args, int n_args)
 {
 	int oldAngle = w->threed.angle.phi;
 
@@ -1753,11 +1810,11 @@ MoveLowerPhiThreeD(ThreeDWidget w, XEvent *event, char **args, int n_args)
 		w->threed.angle.phi += NUM_DEGREES;
 	w->threed.deltaAngle.phi = w->threed.angle.phi - oldAngle;
 	setThreed(w, ACTION_SET);
-	RepaintGraphicsThreeD(w);
+	repaintGraphicsThreeD(w);
 }
 
 static void
-MoveLowerThetaThreeD(ThreeDWidget w, XEvent *event, char **args, int n_args)
+moveLowerThetaThreeD(ThreeDWidget w, XEvent *event, char **args, int n_args)
 {
 	int oldAngle = w->threed.angle.theta;
 
@@ -1766,11 +1823,11 @@ MoveLowerThetaThreeD(ThreeDWidget w, XEvent *event, char **args, int n_args)
 		w->threed.angle.theta += NUM_DEGREES;
 	w->threed.deltaAngle.theta = w->threed.angle.theta - oldAngle;
 	setThreed(w, ACTION_SET);
-	RepaintGraphicsThreeD(w);
+	repaintGraphicsThreeD(w);
 }
 
 static void
-MoveRaiseThetaThreeD(ThreeDWidget w, XEvent *event, char **args, int n_args)
+moveRaiseThetaThreeD(ThreeDWidget w, XEvent *event, char **args, int n_args)
 {
 	int oldAngle = w->threed.angle.theta;
 
@@ -1779,11 +1836,11 @@ MoveRaiseThetaThreeD(ThreeDWidget w, XEvent *event, char **args, int n_args)
 		w->threed.angle.theta -= NUM_DEGREES;
 	w->threed.deltaAngle.theta = w->threed.angle.theta - oldAngle;
 	setThreed(w, ACTION_SET);
-	RepaintGraphicsThreeD(w);
+	repaintGraphicsThreeD(w);
 }
 
 static void
-MoveRaisePhiThreeD(ThreeDWidget w, XEvent *event, char **args, int n_args)
+moveRaisePhiThreeD(ThreeDWidget w, XEvent *event, char **args, int n_args)
 {
 	int oldAngle = w->threed.angle.phi;
 
@@ -1792,11 +1849,11 @@ MoveRaisePhiThreeD(ThreeDWidget w, XEvent *event, char **args, int n_args)
 		w->threed.angle.phi -= NUM_DEGREES;
 	w->threed.deltaAngle.phi = w->threed.angle.phi - oldAngle;
 	setThreed(w, ACTION_SET);
-	RepaintGraphicsThreeD(w);
+	repaintGraphicsThreeD(w);
 }
 
 static void
-MoveLowerPsiThreeD(ThreeDWidget w, XEvent *event, char **args, int n_args)
+moveLowerPsiThreeD(ThreeDWidget w, XEvent *event, char **args, int n_args)
 {
 	int oldAngle = w->threed.angle.psi;
 
@@ -1805,11 +1862,11 @@ MoveLowerPsiThreeD(ThreeDWidget w, XEvent *event, char **args, int n_args)
 		w->threed.angle.psi += NUM_DEGREES;
 	w->threed.deltaAngle.psi = w->threed.angle.psi - oldAngle;
 	setThreed(w, ACTION_SET);
-	RepaintGraphicsThreeD(w);
+	repaintGraphicsThreeD(w);
 }
 
 static void
-MoveRaisePsiThreeD(ThreeDWidget w, XEvent *event, char **args, int n_args)
+moveRaisePsiThreeD(ThreeDWidget w, XEvent *event, char **args, int n_args)
 {
 	int oldAngle = w->threed.angle.psi;
 
@@ -1818,11 +1875,11 @@ MoveRaisePsiThreeD(ThreeDWidget w, XEvent *event, char **args, int n_args)
 		w->threed.angle.psi -= NUM_DEGREES;
 	w->threed.deltaAngle.psi = w->threed.angle.psi - oldAngle;
 	setThreed(w, ACTION_SET);
-	RepaintGraphicsThreeD(w);
+	repaintGraphicsThreeD(w);
 }
 
 static void
-MoveLowerThetaLowerPhiThreeD(ThreeDWidget w, XEvent *event,
+moveLowerThetaLowerPhiThreeD(ThreeDWidget w, XEvent *event,
 		char **args, int n_args)
 {
 	int oldAngleTheta = w->threed.angle.theta;
@@ -1837,11 +1894,11 @@ MoveLowerThetaLowerPhiThreeD(ThreeDWidget w, XEvent *event,
 	w->threed.deltaAngle.theta = w->threed.angle.theta - oldAngleTheta;
 	w->threed.deltaAngle.phi = w->threed.angle.phi - oldAnglePhi;
 	setThreed(w, ACTION_SET);
-	RepaintGraphicsThreeD(w);
+	repaintGraphicsThreeD(w);
 }
 
 static void
-MoveLowerThetaRaisePhiThreeD(ThreeDWidget w, XEvent *event,
+moveLowerThetaRaisePhiThreeD(ThreeDWidget w, XEvent *event,
 		char **args, int n_args)
 {
 	int oldAngleTheta = w->threed.angle.theta;
@@ -1856,11 +1913,11 @@ MoveLowerThetaRaisePhiThreeD(ThreeDWidget w, XEvent *event,
 	w->threed.deltaAngle.theta = w->threed.angle.theta - oldAngleTheta;
 	w->threed.deltaAngle.phi = w->threed.angle.phi - oldAnglePhi;
 	setThreed(w, ACTION_SET);
-	RepaintGraphicsThreeD(w);
+	repaintGraphicsThreeD(w);
 }
 
 static void
-MoveRaiseThetaLowerPhiThreeD(ThreeDWidget w, XEvent *event,
+oveRaiseThetaLowerPhiThreeD(ThreeDWidget w, XEvent *event,
 		char **args, int n_args)
 {
 	int oldAngleTheta = w->threed.angle.theta;
@@ -1875,11 +1932,11 @@ MoveRaiseThetaLowerPhiThreeD(ThreeDWidget w, XEvent *event,
 	w->threed.deltaAngle.theta = w->threed.angle.theta - oldAngleTheta;
 	w->threed.deltaAngle.phi = w->threed.angle.phi - oldAnglePhi;
 	setThreed(w, ACTION_SET);
-	RepaintGraphicsThreeD(w);
+	repaintGraphicsThreeD(w);
 }
 
 static void
-MoveRaiseThetaRaisePhiThreeD(ThreeDWidget w, XEvent *event,
+moveRaiseThetaRaisePhiThreeD(ThreeDWidget w, XEvent *event,
 		char **args, int n_args)
 {
 	int oldAngleTheta = w->threed.angle.theta;
@@ -1894,60 +1951,60 @@ MoveRaiseThetaRaisePhiThreeD(ThreeDWidget w, XEvent *event,
 	w->threed.deltaAngle.theta = w->threed.angle.theta - oldAngleTheta;
 	w->threed.deltaAngle.phi = w->threed.angle.phi - oldAnglePhi;
 	setThreed(w, ACTION_SET);
-	RepaintGraphicsThreeD(w);
+	repaintGraphicsThreeD(w);
 }
 
 static void
-MoveRightThreeD(ThreeDWidget w, XEvent *event, char **args, int n_args)
+moveRightThreeD(ThreeDWidget w, XEvent *event, char **args, int n_args)
 {
 	if (w->threed.distance.x < MAX_DISTANCE)
 		w->threed.distance.x += DELTADISTANCE;
 	setThreed(w, ACTION_SET);
-	RepaintGraphicsThreeD(w);
+	repaintGraphicsThreeD(w);
 }
 
 static void
-MoveLeftThreeD(ThreeDWidget w, XEvent *event, char **args, int n_args)
+moveLeftThreeD(ThreeDWidget w, XEvent *event, char **args, int n_args)
 {
 	if (w->threed.distance.x > MINDISTANCE)
 		w->threed.distance.x -= DELTADISTANCE;
 	setThreed(w, ACTION_SET);
-	RepaintGraphicsThreeD(w);
+	repaintGraphicsThreeD(w);
 }
 
 static void
-MoveUpThreeD(ThreeDWidget w, XEvent *event, char **args, int n_args)
+moveUpThreeD(ThreeDWidget w, XEvent *event, char **args, int n_args)
 {
 	if (w->threed.distance.y < MAX_DISTANCE)
 		w->threed.distance.y += DELTADISTANCE;
 	setThreed(w, ACTION_SET);
-	RepaintGraphicsThreeD(w);
+	repaintGraphicsThreeD(w);
 }
 
 static void
-MoveDownThreeD(ThreeDWidget w, XEvent *event, char **args, int n_args)
+moveDownThreeD(ThreeDWidget w, XEvent *event, char **args, int n_args)
 {
 	if (w->threed.distance.y > MINDISTANCE)
 		w->threed.distance.y -= DELTADISTANCE;
 	setThreed(w, ACTION_SET);
-	RepaintGraphicsThreeD(w);
+	repaintGraphicsThreeD(w);
 }
 
 static void
-MoveOutThreeD(ThreeDWidget w, XEvent *event, char **args, int n_args)
+moveOutThreeD(ThreeDWidget w, XEvent *event, char **args, int n_args)
 {
 	if (w->threed.distance.z < MAX_DEPTH)
 		w->threed.distance.z += DELTADEPTH;
 	setThreed(w, ACTION_SET);
-	RepaintGraphicsThreeD(w);
+	repaintGraphicsThreeD(w);
 }
 
 static void
-MoveInThreeD(ThreeDWidget w, XEvent *event, char **args, int n_args)
+moveInThreeD(ThreeDWidget w, XEvent *event, char **args, int n_args)
 {
 	if (w->threed.distance.z > MIN_DEPTH)
 		w->threed.distance.z -= DELTADEPTH;
 	setThreed(w, ACTION_SET);
-	RepaintGraphicsThreeD(w);
+	repaintGraphicsThreeD(w);
 }
 #endif
