@@ -1,27 +1,22 @@
 /*
-# X-BASED THREED
-#
-#  ThreedP.h
-#
-###
-#
-#  Copyright (c) 1994 - 2008	David A. Bagley, bagleyd@tux.org
-#
-#                   All Rights Reserved
-#
-#  Permission to use, copy, modify, and distribute this software and
-#  its documentation for any purpose and without fee is hereby granted,
-#  provided that the above copyright notice appear in all copies and
-#  that both that copyright notice and this permission notice appear in
-#  supporting documentation, and that the name of the author not be
-#  used in advertising or publicity pertaining to distribution of the
-#  software without specific, written prior permission.
-#
-#  This program is distributed in the hope that it will be "useful",
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-#
-*/
+ * @(#)ThreedP.h
+ *
+ * Copyright 1994 - 2008  David A. Bagley, bagleyd@tux.org
+ *
+ * All rights reserved.
+ *
+ * Permission to use, copy, modify, and distribute this software and
+ * its documentation for any purpose and without fee is hereby granted,
+ * provided that the above copyright notice appear in all copies and
+ * that both that copyright notice and this permission notice appear in
+ * supporting documentation, and that the name of the author not be
+ * used in advertising or publicity pertaining to distribution of the
+ * software without specific, written prior permission.
+ *
+ * This program is distributed in the hope that it will be "useful",
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ */
 
 /* Private header file for Threed */
 
@@ -33,18 +28,19 @@
 #include "Threed.h"
 
 #ifdef WINVER
-extern void DestroyThreeD(HBRUSH brush);
-extern void InitializeThreeD(ThreeDWidget w, HBRUSH brush);
-extern void ExposeThreeD(ThreeDWidget w);
-extern void HideThreeD(ThreeDWidget w);
-extern void SelectThreeD(const ThreeDWidget w, const int x, const int y);
-extern void MotionThreeD(const ThreeDWidget w, const int x, const int y);
-extern void ReleaseThreeD(const ThreeDWidget w);
-extern void SpeedThreeD(ThreeDWidget w);
-extern void SlowThreeD(ThreeDWidget w);
-extern void SoundThreeD(ThreeDWidget w);
-extern void setSurfaceThreeD(ThreeDWidget w, int surface);
-extern void setObjectThreeD(ThreeDWidget w, int object3D);
+extern void destroyThreeD(HBRUSH brush);
+extern void initializeThreeD(ThreeDWidget w, HBRUSH brush);
+extern void exposeThreeD(ThreeDWidget w);
+extern void hideThreeD(ThreeDWidget w);
+extern void selectThreeD(const ThreeDWidget w, const int x, const int y);
+extern void motionThreeD(const ThreeDWidget w, const int x, const int y);
+extern void releaseThreeD(const ThreeDWidget w);
+extern void speedThreeD(ThreeDWidget w);
+extern void slowThreeD(ThreeDWidget w);
+extern void soundThreeD(ThreeDWidget w);
+extern void surfaceThreeD(ThreeDWidget w);
+extern void objectThreeD(ThreeDWidget w);
+extern void setobjectThreeD(ThreeDWidget w, int object3D);
 extern void setThreed(ThreeDWidget w, int reason);
 
 #else
