@@ -1,31 +1,28 @@
 /*
-# MOTIF/X-BASED THREED
-#
-#  xthreed.c
-#
-###
-#
-#  Copyright (c) 1994 - 2007	David A. Bagley, bagleyd@tux.org
-#
-#                   All Rights Reserved
-#
-#  Permission to use, copy, modify, and distribute this software and
-#  its documentation for any purpose and without fee is hereby granted,
-#  provided that the above copyright notice appear in all copies and
-#  that both that copyright notice and this permission notice appear in
-#  supporting documentation, and that the name of the author not be
-#  used in advertising or publicity pertaining to distribution of the
-#  software without specific, written prior permission.
-#
-#  This program is distributed in the hope that it will be "useful",
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-#
-*/
+ * @(#)xthreed.c
+ *
+ * Copyright 1994 - 2008  David A. Bagley, bagleyd@tux.org
+ *
+ * All rights reserved.
+ *
+ * Permission to use, copy, modify, and distribute this software and
+ * its documentation for any purpose and without fee is hereby granted,
+ * provided that the above copyright notice appear in all copies and
+ * that both that copyright notice and this permission notice appear in
+ * supporting documentation, and that the name of the author not be
+ * used in advertising or publicity pertaining to distribution of the
+ * software without specific, written prior permission.
+ *
+ * This program is distributed in the hope that it will be "useful",
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ */
+
+/* Driver file for Threed */
 
 #ifndef WINVER
 static const char aboutHelp[] = {
-"Threed Version 7.3.2\n"
+"Threed Version 7.4\n"
 "Send bugs (reports or fixes) to the author: "
 "David Bagley <bagleyd@tux.org>\n"
 "The latest version is at: "
@@ -117,48 +114,47 @@ static ThreeDRec widget;
 #define PRINT_MESSAGE(b) (void) MessageBox(widget.core.hWnd, (LPCSTR) b, "Warning", MB_OK);
 
 static void
-Initialize(ThreeDWidget w, HBRUSH brush)
+initialize(ThreeDWidget w, HBRUSH brush)
 {
 	HMENU hMenu;
 
-	InitializeThreeD(w, brush);
+	initializeThreeD(w, brush);
 
 	hMenu = GetMenu(w->core.hWnd);
 	(void) CheckMenuItem(hMenu, (unsigned int)
 		w->threed.object + ACTION_TETRA, MF_CHECKED);
-	(void) CheckMenuItem(hMenu, (unsigned int)
-		w->threed.surface + ACTION_WIRE, MF_CHECKED);
 }
 
 void
 setThreed(ThreeDWidget w, int reason)
 {
+	HMENU hMenu;
+
 	switch (reason) {
 	case ACTION_HIDE:
 		ShowWindow(w->core.hWnd, SW_SHOWMINIMIZED);
 		break;
-#if 0
 	case ACTION_SURFACE:
 		w->threed.surface = !w->threed.surface;
 		break;
 	case ACTION_OBJECT:
+		hMenu = GetMenu(w->core.hWnd);
+		(void) CheckMenuItem(hMenu, (unsigned int)
+			w->threed.object + ACTION_TETRA, MF_UNCHECKED);
 		w->threed.object = (w->threed.object + 1) %
 			w->threed.numObjects;
+		(void) CheckMenuItem(hMenu, (unsigned int)
+			w->threed.object + ACTION_TETRA, MF_CHECKED);
 		break;
-#endif
 	}
 }
 
 static LRESULT CALLBACK
-About(HWND hDlg, UINT message, WPARAM wParam, LPARAM lParam)
+about(HWND hDlg, UINT message, WPARAM wParam, LPARAM lParam)
 {
-	switch (message) {
-	case WM_COMMAND:
-		if (LOWORD(wParam) == IDOK) {
-			(void) EndDialog(hDlg, TRUE);
-			return TRUE;
-		}
-		break;
+	if (message == WM_COMMAND && LOWORD(wParam) == IDOK) {
+		(void) EndDialog(hDlg, TRUE);
+		return TRUE;
 	}
 	return FALSE;
 }
@@ -175,10 +171,10 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 	widget.core.hWnd = hWnd;
 	switch (message) {
 	case WM_CREATE:
-		Initialize(&widget, brush);
+		initialize(&widget, brush);
 		break;
 	case WM_DESTROY:
-		DestroyThreeD(brush);
+		destroyThreeD(brush);
 		break;
 	case WM_SIZE:
 		(void) InvalidateRect(widget.core.hWnd, NULL, TRUE);
@@ -187,7 +183,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 		widget.core.hDC = BeginPaint(widget.core.hWnd, &paint);
 		(void) SelectObject(widget.core.hDC,
 			GetStockObject(NULL_BRUSH));
-		ExposeThreeD(&widget);
+		exposeThreeD(&widget);
 		(void) EndPaint(hWnd, &paint);
 		break;
 	case WM_LBUTTONDOWN:
@@ -195,7 +191,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 		widget.core.hDC = GetDC(hWnd);
 		(void) SelectObject(widget.core.hDC,
 			GetStockObject(NULL_PEN));
-		SelectThreeD(&widget, LOWORD(lParam), HIWORD(lParam)
+		selectThreeD(&widget, LOWORD(lParam), HIWORD(lParam)
 			/*, (GetKeyState(VK_CONTROL) >> 1) ? 1 : 0*/);
 		(void) ReleaseDC(hWnd, widget.core.hDC);
 		break;
@@ -206,7 +202,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 				widget.core.hDC = GetDC(hWnd);
 				(void) SelectObject(widget.core.hDC,
 					GetStockObject(NULL_PEN));
-				ReleaseThreeD(&widget/*, LOWORD(lParam), HIWORD(lParam)
+				releaseThreeD(&widget/*, LOWORD(lParam), HIWORD(lParam)
 					((GetKeyState(VK_SHIFT) >> 1) || (GetKeyState(VK_CAPITAL) & 1)),
 					(GetKeyState(VK_CONTROL) >> 1) ? 1 : 0*/);
 				(void) ReleaseDC(hWnd, widget.core.hDC);
@@ -216,7 +212,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 		widget.core.hDC = GetDC(hWnd);
 		(void) SelectObject(widget.core.hDC,
 			GetStockObject(NULL_PEN));
-		MotionThreeD(&widget, LOWORD(lParam), HIWORD(lParam)
+		motionThreeD(&widget, LOWORD(lParam), HIWORD(lParam)
 			/*, ((GetKeyState(VK_SHIFT) >> 1) || (GetKeyState(VK_CAPITAL) & 1)),
 				(GetKeyState(VK_CONTROL) >> 1) ? 1 : 0*/);
 		(void) ReleaseDC(hWnd, widget.core.hDC);
@@ -226,7 +222,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 		widget.core.hDC = GetDC(hWnd);
 		(void) SelectObject(widget.core.hDC,
 			GetStockObject(NULL_PEN));
-		ReleaseThreeD(&widget/*, LOWORD(lParam), HIWORD(lParam)
+		releaseThreeD(&widget/*, LOWORD(lParam), HIWORD(lParam)
 			((GetKeyState(VK_SHIFT) >> 1) || (GetKeyState(VK_CAPITAL) & 1)),
 			(GetKeyState(VK_CONTROL) >> 1) ? 1 : 0*/);
 		(void) ReleaseDC(hWnd, widget.core.hDC);
@@ -269,7 +265,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 	case WM_COMMAND:
 		switch (LOWORD(wParam)) {
 		case ACTION_EXIT:
-			DestroyThreeD(brush);
+			destroyThreeD(brush);
 			break;
 		case ACTION_TETRA:
 		case ACTION_HEXA:
@@ -286,21 +282,18 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 				MF_UNCHECKED);
 			(void) CheckMenuItem(hMenu,
 				LOWORD(wParam), MF_CHECKED);
-			setObjectThreeD(&widget, LOWORD(wParam) - ACTION_TETRA);
+			setobjectThreeD(&widget, LOWORD(wParam) - ACTION_TETRA);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
 		case ACTION_HIDE:
-			HideThreeD(&widget);
+			hideThreeD(&widget);
 			break;
-		case ACTION_WIRE:
-		case ACTION_SOLID:
-			hMenu = GetMenu(hWnd);
-			(void) CheckMenuItem(hMenu,
-				(unsigned int) widget.threed.surface + ACTION_WIRE,
-				MF_UNCHECKED);
-			(void) CheckMenuItem(hMenu, LOWORD(wParam), MF_CHECKED);
-			setSurfaceThreeD(&widget, (BOOL) (LOWORD(wParam) -
-				ACTION_WIRE));
+		case ACTION_SURFACE:
+			surfaceThreeD(&widget);
+			(void) InvalidateRect(hWnd, NULL, TRUE);
+			break;
+		case ACTION_OBJECT:
+			objectThreeD(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
 		case ACTION_DISTXI:
@@ -467,13 +460,13 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
 		case ACTION_SPEED:
-			SpeedThreeD(&widget);
+			speedThreeD(&widget);
 			break;
 		case ACTION_SLOW:
-			SlowThreeD(&widget);
+			slowThreeD(&widget);
 			break;
 		case ACTION_SOUND:
-			SoundThreeD(&widget);
+			soundThreeD(&widget);
 			break;
 		case ACTION_DESCRIPTION:
 			(void) MessageBox(hWnd, descriptionHelp,
@@ -489,7 +482,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			break;
 		case ACTION_ABOUT:
 			(void) DialogBox(widget.core.hInstance,
-				"About", hWnd, (DLGPROC) About);
+				"About", hWnd, (DLGPROC) about);
 			break;
 		}
 		break;
@@ -669,7 +662,7 @@ static Pixmap pixmap = None;
 static Widget topLevel, threed;
 
 static void
-Usage(char *programName)
+usage(char *programName)
 {
 	unsigned int i;
 
@@ -726,7 +719,7 @@ static void PrintState(Widget w, char *name, Boolean surface, int object,
 }
 #endif
 
-static void Initialize(Widget w)
+static void initialize(Widget w)
 {
 	IntPoint3D distance;
 	IntAngle3D angle;
@@ -790,7 +783,7 @@ static void makePosVisible(Widget list_w, int item_no)
 }
 #endif
 
-static void CallbackThreeD(Widget w, caddr_t clientData,
+static void callbackThreeD(Widget w, caddr_t clientData,
 		threedCallbackStruct *callData)
 {
 	Boolean surface;
@@ -849,7 +842,7 @@ static void CallbackThreeD(Widget w, caddr_t clientData,
 
 #ifdef HAVE_MOTIF
 static void
-XDistSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
+xDistSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 {
 	int value = cbs->value, old;
 
@@ -863,7 +856,7 @@ XDistSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 }
 
 static void
-YDistSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
+yDistSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 {
 	int value = cbs->value, old;
 
@@ -877,7 +870,7 @@ YDistSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 }
 
 static void
-ZDistSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
+zDistSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 {
 	int value = cbs->value, old;
 
@@ -891,7 +884,7 @@ ZDistSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 }
 
 static void
-ThetaSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
+thetaSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 {
 	int value = cbs->value, old;
 
@@ -905,7 +898,7 @@ ThetaSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 }
 
 static void
-PhiSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
+phiSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 {
 	int value = cbs->value, old;
 
@@ -920,7 +913,7 @@ PhiSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 
 
 static void
-PsiSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
+psiSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 {
 	int value = cbs->value, old;
 
@@ -935,7 +928,7 @@ PsiSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 
 
 static void
-SurfaceToggle(Widget w, XtPointer clientData, XmToggleButtonCallbackStruct *cbs)
+surfaceToggle(Widget w, XtPointer clientData, XmToggleButtonCallbackStruct *cbs)
 {
 	XtVaSetValues(threed,
 		XtNsurface, cbs->set,
@@ -943,7 +936,7 @@ SurfaceToggle(Widget w, XtPointer clientData, XmToggleButtonCallbackStruct *cbs)
 }
 
 static void
-ObjectResponse(Widget listItem, XtPointer clientData, XmListCallbackStruct *cbs)
+objectResponse(Widget listItem, XtPointer clientData, XmListCallbackStruct *cbs)
 {
 	char	*name;
 	int object = cbs->item_position - 1, old;
@@ -1022,7 +1015,7 @@ createList(Widget *rowcol, char **list, int init, int num)
 		NULL);
 	XtManageChild(objectList);
 	XtAddCallback(objectList, XmNbrowseSelectionCallback,
-		(XtCallbackProc) ObjectResponse, (XtPointer) NULL);
+		(XtCallbackProc) objectResponse, (XtPointer) NULL);
 	XmListSelectPos(objectList, init + 1, True);
 
 	for (i = 0; i < num; i++)
@@ -1059,13 +1052,13 @@ createHelp(Widget w, char *text, char *title)
 }
 
 static void
-fileCB(Widget w, void *value, void *clientData)
+fileMenuListener(Widget w, void *value, void *clientData)
 {
 	exit(0);
 }
 
 static void
-controlsCB(Widget w, void *value, void *clientData)
+controlsMenuListener(Widget w, void *value, void *clientData)
 {
 	int val = (int) value;
 
@@ -1074,7 +1067,7 @@ controlsCB(Widget w, void *value, void *clientData)
 
 
 static void
-helpCB(Widget w, XtPointer value, XtPointer clientData)
+helpMenuListener(Widget w, XtPointer value, XtPointer clientData)
 {
 	int val = (int) value;
 
@@ -1098,7 +1091,7 @@ helpCB(Widget w, XtPointer value, XtPointer clientData)
 		{
 			char *buf;
 
-			intCat(&buf, "helpCB: %d", val);
+			intCat(&buf, "helpMenuListener: %d", val);
 			XtWarning(buf);
 			free(buf);
 		}
@@ -1124,7 +1117,7 @@ int main(int argc, char **argv)
 	topLevel = XtInitialize(argv[0], "Threed",
 		options, XtNumber(options), &argc, argv);
 	if (argc != 1)
-		Usage(argv[0]);
+		usage(argv[0]);
 
 #ifdef HAVE_MOTIF
 	panel = XtVaCreateManagedWidget("panel",
@@ -1142,7 +1135,7 @@ int main(int argc, char **argv)
 	XmStringFree(controlsString);
 	quitString = XmStringCreateSimple((char *) "Quit");
 	(void) XmVaCreateSimplePulldownMenu(menuBar, (char *) "file_menu",
-		0, fileCB,
+		0, fileMenuListener,
 		XmVaPUSHBUTTON, quitString, 'Q', NULL, NULL,
 		NULL);
 	XmStringFree(quitString);
@@ -1150,7 +1143,7 @@ int main(int argc, char **argv)
 	slowString = XmStringCreateSimple((char *) "<Slow");
 	soundString = XmStringCreateSimple((char *) "@Sound");
 	(void) XmVaCreateSimplePulldownMenu(menuBar, (char *) "controlsMenu",
-		1, controlsCB,
+		1, controlsMenuListener,
 		XmVaPUSHBUTTON, speedString, '>', NULL, NULL,
 		XmVaPUSHBUTTON, slowString, '<', NULL, NULL,
 		XmVaPUSHBUTTON, soundString, '@', NULL, NULL,
@@ -1168,23 +1161,23 @@ int main(int argc, char **argv)
 	widget = XtVaCreateManagedWidget("Description",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'D', NULL);
-		XtAddCallback(widget, XmNactivateCallback, helpCB, (char *) 0);
+		XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 0);
 	widget = XtVaCreateManagedWidget("Features",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'F', NULL);
-	XtAddCallback(widget, XmNactivateCallback, helpCB, (char *) 1);
+	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 1);
 	widget = XtVaCreateManagedWidget("Options",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'O', NULL);
-	XtAddCallback(widget, XmNactivateCallback, helpCB, (char *) 2);
+	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 2);
 	widget = XtVaCreateManagedWidget("References",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'R', NULL);
-	XtAddCallback(widget, XmNactivateCallback, helpCB, (char *) 3);
+	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 3);
 	widget = XtVaCreateManagedWidget("About",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'A', NULL);
-	XtAddCallback(widget, XmNactivateCallback, helpCB, (char *) 4);
+	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 4);
 	XtManageChild(menuBar);
 	descriptionDialog = createHelp(menuBar, (char *) descriptionHelp,
 		(char *) "Description");
@@ -1218,7 +1211,7 @@ int main(int argc, char **argv)
 		XmNshowValue, True,
 		XmNorientation, XmHORIZONTAL, NULL);
 	XtAddCallback(xDist, XmNvalueChangedCallback,
-		(XtCallbackProc) XDistSlider, (XtPointer) NULL);
+		(XtCallbackProc) xDistSlider, (XtPointer) NULL);
 	yDist = XtVaCreateManagedWidget("yDist",
 		xmScaleWidgetClass, distRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Y", 2,
@@ -1228,7 +1221,7 @@ int main(int argc, char **argv)
 		XmNshowValue, True,
 		XmNorientation, XmHORIZONTAL, NULL);
 	XtAddCallback(yDist, XmNvalueChangedCallback,
-		(XtCallbackProc) YDistSlider, (XtPointer) NULL);
+		(XtCallbackProc) yDistSlider, (XtPointer) NULL);
 	zDist = XtVaCreateManagedWidget("zDist",
 		xmScaleWidgetClass, distRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Z", 2,
@@ -1238,7 +1231,7 @@ int main(int argc, char **argv)
 		XmNshowValue, True,
 		XmNorientation, XmHORIZONTAL, NULL);
 	XtAddCallback(zDist, XmNvalueChangedCallback,
-		(XtCallbackProc) ZDistSlider, (XtPointer) NULL);
+		(XtCallbackProc) zDistSlider, (XtPointer) NULL);
 	angleRowCol = XtVaCreateManagedWidget("angleRowCol",
 		xmRowColumnWidgetClass, controlPanel,
 		XmNnumColumns, 1,
@@ -1253,7 +1246,7 @@ int main(int argc, char **argv)
 		XmNshowValue, True,
 		XmNorientation, XmHORIZONTAL, NULL);
 	XtAddCallback(thetaAng, XmNvalueChangedCallback,
-		(XtCallbackProc) ThetaSlider, (XtPointer) NULL);
+		(XtCallbackProc) thetaSlider, (XtPointer) NULL);
 	phiAng = XtVaCreateManagedWidget("phiAng",
 		xmScaleWidgetClass, angleRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Phi", 4,
@@ -1263,7 +1256,7 @@ int main(int argc, char **argv)
 		XmNshowValue, True,
 		XmNorientation, XmHORIZONTAL, NULL);
 	XtAddCallback(phiAng, XmNvalueChangedCallback,
-		(XtCallbackProc) PhiSlider, (XtPointer) NULL);
+		(XtCallbackProc) phiSlider, (XtPointer) NULL);
 	psiAng = XtVaCreateManagedWidget("psiAng",
 		xmScaleWidgetClass, angleRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Psi", 4,
@@ -1273,7 +1266,7 @@ int main(int argc, char **argv)
 		XmNshowValue, True,
 		XmNorientation, XmHORIZONTAL, NULL);
 	XtAddCallback(psiAng, XmNvalueChangedCallback,
-		(XtCallbackProc) PsiSlider, (XtPointer) NULL);
+		(XtCallbackProc) psiSlider, (XtPointer) NULL);
 	shapeRowCol = XtVaCreateManagedWidget("shapeRowCol",
 		xmRowColumnWidgetClass, controlPanel,
 		XmNnumColumns, 1,
@@ -1324,7 +1317,7 @@ int main(int argc, char **argv)
 #endif
 		XtNiconPixmap, pixmap, NULL);
 	XtAddCallback(threed, XtNselectCallback,
-		(XtCallbackProc) CallbackThreeD, (XtPointer) NULL);
+		(XtCallbackProc) callbackThreeD, (XtPointer) NULL);
 #ifdef HAVE_MOTIF
 	/*createMenu(&objectMenu, shapeRowCol, object);*/
 	createList(&shapeRowCol, list, object, number);
@@ -1332,15 +1325,15 @@ int main(int argc, char **argv)
 		xmToggleButtonWidgetClass, shapeRowCol,
 		XmNset, DEFAULTSURFACE, NULL);
 	XtAddCallback(surfaceSwitch, XmNvalueChangedCallback,
-		(XtCallbackProc) SurfaceToggle, (XtPointer) NULL);
+		(XtCallbackProc) surfaceToggle, (XtPointer) NULL);
 #endif
-	Initialize(threed);
+	initialize(threed);
 	XtRealizeWidget(topLevel);
 	XGrabButton(XtDisplay(threed), (unsigned int) AnyButton, AnyModifier,
 		XtWindow(threed), TRUE, (unsigned int) (ButtonPressMask |
 		ButtonMotionMask | ButtonReleaseMask),
 		GrabModeAsync, GrabModeAsync, XtWindow(threed),
-		XCreateFontCursor(XtDisplay(threed), XC_crosshair));
+		XCreateFontCursor(XtDisplay(threed), XC_hand2));
 	XtMainLoop();
 
 #ifdef VMS
