@@ -1,27 +1,24 @@
-/*-
-# MOTIF/X-BASED TRIANGLES
-#
-#  xtriangles.c
-#
-###
-#
-#  Copyright (c) 1993 - 2008	David A. Bagley, bagleyd@tux.org
-#
-#                   All Rights Reserved
-#
-#  Permission to use, copy, modify, and distribute this software and
-#  its documentation for any purpose and without fee is hereby granted,
-#  provided that the above copyright notice appear in all copies and
-#  that both that copyright notice and this permission notice appear in
-#  supporting documentation, and that the name of the author not be
-#  used in advertising or publicity pertaining to distribution of the
-#  software without specific, written prior permission.
-#
-#  This program is distributed in the hope that it will be "playable",
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-#
-*/
+/*
+ * @(#)xtriangles.c
+ *
+ * Copyright 1993 - 2008  David A. Bagley, bagleyd@tux.org
+ *
+ * All rights reserved.
+ *
+ * Permission to use, copy, modify, and distribute this software and
+ * its documentation for any purpose and without fee is hereby granted,
+ * provided that the above copyright notice appear in all copies and
+ * that both that copyright notice and this permission notice appear in
+ * supporting documentation, and that the name of the author not be
+ * used in advertising or publicity pertaining to distribution of the
+ * software without specific, written prior permission.
+ *
+ * This program is distributed in the hope that it will be "useful",
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ */
+
+/* Driver file for Triangles */
 
 #include "file.h"
 #ifdef WINVER
@@ -56,7 +53,7 @@ static TrianglesRec widget;
 #include "pixmaps/mouse-l.xbm"
 #include "pixmaps/mouse-r.xbm"
 #endif
-#define PRINT_MESSAGE(b) PrintState(message, b)
+#define PRINT_MESSAGE(b) printState(message, b)
 #else
 #define PRINT_MESSAGE(b) XtWarning(b)
 #endif
@@ -88,7 +85,7 @@ static TrianglesRec widget;
 
 #ifndef WINVER
 static const char aboutHelp[] = {
-"Triangles Version 7.3.3\n"
+"Triangles Version 7.4\n"
 "Send bugs (reports or fixes) to the author: "
 "David Bagley <bagleyd@tux.org>\n"
 "The latest version is at: "
@@ -206,9 +203,9 @@ static char recordDsp[MESSAGE_LENGTH] = "NOT RECORDED";
 #define MIN_SPEED 1
 #define MAX_SPEED 50
 #ifdef ANIMATE
-static Widget speed;
+static Widget speedSlider;
 #endif
-static Widget moves, record, message, tile;
+static Widget movesText, recordText, message, tileSlider;
 static char buff[21];
 static Widget descriptionDialog, featuresDialog;
 static Widget optionsDialog, referencesDialog, aboutDialog;
@@ -232,19 +229,19 @@ static char userNameDsp[USER_NAME_LENGTH] = "";
 
 #ifdef HAVE_MOTIF
 static void
-PrintState(Widget w, char *msg)
+printState(Widget w, char *msg)
 {
 	XmString xmstr;
 
 	if (!XtIsSubclass(w, xmLabelWidgetClass))
-		XtError("PrintState() requires a Label Widget");
+		XtError("printState() requires a Label Widget");
 	xmstr = XmStringCreateLtoR(msg, XmSTRING_DEFAULT_CHARSET);
 	XtVaSetValues(w, XmNlabelString, xmstr, NULL);
 }
 #endif
 
 static void
-PrintRecords(void)
+printRecords(void)
 {
 	int i;
 
@@ -261,7 +258,7 @@ PrintRecords(void)
 #endif
 
 static void
-InitRecords(void)
+initRecords(void)
 {
 	int i;
 
@@ -272,7 +269,7 @@ InitRecords(void)
 }
 
 static void
-ReadRecords(void)
+readRecords(void)
 {
 	FILE *fp;
 	int i, n;
@@ -330,7 +327,7 @@ ReadRecords(void)
 }
 
 static void
-WriteRecords(void)
+writeRecords(void)
 {
 	FILE *fp;
 	int i;
@@ -376,7 +373,7 @@ WriteRecords(void)
 }
 
 static void
-PrintRecord(int size)
+printRecord(int size)
 {
 	int i = size - MIN_TILES;
 
@@ -389,21 +386,21 @@ PrintRecord(int size)
 			puzzleRecord[i].score, puzzleRecord[i].name);
 	}
 #ifdef HAVE_MOTIF
-	PrintState(record, recordDsp);
+	printState(recordText, recordDsp);
 #endif
 }
 
 static void
-PrintStatus(char *msg, int nMoves
+printStatus(char *msg, int nMoves
 #ifndef HAVE_MOTIF
 		, int size
 #endif
 		)
 {
 #ifdef HAVE_MOTIF
-	PrintState(message, msg);
+	printState(message, msg);
 	(void) sprintf(buff, "%d", nMoves);
-	PrintState(moves, buff);
+	printState(movesText, buff);
 #else
 	(void) sprintf(titleDsp, "%s: %d@ (%d/%s) - %s",
 		progDsp, size, nMoves, recordDsp, msg);
@@ -416,25 +413,25 @@ PrintStatus(char *msg, int nMoves
 }
 
 static Boolean
-HandleSolved(int counter, int size)
+handleSolved(int counter, int size)
 {
 	int i = size - MIN_TILES;
 
 	if (size <= MAX_TILES && (counter < puzzleRecord[i].score ||
 			puzzleRecord[i].score <= NEVER)) {
-		ReadRecords();	/* Maybe its been updated by another */
+		readRecords();	/* Maybe its been updated by another */
 		puzzleRecord[i].score = counter;
 		(void) strncpy(puzzleRecord[i].name, userNameDsp,
 			USER_NAME_LENGTH);
-		WriteRecords();
-		PrintRecord(size);
+		writeRecords();
+		printRecord(size);
 		return True;
 	}
 	return False;
 }
 
 static void
-Initialize(
+initialize(
 #ifdef WINVER
 TrianglesWidget w, HBRUSH brush
 #else
@@ -446,7 +443,7 @@ Widget w
 	char *userName, *scoreFile;
 
 #ifdef WINVER
-	InitializePuzzle(w, brush);
+	initializePuzzle(w, brush);
 
 	size = w->triangles.size;
 	userName = w->triangles.userName;
@@ -469,28 +466,29 @@ Widget w
 	if (strcmp(scoreFile, ""))
 		(void) strncpy(scoreFileName, scoreFile, FILE_NAME_LENGTH);
 	if (scoreOnly) {
-		InitRecords();
-		ReadRecords();
-		PrintRecords();
+		initRecords();
+		readRecords();
+		printRecords();
 		exit(0);
 	}
 #ifdef HAVE_MOTIF
 	if (size > MAX_TILES)
-		XtVaSetValues(tile, XmNmaximum, size, NULL);
-	XmScaleSetValue(tile, size);
+		XtVaSetValues(tileSlider, XmNmaximum, size, NULL);
+	XmScaleSetValue(tileSlider, size);
 #ifdef ANIMATE
 	{
 		int delay;
 
 		XtVaGetValues(w, XtNdelay, &delay, NULL);
-		XmScaleSetValue(speed, MAX_SPEED + MIN_SPEED - delay - 1);
+		XmScaleSetValue(speedSlider,
+			MAX_SPEED + MIN_SPEED - delay - 1);
 	}
 #endif
 #endif
 #endif
 	SET_STARTED(w, False);
-	InitRecords();
-	ReadRecords();
+	initRecords();
+	readRecords();
 #ifndef WINVER
 	(void) strncpy(userNameDsp, userName, USER_NAME_LENGTH);
 #endif
@@ -515,8 +513,8 @@ Widget w
 			(void) sprintf(userNameDsp, "%s", "guest");
 #endif
 	}
-	PrintRecord(size);
-	PrintStatus(messageDsp, movesDsp
+	printRecord(size);
+	printStatus(messageDsp, movesDsp
 #ifndef HAVE_MOTIF
 		, size
 #endif
@@ -528,7 +526,7 @@ void
 setPuzzle(TrianglesWidget w, int reason)
 #else
 static void
-CallbackPuzzle(Widget w, caddr_t clientData,
+puzzleListener(Widget w, caddr_t clientData,
 		trianglesCallbackStruct *callData)
 #endif
 {
@@ -605,7 +603,7 @@ CallbackPuzzle(Widget w, caddr_t clientData,
 		if (cheat)
 			(void) sprintf(messageDsp,
 				"No cheating %s!!", userNameDsp);
-		else if (!randomized && HandleSolved(movesDsp, size))
+		else if (!randomized && handleSolved(movesDsp, size))
 			(void) sprintf(messageDsp,
 				"Congratulations %s!!", userNameDsp);
 		else
@@ -624,30 +622,30 @@ CallbackPuzzle(Widget w, caddr_t clientData,
 	case ACTION_INCREMENT:
 		movesDsp = 0;
 		size++;
-		PrintRecord(size);
+		printRecord(size);
 #ifdef WINVER
 		w->triangles.size = size;
 #else
 		XtVaSetValues(w, XtNsize, size, NULL);
 #ifdef HAVE_MOTIF
 		if (size > MAX_TILES)
-			XtVaSetValues(tile, XmNmaximum, size, NULL);
-		XmScaleSetValue(tile, size);
+			XtVaSetValues(tileSlider, XmNmaximum, size, NULL);
+		XmScaleSetValue(tileSlider, size);
 #endif
 #endif
 		break;
 	case ACTION_DECREMENT:
 		movesDsp = 0;
 		size--;
-		PrintRecord(size);
+		printRecord(size);
 #ifdef WINVER
 		w->triangles.size = size;
 #else
 		XtVaSetValues(w, XtNsize, size, NULL);
 #ifdef HAVE_MOTIF
-		XmScaleSetValue(tile, size);
+		XmScaleSetValue(tileSlider, size);
 		if (size >= MAX_TILES)
-			XtVaSetValues(tile, XmNmaximum, size, NULL);
+			XtVaSetValues(tileSlider, XmNmaximum, size, NULL);
 #endif
 #endif
 		break;
@@ -675,13 +673,13 @@ CallbackPuzzle(Widget w, caddr_t clientData,
 				XtVaSetValues(w,
 					XtNdelay, delay, NULL);
 			}
-			XmScaleSetValue(speed,
+			XmScaleSetValue(speedSlider,
 				MAX_SPEED + MIN_SPEED - delay - 1);
 		}
 		return;
 #endif
 	}
-	PrintStatus(messageDsp, movesDsp
+	printStatus(messageDsp, movesDsp
 #ifndef HAVE_MOTIF
 		, size
 #endif
@@ -690,15 +688,11 @@ CallbackPuzzle(Widget w, caddr_t clientData,
 
 #ifdef WINVER
 static LRESULT CALLBACK
-About(HWND hDlg, UINT message, WPARAM wParam, LPARAM lParam)
+about(HWND hDlg, UINT message, WPARAM wParam, LPARAM lParam)
 {
-	switch (message) {
-	case WM_COMMAND:
-		if (LOWORD(wParam) == IDOK) {
-			(void) EndDialog(hDlg, TRUE);
-			return TRUE;
-		}
-		break;
+	if (message == WM_COMMAND && LOWORD(wParam) == IDOK) {
+		(void) EndDialog(hDlg, TRUE);
+		return TRUE;
 	}
 	return FALSE;
 }
@@ -715,7 +709,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_BRUSH));
-			EnterPuzzle(&widget);
+			enterPuzzle(&widget);
 			(void) EndPaint(hWnd, &paint);
 		}
 	} else {
@@ -723,98 +717,98 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_BRUSH));
-			LeavePuzzle(&widget);
+			leavePuzzle(&widget);
 			(void) EndPaint(hWnd, &paint);
 		}
 	}
 	switch (message) {
 	case WM_CREATE:
-		Initialize(&widget, brush);
+		initialize(&widget, brush);
 		break;
 	case WM_DESTROY:
-		DestroyPuzzle(&widget, brush);
+		destroyPuzzle(&widget, brush);
 		break;
 	case WM_SIZE:
-		ResizePuzzle(&widget);
+		resizePuzzle(&widget);
 		(void) InvalidateRect(hWnd, NULL, TRUE);
 		break;
 	case WM_PAINT:
 		widget.core.hDC = BeginPaint(hWnd, &paint);
 		(void) SelectObject(widget.core.hDC,
 			GetStockObject(NULL_PEN));
-		ExposePuzzle(&widget);
+		exposePuzzle(&widget);
 		(void) EndPaint(hWnd, &paint);
 		break;
 	case WM_RBUTTONDOWN:
 		widget.core.hDC = GetDC(hWnd);
 		(void) SelectObject(widget.core.hDC,
 			GetStockObject(NULL_PEN));
-		ClearPuzzle(&widget);
+		clearPuzzle(&widget);
 		(void) ReleaseDC(hWnd, widget.core.hDC);
 		break;
 	case WM_LBUTTONDOWN:
 		widget.core.hDC = GetDC(hWnd);
 		(void) SelectObject(widget.core.hDC,
 			GetStockObject(NULL_PEN));
-		SelectPuzzle(&widget, LOWORD(lParam), HIWORD(lParam));
+		selectPuzzle(&widget, LOWORD(lParam), HIWORD(lParam));
 		(void) ReleaseDC(hWnd, widget.core.hDC);
 		break;
 	case WM_LBUTTONUP:
 		widget.core.hDC = GetDC(hWnd);
 		(void) SelectObject(widget.core.hDC,
 			GetStockObject(NULL_PEN));
-		ReleasePuzzle(&widget);
+		releasePuzzle(&widget);
 		(void) ReleaseDC(hWnd, widget.core.hDC);
 		break;
 	case WM_COMMAND:
 		switch (LOWORD(wParam)) {
 		case ACTION_GET:
-			GetPuzzle(&widget);
-			ResizePuzzle(&widget);
+			getPuzzle(&widget);
+			resizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
 		case ACTION_WRITE:
-			WritePuzzle(&widget);
+			writePuzzle(&widget);
 			break;
 		case ACTION_EXIT:
-			DestroyPuzzle(&widget, brush);
+			destroyPuzzle(&widget, brush);
 			break;
 		case ACTION_HIDE:
-			HidePuzzle(&widget);
+			hidePuzzle(&widget);
 			break;
 		case ACTION_UNDO:
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_PEN));
-			UndoPuzzle(&widget);
+			undoPuzzle(&widget);
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
 		case ACTION_REDO:
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_PEN));
-			RedoPuzzle(&widget);
+			redoPuzzle(&widget);
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
 		case ACTION_CLEAR:
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_PEN));
-			ClearPuzzle(&widget);
+			clearPuzzle(&widget);
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
 		case ACTION_RANDOMIZE:
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_PEN));
-			RandomizePuzzle(&widget);
+			randomizePuzzle(&widget);
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
 		case ACTION_SOLVE:
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_PEN));
-			SolvePuzzle(&widget);
+			solvePuzzle(&widget);
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
 		case ACTION_TR:
@@ -826,28 +820,28 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_PEN));
-			(void) MovePuzzle(&widget,
+			(void) movePuzzle(&widget,
 				(int) LOWORD(wParam) - ACTION_TR);
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
 		case ACTION_INCREMENT:
-			IncrementPuzzle(&widget);
-			SizePuzzle(&widget);
+			incrementPuzzle(&widget);
+			sizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
 		case ACTION_DECREMENT:
-			DecrementPuzzle(&widget);
-			SizePuzzle(&widget);
+			decrementPuzzle(&widget);
+			sizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
 		case ACTION_SPEED:
-			SpeedPuzzle(&widget);
+			speedUpPuzzle(&widget);
 			break;
 		case ACTION_SLOW:
-			SlowPuzzle(&widget);
+			slowDownPuzzle(&widget);
 			break;
 		case ACTION_SOUND:
-			SoundPuzzle(&widget);
+			toggleSoundPuzzle(&widget);
 			break;
 		case ACTION_DESCRIPTION:
 			(void) MessageBox(hWnd, descriptionHelp,
@@ -863,7 +857,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			break;
 		case ACTION_ABOUT:
 			(void) DialogBox(widget.core.hInstance,
-				"About", hWnd, (DLGPROC) About);
+				"About", hWnd, (DLGPROC) about);
 			break;
 		}
 		break;
@@ -924,7 +918,7 @@ WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance, LPSTR lpCmdLine,
 #else
 
 static void
-Usage(char *programName)
+usage(char *programName)
 {
 	unsigned int i;
 
@@ -970,7 +964,7 @@ static XrmOptionDescRec options[] =
 
 #ifdef HAVE_MOTIF
 static void
-CallbackPuzzleClear(Widget w, XtPointer clientData,
+puzzleListenerClear(Widget w, XtPointer clientData,
 		XmAnyCallbackStruct *cbs)
 {
 	if (cbs->reason == XmCR_OK) {
@@ -979,7 +973,7 @@ CallbackPuzzleClear(Widget w, XtPointer clientData,
 }
 
 static void
-TileSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
+tileChangeListener(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 {
 	int size = cbs->value, old;
 
@@ -991,15 +985,15 @@ TileSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 		XtNsize, size, NULL);
 	movesDsp = 0;
 	(void) sprintf(buff, "%d", movesDsp);
-	PrintState(moves, buff);
-	PrintRecord(size);
+	printState(movesText, buff);
+	printRecord(size);
 	(void) strcpy(messageDsp, "");
-	PrintState(message, messageDsp);
+	printState(message, messageDsp);
 }
 
 #ifdef ANIMATE
 static void
-SpeedSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
+speedChangeListener(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 {
 	int delay = MAX_SPEED + MIN_SPEED - cbs->value - 1, oldDelay;
 
@@ -1012,7 +1006,7 @@ SpeedSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 #endif
 
 static void
-fileCB(Widget w, void *value, void *clientData)
+fileMenuListener(Widget w, void *value, void *clientData)
 {
 	int val = (int) value + ACTION_GET;
 
@@ -1084,7 +1078,7 @@ createHelp(Widget w, char *text, char *title)
 }
 
 static void
-helpCB(Widget w, XtPointer value, XtPointer clientData)
+helpMenuListener(Widget w, XtPointer value, XtPointer clientData)
 {
 	int val = (int) value;
 
@@ -1108,7 +1102,7 @@ helpCB(Widget w, XtPointer value, XtPointer clientData)
 		{
 			char *buf;
 
-			intCat(&buf, "helpCB: %d", val);
+			intCat(&buf, "helpMenuListener: %d", val);
 			XtWarning(buf);
 			free(buf);
 		}
@@ -1136,7 +1130,7 @@ main(int argc, char **argv)
 	topLevel = XtInitialize(argv[0], "Triangles",
 		options, XtNumber(options), &argc, argv);
 	if (argc != 1)
-		Usage(argv[0]);
+		usage(argv[0]);
 
 #ifdef HAVE_MOTIF
 	menuBarPanel = XtVaCreateManagedWidget("menuBarPanel",
@@ -1156,7 +1150,7 @@ main(int argc, char **argv)
 	writeString = XmStringCreateSimple((char *) "Write");
 	quitString = XmStringCreateSimple((char *) "Quit");
 	(void) XmVaCreateSimplePulldownMenu(menuBar, (char *) "file_menu",
-		0, fileCB,
+		0, fileMenuListener,
 		XmVaPUSHBUTTON, getString, 'G', NULL, NULL,
 		XmVaPUSHBUTTON, writeString, 'W', NULL, NULL,
 		XmVaSEPARATOR,
@@ -1208,23 +1202,23 @@ main(int argc, char **argv)
 	widget = XtVaCreateManagedWidget("Description",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'D', NULL);
-		XtAddCallback(widget, XmNactivateCallback, helpCB, (char *) 0);
+		XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 0);
 	widget = XtVaCreateManagedWidget("Features",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'F', NULL);
-	XtAddCallback(widget, XmNactivateCallback, helpCB, (char *) 1);
+	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 1);
 	widget = XtVaCreateManagedWidget("Options",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'O', NULL);
-	XtAddCallback(widget, XmNactivateCallback, helpCB, (char *) 2);
+	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 2);
 	widget = XtVaCreateManagedWidget("References",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'R', NULL);
-	XtAddCallback(widget, XmNactivateCallback, helpCB, (char *) 3);
+	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 3);
 	widget = XtVaCreateManagedWidget("About",
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'A', NULL);
-	XtAddCallback(widget, XmNactivateCallback, helpCB, (char *) 4);
+	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 4);
 	XtManageChild(menuBar);
 	descriptionDialog = createHelp(menuBar, (char *) descriptionHelp,
 		(char *) "Description");
@@ -1241,7 +1235,7 @@ main(int argc, char **argv)
 	clearDialog = createQuery(topLevel,
 		(char *) "Are you sure you want to start over?",
 		(char *) "Clear Query",
-		(XtCallbackProc) CallbackPuzzleClear);
+		(XtCallbackProc) puzzleListenerClear);
 	mainPanel = XtCreateManagedWidget("mainPanel",
 		xmPanedWindowWidgetClass, menuBarPanel,
 		NULL, 0);
@@ -1297,19 +1291,19 @@ main(int argc, char **argv)
 	(void) XtVaCreateManagedWidget("movesText",
 		xmLabelGadgetClass, movesRowCol,
 		XtVaTypedArg, XmNlabelString, XmRString, "Moves", 6, NULL);
-	moves = XtVaCreateManagedWidget("0",
+	movesText = XtVaCreateManagedWidget("0",
 		xmLabelWidgetClass, movesRowCol, NULL);
 	(void) XtVaCreateManagedWidget("recordText",
 		xmLabelGadgetClass, movesRowCol,
 		XtVaTypedArg, XmNlabelString, XmRString, "Record", 7, NULL);
-	record = XtVaCreateManagedWidget("0",
+	recordText = XtVaCreateManagedWidget("0",
 		xmLabelWidgetClass, movesRowCol, NULL);
 	tilesRowCol = XtVaCreateManagedWidget("tilesRowCol",
 		xmRowColumnWidgetClass, controlPanel,
 		XmNnumColumns, 1,
 		XmNorientation, XmHORIZONTAL,
 		XmNpacking, XmPACK_COLUMN, NULL);
-	tile = XtVaCreateManagedWidget("tile",
+	tileSlider = XtVaCreateManagedWidget("tile",
 		xmScaleWidgetClass, tilesRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Size", 5,
 		XmNminimum, MIN_TILES,
@@ -1317,10 +1311,10 @@ main(int argc, char **argv)
 		XmNvalue, DEFAULT_TILES,
 		XmNshowValue, True,
 		XmNorientation, XmHORIZONTAL, NULL);
-	XtAddCallback(tile, XmNvalueChangedCallback,
-		(XtCallbackProc) TileSlider, (XtPointer) NULL);
+	XtAddCallback(tileSlider, XmNvalueChangedCallback,
+		(XtCallbackProc) tileChangeListener, (XtPointer) NULL);
 #ifdef ANIMATE
-	speed = XtVaCreateManagedWidget("Animation Speed",
+	speedSlider = XtVaCreateManagedWidget("speedSlider",
 		xmScaleWidgetClass, tilesRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Animation Speed", 16,
 		XmNminimum, MIN_SPEED,
@@ -1328,8 +1322,8 @@ main(int argc, char **argv)
 		XmNvalue, MAX_SPEED - DEFAULT_DELAY,
 		XmNshowValue, True,
 		XmNorientation, XmHORIZONTAL, NULL);
-	XtAddCallback(speed, XmNvalueChangedCallback,
-		(XtCallbackProc) SpeedSlider, (XtPointer) NULL);
+	XtAddCallback(speedSlider, XmNvalueChangedCallback,
+		(XtCallbackProc) speedChangeListener, (XtPointer) NULL);
 #endif
 	messageRowCol = XtVaCreateManagedWidget("messageRowCol",
 		xmRowColumnWidgetClass, controlPanel, NULL);
@@ -1374,14 +1368,14 @@ main(int argc, char **argv)
 #endif
 		XtNiconPixmap, pixmap, NULL);
 	XtAddCallback(puzzle, XtNselectCallback,
-		(XtCallbackProc) CallbackPuzzle, (XtPointer) NULL);
-	Initialize(puzzle);
+		(XtCallbackProc) puzzleListener, (XtPointer) NULL);
+	initialize(puzzle);
 	XtRealizeWidget(topLevel);
 	XGrabButton(XtDisplay(puzzle), (unsigned int) AnyButton, AnyModifier,
 		XtWindow(puzzle), TRUE, (unsigned int) (ButtonPressMask |
 		ButtonMotionMask | ButtonReleaseMask),
 		GrabModeAsync, GrabModeAsync, XtWindow(puzzle),
-		XCreateFontCursor(XtDisplay(puzzle), XC_crosshair));
+		XCreateFontCursor(XtDisplay(puzzle), XC_hand2));
 	XtMainLoop();
 
 #ifdef VMS
